@@ -1,5 +1,5 @@
 <?php
-/* $Id: albanian-iso-8859-1.inc.php,v 2.144 2006/08/09 12:55:35 lem9 Exp $ */
+/* $Id: albanian-iso-8859-1.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Translated by: Laurent Dhima <laurenti at users.sourceforge.net>
@@ -22,7 +22,6 @@ $timespanfmt = '%s dit, %s or, %s minuta dhe %s sekonda';
  
 
 $strAbortedClients = 'Dshtoi';
-$strAbsolutePathToDocSqlDir = 'Ju lutem, shkruani pozicionin absolut n webserver pr tek directory e docSQL';
 $strAccessDeniedExplanation = 'phpMyAdmin u prpoq t lidhet me server-in MySQL, dhe server-i refuzoi lidhjen. Kontrollo emrin e host, prdoruesin dhe fjalkalimin tek file config.inc.php dhe sigurohu q korrispondojn me informacionet q ju ka dhn administratori i serverit MySQL.';
 $strAccessDenied = 'Hyrja nuk u pranua';
 $strAction = 'Veprimi';
@@ -30,8 +29,6 @@ $strAddAutoIncrement = 'Shto vler AUTO_INCREMENT';
 $strAddConstraints = 'Shto kushte';  
 $strAddDeleteColumn = 'Shto/Fshi fushn';
 $strAddDeleteRow = 'Shto/Fshi kriterin';
-$strAddedColumnComment = 'Komenti u shtua n kollon';
-$strAddedColumnRelation = 'Relacioni u shtua pr kollonn';
 $strAddHeaderComment = 'Shto nj koment t personalizuar n header (\\n ndrpret rreshtin)';
 $strAddIntoComments = 'Shto tek komentet';
 $strAddNewField = 'Shto nj fush t re';
@@ -164,15 +161,6 @@ $strDataDict = 'Data Dictionary';
 $strDataOnly = 'Vetm t dhna';
 $strData = 'T dhna';
 $strDBComment = 'Komenti pr Databazn: ';
-$strDBGContextID = 'ID e kontekstit';
-$strDBGContext = 'Konteksti';
-$strDBGHits = 'Hits';
-$strDBGLine = 'Rreshti';
-$strDBGMaxTimeMs = 'Koha maksimum, ms';
-$strDBGMinTimeMs = 'Koha minimum, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Koha/Hit, ms';
-$strDBGTotalTimeMs = 'Koha gjithsej, ms';
 $strDbPrivileges = 'T drejta specifike t databazs';
 $strDBRename = 'Ndysho emrin e databazs n'; 
 $strDbSpecific = 'specifik i databazs';
@@ -278,8 +266,6 @@ $strId = 'ID';
 $strIdxFulltext = 'Teksti komplet';
 $strIgnoreInserts = 'Prdor shprfill shtimet';  
 $strIgnore = 'Shprfill';
-$strIgnoringFile = 'File %s u shprfill';
-$strImportDocSQL = 'Importo files docSQL';
 $strImportFiles = 'Importo files';
 $strIndexes = 'Tregues';
 $strIndexHasBeenDropped = 'Treguesi %s u eleminua';
@@ -339,7 +325,7 @@ $strMIME_description = 'Prshkrimi';
 $strMIME_MIMEtype = 'Lloji MIME';
 $strMIME_nodescription = 'Asnj prshkrim n dispozicion pr kt transformim.<br />Ju lutem pyet autorin, far %s bn.';
 $strMIME_transformation_note = 'Pr listn e opcioneve t transformimeve n dispozicion dhe transformimet relativ t llojeve-MIME, kliko tek %sprshkrimet e transformimeve%s';
-$strMIME_transformation_options_note = 'Ju lutem shkruani vlerat pr opcionet e transformimit duke prdorur kt format: \'a\',\'b\',\'c\'...<br />Nse keni nevoj t shtoni nj backslash ("\") apo nj apostrof ("\'") midis ktyre vlerave, duhet ti backslash-oni (pr shembull \'\\\\xyz\' ose \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Ju lutem shkruani vlerat pr opcionet e transformimit duke prdorur kt format: \'a\', 100, b,\'c\'...<br />Nse keni nevoj t shtoni nj backslash ("\") apo nj apostrof ("\'") midis ktyre vlerave, duhet ti backslash-oni (pr shembull \'\\\\xyz\' ose \'a\\\'b\').';
 $strMIME_transformation_options = 'Opcione t transformimeve';
 $strMIME_transformation = 'Transformimi i Shfletuesit';
 $strMIMETypesForTable = 'LLOJET E MIME PR TABELN';  
@@ -611,7 +597,6 @@ $strTextAreaLength = ' Pr shkak t gjatsis saj,<br /> kjo fush nuk mund t ndrysho
 $strThai = 'Thai';
 $strTheme = 'Tema / Stili';  
 $strThisHost = 'Kt Host';
-$strThisNotDirectory = 'Kjo nuk sht nj directory';
 $strThreadSuccessfullyKilled = 'Thread %s u prfundua me sukses.';
 $strTime = 'Koha';
 $strToggleScratchboard = '(\')aktivo scratchboard';
@@ -624,7 +609,6 @@ $strTransformation_application_octetstream__download = 'Shfaq nj lidhje pr t shk
 $strTransformation_image_jpeg__inline = 'Shfaq nj miniatur t klikueshme; mundsit: gjrsia, lartsia n pixels (ruan proporcionin origjinal)';
 $strTransformation_image_jpeg__link = 'Shfaq nj lidhje pr tek kjo figur (download blob direkt, p.sh.).';
 $strTransformation_image_png__inline = 'Shiko figurn/jpeg: n linj';
-$strTransformation_text_plain__dateformat = 'Merr nj fush TIME, TIMESTAMP apo DATETIME dhe e formaton duke prdorur formatin e dats lokale. Mundsia e par sht offset (n or) q do t\'i shtohet timestamp (Default: 0). Mundsia e dyt sht nj format date n prputhje me parametrat n dispozicion pr funksionin strftime() t PHP.';
 $strTransformation_text_plain__external = 'VETM PR LINUX: Lshon nj program t jashtm dhe plotson t dhnat e fushave me an t standard input. Jep si rezultat standard output e programit. Vendosja default sht Tidy, pr t printuar si duhet kodin HTML. Pr arsye sigurie, do t\'ju duhet t ndryshoni file libraries/transformations/text_plain__external.inc.php dhe t shkruani instrumentet q lejoni t prdoren. Mundsia e par pra sht numri i programit q dshironi t prdorni dhe e dyta jan parametrat pr programin. Parametri i tret, n.q.s. i vendosur n 1 do t konvertoj output duke prdorur htmlspecialchars() (Prezgjedhur: 1). Nj parametr i katrt, po t jet vendosur n 1 do t\'i shtoj nj NOWRAP prmbajtjes s qelis kshtu q output komplet do t shfaqet pa u riformatuar (Default: 1)';
 $strTransformation_text_plain__formatted = 'Konservon formatimin origjinal t fushs. Nuk aplikohet asnj Escaping.';
 $strTransformation_text_plain__imagelink = 'Shfaq nj figur dhe nj link, fusha prmban emrin e file; opcioni i par sht nj prefiks si "http://domain.com/", opcioni i dyt sht gjrsia n pixels, i treti sht lartsia.';
@@ -675,8 +659,6 @@ $strWestEuropean = 'Europa Perndimore';
 $strWildcard = 'wildcard';
 $strWindowNotFound = 'Dritarja e destinimit t browser nuk mund t rifreskohet. Ka mundsi t keni mbyllur dritaren nn apo q browser-i juaj sht duke bllokuar rifreskimet ndrmjet browser-ve pr shkak t ndonj mase sigurie';
 $strWithChecked = 'N.q.s. t zgjedhur:';
-$strWritingCommentNotPossible = 'I pamundur shkrimi i komentit';
-$strWritingRelationNotPossible = 'I pamundur shkrimi i relacionit';
 $strWrongUser = 'Emr prdoruesi apo fjalkalim i gabuar. Ndalohet hyrja.';
 
 $strXML = 'XML';
@@ -1006,7 +988,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1021,4 +1003,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
