@@ -1,5 +1,5 @@
 <?php
-/* $Id: albanian-utf-8.inc.php,v 2.144 2006/08/09 12:55:35 lem9 Exp $ */
+/* $Id: albanian-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Translated by: Laurent Dhima <laurenti at users.sourceforge.net>
@@ -23,7 +23,6 @@ $timespanfmt = '%s ditë, %s orë, %s minuta dhe %s sekonda';
  
 
 $strAbortedClients = 'Dështoi';
-$strAbsolutePathToDocSqlDir = 'Ju lutem, shkruani pozicionin absolut në webserver për tek directory e docSQL';
 $strAccessDeniedExplanation = 'phpMyAdmin u përpoq të lidhet me server-in MySQL, dhe server-i refuzoi lidhjen. Kontrollo emrin e host, përdoruesin dhe fjalëkalimin tek file config.inc.php dhe sigurohu që korrispondojnë me informacionet që ju ka dhënë administratori i serverit MySQL.';
 $strAccessDenied = 'Hyrja nuk u pranua';
 $strAction = 'Veprimi';
@@ -31,8 +30,6 @@ $strAddAutoIncrement = 'Shto vlerë AUTO_INCREMENT';
 $strAddConstraints = 'Shto kushte';  
 $strAddDeleteColumn = 'Shto/Fshi fushën';
 $strAddDeleteRow = 'Shto/Fshi kriterin';
-$strAddedColumnComment = 'Komenti u shtua në kollonë';
-$strAddedColumnRelation = 'Relacioni u shtua për kollonën';
 $strAddHeaderComment = 'Shto një koment të personalizuar në header (\\n ndërpret rreshtin)';
 $strAddIntoComments = 'Shto tek komentet';
 $strAddNewField = 'Shto një fushë të re';
@@ -165,15 +162,6 @@ $strDataDict = 'Data Dictionary';
 $strDataOnly = 'Vetëm të dhëna';
 $strData = 'Të dhëna';
 $strDBComment = 'Komenti për Databazën: ';
-$strDBGContextID = 'ID e kontekstit';
-$strDBGContext = 'Konteksti';
-$strDBGHits = 'Hits';
-$strDBGLine = 'Rreshti';
-$strDBGMaxTimeMs = 'Koha maksimum, ms';
-$strDBGMinTimeMs = 'Koha minimum, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Koha/Hit, ms';
-$strDBGTotalTimeMs = 'Koha gjithsej, ms';
 $strDbPrivileges = 'Të drejta specifike të databazës';
 $strDBRename = 'Ndysho emrin e databazës në'; 
 $strDbSpecific = 'specifik i databazës';
@@ -279,8 +267,6 @@ $strId = 'ID';
 $strIdxFulltext = 'Teksti komplet';
 $strIgnoreInserts = 'Përdor shpërfill shtimet';  
 $strIgnore = 'Shpërfill';
-$strIgnoringFile = 'File %s u shpërfill';
-$strImportDocSQL = 'Importo files docSQL';
 $strImportFiles = 'Importo files';
 $strIndexes = 'Tregues';
 $strIndexHasBeenDropped = 'Treguesi %s u eleminua';
@@ -340,7 +326,7 @@ $strMIME_description = 'Përshkrimi';
 $strMIME_MIMEtype = 'Lloji MIME';
 $strMIME_nodescription = 'Asnjë përshkrim në dispozicion për këtë transformim.<br />Ju lutem pyet autorin, çfarë %s bën.';
 $strMIME_transformation_note = 'Për listën e opcioneve të transformimeve në dispozicion dhe transformimet relativë të llojeve-MIME, kliko tek %spërshkrimet e transformimeve%s';
-$strMIME_transformation_options_note = 'Ju lutem shkruani vlerat për opcionet e transformimit duke përdorur këtë format: \'a\',\'b\',\'c\'...<br />Nëse keni nevojë të shtoni një backslash ("\") apo një apostrofë ("\'") midis këtyre vlerave, duhet ti backslash-oni (për shembull \'\\\\xyz\' ose \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Ju lutem shkruani vlerat për opcionet e transformimit duke përdorur këtë format: \'a\', 100, b,\'c\'...<br />Nëse keni nevojë të shtoni një backslash ("\") apo një apostrofë ("\'") midis këtyre vlerave, duhet ti backslash-oni (për shembull \'\\\\xyz\' ose \'a\\\'b\').';
 $strMIME_transformation_options = 'Opcione të transformimeve';
 $strMIME_transformation = 'Transformimi i Shfletuesit';
 $strMIMETypesForTable = 'LLOJET E MIME PËR TABELËN';  
@@ -612,7 +598,6 @@ $strTextAreaLength = ' Për shkak të gjatësisë saj,<br /> kjo fushë nuk mund
 $strThai = 'Thai';
 $strTheme = 'Tema / Stili';  
 $strThisHost = 'Këtë Host';
-$strThisNotDirectory = 'Kjo nuk është një directory';
 $strThreadSuccessfullyKilled = 'Thread %s u përfundua me sukses.';
 $strTime = 'Koha';
 $strToggleScratchboard = '(ç\')aktivo scratchboard';
@@ -625,7 +610,6 @@ $strTransformation_application_octetstream__download = 'Shfaq një lidhje për t
 $strTransformation_image_jpeg__inline = 'Shfaq një miniaturë të klikueshme; mundësitë: gjërësia, lartësia në pixels (ruan proporcionin origjinal)';
 $strTransformation_image_jpeg__link = 'Shfaq një lidhje për tek kjo figurë (download blob direkt, p.sh.).';
 $strTransformation_image_png__inline = 'Shiko figurën/jpeg: në linjë';
-$strTransformation_text_plain__dateformat = 'Merr një fushë TIME, TIMESTAMP apo DATETIME dhe e formaton duke përdorur formatin e datës lokale. Mundësia e parë është offset (në orë) që do t\'i shtohet timestamp (Default: 0). Mundësia e dytë është një format date në përputhje me parametrat në dispozicion për funksionin strftime() të PHP.';
 $strTransformation_text_plain__external = 'VETËM PËR LINUX: Lëshon një program të jashtëm dhe plotëson të dhënat e fushave me anë të standard input. Jep si rezultat standard output e programit. Vendosja default është Tidy, për të printuar si duhet kodin HTML. Për arsye sigurie, do t\'ju duhet të ndryshoni file libraries/transformations/text_plain__external.inc.php dhe të shkruani instrumentet që lejoni të përdoren. Mundësia e parë pra është numri i programit që dëshironi të përdorni dhe e dyta janë parametrat për programin. Parametri i tretë, n.q.s. i vendosur në 1 do të konvertojë output duke përdorur htmlspecialchars() (Prezgjedhur: 1). Një parametër i katërt, po të jetë vendosur në 1 do t\'i shtojë një NOWRAP përmbajtjes së qelisë kështu që output komplet do të shfaqet pa u riformatuar (Default: 1)';
 $strTransformation_text_plain__formatted = 'Konservon formatimin origjinal të fushës. Nuk aplikohet asnjë Escaping.';
 $strTransformation_text_plain__imagelink = 'Shfaq një figurë dhe një link, fusha përmban emrin e file; opcioni i parë është një prefiks si "http://domain.com/", opcioni i dytë është gjërësia në pixels, i treti është lartësia.';
@@ -676,8 +660,6 @@ $strWestEuropean = 'Europa Perëndimore';
 $strWildcard = 'wildcard';
 $strWindowNotFound = 'Dritarja e destinimit të browser nuk mund të rifreskohet. Ka mundësi të keni mbyllur dritaren nënë apo që browser-i juaj është duke bllokuar rifreskimet ndërmjet browser-ve për shkak të ndonjë mase sigurie';
 $strWithChecked = 'N.q.s. të zgjedhur:';
-$strWritingCommentNotPossible = 'I pamundur shkrimi i komentit';
-$strWritingRelationNotPossible = 'I pamundur shkrimi i relacionit';
 $strWrongUser = 'Emër përdoruesi apo fjalëkalim i gabuar. Ndalohet hyrja.';
 
 $strXML = 'XML';
@@ -1007,7 +989,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1022,4 +1004,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
