@@ -1,5 +1,5 @@
 <?php
-/* $Id: arabic-utf-8.inc.php,v 2.145 2006/08/09 12:55:35 lem9 Exp $ */
+/* $Id: arabic-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Original translation to Arabic by Fisal <fisal77 at hotmail.com>
@@ -25,7 +25,6 @@ $datefmt = '%d %B %Y الساعة %H:%M';
 $timespanfmt = '%s يوم، %s ساعة، %s دقيقة و%s ثانية';
 
 $strAbortedClients = 'ألغي';
-$strAbsolutePathToDocSqlDir = 'الرجاء كتابة المسار المطلق على خادم الشبكة إلى دليل docSQL';
 $strAccessDeniedExplanation = 'حاول phpMyAdmin الاتصال بخادم MySQL، ورفض الخادم الاتصال. عليك أن تتحقق من المستضيف، أو اسم المستخدم وكلمة المرور في ملف الإعداد config.inc.php وتتأكد أنها مطابقة للمعلومات المعطاة إليك من قبل المسؤول عن خادم MySQL.';
 $strAccessDenied = 'غير مسموح';
 $strAction = 'العملية';
@@ -33,8 +32,6 @@ $strAddAutoIncrement = 'أضف قيمة AUTO_INCREMENT';
 $strAddConstraints = 'أضف قيوداً';
 $strAddDeleteColumn = 'إضافه/حذف عمود حقل';
 $strAddDeleteRow = 'إضافه/حذف صف سجل';
-$strAddedColumnComment = 'تم إضافة التعليق للعمود';
-$strAddedColumnRelation = 'تم إضافة العلاقة للعمود';
 $strAddIntoComments = 'أضف إلى الملاحظات';
 $strAddNewField = 'إضافة حقل جديد';
 $strAddPrivilegesOnDb = 'إضافة الصلاحيات على قاعدة البيانات التالية';
@@ -160,15 +157,6 @@ $strDataDict = 'قاموس البيانات';
 $strDataOnly = 'بيانات فقط';
 $strData = 'بيانات';
 $strDBComment = 'ملاحظة قاعدة البيانات: ';
-$strDBGContextID = 'رقم السياق';
-$strDBGContext = 'السياق';
-$strDBGHits = 'استخدامات';
-$strDBGLine = 'سطر';
-$strDBGMaxTimeMs = 'أقصى وقت، مث';
-$strDBGMinTimeMs = 'أقل وقت، مث';
-$strDBGModule = 'وِحْدة';
-$strDBGTimePerHitMs = 'وقت/استخدام، مث';
-$strDBGTotalTimeMs = 'الوقت الكلي، مث';
 $strDbPrivileges = 'صلاحيات خاصة بقاعدة البيانات';
 $strDbSpecific = 'خاص بقاعدة بيانات';
 $strDefaultValueHelp = 'للقيم الافتراضية، الرجاء أدخل قيمة مفردة، دون علامات هروب أو تنصيص، باستخدام التنسيق: a';
@@ -265,8 +253,6 @@ $strHungarian = 'الهنغارية';
 $strIdxFulltext = 'النص كاملاً';
 $strId = 'رقم';
 $strIgnore = 'تجاهل';
-$strIgnoringFile = 'تجاهل الملف %s';
-$strImportDocSQL = 'استيراد ملفات docSQL';
 $strImportFiles = 'استورد الملفات';
 $strIndexes = 'فهارس';
 $strIndexHasBeenDropped = 'فهرسه محذوفه %s';
@@ -324,7 +310,7 @@ $strMIME_description = 'الوصف';
 $strMIME_MIMEtype = 'نوع MIME';
 $strMIME_nodescription = 'ليس هناك وصف متوفر لهذا التحويل.<br />رجاء اسأل الناشر، ما يفعله %s.';
 $strMIME_transformation_note = 'لعرض قائمة بخيارات التحويل المتوفرة وأنواع تحويلات MIME الخاصة بها، إضغط على %sخيارات التحويل%s';
-$strMIME_transformation_options_note = 'رجاءً أدخل القيم لخيارات التحويل باستخدام هذا التنسيق: \'a\',\'b\',\'c\'...<br />إذا احتجت أن تضع شرْطة مائلة ("\") أو علامة تنصيص ("\'") بين هذه القيم، اسبقها بشرْطة مائلة )على سبيل المثال \'\\\\xyz\' أو \'a\\\'b\'(.';
+$strMIME_transformation_options_note = 'رجاءً أدخل القيم لخيارات التحويل باستخدام هذا التنسيق: \'a\', 100, b,\'c\'...<br />إذا احتجت أن تضع شرْطة مائلة ("\") أو علامة تنصيص ("\'") بين هذه القيم، اسبقها بشرْطة مائلة )على سبيل المثال \'\\\\xyz\' أو \'a\\\'b\'(.';
 $strMIME_transformation_options = 'خيارات التحويل';
 $strMIME_transformation = 'تحويل المتصفح';
 $strMIME_without = 'أنواع MIME التي تظهر بحروف مائلة ليس لها وظيفة تحويل منفصلة';
@@ -580,7 +566,6 @@ $strTblPrivileges = 'صلاحيات خاصة بالجدول';
 $strTextAreaLength = ' بسبب طوله,<br /> فمن المحتمل أن هذا الحقل غير قابل للتحرير ';
 $strThai = 'التايلندية';
 $strThisHost = 'هذا المضيف';
-$strThisNotDirectory = 'لم يكن هذا دليلاً';
 $strThreadSuccessfullyKilled = 'تم إيقاف العمليّة %s بنجاح.';
 $strTime = 'وقت';
 $strToggleScratchboard = 'toggle scratchboard';
@@ -591,7 +576,6 @@ $strTraffic = 'بيانات سير';
 $strTransformation_image_jpeg__inline = 'يظهر صورة مصغرة للضغط عليها، الخيارات:  العرض، الارتفاع بالبكسل )ويبقي التناسب الأصلي للحجم(.';
 $strTransformation_image_jpeg__link = 'يظهر رابطاً لهذه الصورة (direct blob download, i.e.).';
 $strTransformation_image_png__inline = 'إعرض صور/jpeg: بنفس السطر';
-$strTransformation_text_plain__dateformat = 'يتطلّب TIME, TIMESTAMP أو DATETIME والتنسيق باستخدام تنسيق التاريخ المحلي الخاص بك. الخيار الأول هو التعديل )بالساعات) والذي سوف يضاف إلى timestamp )صفر بشكل افتراضي(. الخيار الثاني هو تنسيق تاريخ مختلف بناءً على المتغيرات المتوفرة لـPHP strftime().';
 $strTransformation_text_plain__external = 'لينكس فقط: يشغّل تطبيقاً خارجياً و يقوم بتغذية بيانات الحقل عبر المدخل الافتراضي. يسترجع مخرجات التطبيق الافتراضية. القيمة الافتراضية هي Tidy، كي تطبع شيفرة نص HTML بشكل جميل. لأسباب أمنية، عليك أن تقوم بتعديل الملف libraries/transformations/text_plain__external.inc.php وإضافة الأدوات التي تريد أن تسمح لها بالعمل. الخيار الأول عند ذلك هو رقم البرنامج الذي تريد أن تستخدمه والخيار الثاني هو المتغيرات للبرنامج. سوف يقوم الخيار الثالث، إن حدد بقيمة 1، بتحويل المخرجات باستخدام htmlspecialchars() )القيمة الافتراضية 1(. متغير رابع، إن حدد بقيمة 1 سوف يضيف الصفة NOWRAP إلى الخلية الحاوية حتى يصبح المخرج بأكمله بدن إعادة تنسيق )القيمة الافتراضية 1(.';
 $strTransformation_text_plain__formatted = 'يُبقي التنسيق الأصلي للحقل. لا يتم عمل أي Escaping.';
 $strTransformation_text_plain__imagelink = 'تظهر صورة ورابط، يتحوي الحقل على إسم الملف، الخيار الأول هو سابقة مثل "http://domain.com/"، والخيار الثاني هو العرض بالبكسل، والثالث هو الارتفاع.';
@@ -642,8 +626,6 @@ $strWestEuropean = 'أوروبا الغربية';
 $strWildcard = 'حرف شامل';
 $strWindowNotFound = 'لم يمكن تحديث نافذة المتصفح المستهدفة. يبدو أنك أغلقت الرئيسية أو أن مستعرضك يمنع التحديث عبر النوافذ بسبب إعدادات الأمان.';
 $strWithChecked = ': على المحدد';
-$strWritingCommentNotPossible = 'كتابة التعليق غير ممكن';
-$strWritingRelationNotPossible = 'كتابة العلاقة غير ممكنة';
 $strWrongUser = 'خطأ إسم المستخدم/كلمة السر. الدخول ممنوع.';
 
 $strXML = 'XML';
@@ -1009,7 +991,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1024,4 +1006,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
