@@ -1,5 +1,5 @@
 <?php
-/* $Id: azerbaijani-utf-8.inc.php,v 2.143 2006/08/09 12:55:35 lem9 Exp $ */
+/* $Id: azerbaijani-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 // tercümedeki eksiklerimi ve ya sehv olduğunu düşündüyünüz yerleri shehriyari@trcomm.net adresine göndere bilersiniz...
 // Şehriyar İmanov 30 Avqust 2003... Shehi
@@ -20,14 +20,11 @@ $datefmt = '%d %B, %Y saat %H:%M';
 $timespanfmt = '%s gün, %s saat, %s deqiqe ve %s saniye';
 
 $strAbortedClients = 'Dayandırılmış Elaqeler';
-$strAbsolutePathToDocSqlDir = 'Xahiş edirik, docSQL direktoriyasına webserver-deki mütleq yolu (absolute path) gösterin.';
 $strAccessDenied = 'Giriş Tesdiq Edilmedi';
 $strAction = 'Fealiyyetler';
 $strAddAutoIncrement = 'AUTO_INCREMENT deyeri elave et';
 $strAddDeleteColumn = 'Sahe Sütunlarını Elave Et/Sil';
 $strAddDeleteRow = 'Kriteria Setirlerini Elave Et/Sil';
-$strAddedColumnComment = 'Bu sütun üçün qısa izahat elave edildi';
-$strAddedColumnRelation = 'Sütun üçün elaqe elave edildi';
 $strAddHeaderComment = 'Başlığa xülase me\'lumatı elave et (\\n yeni setire keçir)';
 $strAddIntoComments = 'Xülaseye elave et';
 $strAddNewField = 'Yeni sahe elave et';
@@ -144,15 +141,6 @@ $strDataDict = 'Me\'lumat lüğeti';
 $strData = 'Me\'lumat';
 $strDataOnly = 'Sadece me\'lumat';
 $strDBComment = 'Baza qısa izahatı: ';
-$strDBGContextID = 'Kontekst Nömresi';
-$strDBGContext = 'Metn (kontekst)';
-$strDBGHits = 'Hit-ler';
-$strDBGLine = 'Setr';
-$strDBGMaxTimeMs = 'Min. müddet, ms';
-$strDBGMinTimeMs = 'Maks. müddet, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Vaxt/Hit, ms';
-$strDBGTotalTimeMs = 'Toplam müddet, ms';
 $strDbPrivileges = 'Me\'lumat Bazasına Mexsus Selahiyyetler';
 $strDbSpecific = 'bazayaxas';
 $strDefault = 'Başlanğıc deyeri';
@@ -254,8 +242,6 @@ $strHungarian = 'Macar Dili';
 $strId = 'Nömre';
 $strIdxFulltext = 'Tam metn (Fulltext)';
 $strIgnore = 'Diqqete Alma';
-$strIgnoringFile = '%s Diqqete Almama (Ignore) faylı';
-$strImportDocSQL = 'docSQL Fayllarını İmport Et';
 $strImportFiles = 'Faylları import et';
 $strIndexes = 'Indeksler';
 $strIndexHasBeenDropped = '%s indeksi leğv edildi';
@@ -308,7 +294,7 @@ $strMIME_MIMEtype = 'MIME-tipi';
 $strMIME_nodescription = 'No Description is available for this transformation.<br />Please ask the author, what %s does.';
 $strMIME_transformation = 'Browser transformation';
 $strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s';
-$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\', 100, b,\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_transformation_options = 'Transformasiya variantları';
 $strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function';
 $strModifications = 'Modifications have been saved';
@@ -558,7 +544,6 @@ $strTableStructure = 'Table structure for table';
 $strTblPrivileges = 'Cedvelexas selahiyyetler';
 $strTextAreaLength = ' Uzun olduğuna göre,<br /> bu sahedeki me\'lumatlar deyişdirilmeye biler ';
 $strThisHost = 'Bu Host';
-$strThisNotDirectory = 'Bu direktoriya deyildi';
 $strThreadSuccessfullyKilled = 'Thread %s uğurla söndürüldü (killed).';
 $strTime = 'Müddet';
 $strTotal = 'cemi';
@@ -568,7 +553,6 @@ $strTraffic = 'Neqliyyat';
 $strTransformation_image_jpeg__inline = 'Displays a clickable thumbnail; options: width,height in pixels (keeps the original ratio)';
 $strTransformation_image_jpeg__link = 'Displays a link to this image (direct blob download, i.e.).';
 $strTransformation_image_png__inline = 'See image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';
 $strTransformation_text_plain__external = 'LINUX ONLY: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';
 $strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.';
 $strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';
@@ -614,8 +598,6 @@ $strWelcome = '%s - e Xoş Gelmişsiniz!';
 $strWestEuropean = 'Qerbi Avropa';
 $strWildcard = 'xüsusi işare';
 $strWithChecked = 'Seçilenleri:';
-$strWritingCommentNotPossible = 'Qısa izahat yazılışı mümkün deyil';
-$strWritingRelationNotPossible = 'Elaqe yazılışı mümkün deyil';
 $strWrongUser = 'Yanlış istifadeçi adı ve ya parol. Giriş tesdiq edilmedi.';
 
 $strXML = 'XML';
@@ -1004,7 +986,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1019,4 +1001,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
