@@ -1,5 +1,5 @@
 <?php
-/* $Id: basque-iso-8859-1.inc.php,v 2.136 2006/08/09 12:55:35 lem9 Exp $ */
+/* $Id: basque-iso-8859-1.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr';
@@ -16,7 +16,6 @@ $datefmt = '%Y-%m-%d, %H:%M:%S';
 $timespanfmt = '%s egun, %s ordu, %s minutu eta %s segundu';
 
 $strAbortedClients = 'Deuseztatua';
-$strAbsolutePathToDocSqlDir = 'Mesedez, docSQL direktorioaren zerbitzariko helbide absolutoa idatzi';
 $strAccessDeniedExplanation = 'phpMyAdmin MySQL zerbitzariarekin konektatzen saiatu zen, eta zerbitzariak konexioa ukatu zuen. Config.inc.php fitxategian host-a, erabiltzaile-izena eta pasahitza berpasatu beharko dituzu eta MySQL zerbitzariaren administratzaileak emaniko informazioarekin bat egiten dutela ziurtatu.';
 $strAccessDenied = 'Sarbidea ukatua';
 $strAction = 'Ekintza';
@@ -24,8 +23,6 @@ $strAddAutoIncrement = 'Gehitu AUTO_INCREMENT balioa';
 $strAddConstraints = 'Murrizketak gehitu';
 $strAddDeleteColumn = 'Gehitu/ezabatu irizpide-zutabea';
 $strAddDeleteRow = 'Gehitu/ezabatu irizpide-errenkada';
-$strAddedColumnComment = 'Zutabearentzako iruzkin bat gehitu da';
-$strAddedColumnRelation = 'Zutabearentzako erlazio bat gehitu da';
 $strAddIntoComments = 'Iruzkinetan gehitu';
 $strAddNewField = 'Eremu berria gehitu';
 $strAddPrivilegesOnDb = 'Pribilegioak gehitu datu-base honetan';
@@ -150,15 +147,6 @@ $strData = 'Datuak';
 $strDataDict = 'Datu-hiztegia';
 $strDataOnly = 'Datuak soilik';
 $strDBComment = 'Datu-basearen iruzkina: ';
-$strDBGContextID = 'Testuinguruaren IDa';
-$strDBGContext = 'Testuingurua';
-$strDBGHits = 'Atzialdiak';
-$strDBGLine = 'Lerroa';
-$strDBGMaxTimeMs = 'Denbora Min , ms';
-$strDBGMinTimeMs = 'Denbora Max, ms';
-$strDBGModule = 'Modulua';
-$strDBGTimePerHitMs = 'Denbora/Atzialdi, ms';
-$strDBGTotalTimeMs = 'Denbora orokorra, ms';
 $strDbPrivileges = 'Datu-basearen pribilegio espezifikoak';
 $strDbSpecific = 'Datubasearentzat espezifikoa';
 $strDefault = 'Lehenetsia';
@@ -255,8 +243,6 @@ $strHungarian = 'Hungariera';
 $strId = 'ID';
 $strIdxFulltext = 'Testu osoa';
 $strIgnore = 'Ezikusi';
-$strIgnoringFile = '%s fitxategia ezikusten';
-$strImportDocSQL = 'docSQL Fitxategiak inportatu';
 $strImportFiles = 'Fitxategiak inportatu';
 $strIndexes = 'Indizeak';
 $strIndexHasBeenDropped = '%s indizea ezabatu da';
@@ -312,7 +298,7 @@ $strMIME_nodescription = 'Eraldaketa honentzako deskribapenik ez dago erabilgarr
 $strMIME_transformation = 'Nabigatzailearen eraldaketa';
 $strMIME_transformation_note = 'Eraldaketen hobespen eta haien MIME-mota eraldaketen zerrendarako, egizu klik hemen %stransformation descriptions%s';
 $strMIME_transformation_options = 'Eraldaketen hobespenak';
-$strMIME_transformation_options_note = 'Mesedez, formato honi jarraiki, sartu itzazu eraldaketen hobespenentzako balioak: \'a\',\'b\',\'c\'...<br />Noizbait alderantzikaturiko barra ("\") edo barra arrunta ("\'") erabili beharko bazenu, beti erabili alderantzikaturiko barra (adibidez \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Mesedez, formato honi jarraiki, sartu itzazu eraldaketen hobespenentzako balioak: \'a\', 100, b,\'c\'...<br />Noizbait alderantzikaturiko barra ("\") edo barra arrunta ("\'") erabili beharko bazenu, beti erabili alderantzikaturiko barra (adibidez \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_without = 'Etzanez inprimaturiko MIME-motek ez dute eraldaketa-funtzio berezirik';
 $strModifications = 'Aldaketak gorde dira';
 $strModify = 'Aldatu';
@@ -565,7 +551,6 @@ $strTblPrivileges = 'Taularen pribilegio espezifikoak';
 $strTextAreaLength = ' Bere luzeragatik,<br /> eremu hau ez da editagarria ';
 $strThai = 'Thailandiarra';
 $strThisHost = 'Host hau';
-$strThisNotDirectory = 'Hau ez zen direktorio bat';
 $strThreadSuccessfullyKilled = '%s haria arrakastaz ezabatu da.';
 $strTime = 'Denbora';
 $strToggleScratchboard = 'Aldatu "scratchboard"-a';
@@ -576,7 +561,6 @@ $strTraffic = 'Trafikoa';
 $strTransformation_image_jpeg__inline = 'Miniatura klikagarri bat erakusten du; aukerak: luzera,altuera pixeletan (jatorrizko erlazioa mantentzen du)';
 $strTransformation_image_jpeg__link = 'Irudi honi zuzendutako esketa bat erakusten du(blob deskarga zuzena, i.e.).';
 $strTransformation_image_png__inline = 'Ikusi image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'TIME, TIMESTAMP edo DATETIME eremu bat hartu eta zure data lokalaren formateo mota erabiliz formateatzen du. Lehenengo aukera orduari gehitu beharreko aldea (orduetan) da (Lehenetsia: 0). Bigarren aukera dataren formateo ezberdin bat da, PHPren strftime() funtzioaren eskuragarri dauden parametroen arabera.';
 $strTransformation_text_plain__external = 'LINUX SOILIK: Kanpoko aplikazio bat abiaratzen du eta datu-eremua sarrera estandarraren bidez osatzen du. Aplikazioaren irteera estandarra itzultzen du. Lehenetsitakoa Tidy da, HTML kodea txukun pantailaratzeko. Segurtasun arrazoiengatik, libraries/transformations/text_plain__external.inc.php fitxategia eskuz editatu beharko duzu eta hor zehaztu zein tresna exekutatzea baimentzen duzun. Lehenengo aukera erabili nahi duzun programaren zenbakia da eta bigarren aukera programarentzako parametroak dira . Hirugarren parametroa, 1 izanez gero irteera bihurtuko du  htmlspecialchars() funtzioa erabiliz (Lehenetsia: 1). Laugarren parametroa, 1 izanez gero NOWRAP bat ezarriko dio edukin-gelaxkari, beraz irteera osoa berformateatu barik erakutsiko da(Lehenetsi 1)';
 $strTransformation_text_plain__formatted = 'Eremuaren jatorrizko formateoa mantentzen du. Aldaketarik egin gabe.';
 $strTransformation_text_plain__imagelink = 'Irudi eta esteka bana erakusten ditu, eremuak fitxategiaren izena dauka; lehenengo aukera "http://domain.com/" moduko aurrizki bat da, bigarren aukera pixeletan neurtutako zabalera da, hirugarrena altuera da.';
@@ -627,8 +611,6 @@ $strWestEuropean = 'Mendebaldeko europearra';
 $strWildcard = 'komodina';
 $strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings';
 $strWithChecked = 'Ikurdunak:';
-$strWritingCommentNotPossible = 'Ezin izan da iruzkina idatzi';
-$strWritingRelationNotPossible = 'Ezin izan da erlazioa idatzi';
 $strWrongUser = 'Erabiltzaile-izena/pasahitza okerra. Atzipena ukatuta.';
 
 $strXML = 'XML';
@@ -1000,7 +982,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1015,4 +997,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
