@@ -1,5 +1,5 @@
 <?php
-/* $Id: belarusian_cyrillic-windows-1251.inc.php,v 1.74.2.1 2006/08/12 20:24:34 lem9 Exp $ */
+/* $Id: belarusian_cyrillic-windows-1251.inc.php 9853 2007-01-19 18:14:44Z lem9 $ */
 
 /**
  *     Translated by:
@@ -23,7 +23,6 @@ $datefmt = '%d %B %Y, %H:%M';
 $timespanfmt = '%s , %s , %s   %s ';
 
 $strAbortedClients = '';
-$strAbsolutePathToDocSqlDir = ' ,     -   docSQL';
 $strAccessDeniedCreateConfig = ',    ,     .   ,   %1$s %2$s.';
 $strAccessDeniedExplanation = 'phpMyAdmin     MySQL,   볢 .   ,     config.inc.php  ,    ,    MySQL-.';
 $strAccessDenied = '  ';
@@ -33,8 +32,6 @@ $strAddClause = ' %s';
 $strAddConstraints = ' ';
 $strAddDeleteColumn = '/  ';
 $strAddDeleteRow = '/  ';
-$strAddedColumnComment = '   ';
-$strAddedColumnRelation = '   ';
 $strAddFields = '  ';
 $strAddHeaderComment = '     (\\n  )';
 $strAddIntoComments = '  ';
@@ -206,15 +203,6 @@ $strDataOnly = ' ';
 $strDataPages = '  ';
 $strDBComment = '   : ';
 $strDBCopy = '   ';
-$strDBGContext = '';
-$strDBGContextID = ' ID';
-$strDBGHits = '';
-$strDBGLine = '';
-$strDBGMaxTimeMs = ' , ';
-$strDBGMinTimeMs = '̳ , ';
-$strDBGModule = '';
-$strDBGTimePerHitMs = '/, ';
-$strDBGTotalTimeMs = ' , ';
 $strDbPrivileges = '   ';
 $strDBRename = '   ';
 $strDbSpecific = '   ';
@@ -351,9 +339,7 @@ $strIdxFulltext = '';
 $strIgnore = '';
 $strIgnoreDuplicates = ' ,  ';
 $strIgnoreInserts = '  ';
-$strIgnoringFile = ' %s ';
 $strImport = '';
-$strImportDocSQL = '  docSQL';
 $strImportFiles = ' ';
 $strImportFormat = '  ';
 $strImportSuccessfullyFinished = '  ,  %d .';
@@ -457,7 +443,7 @@ $strMIME_nodescription = '     .<br /> ,  ,   %s.';
 $strMIME_transformation = ' MIME- ';
 $strMIME_transformation_note = '         MIME-,   %s %s';
 $strMIME_transformation_options = ' ';
-$strMIME_transformation_options_note = ' ,       : \'a\',\'b\',\'c\'...<br />      ("\")   ("\'")   ,      (, \'\\\\xyz\'  \'a\\\'b\').';
+$strMIME_transformation_options_note = ' ,       : \'a\', 100, b,\'c\'...<br />      ("\")   ("\'")   ,      (, \'\\\\xyz\'  \'a\\\'b\').';
 $strMIMETypesForTable = 'MIME- ';
 $strMIME_without = 'MIME-,  ,     ';
 $strModifications = '  ';
@@ -905,7 +891,6 @@ $strThemeNoValidImgPath = '     %s  !';
 $strTheme = ' / ';
 $strThemePathNotFound = '     %s!';
 $strThisHost = ' ';
-$strThisNotDirectory = '  ';
 $strThreads = '';
 $strThreadSuccessfullyKilled = ' %s   .';
 $strTime = '';
@@ -924,7 +909,6 @@ $strTransformation_application_octetstream__hex = '    .        (-    8 ).';
 $strTransformation_image_jpeg__inline = '  ;        .   .';
 $strTransformation_image_jpeg__link = '     .';
 $strTransformation_image_png__inline = '  image/jpeg: ';
-$strTransformation_text_plain__dateformat = '    TIME, TIMESTAMP  DATETIME        .      ( ),       ( : 0).   ,     ;     PHP strftime().';
 $strTransformation_text_plain__external = 'ʲ  LINUX:           .    .     Tidy,    HTML-.   ,      libraries/transformations/text_plain__external.inc.php    ,     .      ,    ,      .  ,    1,       htmlspecialchars() (  1).  ,    1,    ,  ,          (  1).';
 $strTransformation_text_plain__formatted = '   -,     htmlspecialchars().  ,     HTML-.';
 $strTransformation_text_plain__imagelink = '   ,    .       "http://www.example.com/".          .';
@@ -986,8 +970,6 @@ $strWildcard = '';
 $strWindowNotFound = '    . ,              ';
 $strWithChecked = ' :';
 $strWriteRequests = ' ';
-$strWritingCommentNotPossible = '  ';
-$strWritingRelationNotPossible = '  ';
 $strWrongUser = ' /.   .';
 
 $strXMLOptions = ' XML';
@@ -998,4 +980,52 @@ $strYes = '';
 $strZeroRemovesTheLimit = ':     0 ()  .';
 $strZip = '  zip';
 
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
