@@ -1,5 +1,5 @@
 <?php
-/* $Id: bosnian-utf-8.inc.php,v 2.140 2006/08/09 12:55:35 lem9 Exp $ */
+/* $Id: bosnian-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  *     Translated by:
@@ -23,15 +23,12 @@ $datefmt = '%d. %B %Y. u %H:%M';
 $timespanfmt = '%s dana, %s sati, %s minuta i %s sekundi';
 
 $strAbortedClients = 'Prekinuto';
-$strAbsolutePathToDocSqlDir = 'Unesite kompletnu putanju do direkcije docSQL na veb serveru';
 $strAccessDeniedExplanation = 'phpMyAdmin je pokušao da se poveže na MySQL server, ali je server odbio povezivanje. Provjerite naziv hosta, korisničko ime i lozinku u config.inc.php i uvjerite se da odgovaraju podacima koje ste dobili od administratora MySQL servera.';
 $strAccessDenied = 'Ulaz nije dozvoljen';
 $strAction = 'Akcija';
 $strAddAutoIncrement = 'Dodaj AUTO_INCREMENT vrijednost';
 $strAddDeleteColumn = 'Dodaj/obriši kolonu';
 $strAddDeleteRow = 'Dodaj/obriši polje za kriterij';
-$strAddedColumnComment = 'Dodan je komentar koloni';
-$strAddedColumnRelation = 'Dodana je relacija koloni';
 $strAddIntoComments = 'Dodaj u komentare';
 $strAddNewField = 'Dodaj novo polje';
 $strAddPrivilegesOnDb = 'Dodaj privilegije na slijedećoj bazi';
@@ -152,15 +149,6 @@ $strDataDict = 'Rečnik podataka';
 $strDataOnly = 'Samo podaci';
 $strData = 'Podaci';
 $strDBComment = 'Komentar baze:';
-$strDBGContextID = 'Kontekst ID';
-$strDBGContext = 'Kontekst';
-$strDBGHits = 'Pogodaka';
-$strDBGLine = 'Linija';
-$strDBGMaxTimeMs = 'Max vrijeme, ms';
-$strDBGMinTimeMs = 'Min vrijeme, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Vrijeme/pogodak, ms';
-$strDBGTotalTimeMs = 'Ukupno vrijeme, ms';
 $strDbPrivileges = 'Privilegije vezane za bazu';
 $strDbSpecific = 'Specifično za bazu';
 $strDefault = 'Podrazumjevano';
@@ -255,8 +243,6 @@ $strHungarian = 'Mađarski';
 $strId = 'ID';
 $strIdxFulltext = 'Tekst ključ';
 $strIgnore = 'Ignoriši';
-$strIgnoringFile = 'Ignorišem fajl %s';
-$strImportDocSQL = 'Uvoz docSQL fajlova';
 $strImportFiles = 'Uvoz fajlova';
 $strIndexes = 'Ključevi';
 $strIndexHasBeenDropped = 'Ključ %s je obrisan';
@@ -304,7 +290,7 @@ $strMIME_description = 'Opis';
 $strMIME_MIMEtype = 'MIME-tipovi';
 $strMIME_nodescription = 'Nema opisa za ovu transformaciju.<br />Molimo pitajte autora šta %s radi.';
 $strMIME_transformation_note = 'Za listu dostupnih opcija transformacije i njihove transformacije MIME-tipova, kliknite na %sopise transformacija%s';
-$strMIME_transformation_options_note = 'Molimo unesite vrijednosti za opcije transformacije koristeći ovaj oblik: \'a\',\'b\',\'c\'...<br />Ako treba da unesete obrnutu kosu crtu ("\\") ili apostrof ("\'") u te vrijednosti, stavite obrnutu kosu crtu ispred njih (na primjer \'\\\\xyz\' ili \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Molimo unesite vrijednosti za opcije transformacije koristeći ovaj oblik: \'a\', 100, b,\'c\'...<br />Ako treba da unesete obrnutu kosu crtu ("\\") ili apostrof ("\'") u te vrijednosti, stavite obrnutu kosu crtu ispred njih (na primjer \'\\\\xyz\' ili \'a\\\'b\').';
 $strMIME_transformation_options = 'Opcije transformacije';
 $strMIME_transformation = 'Tranformacije čitača';
 $strMIME_without = 'MIME-tipovi prikazani u kursivu nemaju odvojene funkcije transformacije.';
@@ -557,7 +543,6 @@ $strTblPrivileges = 'Privilegije vezane za tabele';
 $strTextAreaLength = 'Zbog njehove veličine, polje<br />možda nećete moći da izmenite';
 $strThai = 'Tajlandski ';
 $strThisHost = 'Ovaj server';
-$strThisNotDirectory = 'Ovo nije direktorijum';
 $strThreadSuccessfullyKilled = 'Proces %s je uspješno prekinut.';
 $strTime = 'Vrijeme';
 $strToggleScratchboard = 'Uključuje/isključuje scratchboard';
@@ -568,7 +553,6 @@ $strTraffic = 'Saobraćaj';
 $strTransformation_image_jpeg__inline = 'Prikazuje umanjenu sliku na koju je moguće kliknuti; opcije: širina, visina u pikselima (čuva originalni odnos)';
 $strTransformation_image_jpeg__link = 'Prikazuje link ka ovoj slici (npr. direktno preuzimanje iz BLOB-a).';
 $strTransformation_image_png__inline = 'Prikaži JPEG slike na strani';
-$strTransformation_text_plain__dateformat = 'Uzima TIME, TIMESTAMP ili DATETIME polje i formatira ga koristeći lokalni oblik prikazivanja datuma. Prva opcija je ofset (u satima) koji se dodaje vremenskoj oznaci (podrazumevano: 0). Druga opcija je različit format datuma prema parametrima koji su dostupni za PHP-ov strftime().';
 $strTransformation_text_plain__external = 'SAMO LINUX: Pokreće eksternu aplikaciju i popunjava podatke u poljima preko standardnog ulaza. Vraća standardni izlaz aplikacije. Podrazumevano je Tidy, za lepši prikaz HTML koda. Zbog sigurnosnih razloga, morate ručno izmeniti datoteku libraries/transformations/text_plain__external.inc.php i dodati alate koje želite da koristite. Prva opcija je broj programa koje želite da koristite, a druga su parametri programa. Ako se treći parametar postavi na 1 izlaz će biti konvertovan koristeći htmlspecialchars() (podrazumevano je 1). Ako je četvrti parametar postavljen na 1, NOWRAP će biti dodato ćeliji sa sadržajem tako da će izlaz biti prikazan bez izmena. (podrazumevano 1)';
 $strTransformation_text_plain__formatted = 'Čuva originalno formatiranje polja. Escaping se ne vrši.';
 $strTransformation_text_plain__imagelink = 'Prikazuje sliku i link, polje sadrži naziv datoteke; prva opcija je prefiks kao "http://domain.com/", druga opcija je širina u pikselima, treća je visina.';
@@ -618,8 +602,6 @@ $strWestEuropean = 'Zapadnoevropski';
 $strWildcard = 'Džoker';
 $strWindowNotFound = 'Odredišnji prozor pretraživača nije mogao da bude ažuriran. Možda ste zatvorili matični prozor, ili vaš preraživač onemogućava ažuriranje među prozorima zbog sigurnosnih podešavanja';
 $strWithChecked = 'Označeno:';
-$strWritingCommentNotPossible = 'Pisanje komentara nije moguće';
-$strWritingRelationNotPossible = 'Upisivanje relacije nije moguće';
 $strWrongUser = 'Pogrešno korisničko ime/lozinka. Ulaz nije dozvoljen.';
 
 $strXML = 'XML';
@@ -1007,7 +989,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1022,4 +1004,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
