@@ -1,5 +1,5 @@
 <?php
-/* $Id: bulgarian-utf-8.inc.php,v 2.149.2.3 2006/09/15 12:03:00 lem9 Exp $ */
+/* $Id: bulgarian-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Translated by Stanislav Yordanov <stanprog at stanprog.com>
@@ -23,7 +23,6 @@ $datefmt = '%e %B %Y в %H:%M';
 $timespanfmt = '%s дена, %s часа, %s минути и %s секунди';
 
 $strAbortedClients = 'Прекъснати';
-$strAbsolutePathToDocSqlDir = 'Моля въведете абсолютния път на уеб сървъра до docSQL директорията';
 $strAccessDeniedExplanation = 'phpMyAdmin направи опит да се свърже към MySQL сървъра, но сървъра отхвърли конекцията. Трябва да проверите хоста, потребителското име и паролата в config.inc.php файла и да се уверите, че те отговарят на информацията предоставена от администратора на MySQL сървъра.';
 $strAccessDenied = 'Отказан достъп';
 $strAction = 'Действие';
@@ -32,8 +31,6 @@ $strAddClause = 'Добавяне на %s';
 $strAddConstraints = 'Добавяне на ограничение';
 $strAddDeleteColumn = 'Добави/изтрий колона по критерий';
 $strAddDeleteRow = 'Добави/изтрий ред по критерий';
-$strAddedColumnComment = 'Добавен коментар към колона';
-$strAddedColumnRelation = 'Добавена релациа към колона';
 $strAddFields = 'Добавяне на  %s поле(та)';
 $strAddHeaderComment = 'Добавяне на коментар в хедъра (\\n нов ред)';
 $strAddIntoComments = 'Добавяне в коментарите';
@@ -185,15 +182,6 @@ $strDataOnly = 'Само данните';
 $strDataPages = 'Страници съдържащи данни';
 $strDBComment = 'Коментар към базата от данни: ';
 $strDBCopy = 'Копиране на базата от данни в';
-$strDBGContextID = 'Контекстно ID';
-$strDBGContext = 'Контекст';
-$strDBGHits = 'Попадения';
-$strDBGLine = 'Линия';
-$strDBGMaxTimeMs = 'Макс. време, ms';
-$strDBGMinTimeMs = 'Мин. време, ms';
-$strDBGModule = 'Модул';
-$strDBGTimePerHitMs = 'Време/Попадение, ms';
-$strDBGTotalTimeMs = 'Общо време, ms';
 $strDbPrivileges = 'Привилегии специфични за базата от данни';
 $strDBRename = 'Преименуване на базата от данни на';
 $strDbSpecific = 'специфични за базата от данни';
@@ -320,8 +308,6 @@ $strIdxFulltext = 'Пълнотекстово';
 $strIgnore = 'Игнориране';
 $strIgnoreDuplicates = 'Игнориране на дублиращите се редове';
 $strIgnoreInserts = 'Използване на INSERT IGNORE';
-$strIgnoringFile = 'Игнориране на файл %s';
-$strImportDocSQL = 'Импортирай docSQL файловете';
 $strImportFiles = 'Импортиране на файлове';
 $strImportFormat = 'Формат на импортирания файл';
 $strImport = 'Импортиране';
@@ -404,7 +390,7 @@ $strMIME_MIMEtype = 'MIME-тип';
 $strMIME_nodescription = 'Няма Описание за тази трансформация.<br />Моля обърнете се към автора относно това какво прави %s.';
 $strMIME_transformation = 'Браузърна трансформация';
 $strMIME_transformation_note = 'За списъка на достъпните опции на трансформацията и техните MIME-type трансформации кликнете на %sописания на трансформацията%s';
-$strMIME_transformation_options_note = 'Моля въведете стойностите за опциите на трансформацията като използвате следния формат: \'a\',\'b\',\'c\'...<br />Ако трябва да поставите обратно наклонена черта ("\") или единична кавичка ("\'") между тези стойности, поставете пред тях допълнителна обратно наклонена черта (например \'\\\\xyz\' или \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Моля въведете стойностите за опциите на трансформацията като използвате следния формат: \'a\', 100, b,\'c\'...<br />Ако трябва да поставите обратно наклонена черта ("\") или единична кавичка ("\'") между тези стойности, поставете пред тях допълнителна обратно наклонена черта (например \'\\\\xyz\' или \'a\\\'b\').';
 $strMIME_transformation_options = 'Опции на трансформацията';
 $strMIMETypesForTable = 'MIME ТИПОВЕ ЗА ТАБЛИЦА';
 $strMIME_without = 'MIME-types показани в наклонен шрифт не притежават отделна функция за трансформация';
@@ -724,7 +710,6 @@ $strThemeNoValidImgPath = 'Не е открит валиден път на те
 $strTheme = 'Тема / Стил';
 $strThemePathNotFound = 'Не е открит пътя на тема %s!';
 $strThisHost = 'Този Хост';
-$strThisNotDirectory = 'Това не беше директория';
 $strThreadSuccessfullyKilled = 'Нишка %s беше успешно отстранена.';
 $strThreads = 'Нишки';
 $strTime = 'Време';
@@ -738,7 +723,6 @@ $strTransformation_application_octetstream__download = 'Показва връз
 $strTransformation_image_jpeg__inline = 'Показва thumbnail; опции: ширина, височина в пиксели (запазва оригиналната пропорция)';
 $strTransformation_image_jpeg__link = 'Показва връзката на това изображение (за директно сваляне, i.e.).';
 $strTransformation_image_png__inline = 'Виж image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Взема поле TIME, TIMESTAMP или DATETIME и го форматира като използва локалния формат за дата. Първата опция е отместването (в часове) която ще бъде добавена към времето (По подразбиране: 0). Втората опция представлява различен формат на датата в зависимост от параметрите на функцията на PHP - strftime().';
 $strTransformation_text_plain__external = 'САМО ЗА ЛИНУКС: Стартира външното приложение и попълва данните в полетата чрез стандартния вход. Връща стандартния изход на приложението. По подразбиране е Tidy, за да покаже HTML кода. От съображения за сигурност, трябва ръчно да редактирате файла libraries/transformations/text_plain__external.inc.php и да вмъкнете програмите на които вие позволявате да бъдат стартирани. Първата опция тогава е номера на програмата която бихте искали да използвате а втората опция са параметрите за програмата. Ако третият параметър е установен в 1, ще конвертира изхода използвайки htmlspecialchars() (По подразбиране е 1). Ако четвъртият параметър е установен в 1, ще постави NOWRAP на клетката на съдържанието, така че целия изход ще бъде показан без преформатиране (По подразбиране е 1)';
 $strTransformation_text_plain__formatted = 'Запазва оригиналното форматиране на полето.';
 $strTransformation_text_plain__imagelink = 'Показва изображение и връзка на полето съдържащо файлово име; първата опция е префикс като "http://domain.com/", втората опция е ширината в пиксели, третата е височината.';
@@ -797,8 +781,6 @@ $strWestEuropean = 'Западно-европейски';
 $strWildcard = 'знак за заместване';
 $strWindowNotFound = 'Прозореца на браузъра не може да бъде обновен. Може би сте затворили отварящият го прозорец или браузърът Ви е блокирал обновяване на данни от един прозорец в друг от съображения за сигурност';
 $strWithChecked = 'Когато има отметка:';
-$strWritingCommentNotPossible = 'Записа на коментар не е възможен';
-$strWritingRelationNotPossible = 'Записа на релацията не е възможен';
 $strWrongUser = 'Грешно име/парола. Достъп отказан.';
 
 $strXMLOptions = 'XML опции';
@@ -831,7 +813,7 @@ $strBusyPages = 'Busy pages';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseNone = 'Няма';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strCSV = 'CSV';  //to translate
 
 $strDirtyPages = 'Dirty pages';  //to translate
@@ -1019,4 +1001,52 @@ $strUnsupportedCompressionDetected = 'You attempted to load file with unsupporte
 
 $strWriteRequests = 'Write requests';  //to translate
 
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
