@@ -1,5 +1,5 @@
 <?php
-/* $Id: bulgarian-windows-1251.inc.php,v 2.123.2.3 2006/03/23 17:42:11 lem9 Exp $ */
+/* $Id: bulgarian-windows-1251.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Translated by Stanislav Yordanov <stanprog at stanprog.com>
@@ -8,8 +8,6 @@
 
 $charset = 'windows-1251';
 $text_dir = 'ltr';
-$left_font_family = 'sans-serif';
-$right_font_family = 'sans-serif';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
@@ -24,25 +22,21 @@ $datefmt = '%e %B %Y  %H:%M';
 $timespanfmt = '%s , %s , %s   %s ';
 
 $strAbortedClients = '';
-$strAbsolutePathToDocSqlDir = '        docSQL ';
 $strAccessDeniedExplanation = 'phpMyAdmin       MySQL ,    .    ,      config.inc.php     ,          MySQL .';
 $strAccessDenied = ' ';
 $strAction = '';
 $strAddAutoIncrement = '  AUTO_INCREMENT';
+$strAddClause = '  %s';
 $strAddConstraints = '  ';
 $strAddDeleteColumn = '/   ';
 $strAddDeleteRow = '/   ';
-$strAddDropDatabase = '  DROP DATABASE';
-$strAddedColumnComment = '   ';
-$strAddedColumnRelation = '   ';
 $strAddFields = '   %s ()';
 $strAddHeaderComment = '     (\\n  )';
-$strAddIfNotExists = '  IF NOT EXISTS'; 
 $strAddIntoComments = '  ';
 $strAddNewField = '   ';
 $strAddPrivilegesOnDb = '       ';
 $strAddPrivilegesOnTbl = '     ';
-$strAddSearchConditions = '    (  "where" ):';
+$strAddSearchConditions = '     (  "where" ):';
 $strAddToIndex = ' &nbsp;%s&nbsp;() ()   ';
 $strAddUserMessage = '   .';
 $strAddUser = '   .';
@@ -80,6 +74,8 @@ $strBeginCut = 'BEGIN CUT';
 $strBeginRaw = 'BEGIN RAW';
 $strBinary = '  ';
 $strBinaryDoNotEdit = '  -    ';
+$strBinLogEventType = '  ';
+$strBinLogInfo = '';
 $strBookmarkAllUsers = '       ';
 $strBookmarkCreated = ' %s   ';
 $strBookmarkDeleted = '  .';
@@ -94,10 +90,12 @@ $strBulgarian = '';
 $strBzError = 'phpMyAdmin     (dump)    Bz2      PHP.        <code>$cfg[\'BZipDump\']</code>       phpMyAdmin  <code>FALSE</code>.        Bz2 ,      -   PHP.   %s   .';
 $strBzip = '"bzip-"';
 
-$strCalendar = ''; 
+$strCalendar = '';
+$strCanNotLoadExportPlugins = '       ,   !';
+$strCanNotLoadImportPlugins = 'Plugin-       ,     phpMyAdmin!';
 $strCannotLogin = '      MySQL ';
 $strCantLoad = '     %s,<br />    PHP';
-$strCantLoadRecodeIconv = '     iconv  recode        (charset),  PHP ,              (charset)  phpMyAdmin.';
+$strCantLoadRecodeIconv = '     iconv  recode        ,  PHP ,                phpMyAdmin.';
 $strCantRenameIdxToPrimary = '      PRIMARY!';
 $strCantUseRecodeIconv = '      iconv  libiconv  recode_string       .    PHP.';
 $strCardinality = '';
@@ -132,7 +130,9 @@ $strCommentsForTable = '  ';
 $strComments = '';
 $strCompatibleHashing = 'MySQL&nbsp;4.0 ';
 $strCompleteInserts = ' INSERT-';
+$strCompressionWillBeDetected = '         : %s';
 $strCompression = '';
+$strConfigDefaultFileError = '        : "%1$s"';
 $strConfigFileError = 'phpMyAdmin       !<br />      PHP           .<br />        -       PHP .  -   ,       .<br />    ,   .';
 $strConfigureTableCoord = '     %s';
 $strConnectionError = '     :  .';
@@ -171,26 +171,18 @@ $strDatabaseHasBeenDropped = '  %s  .';
 $strDatabaseNoTable = '    !';
 $strDatabasesDropped = '%s      .';
 $strDatabasesStatsDisable = ' ';
-$strDatabasesStatsEnable = ' ';
+$strDatabasesStatsEnable = '  ';
 $strDatabasesStatsHeavyTraffic = ':                  MySQL .';
 $strDatabasesStats = '    ';
 $strDatabases = '  ';
 $strDataDict = '  ';
 $strData = '';
 $strDataOnly = ' ';
+$strDataPages = '  ';
 $strDBComment = '    : ';
 $strDBCopy = '     ';
-$strDBGContextID = ' ID';
-$strDBGContext = '';
-$strDBGHits = '';
-$strDBGLine = '';
-$strDBGMaxTimeMs = '. , ms';
-$strDBGMinTimeMs = '. , ms';
-$strDBGModule = '';
-$strDBGTimePerHitMs = '/, ms';
-$strDBGTotalTimeMs = ' , ms';
 $strDbPrivileges = '     ';
-$strDBRename = '     '; 
+$strDBRename = '     ';
 $strDbSpecific = '    ';
 $strDefaultEngine = '%s         MySQL .';
 $strDefaultValueHelp = '   ,     ,     ,   : a';
@@ -202,7 +194,9 @@ $strDeleteAndFlush = '        .';
 $strDeleted = '  ';
 $strDeletedRows = ' :';
 $strDelete = '';
+$strDeleteNoUsersSelected = '     !';
 $strDeleting = '  %s';
+$strDelimiter = '';
 $strDelOld = '         .      ?';
 $strDescending = '';
 $strDescription = '';
@@ -212,7 +206,7 @@ $strDisableForeignChecks = '     ';
 $strDisplayFeat = ' ';
 $strDisplayOrder = ' :';
 $strDisplayPDF = ' PDF ';
-$strDoAQuery = ' "  " (   : "%")';
+$strDoAQuery = '  "  " (   : "%")';
 $strDocu = '';
 $strDoYouReally = '     ';
 $strDropDatabaseStrongWarning = '      !';
@@ -242,6 +236,7 @@ $strEnglish = '';
 $strEnglishPrivileges = ' :     MySQL    . ';
 $strErrorInZipFile = '  ZIP :';
 $strError = '';
+$strErrorRenamingTable = '     %1$s  %2$s';
 $strEsperanto = '';
 $strEstonian = '';
 $strExcelEdition = '  Excel';
@@ -262,16 +257,21 @@ $strFields = '';
 $strField = '';
 $strFileAlreadyExists = ' %s    ,         .';
 $strFileCouldNotBeRead = '     ';
+$strFileNameTemplateDescriptionDatabase = '    ';
+$strFileNameTemplateDescriptionServer = '  ';
+$strFileNameTemplateDescriptionTable = '  ';
 $strFileNameTemplateRemember = '  ';
 $strFileNameTemplate = '   ';
 $strFileToImport = '  ';
 $strFixed = '';
 $strFlushPrivilegesNote = ': phpMyAdmin          MySQL.                     .   ,   %s %s   .';
 $strFlushTable = '     ("FLUSH")';
+$strFontSize = '  ';
 $strFormat = '';
 $strFormEmpty = '     !';
 $strFullText = ' ';
 $strFunction = '';
+$strFunctions = '';
 
 $strGenBy = ' ';
 $strGeneralRelationFeat = '   ';
@@ -298,6 +298,7 @@ $strHomepageOfficial = '    phpMyAdmin ';
 $strHostEmpty = '    !';
 $strHost = '';
 $strHTMLExcelOptions = '    Microsoft Excel 2000';
+$strHTMLWordOptions = '    Microsoft Word 2000';
 $strHungarian = '';
 
 $strIcelandic = '';
@@ -306,11 +307,10 @@ $strIdxFulltext = '';
 $strIgnore = '';
 $strIgnoreDuplicates = '    ';
 $strIgnoreInserts = '  INSERT IGNORE';
-$strIgnoringFile = '   %s';
-$strImportDocSQL = ' docSQL ';
 $strImportFiles = '  ';
 $strImportFormat = '   ';
 $strImport = '';
+$strImportSuccessfullyFinished = '  .   %d .';
 $strIndexes = '';
 $strIndexHasBeenDropped = ' %s  ';
 $strIndexName = '  &nbsp;:';
@@ -325,16 +325,17 @@ $strInsecureMySQL = '     (root  ),       MySQL  .  MySQL             .       .'
 $strInsertAsNewRow = '   ';
 $strInsertedRowId = ' ID  :';
 $strInsertedRows = ' :';
-$strInsertNewRow = '   ';
 $strInsert = '';
 $strInternalNotNecessary = '*          InnoDB.';
 $strInternalRelations = ' ';
 $strInUse = '';
 $strInvalidColumn = '  (%s)!';
 $strInvalidColumnCount = '      -  .';
+$strInvalidDatabase = '   ';
 $strInvalidFieldAddCount = '     .';
 $strInvalidFieldCount = '      .';
 $strInvalidRowNumber = '%d      .';
+$strInvalidTableName = '   ';
 
 $strJapanese = '';
 $strJumpToDB = '     &quot;%s&quot;.';
@@ -347,6 +348,8 @@ $strKill = '';
 $strKorean = '';
 
 $strLandscape = '';
+$strLanguageFileNotFound = '  "%1$s"   .';
+$strLanguage = '';
 $strLatexCaption = '  ';
 $strLatexContent = '   __TABLE__';
 $strLatexContinuedCaption = '    ';
@@ -386,7 +389,7 @@ $strMIME_MIMEtype = 'MIME-';
 $strMIME_nodescription = '    .<br />         %s.';
 $strMIME_transformation = ' ';
 $strMIME_transformation_note = '         MIME-type    %s  %s';
-$strMIME_transformation_options_note = '          : \'a\',\'b\',\'c\'...<br />       ("\")    ("\'")   ,        ( \'\\\\xyz\'  \'a\\\'b\').';
+$strMIME_transformation_options_note = '          : \'a\', 100, b,\'c\'...<br />       ("\")    ("\'")   ,        ( \'\\\\xyz\'  \'a\\\'b\').';
 $strMIME_transformation_options = '  ';
 $strMIMETypesForTable = 'MIME   ';
 $strMIME_without = 'MIME-types          ';
@@ -402,6 +405,7 @@ $strMyISAMRecoverOptions = '   ';
 $strMyISAMRepairThreads = '  ';
 $strMyISAMSortBufferSize = '    ';
 $strMySQLCharset = '    MySQL';
+$strMysqlClientVersion = '    MySQL';
 $strMySQLConnectionCollation = '  MySQL';
 $strMySQLSaid = 'MySQL : ';
 $strMySQLShowProcess = 'MySQL ';
@@ -438,12 +442,13 @@ $strNotSet = '  <b>%s</b>         %s';
 $strNoUsersFound = ' ().';
 $strNoValidateSQL = ' Validate SQL';
 $strNull = '';
-$strNumberOfFields = '  ';
+$strNumberOfFields = ' ';
 $strNumSearchResultsInTable = '%s ()   <i>%s</i>';
 $strNumSearchResultsTotal = '<b>:</b> <i>%s</i> ()';
 $strNumTables = '';
 
 $strOK = 'OK';
+$strOpenNewWindow = '     phpMyAdmin';
 $strOperations = '';
 $strOperator = '';
 $strOptimizeTable = '  ';
@@ -462,6 +467,9 @@ $strPassword = '';
 $strPdfDbSchema = '     "%s" -  %s';
 $strPdfInvalidTblName = ' "%s"  !';
 $strPdfNoTables = ' ';
+$strPDFOptions = 'PDF ';
+$strPDFReportExplanation = '(      )';
+$strPDFReportTitle = '  ';
 $strPerHour = ' ';
 $strPerMinute = ' ';
 $strPerSecond = ' ';
@@ -481,8 +489,8 @@ $strPrimaryKeyName = '      ... PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b></b>     <b>  </b>  !)';
 $strPrimary = 'PRIMARY';
 $strPrint = '';
-$strPrintView = '  ';
 $strPrintViewFull = '   (  )';
+$strPrintView = '  ';
 $strPrivDescAllPrivileges = '    GRANT.';
 $strPrivDescAlterRoutine = '       .';
 $strPrivDescAlter = '      .';
@@ -520,7 +528,10 @@ $strPrivDescUpdate = '   .';
 $strPrivDescUsage = ' .';
 $strPrivileges = '';
 $strPrivilegesReloaded = '   .';
+$strProcedures = '';
+$strProcesses = '';
 $strProcesslist = '  ';
+$strProtocolVersion = '  ';
 $strPutColNames = '      ';
 
 $strQBEDel = '';
@@ -529,8 +540,9 @@ $strQBE = '  ';
 $strQueryCache = '  ';
 $strQueryFrame = '  ';
 $strQueryOnDb = 'SQL-     <b>%s</b>:';
+$strQueryResultsOperations = '    ';
 $strQuerySQLHistory = 'SQL-';
-$strQueryStatistics = '<b>  </b>:    , %s     .';
+$strQueryStatistics = '<b>  </b>:     %s     .';
 $strQueryTime = '  %01.4f ';
 $strQueryType = '  ';
 $strQueryWindowLock = '      ';
@@ -545,14 +557,14 @@ $strRelations = '';
 $strRelationsForTable = '  ';
 $strRelationView = '  ';
 $strReloadingThePrivileges = '  ';
-$strReloadMySQL = '  MySQL';
+$strReloadPrivileges = '  ';
 $strRemoveSelectedUsers = '   ';
 $strRenameDatabaseOK = '  %s    %s';
 $strRenameTable = '   ';
 $strRenameTableOK = ' %s    %s';
 $strRepairTable = '  ';
 $strReplaceNULLBy = ' NULL ';
-$strReplaceTable = '       ';
+$strReplaceTable = '        ';
 $strReplication = '';
 $strReset = '';
 $strResourceLimits = ' ';
@@ -573,7 +585,8 @@ $strRowsModeVertical = '';
 $strRowsStatistic = '  ';
 $strRunning = '  %s';
 $strRunQuery = ' ';
-$strRunSQLQuery = ' SQL /     %s';
+$strRunSQLQuery = '  SQL /     %s';
+$strRunSQLQueryOnServer = '  SQL /   %s';
 $strRussian = '';
 
 $strSaveOnServer = '     %s';
@@ -593,7 +606,7 @@ $strSecretRequired = '       (blowfish_secret).';
 $strSelectADb = '    ';
 $strSelectAll = '  ';
 $strSelectBinaryLog = '    ';
-$strSelectFields = '  ( ):';
+$strSelectFields = '   ( ):';
 $strSelectNumRows = ' ';
 $strSelectTables = ' ';
 $strSend = '';
@@ -601,9 +614,9 @@ $strSent = '';
 $strServerChoice = '  ';
 $strServer = '';
 $strServerNotResponding = '   ';
+$strServers = '';
 $strServerStatus = '    MySQL ';
 $strServerStatusUptime = ' MySQL    %s.    %s.';
-$strServerTabProcesslist = '';
 $strServerTabVariables = '';
 $strServerTrafficNotes = '<b>  </b>:         MySQL     .';
 $strServerVars = '   ';
@@ -618,6 +631,14 @@ $strShowGrid = ' ';
 $strShowingRecords = '   ';
 $strShowOpenTables = '   ';
 $strShowPHPInfo = '  PHP ';
+$strShowStatusCreated_tmp_filesDescr = '    mysqld  .';
+$strShowStatusDelayed_writesDescr = '    INSERT DELAYED .';
+$strShowStatusHandler_updateDescr = '       .';
+$strShowStatusHandler_writeDescr = '       .';
+$strShowStatusOpen_filesDescr = '   .';
+$strShowStatusOpen_streamsDescr = '    (    ).';
+$strShowStatusOpen_tablesDescr = '   .';
+$strShowStatusSort_rowsDescr = '   .';
 $strShowTableDimension = '   ';
 $strShowTables = ' ';
 $strShowThisQuery = '    ';
@@ -625,6 +646,7 @@ $strShow = '';
 $strSimplifiedChinese = ' ';
 $strSingly = '()';
 $strSize = '';
+$strSkipQueries = ' (),      ';
 $strSlovak = '';
 $strSlovenian = '';
 $strSortByKey = '  ';
@@ -633,8 +655,9 @@ $strSort = '';
 $strSpaceUsage = ' ';
 $strSpanish = '';
 $strSplitWordsWithSpace = '       (" ").';
-$strSQLExportCompatibility = '   SQL';
+$strSQLCompatibility = '    SQL';
 $strSQLExportType = '  ';
+$strSQLImportOptions = 'SQL ';
 $strSQLOptions = '   SQL';
 $strSQLParserBugMessage = '        SQL .   -,     .        ,           .                MySQL.    MySQL  -,   ,         .                  ,    SQL     ,           CUT  -:';
 $strSQLParserUserError = ',     SQL  .    MySQL   ,   ,         ';
@@ -653,7 +676,6 @@ $strStorageEngine = '  ';
 $strStorageEngines = '  ';
 $strStrucCSV = 'CSV ';
 $strStrucData = '  ';
-$strStrucDrop = '  \'DROP TABLE\'';
 $strStrucExcelCSV = 'CSV  MS Excel ';
 $strStrucOnly = ' ';
 $strStructPropose = '  ';
@@ -676,15 +698,17 @@ $strTableOfContents = '';
 $strTableOptions = '  ';
 $strTables = '%s ()';
 $strTableStructure = '  ';
-$strTableType = '  ';
 $strTable = ' ';
 $strTblPrivileges = '   ';
 $strTempData = ' ';
 $strTextAreaLength = '   ,<br />        ';
 $strThai = '';
+$strThemeDefaultNotFound = '   %s   !';
+$strThemeNotFound = ' %s   !';
+$strThemeNoValidImgPath = '       %s!';
 $strTheme = ' / ';
+$strThemePathNotFound = '      %s!';
 $strThisHost = ' ';
-$strThisNotDirectory = '   ';
 $strThreadSuccessfullyKilled = ' %s   .';
 $strThreads = '';
 $strTime = '';
@@ -693,12 +717,11 @@ $strTotalUC = '';
 $strTraditionalChinese = ' ';
 $strTraditionalSpanish = ' ';
 $strTraffic = '';
+$strTransactionCoordinator = '  ';
 $strTransformation_application_octetstream__download = '       a .        .              .    ,          .';
-$strTransformation_application_octetstream__hex = '    .';
 $strTransformation_image_jpeg__inline = ' thumbnail; : ,    (  )';
 $strTransformation_image_jpeg__link = '     (  , i.e.).';
 $strTransformation_image_png__inline = ' image/jpeg: inline';
-$strTransformation_text_plain__dateformat = '  TIME, TIMESTAMP  DATETIME         .     ( )       ( : 0).               PHP - strftime().';
 $strTransformation_text_plain__external = '  :           .     .    Tidy,    HTML .    ,      libraries/transformations/text_plain__external.inc.php           .                   .       1,     htmlspecialchars() (   1).       1,   NOWRAP    ,          (   1)';
 $strTransformation_text_plain__formatted = '    .';
 $strTransformation_text_plain__imagelink = '        ;      "http://domain.com/",      ,   .';
@@ -719,8 +742,11 @@ $strUpdateProfileMessage = '  .';
 $strUpdateQuery = ' ';
 $strUpdComTab = '           Column_comments ';
 $strUpgrade = '    %s %s  -.';
+$strUploadLimit = '        . ,    %sd%s        .';
+$strUploadsNotAllowed = '        .';
 $strUsage = '';
 $strUseBackquotes = '         ';
+$strUsedPhpExtensions = ' PHP ';
 $strUseHostTable = '  Host';
 $strUserAlreadyExists = ' %s  !';
 $strUserEmpty = '   !';
@@ -739,10 +765,13 @@ $strValidateSQL = ' SQL-';
 $strValidatorError = 'SQL      .       PHP ,      %s%s.';
 $strValue = '';
 $strVar = '';
+$strVersionInformation = '  ';
+$strView = '';
 $strViewDumpDatabases = '      ';
 $strViewDumpDB = '  ';
 $strViewDump = '  ';
 $strViewHasBeenDropped = ' %s  ';
+$strViewMaxExactCount = '     %s . ,    %s%s.';
 
 $strWebServerUploadDirectoryError = '     upload     ';
 $strWebServerUploadDirectory = '  upload   ';
@@ -751,10 +780,9 @@ $strWestEuropean = '-';
 $strWildcard = '  ';
 $strWindowNotFound = '       .                        ';
 $strWithChecked = '  :';
-$strWritingCommentNotPossible = '     ';
-$strWritingRelationNotPossible = '     ';
 $strWrongUser = ' /.  .';
 
+$strXMLOptions = 'XML ';
 $strXML = 'XML';
 
 $strYes = '';
@@ -763,15 +791,15 @@ $strZeroRemovesTheLimit = ':      0 ()  .';
 $strZip = '"zip-"';
 
 // To translate:
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
 
 $strBinaryLog = 'Binary log';  //to translate
-$strBinLogEventType = 'Event type';  //to translate
-$strBinLogInfo = 'Information';  //to translate
 $strBinLogName = 'Log name';  //to translate
 $strBinLogOriginalPosition = 'Original position';  //to translate
 $strBinLogPosition = 'Position';  //to translate
 $strBinLogServerId = 'Server ID';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
 $strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
 $strBufferPool = 'Buffer Pool';  //to translate
 $strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
@@ -781,16 +809,18 @@ $strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
 $strBufferWriteWaits = 'Write waits';  //to translate
 $strBusyPages = 'Busy pages';  //to translate
 
-$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
-$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
+$strCreateUserDatabase = 'Database for user';  //to translate
+$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
+$strCreateUserDatabaseNone = '';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strCSV = 'CSV';  //to translate
 
-$strDataPages = 'Pages containing data';  //to translate
-$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
 $strDirtyPages = 'Dirty pages';  //to translate
 
 $strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
+$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
 
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
 $strFlushQueryCache = 'Flush query cache';  //to translate
 $strFlushTables = 'Flush (close) all tables';  //to translate
 $strFreePages = 'Free pages';  //to translate
@@ -798,7 +828,6 @@ $strFreePages = 'Free pages';  //to translate
 $strHandler = 'Handler';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
@@ -809,12 +838,18 @@ $strInnoDBDataFilePath = 'Data files';  //to translate
 $strInnoDBDataHomeDir = 'Data home directory';  //to translate
 $strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
 $strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
 $strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
 
 $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
+$strLanguageUnknown = ' : %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 
 $strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
@@ -829,15 +864,20 @@ $strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table ind
 $strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
 
 $strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
+$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
-$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
+
+$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
+$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
+$strOpenDocumentText = 'Open Document Text';  //to translate
+$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
+$strPDF = 'PDF';  //to translate
 $strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
 
 $strReadRequests = 'Read requests';  //to translate
-$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
 
 $strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
 $strShowingBookmark = 'Showing bookmark';  //to translate
@@ -846,11 +886,9 @@ $strShowSlaveStatus = 'Show slave status';  //to translate
 $strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
 $strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
 $strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
-$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
 $strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
 $strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
 $strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
-$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
 $strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
 $strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
 $strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
@@ -862,8 +900,6 @@ $strShowStatusHandler_read_prevDescr = 'The number of requests to read the previ
 $strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
 $strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
 $strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
-$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
-$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
 $strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
 $strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
 $strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
@@ -917,9 +953,6 @@ $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
 $strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
-$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
-$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
-$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
 $strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
 $strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
 $strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
@@ -942,7 +975,6 @@ $strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken
 $strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
 $strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
 $strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
-$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
 $strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
 $strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
 $strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
@@ -950,54 +982,70 @@ $strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache.
 $strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
 $strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
 $strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
-$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStrucNativeExcel = 'Native MS Excel data';  //to translate
+$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 
 $strTakeIt = 'take it';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
 $strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
 $strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
 $strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
 $strToggleScratchboard = 'toggle scratchboard';  //to translate
-$strTransactionCoordinator = 'Transaction coordinator';  //to translate
+$strTransformation_application_octetstream__hex = '    . Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
 
 $strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
-$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
-
-$strVersionInformation = 'Version information';  //to translate
-$strView = 'View';  //to translate
 
 $strWriteRequests = 'Write requests';  //to translate
 
-$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
-$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
-$strFileNameTemplateDescriptionTable = 'table name';  //to translate
-$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
-$strFileNameTemplateDescriptionServer = 'server name';  //to translate
-$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
-$strProtocolVersion = 'Protocol version';  //to translate
-$strMysqlClientVersion = 'MySQL client version';  //to translate
-$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
-$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
-$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
-$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
-$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
-$strPDF = 'PDF';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
-$strPDFReportTitle = 'Report title';  //to translate
-$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
-$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
-$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
-$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strThemeNotFound = 'Theme %s not found!';  //to translate
-$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
-$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
-$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
-$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
-$strBrowseDistinctValues = 'Browse distinct values';  //to translate
-$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
-$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
