@@ -1,5 +1,5 @@
 <?php
-/* $Id: catalan-iso-8859-1.inc.php,v 2.156.2.1 2006/08/18 17:02:39 lem9 Exp $ */
+/* $Id: catalan-iso-8859-1.inc.php 9879 2007-01-29 17:36:33Z lem9 $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr'; // ('ltr' d'esquerra a dreta, 'rtl' de dreta a esquerra)
@@ -16,7 +16,6 @@ $month = array('Gen', 'Feb', 'Mar', 'Abr', 'Mai', 'Jun', 'Jul', 'Ago', 'Set', 'O
 $datefmt = '%d-%m-%Y a les %H:%M:%S';
 
 $strAbortedClients = 'Avortat';
-$strAbsolutePathToDocSqlDir = 'S\'ha d\'entrar el cam absolut en el servidor web per el directori de docSQL';
 $strAccessDenied = 'Accs denegat';
 $strAccessDeniedCreateConfig = 'La ra ms probable d\'aix s que no heu creat l\'arxiu de configuraci. Podriau voler utilitzar %1$ssetup script%2$s per crear-ne un.';
 $strAccessDeniedExplanation = 'phpMyAdmin ha intentat connectar amb el servidor de MySQL, pero el servidor ha rebutjat la connexi. Comprova el host, el num d\' usuari i la contrasenya a l\'arxiu config.inc.php i mira que es correspongui amb la informaci facilitada per l\' administrador del servidor de MySQL.';
@@ -26,8 +25,6 @@ $strAddClause = 'Afegir %s';
 $strAddConstraints = 'Afegir restriccions';
 $strAddDeleteColumn = 'Afegir/esborrar Camps de Columna';
 $strAddDeleteRow = 'Afegir/esborrar fila de criteri';
-$strAddedColumnComment = 'Afegit comentari per la columna';
-$strAddedColumnRelation = 'Afegida relaci per la columna';
 $strAddFields = 'Afegir %s camp(s)';
 $strAddHeaderComment = 'Afegir comentari personalitzat a la capalera (\\n divideix linies)';
 $strAddIntoComments = 'Afegir en comentaris';
@@ -52,6 +49,7 @@ $strAlterOrderBy = 'Altera la taula i ordena per';
 $strAnalyzeTable = 'Analitza la taula';
 $strAnd = 'I';
 $strAndThen = 'i llavors';
+$strAngularLinks = 'Enllaos angulars';
 $strAnIndex = 'S\'ha afegit un ndex a %s';
 $strAnyHost = 'Qualsevol servidor';
 $strAny = 'Qualsevol';
@@ -104,6 +102,7 @@ $strBzError = 'phpMyAdmin s incapa de comprimir el bolcat degut a una extensi Bz
 $strBzip = '"comprimit amb bzip"';
 
 $strCalendar = 'Calendari';
+$strCancel = 'Cancel.lar';
 $strCanNotLoadExportPlugins = 'No es poden carregar les extensions d\'exportaci, comprova l\'instal.laci!';
 $strCanNotLoadImportPlugins = 'No es poden carregar les extensions d\'importaci, comprova l\'instal.laci!';
 $strCannotLogin = 'No podem connectar amb el servidor MySQL';
@@ -167,6 +166,8 @@ $strCreateNewDatabase = 'Crea una nova base de dades';
 $strCreateNewTable = 'Crear una taula nova a la base de dades %s';
 $strCreatePage = 'Crea una nova Pgina';
 $strCreatePdfFeat = 'Creaci de PDFs';
+$strCreateRelation = 'Crear relaci';
+$strCreateTable  = 'Crear taula';
 $strCreateUserDatabase = 'Base de dades per usuari';
 $strCreateUserDatabaseName = 'Crear base de dades amb el mateix nom i atorgar tots els permissos';
 $strCreateUserDatabaseNone = 'Cap';
@@ -199,15 +200,7 @@ $strDataOnly = 'Noms dades';
 $strDataPages = 'Pgines contenint dades';
 $strDBComment = 'Comentaris de la Base de Dades: ';
 $strDBCopy = 'Copiar base de dades a';
-$strDBGContext = 'Contexte';
-$strDBGContextID = 'ID de contexte';
-$strDBGHits = 'Accessos';
-$strDBGLine = 'Linia';
-$strDBGMaxTimeMs = 'Temps max, ms';
-$strDBGMinTimeMs = 'Temps min, ms';
-$strDBGModule = 'Mdul';
-$strDBGTimePerHitMs = 'Temps/Accs, ms';
-$strDBGTotalTimeMs = 'Temps total, ms';
+$strDbIsEmpty = 'La base de dades sembla buida!';
 $strDbPrivileges = 'Permissos especifics de Base de dades';
 $strDBRename = 'Reanomenar base de dades a';
 $strDbSpecific = 'especfic de la base de dades';
@@ -222,12 +215,16 @@ $strDeletedRows = 'Files esborrades:';
 $strDeleted = 'S\'ha esborrat la fila';
 $strDelete = 'Esborrar';
 $strDeleteNoUsersSelected = 'No s\han triat usuaris per esborrar!';
+$strDeleteRelation = 'Esborrar relaci';
 $strDeleting = 'Esborrant %s';
 $strDelimiter = 'Separador';
 $strDelOld = 'La pgina actual t referncies a taules que no existeixen. Vols esborrar aquestes referncies?';
 $strDescending = 'Descendent';
 $strDescription = 'Descripci';
+$strDesigner = 'Dissenyador';
+$strDesignerHelpDisplayField = 'El camp a visualitzar es mostra en rosa. Per establir/treure un camp com a camp de visualitzaci, clica la icona "Tria camp a visualitzar", i clica tamb en el nom de camp adient.';
 $strDictionary = 'diccionari';
+$strDirectLinks = 'Enllaos directes';
 $strDirtyPages = 'Pgines brutes';
 $strDisabled = 'Desactivat';
 $strDisableForeignChecks = 'Desactivar comprovacions de claus externes';
@@ -235,6 +232,8 @@ $strDisplayFeat = 'Mostrar caracterstiques';
 $strDisplayOrder = 'Ordre del llistat:';
 $strDisplayPDF = 'Mostrar esquema PDF';
 $strDoAQuery = 'Fer una "petici segons exemple" (comod: "%")';
+$strDocSQL = 'DocSQL';
+$strDocSQLOptions = 'Opcions de DocSQL';
 $strDocu = 'Documentaci';
 $strDoYouReally = 'Realment vols fer?';
 $strDropDatabaseStrongWarning = 'Ets a punt d\' ELIMINAR completament una base de dades!';
@@ -264,7 +263,10 @@ $strEnglish = 'Angls';
 $strEnglishPrivileges = ' Nota: Els noms dels privilegis del MySQL sn en idioma angls ';
 $strError = 'Errada';
 $strErrorInZipFile = 'Error en arxiu ZIP:';
+$strErrorRelationAdded = 'Error: La relaci no s\'ha afegit.';
+$strErrorRelationExists = 'Error: La relaci ja existeix.';
 $strErrorRenamingTable = 'Error reanomenant la taula %1$s a %2$s';
+$strErrorSaveTable = 'Error desant coordenades per al Dissenyador.';
 $strEscapeWildcards = 'Els comodins _ i % han de marcar-se amb una \ per usar-los literalment';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estoni ';
@@ -273,6 +275,7 @@ $strExcelOptions = 'Opcions d\'Excel';
 $strExecuteBookmarked = 'Executa una consulta desada';
 $strExplain = 'Explicaci de l\'SQL';
 $strExport = 'Exportar';
+$strExportImportToScale = 'Exporta/Importa a escala';
 $strExportMustBeFile = 'El tipus d\'exportaci triat s\'ha de desar en un arxiu!';
 $strExtendedInserts = 'Insercions ampliades';
 $strExtra = 'Extra';
@@ -300,6 +303,7 @@ $strFlushQueryCache = 'Buidar la memria intermdia de consultes';
 $strFlushTable = 'Buidar la memria cau de la taula ("FLUSH")';
 $strFlushTables = 'Sincronitzar (tancar) totes les taules';
 $strFontSize = 'Tamany de lletra';
+$strForeignKeyError = 'Error creant clau externa (comprova els tipus de dades)';
 $strFormat = 'Format';
 $strFormEmpty = 'Falta un valor al formulari !';
 $strFreePages = 'Pgines lliures';
@@ -327,7 +331,11 @@ $strHasBeenAltered = 'ha estat alterada.';
 $strHasBeenCreated = 'ha estat creada.';
 $strHaveToShow = 'Has de triar al menys una columna per mostrar';
 $strHebrew = 'Hebreu';
+$strHelp = 'Ajuda';
 $strHexForBinary = 'Usa hexadecimal per camps binaris';
+$strHide         = 'Amaga';
+$strHideShowAll = 'Amaga/Mostra tot';
+$strHideShowNoRelation = 'Amaga/Mostra taules sense relacions';
 $strHome = 'Inici';
 $strHomepageOfficial = 'Pgina oficial del phpMyAdmin';
 $strHostEmpty = 'El nom del servidor s buit!';
@@ -341,11 +349,11 @@ $strHungarian = 'Hngar';
 $strIcelandic = 'Islands';
 $strId = 'ID';
 $strIdxFulltext = 'Text sencer';
+$strIEUnsupported = 'Internet Explorer no suporta aquesta funci.';
 $strIgnoreDuplicates = 'Ignorar files duplicades';
 $strIgnore = 'Ignora';
 $strIgnoreInserts = 'Utilitzar "ignore inserts"';
-$strIgnoringFile = 'Ignorant arxiu %s';
-$strImportDocSQL = 'Importa Arxius docSQL';
+$strImportExportCoords = 'Importa/Exporta coordenades per a esquema PDF';
 $strImportFiles = 'Importar arxius';
 $strImportFormat = 'Format de l\'arxiu importat';
 $strImport = 'Importar';
@@ -367,6 +375,7 @@ $strInnoDBDataFilePath = 'Arxius de dades';
 $strInnoDBDataHomeDirDesc = 'La part comuna de la ruta al directori per tots els arxius de dades InnoDB.';
 $strInnoDBDataHomeDir = 'Directori local de dades';
 $strInnoDBPages = 'pgines';
+$strInnoDBRelationAdded = 'Afegida relaci InnoDB';
 $strInnodbStat = 'Estat InnoDB';
 $strInsecureMySQL = 'El vostre arxiu de configuraci t parmetres (root sense contrasenya) que corresponen al compte privilegiat predetermitat de MySQL. El servidor MySQL est funcionant amb aquests valors, el que significa un forat de seguretat, i s\'exposa a intrusions, pel que recomanem la reparaci urgent d\'aquest forat de seguretat.';
 $strInsertAsNewRow = 'Inserir com a nova fila';
@@ -374,6 +383,7 @@ $strInsertedRowId = 'Id de la fila inserida:';
 $strInsertedRows = 'Files Inserides:';
 $strInsert = 'Insereix';
 $strInternalNotNecessary = '* No es necessita una relaci interna si ja existeix a InnoDB.';
+$strInternalRelationAdded = 'Afegida relaci interna';
 $strInternalRelations = 'Relacions internes';
 $strInUse = 'en s';
 $strInvalidAuthMethod = 'Mtode d\'identificaci incorrecte establert a la configuraci:';
@@ -401,6 +411,7 @@ $strKeepPass = 'No canvis la contrasenya';
 $strKeyCache = 'Memria intermdia de claus';
 $strKeyname = 'Nom Clau';
 $strKill = 'Finalitzar';
+$strKnownExternalBug = 'La funcionalitat %s es veu afectada per un error conegut, veieu %s';
 $strKorean = 'Core';
 
 $strLandscape = 'Horitzontal';
@@ -448,7 +459,7 @@ $strMIME_description = 'Descripci';
 $strMIME_MIMEtype = 'Tipus MIME';
 $strMIME_nodescription = 'No hi ha cap descripci disponible per a aquesta transformaci.<br />Demana a l\'autor qu fa %s.';
 $strMIME_transformation_note = 'Per veure una llista d\'opcions de transformaci disponibles i els seus tipus MIME de  transformaci, prem a %sdescripcions de transformaci%s';
-$strMIME_transformation_options_note = 'Entra els valors per a transformar utilitzant aquest format: \'a\',\'b\',\'c\'...<br />Si mai necessites escriure una barra invertida ("\") o un apstrof ("\'") entre aquests valors, posa una barra invertida devant (per exemple \'\\\\xyz\' o \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Entra els valors per a transformar utilitzant aquest format: \'a\', 100, b,\'c\'...<br />Si mai necessites escriure una barra invertida ("\") o un apstrof ("\'") entre aquests valors, posa una barra invertida devant (per exemple \'\\\\xyz\' o \'a\\\'b\').';
 $strMIME_transformation_options = 'Opcions de Transformaci';
 $strMIME_transformation = 'Transformaci del Navegador';
 $strMIMETypesForTable = 'TIPUS MIME PER LA TAULA';
@@ -456,6 +467,7 @@ $strMIME_without = 'Els tipus MIME en cursiva no tenen funcions de transformaci
 $strModifications = 'Les modificacions han estat desades';
 $strModifyIndexTopic = 'Modifica un ndex';
 $strModify = 'Modificar';
+$strMoveMenu = 'Men Mou';
 $strMoveTable = 'Mou taula a (base-de-dades<b>.</b>taula):';
 $strMoveTableOK = 'Taula %s moguda a %s.';
 $strMoveTableSameNames = 'No es pot moure la taula sobre ella mateixa!';
@@ -514,6 +526,7 @@ $strNoUsersFound = 'No s\'han trobat usuaris.';
 $strNoValidateSQL = 'Saltar la Validaci de l\'SQL';
 $strNull = 'Nul';
 $strNumberOfFields = 'Nombre de camps';
+$strNumberOfTables = 'Nombre de taules';
 $strNumSearchResultsInTable = '%s resultat(s) a la taula <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> resultat(s)';
 $strNumTables = 'Taules';
@@ -556,8 +569,10 @@ $strPhoneBook = 'Libreta d\' adreces';
 $strPHP40203 = 'S\'est fent servir la versi 4.2.3 de PHP, que t un serios error amb cadenes de multi-byte (mbstring). Mira l\'informe d\'error 19404 de PHP. No es recomana aquesta versi de PHP per treballar amb phpMyAdmin.';
 $strPhp = 'Crear codi PHP';
 $strPHPVersion = 'PHP versi';
+$strPleaseSelectPrimaryOrUniqueKey = 'Tria la clau principal o una clau nica';
 $strPmaDocumentation = 'Documentaci de phpMyAdmin';
 $strPmaUriError = 'La directiva <tt>$cfg[\'PmaAbsoluteUri\']</tt> HA d\'estar a l\'arxiu de configuraci!';
+$strPmaWiki = 'wiki del phpMyAdmin';
 $strPolish = 'Polac';
 $strPortrait = 'Vertical';
 $strPos1 = 'Inici';
@@ -628,16 +643,19 @@ $strQueryWindowLock = 'No sobreescriure aquesta consulta des de fora de la fines
 
 $strReadRequests = 'Peticions de lectura';
 $strReceived = 'Rebut';
+$strRecommended = 'recomanat';
 $strRecords = 'Registres';
 $strReferentialIntegrity = 'Comprova la integritat referencial:';
 $strRefresh = 'Actualitzar';
 $strRelationalSchema = 'Esquema Relacional';
+$strRelationDeleted = 'Relaci esborrada';
 $strRelationNotWorking = 'Les caracterstiques addicionals per treballar amb taules enllaades s\'han desactivat. Per saber perqu prem a %saqu%s.';
 $strRelationsForTable = 'RELACIONS DE LA TAULA';
 $strRelations = 'Relacions';
 $strRelationView = 'Vista de Relacions';
 $strReloadingThePrivileges = 'Recarregant permissos';
 $strReloadPrivileges = 'Recarregar permissos';
+$strReload = 'Recarregar';
 $strRemoveSelectedUsers = 'Treure els usuaris triats';
 $strRenameDatabaseOK = 'Base de dades %s reanomenada a %s';
 $strRenameTableOK = 'La taula %s ha canviat de nom. Ara es diu %s';
@@ -671,6 +689,7 @@ $strRussian = 'Rus';
 
 $strSave = 'Desar';
 $strSaveOnServer = 'Desar al servidor al directori %s';
+$strSavePosition = 'Desar posici';
 $strScaleFactorSmall = 'El factor de l\'escala s massa petit per posar l\'esquema en una pgina';
 $strSearch = 'Cercar';
 $strSearchFormTitle = 'Cercar a la base de dades';
@@ -687,7 +706,9 @@ $strSelectADb = 'Tria una Base de Dades';
 $strSelectAll = 'Tria Tot';
 $strSelectBinaryLog = 'Tria el registre binari per veure';
 $strSelectFields = 'Tria els camps (un com a mnim):';
+$strSelectForeignKey = 'Triar clau externa';
 $strSelectNumRows = 'en consulta';
+$strSelectReferencedKey = 'Tria la clau referenciada';
 $strSelectTables = 'Tria Taules';
 $strSend = 'enviar';
 $strSent = 'Enviat';
@@ -709,8 +730,11 @@ $strShowColor = 'Mostra color';
 $strShowDatadictAs = 'Format del Diccionari de Dades';
 $strShowFullQueries = 'Mostra Consultes completes';
 $strShowGrid = 'Mostra graella';
+$strShowHideLeftMenu = 'Men esquerre Mostra/Amaga';
 $strShowingBookmark = 'Mostrant consultes desades';
+$strShowingPhp = 'Mostrant com a codi PHP';
 $strShowingRecords = 'Mostrant registres: ';
+$strShowingSQL = 'Mostrant consulta SQL';
 $strShow = 'Mostra';
 $strShowOpenTables = 'Mostrar taules obertes';
 $strShowPHPInfo = 'Mostra informaci de PHP';
@@ -832,6 +856,8 @@ $strSize = 'Mida';
 $strSkipQueries = 'Nombre de registres(consultes) a saltar des de l\'inici';
 $strSlovak = 'Eslovac';
 $strSlovenian = 'Eslov';
+$strSmallBigAll = 'Tot Petit/Gran';
+$strSnapToGrid = 'Aliniar a la graella';
 $strSocketProblem = '(o el scol del servidor local MySQL no est configurat correctament)';
 $strSortByKey = 'Classifica per la clau';
 $strSort = 'Classificaci';
@@ -851,6 +877,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Identificador Incorrecte';
 $strSQPBugUnclosedQuote = 'Cometa no tancada';
 $strSQPBugUnknownPunctuation = 'Signe de puntuaci desconegut';
+$strStandInStructureForView = 'Stand-in estructura per a vista';
 $strStatCheckTime = 'Darrera comprovaci';
 $strStatCreateTime = 'Creaci';
 $strStatement = 'Sentncies';
@@ -867,6 +894,7 @@ $strStrucNativeExcelOptions = 'Opcions d\'exportaci natives d\'Excel';
 $strStrucOnly = 'Noms l\'estructura';
 $strStructPropose = 'Proposa una estructura de taula';
 $strStructure = 'Estructura';
+$strStructureForView = 'Estructura per a vista';
 $strSubmit = 'Enviar';
 $strSuccess = 'La vostra comanda SQL ha estat executada amb xit';
 $strSum = 'Suma';
@@ -880,7 +908,9 @@ $strTableEmpty = 'El nom de la taula s buit!';
 $strTableHasBeenDropped = 'S\'ha esborrat la taula %s';
 $strTableHasBeenEmptied = 'S\'ha buidat la taula %s';
 $strTableHasBeenFlushed = 'S\'ha buidat la memria cau de la taula %s';
+$strTableIsEmpty = 'La taula sembla buida!';
 $strTableMaintenance = 'Manteniment de la taula';
+$strTableName = 'Nom de taula';
 $strTableOfContents = 'Taula de continguts';
 $strTableOptions = 'Opcions de Taula';
 $strTables = '%s taula(es)';
@@ -898,14 +928,16 @@ $strThemeNoValidImgPath = 'El cam de les imatges del tema %s s incorrecte!';
 $strThemePathNotFound = 'No s\'ha trobat el cam de les imatges del tema %s!';
 $strTheme = 'Tema / Estil';
 $strThisHost = 'Aquest Host';
-$strThisNotDirectory = 'Aix no s un directori';
 $strThreads = 'Fils';
 $strThreadSuccessfullyKilled = 'Fil %s cancel.lat correctament.';
 $strTimeoutInfo = 'La darrera importaci ha esgotat el temps, desprs de reenviar continuar des de la posici %d.';
 $strTimeoutNothingParsed = 'Per a la darrera importaci no s\'han processat dades, el que normalment indica que phpMyAdmin no ha pogut finalitzar aquesta importaci a menys que incrementeu els lmits de temps de php.';
 $strTimeoutPassed = 'Temps exaurit de l\'arxiu d\'ordres, si voleu finalitzar l\'importaci, torneu a enviar el mateix arxiu a importar i el procs continuar.';
 $strTime = 'Temps';
+$strToFromPage = 'plana a/de';
 $strToggleScratchboard = 'Canvia l\' scratchboard';
+$strToggleSmallBig = 'Canviar petit/gran';
+$strToSelectRelation = 'Per triar una relaci, clica :';
 $strTotal = 'total';
 $strTotalUC = 'Total';
 $strTraditionalChinese = 'Xins Tradicional';
@@ -917,7 +949,7 @@ $strTransformation_application_octetstream__hex = 'Mostra la representaci hexade
 $strTransformation_image_jpeg__inline = 'Mostra una miniatura amb enlla; opcions: ample,alt en pixels (respecta la proporci original)';
 $strTransformation_image_jpeg__link = 'Es mostra com a enlla a la imatge.';
 $strTransformation_image_png__inline = 'Veure image/jpeg: en linia';
-$strTransformation_text_plain__dateformat = 'Pren un camp TIME, TIMESTAMP o DATETIME i li dona format utilitzant el format d\'hora local. La primera opci es la diferncia (en hores) que s\'ha d\'afegir a l\'hora (Per defecte: 0). La segona opci s un format de data diferent d\'acord als parmetres disponibles per a la funci de PHP strftime().';
+$strTransformation_text_plain__dateformat = 'Mostra un camp TIME, TIMESTAMP, DATETIME o camp de data unix com a data formatejada. La primera opci s la diferncia (en hores) que s\'afegirn a la data (Defecte: 0). Usa la segona opci per indicar un format diferent de data/hora. La tercera opci determina si es vol visualitzar l\'hora local o UTC (usant els texts "local" o "utc"). Segons aix, el format de data t diferent valor - per a "local" veieu la documentaci de la funci strftime() de PHP i per a "utc" s\'obt amb l\'s de la funci gmdate().';
 $strTransformation_text_plain__external = 'NOMS LINUX: Llena una aplicaci externa i facilita el camp de dades via standard input. Retorna per standard output de l\'aplicaci. El defecte s Tidy, per interpretar codi HTML. Per raons de seguretat, has d\' editar manualment l\'arxiu libraries/transformations/text_plain__external.inc.php i afegir les eines que vulguis fer servir. La primera opci s, llavors, el numero del programa que vols fer servir i la segona opci sn els parmetres per el programa. El tercer parmetre, si es posa a 1, convertir la sortida fent servir htmlspecialchars() (El defecte s 1). El quart parmetre, si val 1, posar un NOWRAP al contingut de les cel.les de forma que la sortida sencera es mostrar sense reformatejar (Per defecte 1)';
 $strTransformation_text_plain__formatted = 'Conserva el format original del camp. No es fa cap canvi.';
 $strTransformation_text_plain__imagelink = 'Mostra una imatge i un enlla, el camp cont el nom de l\'arxiu; la primera opci s un prefixe com "http://domini.com/", la segona opci s l\'amplada en pixels, la tercera s l\'alada.';
@@ -979,8 +1011,6 @@ $strWildcard = 'comodins';
 $strWindowNotFound = 'La finestra dest del navegador no s\'ha pogut actualitzar. Potser has tancat la finestra "pare" o b el teu navegador bloqueja actualitzacions entre finestres per la teva configuraci de seguretat';
 $strWithChecked = 'Amb marca:';
 $strWriteRequests = 'Peticions d\'escriptura';
-$strWritingCommentNotPossible = 'No es pot desar aquest comentari';
-$strWritingRelationNotPossible = 'No es pot desar aquesta relaci';
 $strWrongUser = 'Usuari i/o clau erronis. Accs denegat.';
 
 $strXMLOptions = 'Opcions XML';
@@ -988,7 +1018,7 @@ $strXML = 'XML';
 
 $strYes = 'Si';
 
-$strZeroRemovesTheLimit = 'Nota: Establint aquestes opcions a 0 (zero) treu el limit.';
+$strZeroRemovesTheLimit = 'Nota: Es treu el limit establint aquestes opcions a 0 (zero).';
 $strZip = '"comprimit amb zip"';
 
 ?>
