@@ -1,5 +1,5 @@
 <?php
-/* $Id: chinese_simplified-gb2312.inc.php,v 2.110.2.1 2006/08/30 10:43:14 nijel Exp $ */
+/* $Id: chinese_simplified-gb2312.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Last translation by: Funda Wang <fundawang@en2china.com>
@@ -24,7 +24,6 @@ $datefmt = '%Y  %m  %d  %H:%M';
 $timespanfmt = '%s  %s Сʱ%s  %s ';
 
 $strAbortedClients = 'ֹ';
-$strAbsolutePathToDocSqlDir = ' docSQL Ŀ¼վľ·';
 $strAccessDenied = 'ʱܾ';
 $strAccessDeniedExplanation = 'phpMyAdmin ͼӵ MySQL ܾӡӦü config.inc.php еû룬ȷЩϢ MySQL ĹԱϢһ¡';
 $strAction = '';
@@ -32,8 +31,6 @@ $strAddAutoIncrement = ' AUTO_INCREMENT ֵ';
 $strAddConstraints = 'ǿ';
 $strAddDeleteColumn = '/ɾֶ';
 $strAddDeleteRow = '/ɾ';
-$strAddedColumnComment = 'ע';
-$strAddedColumnRelation = 'йϵ';
 $strAddFields = ' %s ֶ';
 $strAddHeaderComment = 'ڱһƵע (\\n и)';
 $strAddIntoComments = 'ӽע';
@@ -179,15 +176,6 @@ $strDataDict = 'ֵ';
 $strDataOnly = 'ֻ';
 $strDBComment = 'ݿעͣ';
 $strDBCopy = 'ݿ⵽';
-$strDBGContext = '';
-$strDBGContextID = ' ID';
-$strDBGHits = '';
-$strDBGLine = '';
-$strDBGMaxTimeMs = 'ʱ䣬';
-$strDBGMinTimeMs = 'Сʱ䣬';
-$strDBGModule = 'ģ';
-$strDBGTimePerHitMs = 'ʱ/Σ';
-$strDBGTotalTimeMs = 'ܼʱ䣬';
 $strDbPrivileges = 'ݿָȨ';
 $strDBRename = 'ݿΪ ';
 $strDbSpecific = 'ݿָ';
@@ -294,8 +282,6 @@ $strId = 'ID'; // use eng
 $strIdxFulltext = 'ȫ';
 $strIgnore = '';
 $strIgnoreInserts = 'Բ';
-$strIgnoringFile = 'ļ %s';
-$strImportDocSQL = ' docSQL ĵ';
 $strImportFiles = 'ļ';
 $strIndex = '';
 $strIndexes = '';
@@ -361,7 +347,7 @@ $strMIME_description = '';
 $strMIME_MIMEtype = 'MIME ';
 $strMIME_nodescription = '˱任޿õ<br />ϸѯ %s ߡ';
 $strMIME_transformation_note = 'Ҫÿñ任ѡ嵥Ӧ MIME ͱ任뵥%s任%s';
-$strMIME_transformation_options_note = 'ʹô˸ʽ任ѡֵ\'a\',\'b\',\'c\'...<br />Ҫֵ뷴б(\)ߵ(\')ǰϷб( \'\\\\xyz\'  \'a\\\'b\')';
+$strMIME_transformation_options_note = 'ʹô˸ʽ任ѡֵ\'a\', 100, b,\'c\'...<br />Ҫֵ뷴б(\)ߵ(\')ǰϷб( \'\\\\xyz\'  \'a\\\'b\')';
 $strMIME_transformation_options = '任ѡ';
 $strMIME_transformation = '任';
 $strMIMETypesForTable = 'MIME ͱ';
@@ -639,7 +625,6 @@ $strTextAreaLength = ' ڳ<br />ֶο޷༭ ';
 $strThai = '̩';
 $strTheme = ' / ';
 $strThisHost = '';
-$strThisNotDirectory = 'ⲢһĿ¼';
 $strThreadSuccessfullyKilled = '߳ %s ѳɹɱ';
 $strTime = 'ʱ';
 $strToggleScratchboard = 'лΰ';
@@ -652,7 +637,6 @@ $strTransformation_application_octetstream__download = 'ֶʾһļӡһѡǶݵ֡ڶѡ
 $strTransformation_image_jpeg__inline = 'ʾɵͼѡָĿȡ߶(ԭб)';
 $strTransformation_image_jpeg__link = 'ʾͼ(ֱӶ)';
 $strTransformation_image_png__inline = '鿴 image/jpeg: Ƕ';
-$strTransformation_text_plain__dateformat = 'ѡ TIMETIMESTAMP  DATETIME ֶβıڸʽиʽһѡǽ뵽ʱеƫ(СʱΪλĬΪ 0)ڶѡǸ PHP  strftime() ĸʽдĲͬڸʽ';
 $strTransformation_text_plain__external = 'ֻ LINUXⲿͨ׼ֶݡشӦóı׼ĬΪ TidyԺܺõĴӡ HTML 롣Ϊ˰ȫҪֶ༭ļ libraries/transformations/text_plain__external.inc.php ȻеĹߡһѡҪʹõĳţڶѡǳĲڵΪ 1 Ļ htmlspecialchars() ת(ĬΪ 1)ĸΪ 1 ĻݵԪ NOWRAPȫͻ᲻¸ʽֱ(ĬΪ 1)';
 $strTransformation_text_plain__formatted = 'ֶεԭʼʽת롣';
 $strTransformation_text_plain__imagelink = 'ʾͼӣֶڰļһѡơhttp://domain.com/ǰ׺ڶѡΪλĿȣǸ߶ȡ';
@@ -704,8 +688,6 @@ $strWestEuropean = 'ŷ';
 $strWildcard = 'ͨ';
 $strWindowNotFound = 'Ŀڲɸ¡Ѿر˸ڻİȫ˸´ڡ';
 $strWithChecked = 'ѡ';
-$strWritingCommentNotPossible = 'дע';
-$strWritingRelationNotPossible = 'дϵ';
 $strWrongUser = 'û/󣬷ʱܾ';
 
 $strXML = 'XML'; //USE ENG
@@ -1008,7 +990,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1023,4 +1005,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
