@@ -1,5 +1,5 @@
 <?php
-/* $Id: chinese_traditional-big5.inc.php,v 2.114.2.1 2006/08/30 10:43:14 nijel Exp $ */
+/* $Id: chinese_traditional-big5.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Last translation by: Siu Sun <siusun@best-view.net>
@@ -24,7 +24,6 @@ $datefmt = '%B %d, %Y, %I:%M %p';
 $timespanfmt = '%s , %s p, %s  %s ';
 
 $strAbortedClients = '';
-$strAbsolutePathToDocSqlDir = 'пJ docSQL ؿA|';
 $strAccessDenied = 'ڵs';
 $strAccessDeniedCreateConfig = 'iAإ߳]w. AiQΦ %1$sw˵{%2$s إ߳]w.';
 $strAccessDeniedExplanation = 'phpMyAdmin ճsu MySQL A, AڵFsu. z config.inc.php ˬdDW, nJW٤αKXνTOoǸƬOPtκ޲zHҴѪ MySQL AƬۦP';
@@ -33,8 +32,6 @@ $strAddAutoIncrement = "sW AUTO_INCREMENT ƭ";
 $strAddConstraints = '[J';
 $strAddDeleteColumn = 'sW/ ';
 $strAddDeleteRow = 'sW/ zC';
-$strAddedColumnComment = 'HU[JѤr';
-$strAddedColumnRelation = 'HU[Jp';
 $strAddFields = 'sW %s ';
 $strAddHeaderComment = 'D[JӤH (\\n }s)';
 $strAddIntoComments = '[JѤr';
@@ -200,15 +197,6 @@ $strDataOnly = 'u';
 $strDataPages = ']tƭ';
 $strDBComment = 'ƮwѤr: ';
 $strDBCopy = 'ƻsƮw';
-$strDBGContext = ' (Context)';
-$strDBGContextID = ' (Context) ID';
-$strDBGHits = '';
-$strDBGLine = '';
-$strDBGMaxTimeMs = '̤jɶ, ms';
-$strDBGMinTimeMs = '̤pɶ, ms';
-$strDBGModule = 'Ҳ';
-$strDBGTimePerHitMs = 'ɶ/, ms';
-$strDBGTotalTimeMs = '`ɶ, ms';
 $strDbPrivileges = 'wƮwv';
 $strDBRename = 'ƮwW٨';
 $strDbSpecific = 'wƮw';
@@ -339,9 +327,7 @@ $strIdxFulltext = '˯';
 $strIgnore = '';
 $strIgnoreDuplicates = 'LЦC';
 $strIgnoreInserts = 'ϥΩ[J (insert)'; 
-$strIgnoringFile = 'ɮ %s';
 $strImport = 'J';
-$strImportDocSQL = 'Ū docSQL ɮ';
 $strImportFiles = 'Jɮ';
 $strImportFormat = 'Jɮ׮榡';
 $strImportSuccessfullyFinished = 'J\, @ %d yykw.';
@@ -442,7 +428,7 @@ $strMIME_nodescription = 'oഫ覡S.<br />ЦV@̬d %s Oƻγ~.';
 $strMIME_transformation = 'sഫ覡';
 $strMIME_transformation_note = 'iϥΤഫ覡ﶵ MINE ഫﶵ, Ьd %sഫ覡%s';
 $strMIME_transformation_options = 'ഫ覡ﶵ';
-$strMIME_transformation_options_note = 'ХΥHU榡Jഫﶵ: \'a\',\'b\',\'c\'...<br />pzݭnJϱ׽u ("\") γ޸ ("\'") ЦA[Wϱ׽u (Ҧp \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'ХΥHU榡Jഫﶵ: \'a\', 100, b,\'c\'...<br />pzݭnJϱ׽u ("\") γ޸ ("\'") ЦA[Wϱ׽u (Ҧp \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_without = 'MIME HܬOSjഫ\';
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';  // keep in SQL statement
 $strModifications = 'קwxs';
@@ -775,7 +761,6 @@ $strThemeNotFound = '䤣GDD %s !';
 $strThemeNoValidImgPath = '䤣GDD %s ]wϹ|!';
 $strThemePathNotFound = '䤣GDD %s ]w|!';
 $strThisHost = 'wD';
-$strThisNotDirectory = 'oäO@ӥؿ';
 $strThreads = 'u{';
 $strThreadSuccessfullyKilled = 'O %s w\.';
 $strTime = 'ɶ';
@@ -791,7 +776,6 @@ $strTransformation_application_octetstream__hex = 'HQi覡.';
 $strTransformation_image_jpeg__inline = 'ܥiϹ; ﶵ; e,[H] (Oɭ즳)';
 $strTransformation_image_jpeg__link = 'ܹϹsu (U).';
 $strTransformation_image_png__inline = 'Ѭ image/jpeg: ';
-$strTransformation_text_plain__dateformat = 'ϥ TIME, TIMESTAMP  DATETIME åHaɰϮɶ. Ĥ@ӿﶵOץ (Hpɬ) ӽվܤɶ (w]: 0). ĤGӿﶵO榡 [ PHPs strftime() Ѽ].';
 $strTransformation_text_plain__external = 'u LINUX : ~{αNeHзǿJҦJ. X{зǿX. w]O, K HTML X. ѩOwz, zݭnۦs libraries/transformations/text_plain__external.inc.php Υ[JݭnϥΤu@. Ĥ@ӿﶵh֭ӵ{ݭnϥ, ĤGӿﶵo{Ѽ, ĤTӿﶵ, p]w 1 N|ϥ htmlspecialchars() ഫX (w]: 1). ĥ|ӿﶵ, p]w 1 N|[J NOWRAP 󤺮e椺, OXҦe|sƦ (w]: 1)';
 $strTransformation_text_plain__formatted = 'Os쥻e榡. i Escaping Bz.';
 $strTransformation_text_plain__imagelink = 'ܹϹγs, ƾڤeOɮצW; Ĥ@ӿﶵO}eq ( "http://domain.com/" ), ĤGӿﶵOeת,ĤTӿﶵOת.';
@@ -851,8 +835,6 @@ $strWildcard = 'UΦr';
 $strWindowNotFound = 'ئaLks. iAwΧAsw]wҰʤFLks';
 $strWithChecked = 'ܪƪG';
 $strWriteRequests = 'gJnD';
-$strWritingCommentNotPossible = 'LkxsѤr';
-$strWritingRelationNotPossible = 'Lkxsp';
 $strWrongUser = '~ϥΪ̦W٩αKXAڵs';
 
 $strXML = 'XML'; //USE ENG
@@ -987,7 +969,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1002,4 +984,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
