@@ -1,5 +1,5 @@
 <?php
-/* $Id: czech-utf-8.inc.php,v 2.166.2.2 2006/03/23 17:42:11 lem9 Exp $ */
+/* $Id: czech-utf-8.inc.php 9857 2007-01-22 15:24:43Z nijel $ */
 
 /**
  * Czech language file by
@@ -9,12 +9,10 @@
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr';
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'tahoma, arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ' ';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits = array('bajtů', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB');
+$byteUnits = array('B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');
 
 $day_of_week = array('Neděle', 'Pondělí', 'Úterý', 'Středa', 'Čtvrtek', 'Pátek', 'Sobota');
 $month = array('ledna', 'února', 'března', 'dubna', 'května', 'června', 'července', 'srpna', 'září', 'října', 'listopadu', 'prosince');
@@ -25,21 +23,17 @@ $datefmt = '%a %d. %b %Y, %H:%M';
 $timespanfmt = '%s dnů, %s hodin, %s minut a %s sekund';
 
 $strAbortedClients = 'Přerušené';
-$strAbsolutePathToDocSqlDir = 'docSQL adresář';
 $strAccessDeniedCreateConfig = 'Pravděpodobná příčina je, že nemáte vytvořený konfigurační soubor. Pro jeho vytvoření by se vám mohl hodit %1$snastavovací skript%2$s.';
 $strAccessDeniedExplanation = 'phpMyAdmin se pokusil připojit k&nbsp;MySQL serveru, a ten odmítl připojení. Zkontrolujte jméno serveru, uživatelské jméno a heslo v&nbsp;souboru config.inc.php a ujistěte se, že jsou totožné s&nbsp;těmi, které máte od administrátora MySQL serveru.';
 $strAccessDenied = 'Přístup odepřen';
 $strAction = 'Akce';
 $strAddAutoIncrement = 'Přidat hodnotu AUTO_INCREMENT';
+$strAddClause = 'Přidat %s';
 $strAddConstraints = 'Přidat integritní omezení';
 $strAddDeleteColumn = 'Přidat nebo odebrat sloupec';
 $strAddDeleteRow = 'Přidat nebo odebrat řádek';
-$strAddDropDatabase = 'Přidat DROP DATABASE';
-$strAddedColumnComment = 'Přidán komentář ke sloupci';
-$strAddedColumnRelation = 'Přidána relace pro sloupec';
 $strAddFields = 'Přidat %s sloupců';
 $strAddHeaderComment = 'Přidat vlastní komentář do hlavičky (\\n odděluje řádky)';
-$strAddIfNotExists = 'Přidat IF NOT EXISTS';
 $strAddIntoComments = 'Do komentářů přidat';
 $strAddNewField = 'Přidat sloupec';
 $strAddPrivilegesOnDb = 'Přidat oprávnění pro databázi';
@@ -62,6 +56,7 @@ $strAlterOrderBy = 'Změnit pořadí tabulky podle';
 $strAnalyzeTable = 'Analyzovat tabulku';
 $strAnd = 'a';
 $strAndThen = 'a poté';
+$strAngularLinks = 'Pravoúhlé spoje';
 $strAnIndex = 'K&nbsp;tabulce %s byl přidán index';
 $strAnyHost = 'Jakýkoliv počítač';
 $strAny = 'Jakýkoliv';
@@ -114,6 +109,8 @@ $strBzError = 'phpMyAdminovi se nepodařilo zkomprimovat výpis, protože rozš
 $strBzip = '&bdquo;zabzipováno&ldquo;';
 
 $strCalendar = 'Kalendář';
+$strCancel = 'Zrušit';
+$strCanNotLoadExportPlugins = 'Nepodařilo se nahrát pluginy pro export, zkontrolujte prosím vaší instalaci!';
 $strCanNotLoadImportPlugins = 'Nepodařilo se nahrát pluginy pro import, zkontrolujte prosím vaší instalaci!';
 $strCannotLogin = 'Nepodařilo se přihlášení k&nbsp;MySQL serveru';
 $strCantLoad = 'nelze nahrát rozšíření %s,<br />zkontrolujte prosím nastavení PHP';
@@ -175,11 +172,17 @@ $strCreateNewDatabase = 'Vytvořit novou databázi';
 $strCreateNewTable = 'Vytvořit novou tabulku v&nbsp;databázi %s';
 $strCreatePage = 'Vytvořit novou stránku';
 $strCreatePdfFeat = 'Vytváření PDF';
+$strCreateRelation = 'Vytvořit relaci';
+$strCreateTable  = 'Vytvořit tabulku';
+$strCreateUserDatabase = 'Databáze pro uživatele';
+$strCreateUserDatabaseName = 'Vytvořit databázi stejného jména a přidělit všechna oprávnění';
+$strCreateUserDatabaseNone = 'Žádná';
+$strCreateUserDatabaseWildcard = 'Přidělit všechna oprávnění na jméno odpovídající masce (uživatel_%)';
 $strCreate = 'Vytvořit';
 $strCreationDates = 'Datum vytvoření, poslední změny a kontroly';
 $strCriteria = 'Podmínka';
 $strCroatian = 'Chorvatština';
-$strCSV = 'CSV'; 
+$strCSV = 'CSV';
 $strCSVImportOptions = 'Nastavení CSV';
 $strCSVOptions = 'Nastavení CSV exportu';
 $strCyrillic = 'Cyrilika';
@@ -204,15 +207,7 @@ $strDataOnly = ' Jen data';
 $strDataPages = 'Stránek obshahujících data';
 $strDBComment = 'Komentář k&nbsp;databázi: ';
 $strDBCopy = 'Zkopírovat databázi na';
-$strDBGContextID = 'Kontext ID';
-$strDBGContext = 'Kontext';
-$strDBGHits = 'Zásahů';
-$strDBGLine = 'Řádka';
-$strDBGMaxTimeMs = 'Min. čas, ms';
-$strDBGMinTimeMs = 'Max. čas, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Čas/Zásah, ms';
-$strDBGTotalTimeMs = 'Celkový čas, ms';
+$strDbIsEmpty = 'Databáze se zdá být prázdná!';
 $strDbPrivileges = 'Oprávnění pro jednotlivé databáze';
 $strDBRename = 'Přejmenovat databázi na';
 $strDbSpecific = 'závislé na databázi';
@@ -227,11 +222,16 @@ $strDeleted = 'Řádek byl smazán';
 $strDeletedRows = 'Smazané řádky:';
 $strDeleteNoUsersSelected = 'Musíte vybrat uživatele, které chcete odstranit!';
 $strDelete = 'Odstranit';
+$strDeleteRelation = 'Odstranit relaci';
 $strDeleting = 'Odstraňuji %s';
+$strDelimiter = 'Oddělovač';
 $strDelOld = 'Aktuální stránka se odkazuje na tabulky, které již neexistují. Chcete odstranit tyto odkazy?';
 $strDescending = 'Sestupně';
 $strDescription = 'Popis';
+$strDesignerHelpDisplayField = 'Zobrazované pole je označeno růžovou barvou. Pro jeho změnu klikněte na ikonu "Zvolte které sloupce zobrazit" a poté zvolte odpovídající sloupec.';
+$strDesigner = 'Návrhář';
 $strDictionary = 'slovník';
+$strDirectLinks = 'Přímé spoje';
 $strDirtyPages = 'Změněných stránek';
 $strDisabled = 'Vypnuto';
 $strDisableForeignChecks = 'Vypnout kontrolu cizích klíčů';
@@ -239,6 +239,8 @@ $strDisplayFeat = 'Zobrazení funkcí';
 $strDisplayOrder = 'Seřadit podle:';
 $strDisplayPDF = 'Zobrazit jako schéma v&nbsp;PDF';
 $strDoAQuery = 'Provést &bdquo;dotaz podle příkladu&ldquo; (zástupný znak: &bdquo;%&ldquo;)';
+$strDocSQL = 'DocSQL';
+$strDocSQLOptions = 'Nastavení pro DocSQL';
 $strDocu = 'Dokumentace';
 $strDoYouReally = 'Opravdu si přejete vykonat příkaz';
 $strDropDatabaseStrongWarning = 'Chystáte se ZRUŠIT celou databázi!';
@@ -268,6 +270,10 @@ $strEnglish = 'Anglicky';
 $strEnglishPrivileges = 'Poznámka: názvy oprávnění v&nbsp;MySQL jsou uváděny anglicky';
 $strError = 'Chyba';
 $strErrorInZipFile = 'Chyba v&nbsp;ZIP archívu:';
+$strErrorRelationAdded = 'Chyba: relace nebyla přidána.';
+$strErrorRelationExists = 'Chyba: relace již existuje.';
+$strErrorRenamingTable = 'Chyba při přejmenování tabulky %1$s na %2$s';
+$strErrorSaveTable = 'Chyba při ukládání souřadnic pro Návrháře.';
 $strEscapeWildcards = 'Zástupné znaky _ a % by měly být escapovány pomocí \, pokud je chcete použít jako znak';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estonština';
@@ -276,6 +282,8 @@ $strExcelOptions = 'Nastavení exportu do Excelu';
 $strExecuteBookmarked = 'Spustit oblíbený dotaz';
 $strExplain = 'Vysvětlit dotaz';
 $strExport = 'Export';
+$strExportImportToScale = 'Exportovat/Importovat v měřítku';
+$strExportMustBeFile = 'Zvolený export musí být uložen do souboru!';
 $strExtendedInserts = 'Rozšířené inserty';
 $strExtra = 'Extra';
 
@@ -301,11 +309,14 @@ $strFlushPrivilegesNote = 'Poznámka: phpMyAdmin získává oprávnění přímo
 $strFlushQueryCache = 'Vyprázdnit vyrovnávací paměť dotazů';
 $strFlushTables = 'Zavřít všechny tabulky';
 $strFlushTable = 'Vyprázdnit vyrovnávací paměť pro tabulku (&bdquo;FLUSH&ldquo;)';
+$strFontSize = 'Velikost písma';
+$strForeignKeyError = 'Chyba při vytváření cizího klíče (zkontrolujte typ dat)';
 $strFormat = 'Formát';
 $strFormEmpty = 'Chybějící hodnota ve formuláři!';
 $strFreePages = 'Volných stránek';
 $strFullText = 'Celé texty';
 $strFunction = 'Funkce';
+$strFunctions = 'Funkce';
 
 $strGenBy = 'Vygeneroval';
 $strGeneralRelationFeat = 'Obecné funkce relací';
@@ -327,7 +338,11 @@ $strHasBeenAltered = 'byla změněna.';
 $strHasBeenCreated = 'byla vytvořena.';
 $strHaveToShow = 'Musíte zvolit alespoň jeden sloupec, který chcete zobrazit.';
 $strHebrew = 'Hebrejština';
+$strHelp = 'Nápověda';
 $strHexForBinary = 'Binární pole vypisovat šestnáctkově';
+$strHideShowAll = 'Skrýt/Zobrazit vše';
+$strHideShowNoRelation = 'Skrýt/Zobrazit tabulky bez relací';
+$strHide         = 'Skrýt';
 $strHome = 'Hlavní strana';
 $strHomepageOfficial = 'Oficiální stránka phpMyAdmina';
 $strHostEmpty = 'Jméno počítače je prázdné!';
@@ -341,13 +356,13 @@ $strHungarian = 'Maďarština';
 $strIcelandic = 'Islandština';
 $strId = 'ID';
 $strIdxFulltext = 'Fulltext';
+$strIEUnsupported = 'Prohlížeč Internet Explorer tuto funkci nepodporuje.';
 $strIgnoreDuplicates = 'Ignorovat duplicitní řádky';
 $strIgnore = 'Ignorovat';
 $strIgnoreInserts = 'Použít IGNORE';
-$strIgnoringFile = 'Ignoruji soubor %s';
-$strImportDocSQL = 'Importovat soubory docSQL';
+$strImportExportCoords = 'Import/Export souřadnic pro PDF schéma';
 $strImportFiles = 'Importovat soubory';
-$strImportFormat = 'Formát importovaného souboru'; 
+$strImportFormat = 'Formát importovaného souboru';
 $strImport = 'Import';
 $strImportSuccessfullyFinished = 'Import byl úspěšně dokončen, bylo provedeno %d dotazů.';
 $strIndexes = 'Indexy';
@@ -367,14 +382,15 @@ $strInnoDBDataFilePath = 'Soubor s&nbsp;daty';
 $strInnoDBDataHomeDirDesc = 'Společná část cesty pro všechny soubory obsahující data InnoDB.';
 $strInnoDBDataHomeDir = 'Domovský adresář pro data';
 $strInnoDBPages = 'stránek';
+$strInnoDBRelationAdded = 'Vytvořena relace InnoDB';
 $strInnodbStat = 'Stav InnoDB';
-$strInsecureMySQL = 'Máte standardní nastavení hesla uživatele root v&nbsp;MySQL. Doporučujeme změnit toto nastavení a tím podstatně zvýšit bezpečnost Vašeho serveru.';
+$strInsecureMySQL = 'Máte standardní nastavení hesla uživatele root v&nbsp;MySQL. Doporučujeme změnit toto nastavení a tím podstatně zvýšit bezpečnost vašeho serveru.';
 $strInsertAsNewRow = 'Vložit jako nový řádek';
 $strInsertedRowId = 'Id vloženého řádku:';
 $strInsertedRows = 'Vloženo řádků:';
-$strInsertNewRow = 'Vložit nový řádek';
 $strInsert = 'Vložit';
 $strInternalNotNecessary = '* Interní relace není potřebná, pokud již relace existuje v&nbsp;InnoDB.';
+$strInternalRelationAdded = 'Interní relace vytvořena';
 $strInternalRelations = 'Interní relace';
 $strInUse = 'právě se používá';
 $strInvalidAuthMethod = 'V konfiguraci máte špatnou autentizační metodu:';
@@ -383,12 +399,14 @@ $strInvalidColumnCount = 'Počet sloupců musí být větší než nula.';
 $strInvalidCSVFieldCount = 'Chybný počet položek v&nbsp;CSV datech na řádku %d.';
 $strInvalidCSVFormat = 'Chybný formát CSV dat na řádku %d.';
 $strInvalidCSVParameter = 'Neznámý parametr pro import CSV: %s';
+$strInvalidDatabase = 'Chybná databáze';
 $strInvalidFieldAddCount = 'Musíte přidat alespoň jeden sloupec.';
 $strInvalidFieldCount = 'Tabulka musí mít alespoň jeden sloupec.';
 $strInvalidLDIImport = 'Tento plugin nepodporuje komprimované soubory!';
 $strInvalidRowNumber = '%d není platné číslo řádku.';
 $strInvalidServerHostname = 'Chybné jméno serveru pro server %1$s. Prosím zkontrolujte nastavení.';
 $strInvalidServerIndex = 'Chybný index serveru: "%s"';
+$strInvalidTableName = 'Chybné jméno tabulky';
 
 $strJapanese = 'Japonština';
 $strJoins = 'Použité výběry';
@@ -400,10 +418,12 @@ $strKeepPass = 'Neměnit heslo';
 $strKeyCache = 'Vyrovnávací paměť klíčů';
 $strKeyname = 'Klíčový název';
 $strKill = 'Ukončit';
+$strKnownExternalBug = 'Funkčnost %s je omezena známou chybou, viz %s.';
 $strKorean = 'Korejština';
 
 $strLandscape = 'Na šířku';
 $strLanguageFileNotFound = 'Jazykový soubor "%1$s" nebyl nalezen.';
+$strLanguage = 'Jazyk';
 $strLanguageUnknown = 'Neznámý jazyk: %1$s.';
 $strLatchedPages = 'Zamčených stránek';
 $strLatexCaption = 'Titulek tabulky';
@@ -446,7 +466,7 @@ $strMIME_description = 'Popis';
 $strMIME_MIMEtype = 'MIME typ';
 $strMIME_nodescription = 'Pro tuto transformaci není dostupný žádný popis.<br />Zeptejte se autora co %s dělá.';
 $strMIME_transformation_note = 'Pro seznam dostupných parametrů transformací a jejich MIME typů klikněte na %spopisy transformací%s';
-$strMIME_transformation_options_note = 'Zadejte parametry transformací v&nbsp;následujícím tvaru: \'a\',\'b\',\'c\'...<br />Pokud potřebujete použít zpětné lomítko (&bdquo;\&ldquo;) nebo jednoduché uvozovky (&bdquo;\'&ldquo;) mezi těmito hodnotami, vložte před ně zpětné lomítko (například \'\\\\xyz\' nebo \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Zadejte parametry transformací v&nbsp;následujícím tvaru: \'a\', 100, b,\'c\'...<br />Pokud potřebujete použít zpětné lomítko (&bdquo;\&ldquo;) nebo jednoduché uvozovky (&bdquo;\'&ldquo;) mezi těmito hodnotami, vložte před ně zpětné lomítko (například \'\\\\xyz\' nebo \'a\\\'b\').';
 $strMIME_transformation_options = 'Parametry transformace';
 $strMIME_transformation = 'Transformace při prohlížení';
 $strMIMETypesForTable = 'MIME TYPY PRO TABULKU';
@@ -454,6 +474,7 @@ $strMIME_without = 'MIME typy zobrazené kurzívou nemají vlastní transformač
 $strModifications = 'Změny byly uloženy';
 $strModifyIndexTopic = 'Upravit index';
 $strModify = 'Úpravy';
+$strMoveMenu = 'Přesun menu';
 $strMoveTableOK = 'Tabulka %s byla přesunuta do %s.';
 $strMoveTable = 'Přesunout tabulku do (databáze<b>.</b>tabulka):';
 $strMoveTableSameNames = 'Nelze přesunout tabulku na sebe samu!';
@@ -483,6 +504,7 @@ $strNext = 'Další';
 $strNoActivity = 'Byli jste příliš dlouho neaktivní (déle než %s sekund), prosím přihlaste se znovu';
 $strNoDatabasesSelected = 'Nebyla vybrána žádná databáze.';
 $strNoDatabases = 'Žádné databáze';
+$strNoDataReceived = 'Nepodařilo se načíst žádná data k importu. Buďto nebyl odeslán žádný soubor, nebo jeho velikost překročila velikost povolenou v nastavení PHP. Viz FAQ 1.16.';
 $strNoDescription = 'žádný popisek';
 $strNoDetailsForEngine = 'Nejsou dostupné podrobnější informace o tomto úložišti.';
 $strNoDropDatabases = 'Příkaz &bdquo;DROP DATABASE&ldquo; je vypnutý.';
@@ -504,7 +526,6 @@ $strNoRowsSelected = 'Nebyl vybrán žádný řádek';
 $strNoSpace = 'Nedostatek místa pro uložení souboru %s.';
 $strNoTablesFound = 'V&nbsp;databázi nebyla nalezena žádná tabulka.';
 $strNoThemeSupport = 'Není podporována změna tématu, zkontrolujte nastavení a témata v&nbsp;adresáři %s.';
-$strNothingToImport = 'Nebyla zadána žádná data pro import!';
 $strNotNumber = 'Nebylo zadáno číslo!';
 $strNotOK = 'není v&nbsp;pořádku';
 $strNotSet = '<b>%s</b> tabulka nenalezena nebo není nastavena v&nbsp;%s';
@@ -512,11 +533,16 @@ $strNoUsersFound = 'Žádný uživatel nenalezen.';
 $strNoValidateSQL = 'Bez kontroly SQL';
 $strNull = 'Nulový';
 $strNumberOfFields = 'Počet sloupců';
+$strNumberOfTables = 'Počet tabulek';
 $strNumSearchResultsInTable = '%s odpovídající(ch) záznam(ů) v&nbsp;tabulce <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Celkem:</b> <i>%s</i> odpovídající(ch) záznam(ů)';
 $strNumTables = 'Tabulek';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheetOptions = 'Nastavení exportu do sešitu Open Document';
+$strOpenDocumentSpreadsheet = 'Sešit Open Document';
+$strOpenDocumentTextOptions = 'Nastavení exportu do textu Open Document';
+$strOpenDocumentText = 'Text Open Document';
 $strOpenNewWindow = 'Otevřít nové okno phpMyAdmina';
 $strOperations = 'Úpravy';
 $strOperator = 'Operátor';
@@ -540,6 +566,7 @@ $strPdfInvalidTblName = 'Tabulka &bdquo;%s&ldquo; neexistuje!';
 $strPdfNoTables = 'žádné tabulky';
 $strPDFOptions = 'Nastavení PDF';
 $strPDF = 'PDF';
+$strPDFReportExplanation = '(Vygeneruje dokument obsahující data jedné tabulky)';
 $strPDFReportTitle = 'Název výpisu';
 $strPerHour = 'za hodinu';
 $strPerMinute = 'za minutu';
@@ -548,9 +575,11 @@ $strPersian = 'Perština';
 $strPhoneBook = 'adresář';
 $strPHP40203 = 'Používáte PHP 4.2.3, které má závažnou chybu při práci s&nbsp;vícebajtovými znaky (mbstring), jedná se o&nbsp;chybu PHP číslo 19404. Nedoporučujeme používat tuto verzi PHP s&nbsp;phpMyAdminem.';
 $strPHPVersion = 'Verze PHP';
-$strPhp = 'Zobrazit PHP kód';
+$strPhp = 'Vytvořit PHP kód';
+$strPleaseSelectPrimaryOrUniqueKey = 'Zvolte, prosím, primární nebo unikátní klíč';
 $strPmaDocumentation = 'Dokumentace phpMyAdmina';
 $strPmaUriError = 'Parametr <tt>$cfg[\'PmaAbsoluteUri\']</tt> MUSÍ být nastaven v&nbsp;konfiguračním souboru!';
+$strPmaWiki = 'wiki phpMyAdmina';
 $strPolish = 'Polština';
 $strPortrait = 'Na výšku';
 $strPos1 = 'Začátek';
@@ -600,6 +629,8 @@ $strPrivDescUpdate = 'Umožňuje měnit data.';
 $strPrivDescUsage = 'Žádná oprávnění.';
 $strPrivileges = 'Oprávnění';
 $strPrivilegesReloaded = 'Oprávnění byla znovunačtena úspěšně.';
+$strProcedures = 'Procedury';
+$strProcesses = 'Procesy';
 $strProcesslist = 'Seznam procesů';
 $strProtocolVersion = 'Verze protokolu';
 $strPutColNames = 'Přidat jména sloupců na první řádek';
@@ -610,6 +641,7 @@ $strQBEIns = 'přidat';
 $strQueryCache = 'Vyrovnávací paměť dotazů';
 $strQueryFrame = 'SQL okno';
 $strQueryOnDb = 'SQL dotaz na databázi <b>%s</b>:';
+$strQueryResultsOperations = 'Operace s&nbsp;výsledky dotazu';
 $strQuerySQLHistory = 'SQL historie';
 $strQueryStatistics = '<b>Statistika dotazů</b>: Od spuštění bylo serveru posláno %s dotazů.';
 $strQueryTime = 'Dotaz zabral %01.4f sekund';
@@ -618,16 +650,19 @@ $strQueryWindowLock = 'Nepřepisovat tento dotaz z&nbsp;hlavního okna';
 
 $strReadRequests = 'Požadavků na zápis';
 $strReceived = 'Přijato';
+$strRecommended = 'doporučené';
 $strRecords = 'Záznamů';
 $strReferentialIntegrity = 'Zkontrolovat integritu odkazů:';
 $strRefresh = 'Obnovit';
 $strRelationalSchema = 'Relační schéma';
+$strRelationDeleted = 'Relace smazána';
 $strRelationNotWorking = 'Některé z&nbsp;rozšířených funkcí phpMyAdmina nelze používat. %sZde%s zjistíte proč.';
 $strRelationsForTable = 'RELACE PRO TABULKU';
 $strRelations = 'Relace';
 $strRelationView = 'Zobrazit relace';
 $strReloadingThePrivileges = 'Znovunačítám oprávnění';
-$strReloadMySQL = 'Znovunačtení MySQL';
+$strReloadPrivileges = 'Znovunačíst oprávnění';
+$strReload = 'Znovu načíst';
 $strRemoveSelectedUsers = 'Odstranit vybrané uživatele';
 $strRenameDatabaseOK = 'Databáze %s byla přejmenována na %s';
 $strRenameTableOK = 'Tabulka %s byla přejmenována na %s';
@@ -660,6 +695,7 @@ $strRunSQLQuery = 'Spustit SQL dotaz(y) na databázi %s';
 $strRussian = 'Ruština';
 
 $strSaveOnServer = 'Uložit na serveru v&nbsp;adresáři %s';
+$strSavePosition = 'Uložit rozmístění';
 $strSave = 'Ulož';
 $strScaleFactorSmall = 'Měřítko je příliš malé, aby se schéma vešlo na jednu stránku';
 $strSearchFormTitle = 'Vyhledávání v&nbsp;databázi';
@@ -677,17 +713,19 @@ $strSelectADb = 'Prosím vyberte databázi';
 $strSelectAll = 'Vybrat vše';
 $strSelectBinaryLog = 'Zvolte binární log pro zobrazení';
 $strSelectFields = 'Zvolte sloupec (alespoň jeden):';
+$strSelectForeignKey = 'Zvolte cizí klíč';
 $strSelectNumRows = 'v&nbsp;dotazu';
+$strSelectReferencedKey = 'Zvolte odkazovaný klíč';
 $strSelectTables = 'Vybrat tabulky';
 $strSend = 'Do souboru';
 $strSent = 'Odesláno';
 $strServerChoice = 'Server';
 $strServerNotResponding = 'Server neodpovídá';
 $strServer = 'Server';
+$strServers = 'Servery';
 $strServerStatusDelayedInserts = 'Odložené inserty';
 $strServerStatus = 'Stav serveru';
 $strServerStatusUptime = 'Tento MySQL server běží %s. Čas spuštění: %s.';
-$strServerTabProcesslist = 'Procesy';
 $strServerTabVariables = 'Proměnné';
 $strServerTrafficNotes = '<b>Provoz serveru</b>: Informace o&nbsp;síťovém provozu MySQL serveru od jeho spuštění.';
 $strServerVars = 'Proměnné a nastavení serveru';
@@ -699,8 +737,11 @@ $strShowColor = 'Barevné šipky';
 $strShowDatadictAs = 'Formát datového slovníku';
 $strShowFullQueries = 'Zobrazit celé dotazy';
 $strShowGrid = 'Zobrazit mřížku';
+$strShowHideLeftMenu = 'Zobrazit/Skrýt levé menu';
 $strShowingBookmark = 'Zobrazuji oblíbený dotaz';
+$strShowingPhp = 'Zobrazuji jako PHP kód';
 $strShowingRecords = 'Zobrazeny záznamy';
+$strShowingSQL = 'Zobrazuji SQL dotaz';
 $strShowOpenTables = 'Zobrazit otevřené tabulky';
 $strShowPHPInfo = 'Zobrazit informace o&nbsp;PHP';
 $strShowSlaveHosts = 'Zobrazit podřízené servery';
@@ -773,7 +814,7 @@ $strShowStatusKey_blocks_not_flushedDescr = 'Počet bloků ve vyrovnávací pam
 $strShowStatusKey_blocks_unusedDescr = 'Počet nepoužitých bloků ve vyrovnávací paměti klíčů. Pomocí této hodoty poznáte jak moc je vyrovnávací paměť využitá.';
 $strShowStatusKey_blocks_usedDescr = 'Počet použitých bloků ve vyrovnávací paměti klíčů. Tato hodnota určuje maximum bloků, které kdy byly obsazeny najednou.';
 $strShowStatusKey_read_requestsDescr = 'Počet požadavků na přečtení klíče z&nbsp;vyrovnávací paměti.';
-$strShowStatusKey_readsDescr = 'Počet skutečných čtení bloku zklíče z&nbsp;disku. Pokud je hodnota příliš velká, pravděpodobně máte malou vyrovnávací paměť (key_buffer_size). Úspěšnost vyrovnávací paměti můžete spočítat jako Key_reads/Key_read_requests.'; 
+$strShowStatusKey_readsDescr = 'Počet skutečných čtení bloku zklíče z&nbsp;disku. Pokud je hodnota příliš velká, pravděpodobně máte malou vyrovnávací paměť (key_buffer_size). Úspěšnost vyrovnávací paměti můžete spočítat jako Key_reads/Key_read_requests.';
 $strShowStatusKey_write_requestsDescr = 'Počet požadavků na zápis bloku klíče na disk.';
 $strShowStatusKey_writesDescr = 'Počet skutečných zápisů bloku klíče na disk.';
 $strShowStatusLast_query_costDescr = 'Celková cena posledního kompilovaného dotazu spočítaná optimalizérem dotazů. Užitečné pro porovnání různých dotazů. Výchozí hodnota 0 znamená, že žádný dotaz ještě nebyl kompilován.';
@@ -822,6 +863,8 @@ $strSize = 'Velikost';
 $strSkipQueries = 'Počet záznamů (dotazů) od začátku, které se mají přeskočit';
 $strSlovak = 'Slovenština';
 $strSlovenian = 'Slovinština';
+$strSmallBigAll = 'Vše malé/velké';
+$strSnapToGrid = 'Zachytávat na mřížku';
 $strSocketProblem = '(nebo není spávně nastaven lokální socket MySQL serveru)';
 $strSortByKey = 'Setřídit podle klíče';
 $strSorting = 'Řazení';
@@ -829,18 +872,19 @@ $strSort = 'Řadit';
 $strSpaceUsage = 'Využití místa';
 $strSpanish = 'Španělština';
 $strSplitWordsWithSpace = 'Slova jsou oddělena mezerou (&bdquo; &ldquo;).';
-$strSQLExportCompatibility = 'Kompatibilita SQL exportu';
+$strSQLCompatibility = 'Režim kompatibility SQL';
 $strSQLExportType = 'Typ vytvořených dotazů';
 $strSQLImportOptions = 'Nastavení SQL importu';
 $strSQLOptions = 'Nastavení SQL exportu';
-$strSQLParserBugMessage = 'Je možné, že jste našli chybu v&nbsp;SQL parseru. Prosím prozkoumejte podrobně SQL dotaz, především jestli jsou správně uvozovky a jestli nejsou proházené. Další možnost selhání je pokud nahráváte soubor s&nbsp;binárními daty nezapsanými v&nbsp;uvozovkách. Můžete také vyzkoušet příkazovou řádku MySQL. Níže uvedený výstup z&nbsp;MySQL serveru (pokud je nějaký) Vám také může pomoci při zkoumání problému. Pokud stále máte problémy nebo pokud SQL parser ohlásí chybu u&nbsp;dotazu, který na příkazové řádce funguje, prosím pokuste se zredukovat dotaz na co nejmenší, ve kterém se problém ještě vyskytne, a ohlaste chybu na stránkách phpMyAdmina spolu se sekcí VÝPIS uvedenou níže:';
-$strSQLParserUserError = 'Pravděpodobně máte v&nbsp;SQL dotazu chybu. Níže uvedený výstup MySQL serveru (pokud je nějaký) Vám také může pomoci při zkoumání problému';
+$strSQLParserBugMessage = 'Je možné, že jste našli chybu v&nbsp;SQL parseru. Prosím prozkoumejte podrobně SQL dotaz, především jestli jsou správně uvozovky a jestli nejsou proházené. Další možnost selhání je pokud nahráváte soubor s&nbsp;binárními daty nezapsanými v&nbsp;uvozovkách. Můžete také vyzkoušet příkazovou řádku MySQL. Níže uvedený výstup z&nbsp;MySQL serveru (pokud je nějaký) vám také může pomoci při zkoumání problému. Pokud stále máte problémy nebo pokud SQL parser ohlásí chybu u&nbsp;dotazu, který na příkazové řádce funguje, prosím pokuste se zredukovat dotaz na co nejmenší, ve kterém se problém ještě vyskytne, a ohlaste chybu na stránkách phpMyAdmina spolu se sekcí VÝPIS uvedenou níže:';
+$strSQLParserUserError = 'Pravděpodobně máte v&nbsp;SQL dotazu chybu. Níže uvedený výstup MySQL serveru (pokud je nějaký) vám také může pomoci při zkoumání problému';
 $strSQLQuery = 'SQL-dotaz';
 $strSQLResult = 'Výsledek SQL dotazu';
 $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Chybný identifikátor';
 $strSQPBugUnclosedQuote = 'Neuzavřené uvozovky';
 $strSQPBugUnknownPunctuation = 'Neznámé interpunkční znaménko';
+$strStandInStructureForView = 'Zástupná struktura pro pohled';
 $strStatCheckTime = 'Poslední kontrola';
 $strStatCreateTime = 'Vytvoření';
 $strStatement = 'Údaj';
@@ -851,11 +895,12 @@ $strStorageEngines = 'Úložiště';
 $strStorageEngine = 'Úložiště';
 $strStrucCSV = 'CSV';
 $strStrucData = 'Strukturu a data';
-$strStrucDrop = 'Přidat DROP TABLE';
 $strStrucExcelCSV = 'CSV pro MS Excel';
 $strStrucNativeExcel = 'Nativní formát MS Excelu';
+$strStrucNativeExcelOptions = 'Nastavení exportu do Excelu';
 $strStrucOnly = 'Pouze strukturu';
 $strStructPropose = 'Navrhnout strukturu tabulky';
+$strStructureForView = 'Struktura pro pohled';
 $strStructure = 'Struktura';
 $strSubmit = 'Provést';
 $strSuccess = 'Váš SQL-dotaz byl úspěšně vykonán';
@@ -870,13 +915,14 @@ $strTableEmpty = 'Jméno tabulky je prázdné!';
 $strTableHasBeenDropped = 'Tabulka %s byla odstraněna';
 $strTableHasBeenEmptied = 'Tabulka %s byla vyprázdněna';
 $strTableHasBeenFlushed = 'Vyrovnávací paměť pro tabulku %s byla vyprázdněna';
+$strTableIsEmpty = 'Tabulka se zdá být prázdná!';
 $strTableMaintenance = ' Údržba tabulky ';
+$strTableName = 'Jméno tabulky';
 $strTableOfContents = 'Obsah';
 $strTableOptions = 'Parametry tabulky';
 $strTables = '%s tabulek';
 $strTableStructure = 'Struktura tabulky';
 $strTable = 'Tabulka';
-$strTableType = 'Typ tabulky';
 $strTakeIt = 'zvolit';
 $strTblPrivileges = 'Oprávnění pro jednotlivé tabulky';
 $strTempData = 'Dočasná data';
@@ -889,14 +935,16 @@ $strThemeNoValidImgPath = 'Nebyla nalezena platná cesta k obrázkům pro vzhled
 $strThemePathNotFound = 'Nebyla nalezena platná cesta k vzhledu %s!';
 $strTheme = 'Vzhled';
 $strThisHost = 'Tento počítač';
-$strThisNotDirectory = 'Nebyl zadán adresář';
 $strThreads = 'Počet vláken';
 $strThreadSuccessfullyKilled = 'Vlákno %s bylo úspěšně zabito.';
 $strTime = 'Čas';
 $strTimeoutInfo = 'Předchozí ímport vyčerpal veškerý čas, po dalším odeslání bude import pokračovat od pozize %d.';
 $strTimeoutNothingParsed = 'Bohužel během posledního pokusu nebyla žádná data načtena. Toto obvykle znamená, že phpMyAdmin nebude schopen načíst tento soubor, pokud nezvýšíte časové limity v&nbsp;PHP.';
 $strTimeoutPassed = 'Limit pro běh importu vypršel, prosím odešlete formulář znovu se stejným souborem a import bude pokračovat.';
+$strToFromPage = 'do/ze stránky';
 $strToggleScratchboard = 'Zobrazit grafický návrh';
+$strToggleSmallBig = 'Přepnout malé/velké';
+$strToSelectRelation = 'Pro výběr relace klikněte :';
 $strTotal = 'celkem';
 $strTotalUC = 'Celkem';
 $strTraditionalChinese = 'Tradiční čínština';
@@ -904,11 +952,11 @@ $strTraditionalSpanish = 'Tradiční španělština';
 $strTraffic = 'Provoz';
 $strTransactionCoordinator = 'Koordinátor transakcí';
 $strTransformation_application_octetstream__download = 'Zobrazí odkaz na stáhnutí dat. První parametr je jméno souboru, druhý jméno sloupce v&nbsp;tabulce obsahující jméno souboru. Pokud zadáte druhý parametr, první musí být prázdný.';
-$strTransformation_application_octetstream__hex = 'Zobrazí data šestnáctkově.';
+$strTransformation_application_octetstream__hex = 'Zobrazí data šestnáctkově. Nepovinný parameter určuje po kolika znacích má být přidána mezera (výchozí hodnota je 2).';
 $strTransformation_image_jpeg__inline = 'Zobrazí náhled obrázku s&nbsp;odkazem na obrázek; parametry šířka a výška v&nbsp;bodech (poměr stran obrázku zůstane zachován)';
 $strTransformation_image_jpeg__link = 'Zobrazí odkaz na obrázek (například stáhnutí pole blob).';
 $strTransformation_image_png__inline = 'Viz image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Zobrazí datum nebo čas (TIME, TIMESTAMP a DATETIME) podle místního nastavení. První parametr je posun (v&nbsp;hodinách), který bude přidán k&nbsp;času (výchozí je 0). Druhý parametr je formátovací řetězec pro funkci strftime().';
+$strTransformation_text_plain__dateformat = 'Zobrazí datum nebo čas (TIME, TIMESTAMP, DATETIME nebo unixový timestamp v numerickém sloupci). První parametr je posun (v&nbsp;hodinách), který bude přidán k&nbsp;času (výchozí je 0). Druhý parametr je formátovací řetězec. Třetí určuje jestli chcete zobrazit datum podle místního nastavení nebo UTC čas (použijte text "local" nebo "utc"). Podle tohoto nastavení, formát má buďto syntaxi funkce strftime() pokud použijete "local" nebo pro gmtime() pokud použijete "utc".';
 $strTransformation_text_plain__external = 'JEN PRO LINUX: Spustí externí program, na jeho standardní vstup pošle obsah pole a zobrazí výstup programu. Výchozí je program Tidy, který pěkně zformátuje HTML. Z&nbsp;bezpečnostních důvodů musíte jména povolených programů zapsat do souboru libraries/transformations/text_plain__external.inc.php. První parametr je číslo programu, který má být spuštěn a druhý parametr udává parametry tohoto programu. Třetí parametr určuje, zda mají být ve výstupu nahrazeny HTML entity (např. pro zobrazení zdrojového kódu HTML) (výchozí je 1, tedy převádět na entity), čtvrtý (při nastavení na 1) zajistí přidání parametru NOWRAP k&nbsp;vypisovanému textu, čímž se zachová formátování (výchozí je 1).';
 $strTransformation_text_plain__formatted = 'Zachová původní formátování sloupce, tak jak je uložen v&nbsp;databázi.';
 $strTransformation_text_plain__imagelink = 'Zobrazí obrázek a odkaz z&nbsp;pole obsahujícího odkaz na obrázek. První parametr je prefix URL (například &bdquo;http://mojedomena.cz/&ldquo;), druhý a třetí určuje šířku a výšku obrázku.';
@@ -932,6 +980,7 @@ $strUpdateQuery = 'Aktualizovat dotaz';
 $strUpdComTab = 'Podívejte se prosím do dokumentace, jak aktualizovat tabulku s&nbsp;informacemi o&nbsp;sloupcích (tabulka column_comments)';
 $strUpgrade = 'Měli byste aktualizovat %s na verzi %s nebo vyšší.';
 $strUploadLimit = 'Pravděpodobně jste se pokusili nahrát příliš velký soubor. Přečtěte si prosím %sdokumentaci%s, jak toto omezení obejít.';
+$strUploadsNotAllowed = 'Upload souborů není na tomto serveru povolen.';
 $strUsage = 'Používá';
 $strUseBackquotes = 'Použít zpětné uvozovky u&nbsp;jmen tabulek a sloupců';
 $strUsedPhpExtensions = 'Použitá rozšíření PHP';
@@ -969,10 +1018,9 @@ $strWildcard = 'maska';
 $strWindowNotFound = 'Cílové okno prohlížeče nemohlo být aktualizováno. Možná jste zavřel rodičovské okno, nebo prohlížeč blokuje operace mezi okny z&nbsp;důvodu bezpečnostních nastavení.';
 $strWithChecked = 'Zaškrtnuté:';
 $strWriteRequests = 'Požadavků na čtení';
-$strWritingCommentNotPossible = 'Nelze zapsat komentář';
-$strWritingRelationNotPossible = 'Nelze zapsat relaci';
 $strWrongUser = 'Špatné uživatelské jméno nebo heslo. Přístup odepřen.';
 
+$strXMLOptions = 'Nastavení exportu do XML';
 $strXML = 'XML';
 
 $strYes = 'Ano';
