@@ -1,12 +1,12 @@
 <?php
-/* $Id: danish-iso-8859-1.inc.php,v 2.161.2.1 2006/09/29 16:25:44 lem9 Exp $ */ /* danish - Dansk v 2.162 (based on english 2.159) 2006/09/25 01:23:45 - overstter AlleyKat kan kontaktes p < phpmyadmin (at) phpbb2.dk > */
+/* $Id: danish-iso-8859-1.inc.php 10258 2007-04-07 15:27:37Z lem9 $ */ /* danish - Dansk v 2.162 (based on english 2.159) 2006/09/25 01:23:45 - overstter AlleyKat kan kontaktes p < phpmyadmin (at) phpbb2.dk > */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr';
 $number_thousands_separator = '.';
 $number_decimal_separator = ',';
 // forkortelser for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits  =  array('Bytes', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');
+$byteUnits  =  array('B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');
 
 // MySQL manual sprogdefinition, ikke pkrvet, en bruges hvis
 // ikke defineret - da findes endnu ikke
@@ -22,7 +22,6 @@ $datefmt = '%d/%m %Y kl. %H:%M:%S';
 $timespanfmt = '%s dage, %s timer, %s minutter og %s sekunder';
 
 $strAbortedClients = 'Afbrudt';
-$strAbsolutePathToDocSqlDir = 'Indtast venligst absolut sti p webserveren til docSQL mappen';
 $strAccessDenied = 'Adgang Ngtet';
 $strAccessDeniedCreateConfig = 'Sandsynlig rsag til dette er at du ikke har oprettet en konfigurationsfil. Du kan bruge %1$sopstningsscriptet%2$s til at oprette en.';
 $strAccessDeniedExplanation = 'phpMyAdmin forsgte at forbinde til MySQL-serveren, og serveren afviste forbindelsen. Du br tjekke host, brugernavn og kodeord i config.inc.php og sikre dig at de svarer til den information du har fet af administratoren af MySQL-serveren.';
@@ -32,8 +31,6 @@ $strAddClause = 'Tilfj %s';
 $strAddConstraints = 'Tilfj begrnsninger';
 $strAddDeleteColumn = 'Tilfj/Slet felt-kolonne';
 $strAddDeleteRow = 'Tilfj/Slet kriterie-rkke';
-$strAddedColumnComment = 'Tilfjet kommentar til kolonne';
-$strAddedColumnRelation = 'Tilfjet relation til kolonne';
 $strAddFields = 'Tilfj %s felt(er)';
 $strAddHeaderComment = 'Tilfj tilpassede kommentarer i headeren (\\n deler linjer)';
 $strAddIntoComments = 'Tilfj til kommentarer';
@@ -58,6 +55,7 @@ $strAlterOrderBy = 'Arrangr tabelrkkeflge efter';
 $strAnalyzeTable = 'Analysr tabel';
 $strAnd = 'Og';
 $strAndThen = 'og derefter';
+$strAngularLinks = 'Angulre links';
 $strAnIndex = 'Der er tilfjet et indeks til %s';
 $strAny = 'Enhver';
 $strAnyHost = 'Enhver vrt';
@@ -110,6 +108,7 @@ $strBzError = 'phpMyAdmin kunne ikke komprimere dumpet p grund af en delagt Bz2
 $strBzip = '"bzipped"';
 
 $strCalendar = 'Kalender';
+$strCancel = 'Annuller';
 $strCanNotLoadExportPlugins = 'Kunne ikke indlse eksportplugins, check venligst din installation!';
 $strCanNotLoadImportPlugins = 'Kunne ikke indlse importplugins, check venligst din installation!';
 $strCannotLogin = 'Kan ikke logge ind p MySQL-serveren';
@@ -173,6 +172,8 @@ $strCreateNewTable = 'Opret ny tabel i database %s';
 $strCreate = 'Opret';
 $strCreatePage = 'Opret en ny side';
 $strCreatePdfFeat = 'Oprettelse af PDFer';
+$strCreateRelation = 'Opret relation';
+$strCreateTable  = 'Opret tabel';
 $strCreateUserDatabase = 'Database for bruger';
 $strCreateUserDatabaseName = 'Opret database med samme navn og tildel alle privilegier';
 $strCreateUserDatabaseNone = 'Ingen';
@@ -205,15 +206,7 @@ $strDataOnly = 'Kun data';
 $strDataPages = 'Sider der indeholder data';
 $strDBComment = 'Databasekommentar: ';
 $strDBCopy = 'Kopir database til';
-$strDBGContextID = 'Sammenhng-ID';
-$strDBGContext = 'Sammenhng';
-$strDBGHits = 'Hits';
-$strDBGLine = 'Linje';
-$strDBGMaxTimeMs = 'Max tid, ms';
-$strDBGMinTimeMs = 'Min tid, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Tid/Hit, ms';
-$strDBGTotalTimeMs = 'Total tid, ms';
+$strDbIsEmpty = 'Database ser ud til at vre tom!';
 $strDbPrivileges = 'Database-specifikke privilegier';
 $strDBRename = 'Omdb database til';
 $strDbSpecific = 'database-specifik';
@@ -228,12 +221,16 @@ $strDeleted = 'Rkken er slettet!';
 $strDeletedRows = 'Slettede rkker:';
 $strDeleteNoUsersSelected = 'Ingen brugere valgt til sletning!';
 $strDelete = 'Slet';
+$strDeleteRelation = 'Slet relation';
 $strDeleting = 'Sletter %s';
 $strDelimiter = 'Adskiller';
 $strDelOld = 'Nuvrende side har referencer til tabeller der ikke lngere eksisterer. Vil du slette disse referencer?';
 $strDescending = 'Faldende';
 $strDescription = 'Beskrivelse';
+$strDesigner = 'Designer';
+$strDesignerHelpDisplayField = 'Visningsfeltet er vist som pink. For at stte/fjerne et felt som visningsfelt, klik p "Vlg felt der skal vises" ikonet, og klik derefter p det pgldende feltnavn.';
 $strDictionary = 'ordbog';
+$strDirectLinks = 'Direkte links';
 $strDirtyPages = 'Beskidte sider';
 $strDisabled = 'Slet fra';
 $strDisableForeignChecks = 'Sl fremmedngle-checks fra';
@@ -241,6 +238,8 @@ $strDisplayFeat = 'Vis muligheder';
 $strDisplayOrder = 'Rkkeflge af visning:';
 $strDisplayPDF = 'Vis PDF-skematik';
 $strDoAQuery = 'Kr en foresprgsel p felter (jokertegn: "%")';
+$strDocSQL = 'DocSQL';
+$strDocSQLOptions = 'DocSQL indstillinger';
 $strDocu = 'Dokumentation';
 $strDoYouReally = 'Er du sikker p at du vil ';
 $strDropDatabaseStrongWarning = 'Du er ved at DESTRUERE en komplet database!';
@@ -270,6 +269,9 @@ $strEnglish = 'Engelsk';
 $strEnglishPrivileges = ' NB: Navne p MySQL privilegier er p engelsk ';
 $strError = 'Fejl';
 $strErrorInZipFile = 'Fejl i ZIP arkiv:';
+$strErrorRelationAdded = 'Fejl: Relation ikke tilfjet.';
+$strErrorRelationExists = 'Fejl: Relation findes allerede.';
+$strErrorSaveTable = 'Fejl ved lagring af koordinater for Designer.';
 $strErrorRenamingTable = 'Fejl ved omdbning af tabel  %1$s til %2$s';
 $strEscapeWildcards = 'Jokertegn _ og % skal vre escaped med en \ foran for at bruge dem bogstaveligt';
 $strEsperanto = 'Esperanto';
@@ -279,6 +281,7 @@ $strExcelOptions = 'Excel-indstillinger';
 $strExecuteBookmarked = 'Udfr foresprgsel iflg. bogmrke';
 $strExplain = 'Forklar SQL';
 $strExport = 'Eksport';
+$strExportImportToScale = 'Eksporter/Importer til skala';
 $strExportMustBeFile = 'Valgte eksporttype skal gemmes som fil!';
 $strExtendedInserts = 'Udvidede inserts';
 $strExtra = 'Ekstra';
@@ -306,6 +309,7 @@ $strFlushQueryCache = 'Flush foresprgsel-mellemlager (query cache)';
 $strFlushTable = 'Flush tabellen ("FLUSH")';
 $strFlushTables = 'Flush (luk) alle tabeller';
 $strFontSize = 'Skriftstrrelse';
+$strForeignKeyError = 'Fejl ved oprettelse af fremmedngle (check datatyper)';
 $strFormat = 'Format';
 $strFormEmpty = 'Ingen vrdi i formularen !';
 $strFreePages = 'Frie sider';
@@ -333,7 +337,11 @@ $strHasBeenAltered = 'er ndret.';
 $strHasBeenCreated = 'er oprettet.';
 $strHaveToShow = 'Du skal vlge mindst en kolonne der skal vises';
 $strHebrew = 'Hebrisk';
+$strHelp = 'Hjlp';
 $strHexForBinary = 'Brug hexadecimal til binre felter';
+$strHide         = 'Skjul';
+$strHideShowAll = 'Skjul/Vis alle';
+$strHideShowNoRelation = 'Skjul/Vis tabeller uden relation';
 $strHome = 'Hjem';
 $strHomepageOfficial = 'Officiel phpMyAdmin hjemmeside ';
 $strHostEmpty = 'Der er intet vrtsnavn!';
@@ -347,11 +355,11 @@ $strHungarian = 'Ungarsk';
 $strIcelandic = 'Islandsk';
 $strId = 'ID';
 $strIdxFulltext = 'Fuldtekst';
+$strIEUnsupported = 'Internet Explorer understtter ikke denne funktion.';
 $strIgnoreDuplicates = 'Ignorr gentagne rkker';
 $strIgnore = 'Ignorer';
 $strIgnoreInserts = 'Brug ignorr inserts';
-$strIgnoringFile = 'Ignorerer fil %s';
-$strImportDocSQL = 'Importer docSQL Filer';
+$strImportExportCoords = 'Importer/Eksporter koordinater for PDF-opstilling';
 $strImportFiles = 'Importr filer';
 $strImportFormat = 'Format p importeret fil';
 $strImport = 'Import';
@@ -373,6 +381,7 @@ $strInnoDBDataFilePath = 'Datafiler';
 $strInnoDBDataHomeDir = 'Data hovedmappe';
 $strInnoDBDataHomeDirDesc = 'Den flles del af stien til mappen med alle InnoDB datafiler.';
 $strInnoDBPages = 'sider';
+$strInnoDBRelationAdded = 'InnoDB-relation tilfjet';
 $strInnodbStat = 'InnoDB status';
 $strInsecureMySQL = 'Din konfigurationsfil indeholder indstillinger (root og intet kodeord) som svarer til en standard MySQL-priviligeret brugerkonto. Din MySQL server krer med denne standardindstilling, <u>er ben for indtrngen</u>, og du opfordres strkt til at gre noget ved dette sikkerhedshul.';
 $strInsertAsNewRow = 'Indst som ny rkke';
@@ -380,6 +389,7 @@ $strInsertedRowId = 'Indsat rkke-id:';
 $strInsertedRows = 'Indsatte rkker:';
 $strInsert = 'Indst';
 $strInternalNotNecessary = '* En intern relation er ikke ndvendig nr den ogs eksisterer i InnoDB.';
+$strInternalRelationAdded = 'Intern relation tilfjet';
 $strInternalRelations = 'Interne relationer';
 $strInUse = 'i brug';
 $strInvalidAuthMethod = 'Ugyldig autorisationsmetode sat i konfiguration:';
@@ -407,6 +417,7 @@ $strKeepPass = 'Kodeord m ikke ndres';
 $strKeyCache = 'Nglemellemlager (key cache)';
 $strKeyname = 'Nglenavn';
 $strKill = 'Drb (Kill)';
+$strKnownExternalBug = 'Funktionaliteten af %s er pvirket af en kendt fejl, se %s';
 $strKorean = 'Koreansk';
 
 $strLandscape = 'Liggende';
@@ -455,13 +466,14 @@ $strMIME_MIMEtype = 'MIME-type';
 $strMIME_nodescription = 'Der er ingen beskrivelse af denne transformation.<br />Sprg venligst forfatteren, hvad %s gr.';
 $strMIME_transformation = 'Browser transformation';
 $strMIME_transformation_note = 'For en liste over mulige transformationsindstillinger og deres MIME-type transformationer, klik p %stransformationsbeskrivelser%s';
-$strMIME_transformation_options_note = 'Indtast vrdier for transformationsindstillinger ud fra flgende format: \'a\',\'b\',\'c\'...<br />Skulle du f brug for at indstte en backslash ("\") eller en apostrof ("\'") i vrdierne, backslash det (for eksempel \'\\\\xyz\' eller \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Indtast vrdier for transformationsindstillinger ud fra flgende format: \'a\', 100, b,\'c\'...<br />Skulle du f brug for at indstte en backslash ("\") eller en apostrof ("\'") i vrdierne, backslash det (for eksempel \'\\\\xyz\' eller \'a\\\'b\').';
 $strMIME_transformation_options = 'Transformationsindstillinger';
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE (MIME-typer for tabellen)';
 $strMIME_without = 'MIME-typer skrevet med kursiv har ikke en separat transformationsfunktion';
 $strModifications = 'Rettelserne er gemt!';
 $strModifyIndexTopic = 'ndring af et indeks';
 $strModify = 'Ret';
+$strMoveMenu = 'Flyt Menu';
 $strMoveTable = 'Flyt tabel til (database<b>.</b>tabel):';
 $strMoveTableOK = 'Tabel %s er flyttet til %s.';
 $strMoveTableSameNames = 'Kan ikke flytte tabellen til den samme!';
@@ -520,6 +532,7 @@ $strNoUsersFound = 'Ingen bruger(e) fundet.';
 $strNoValidateSQL = 'Spring over Validr SQL';
 $strNull = 'Nulvrdi';
 $strNumberOfFields = 'Antal felter';
+$strNumberOfTables = 'Antal tabeller';
 $strNumSearchResultsInTable = '%s hit(s) i tabel <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> hit(s)';
 $strNumTables = 'Tabeller';
@@ -562,8 +575,10 @@ $strPhoneBook = 'telefonbog';
 $strPHP40203 = 'Du bruger PHP 4.2.3, som har en alvorlig fejl med multi-byte strenge (mbstring). Se PHP bug report 19404. Denne version af PHP kan ikke anbefales at bruge med phpMyAdmin.';
 $strPhp = 'Fremstil PHP-kode';
 $strPHPVersion = 'PHP-version';
+$strPleaseSelectPrimaryOrUniqueKey = 'Vlg venligst den primre ngle eller en unik ngle';
 $strPmaDocumentation = 'phpMyAdmin dokumentation';
 $strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktivet SKAL vre sat i din konfigurationsfil!';
+$strPmaWiki = 'phpMyAdmin wiki';
 $strPolish = 'Polsk';
 $strPortrait = 'Stende';
 $strPos1 = 'Start';
@@ -634,16 +649,19 @@ $strQueryWindowLock = 'Overskriv ikke denne foresprgsel fra udenfor vinduet';
 
 $strReadRequests = 'Read-anmodninger';
 $strReceived = 'Modtaget';
+$strRecommended = 'anbefalet';
 $strRecords = 'Poster';
 $strReferentialIntegrity = 'Check reference-integriteten';
 $strRefresh = 'Opdatr';
 $strRelationalSchema = 'Relationel skematik';
+$strRelationDeleted = 'Relation slettet';
 $strRelationNotWorking = 'De ekstra features for at arbejde med linkede tabeller er deaktiveret. For at se hvorfor, klik %sher%s.';
 $strRelationsForTable = 'RELATIONS FOR TABLE (Relationer for tabellen)';
 $strRelations = 'Relationer';
 $strRelationView = 'Se Relationer';
 $strReloadingThePrivileges = 'Genindls privilegierne';
 $strReloadPrivileges = 'Genindls privilegier';
+$strReload = 'Genindls';
 $strRemoveSelectedUsers = 'Fjern valgte brugere';
 $strRenameDatabaseOK = 'Database %s er blevet omdbt til %s';
 $strRenameTableOK = 'Tabellen %s er nu omdbt til %s';
@@ -676,6 +694,7 @@ $strRunSQLQueryOnServer = 'Kr SQL-foresprgsel/foresprgsler p server %s';
 $strRussian = 'Russisk';
 
 $strSave = 'Gem';
+$strSavePosition = 'Gem position';
 $strSaveOnServer = 'Gem p serveren i mappen %s ';
 $strScaleFactorSmall = 'Skaleringsfaktoren er for lille til at tilpasse skematikken til en side';
 $strSearchFormTitle = 'Sg i databasen';
@@ -693,7 +712,9 @@ $strSelectADb = 'Vlg en database';
 $strSelectAll = 'Vlg alle';
 $strSelectBinaryLog = 'Vlg binrlog til gennemsyn';
 $strSelectFields = 'Vlg mindst eet felt:';
+$strSelectForeignKey = 'Vlg fremmedngle';
 $strSelectNumRows = 'i foresprgsel';
+$strSelectReferencedKey = 'Vlg refereret ngle';
 $strSelectTables = 'Vlg Tabeller';
 $strSend = 'Send (download)';
 $strSent = 'Sendt';
@@ -715,10 +736,14 @@ $strShowColor = 'Vis farve';
 $strShowDatadictAs = 'Data Dictionary-format';
 $strShowFullQueries = 'Vis fuldstndige foresprgsler';
 $strShowGrid = 'Vis gitter';
+$strShowHideLeftMenu = 'Vis/skjul venstre menu';
 $strShowingBookmark = 'Viser bogmrke';
+$strShowingPhp = 'Viser som PHP-kode';
 $strShowingRecords = 'Viser poster ';
+$strShowingSQL = 'Viser SQL-foresprgsel';
 $strShowOpenTables = 'Vis bne tabeller';
 $strShowPHPInfo = 'Vis PHP-information';
+$strShow = 'Vis';
 $strShowSlaveHosts = 'Vis slavevrter';
 $strShowSlaveStatus = 'Vis slavestatus';
 $strShowStatusBinlog_cache_disk_useDescr = 'Antal transaktioner der brugte det midlertidige binre log mellemlager, men overskred vrdien for binlog_cache_size og brugte en midlertidig fil til at gemme statements fra transaktionen.';
@@ -831,13 +856,14 @@ $strShowStatusThreads_runningDescr = 'Antallet af trde der ikke sover.';
 $strShowTableDimension = 'Vis tabellernes dimensioner';
 $strShowTables = 'Vis tabeller';
 $strShowThisQuery = ' Vis foresprgslen her igen ';
-$strShow = 'Vis';
 $strSimplifiedChinese = 'Simplificeret Kinesisk';
 $strSingly = '(enkeltvis)';
 $strSize = 'Strrelse';
 $strSkipQueries = 'Antal poster (queries) der skal springes over fra start';
 $strSlovak = 'Slovakisk';
 $strSlovenian = 'Slovensk';
+$strSmallBigAll = 'Sm/store alle';
+$strSnapToGrid = 'Snap til gitter';
 $strSocketProblem = '(eller den lokale MySQL servers socket er ikke korrekt konfigureret)';
 $strSortByKey = 'Sorteringsngle';
 $strSorting = 'Sortering';
@@ -857,6 +883,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Ugyldig identifikator';
 $strSQPBugUnclosedQuote = 'Ikke-lukket quote';
 $strSQPBugUnknownPunctuation = 'Ukendt tegnstnings-streng';
+$strStandInStructureForView = 'Stand-in-struktur for visning';
 $strStatCheckTime = 'Sidste check';
 $strStatCreateTime = 'Oprettelse';
 $strStatement = 'Erklringer';
@@ -872,6 +899,7 @@ $strStrucNativeExcel = 'Fdte MS Excel-data';
 $strStrucNativeExcelOptions = 'Fdte Excel eksportindstillinger';
 $strStrucOnly = 'Kun strukturen';
 $strStructPropose = 'Foresl tabelstruktur';
+$strStructureForView = 'Struktur for visning';
 $strStructure = 'Struktur';
 $strSubmit = 'Send';
 $strSuccess = 'Din SQL-foresprgsel blev udfrt korrekt';
@@ -886,7 +914,9 @@ $strTableEmpty = 'Intet tabelnavn!';
 $strTableHasBeenDropped = 'Tabel %s er slettet';
 $strTableHasBeenEmptied = 'Tabel %s er tmt';
 $strTableHasBeenFlushed = 'Tabel %s er blevet flushet';
+$strTableIsEmpty = 'Tabel ser ud til at vre tom!';
 $strTableMaintenance = 'Tabelvedligeholdelse';
+$strTableName = 'Tabelnavn';
 $strTableOfContents = 'Indholdsfortegnelse';
 $strTableOptions = 'Tabel-indstillinger';
 $strTables = '%s tabel(ler)';
@@ -904,14 +934,16 @@ $strThemeNoValidImgPath = 'Ingen gyldig billedsti for tema %s fundet!';
 $strThemePathNotFound = 'Sti til tema ikke fundet for tema %s!';
 $strTheme = 'Tema / Layout';
 $strThisHost = 'Denne Host';
-$strThisNotDirectory = 'Dette var ikke en mappe';
 $strThreads = 'Trde';
 $strThreadSuccessfullyKilled = 'Trd %s blev stoppet.';
 $strTimeoutInfo = 'Foregende import timede ud, efter genindsendelse vil fortstte fra position %d.';
 $strTimeoutNothingParsed = 'Desvrre blev der ikke parset nogen data ved sidste krsel, dette betyder normalt at phpMyAdmin ikke vil vre i stand til at gennemfre importen med mindre du forger PHP-tidsbegrnsningerne.';
 $strTimeoutPassed = 'Script timeout net, hvis du vil afslutte importen, indsend venligst samme fil igen og importen vil fortstte hvor den slap.';
 $strTime = 'Tid';
+$strToFromPage = 'til/fra side';
 $strToggleScratchboard = 'tegnebrt til/fra';
+$strToggleSmallBig = 'Skift mellem sm/store';
+$strToSelectRelation = 'For at vlge relation, klik :';
 $strTotal = 'total';
 $strTotalUC = 'Total';
 $strTraditionalChinese = 'Traditionelt Kinesisk';
@@ -923,7 +955,7 @@ $strTransformation_application_octetstream__hex = 'Viser hexadecimal udgave af d
 $strTransformation_image_jpeg__inline = 'Viser et klikbart minibillede; indstillinger: bredde,hjde i pixel. Det originale perspektiv bevares.';
 $strTransformation_image_jpeg__link = 'Viser et link til dette billede (f.eks. direkte blob-download).';
 $strTransformation_image_png__inline = 'Se under image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Tager et TIME, TIMESTAMP eller DATETIME-felt og formatterer det til dit lokale datoformat. Frste parameter er offset (i timer) som lgges til tidsstemplet (Default: 0). Andet parameter er et andet datoformat ud fra PHPs strftime() definition.';
+$strTransformation_text_plain__dateformat = 'Viser et TIME, TIMESTAMP, DATETIME eller numerisk unix tidsstempel-felt som formatteret dato. Den frste indstilling er offset (i timer) som vil blive lagt til tidsstemplet (Standard: 0). Brug anden indstilling til at angive en anderledes dato-/tidsformatstreng. Tredje indstilling faststter om du vil se lokal dato eller UTC (brug "local" eller "utc" strenge) til dette. Ud fra dette har datoformatet forskellig vrdi - for "local" se dokumentationen for PHP\'s strftime() funktion og for "utc" sker det ved brug af gmdate() funktionen.';
 $strTransformation_text_plain__external = 'KUN LINUX: Starter en ekstern applikation og fder feltdata via standard input. Returnerer standardoutputtet for applikationen. Standard er Tidy, for korrekt udskrivning af HTML-kode. Af sikkerhedsrsager er du ndt til manuelt at redigere filen libraries/transformations/text_plain__external.inc.php og indstte de vrktjer du vil tillade krsel af. Frste indstilling er s nummeret p det program du vil bruge og den anden indstilling er parametrene for dette program. Tredie parameter vil, hvis sat til 1, konvertere outputtet vha. htmlspecialchars() (Standard er 1). Et fjerde parameter vil, hvis sat til 1, stte et NOWRAP om cellens indhold s hele outputtet bliver vist uden omformattering (Standard 1)';
 $strTransformation_text_plain__formatted = 'Bevarer original formattering af feltet. Der laves ikke nogen Escaping.';
 $strTransformation_text_plain__imagelink = 'Viser et billede og et link, feltet indeholder filnavnet; frste indstilling er et prfiks som "http://domain.com/", anden indstilling er bredde i pixel, tredie er hjden.';
@@ -985,8 +1017,6 @@ $strWildcard = 'jokertegn';
 $strWindowNotFound = 'Det angivne browservindue kunne ikke opdateres. Mske har du lukket det overliggende vindue eller din browser blokerer for tvr-vindue opdateringer i sikkerhedsindstillingerne';
 $strWithChecked = 'Med det markerede:';
 $strWriteRequests = 'Write-anmodninger';
-$strWritingCommentNotPossible = 'Skrivning af kommentar ikke muligt';
-$strWritingRelationNotPossible = 'Skrivning af relation ikke muligt';
 $strWrongUser = 'Forkert brugernavn/kodeord. Adgang ngtet.';
 
 $strXMLOptions = 'XML-indstillinger';
