@@ -1,5 +1,5 @@
 <?php
-/* $Id: danish-utf-8.inc.php,v 2.161.2.1 2006/09/29 16:25:44 lem9 Exp $ */ /* danish - Dansk v 2.162 (based on english 2.159) 2006/09/25 01:23:45 - oversætter AlleyKat kan kontaktes på < phpmyadmin (at) phpbb2.dk > */
+/* $Id: danish-utf-8.inc.php 10258 2007-04-07 15:27:37Z lem9 $ */ /* danish - Dansk v 2.162 (based on english 2.159) 2006/09/25 01:23:45 - oversætter AlleyKat kan kontaktes på < phpmyadmin (at) phpbb2.dk > */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -7,7 +7,7 @@ $text_dir = 'ltr';
 $number_thousands_separator = '.';
 $number_decimal_separator = ',';
 // forkortelser for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits  =  array('Bytes', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');
+$byteUnits  =  array('B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');
 
 // MySQL manual sprogdefinition, ikke påkrævet, en bruges hvis
 // ikke defineret - da findes endnu ikke
@@ -23,7 +23,6 @@ $datefmt = '%d/%m %Y kl. %H:%M:%S';
 $timespanfmt = '%s dage, %s timer, %s minutter og %s sekunder';
 
 $strAbortedClients = 'Afbrudt';
-$strAbsolutePathToDocSqlDir = 'Indtast venligst absolut sti på webserveren til docSQL mappen';
 $strAccessDenied = 'Adgang Nægtet';
 $strAccessDeniedCreateConfig = 'Sandsynlig årsag til dette er at du ikke har oprettet en konfigurationsfil. Du kan bruge %1$sopsætningsscriptet%2$s til at oprette en.';
 $strAccessDeniedExplanation = 'phpMyAdmin forsøgte at forbinde til MySQL-serveren, og serveren afviste forbindelsen. Du bør tjekke host, brugernavn og kodeord i config.inc.php og sikre dig at de svarer til den information du har fået af administratoren af MySQL-serveren.';
@@ -33,8 +32,6 @@ $strAddClause = 'Tilføj %s';
 $strAddConstraints = 'Tilføj begrænsninger';
 $strAddDeleteColumn = 'Tilføj/Slet felt-kolonne';
 $strAddDeleteRow = 'Tilføj/Slet kriterie-række';
-$strAddedColumnComment = 'Tilføjet kommentar til kolonne';
-$strAddedColumnRelation = 'Tilføjet relation til kolonne';
 $strAddFields = 'Tilføj %s felt(er)';
 $strAddHeaderComment = 'Tilføj tilpassede kommentarer i headeren (\\n deler linjer)';
 $strAddIntoComments = 'Tilføj til kommentarer';
@@ -59,6 +56,7 @@ $strAlterOrderBy = 'Arrangér tabelrækkefølge efter';
 $strAnalyzeTable = 'Analysér tabel';
 $strAnd = 'Og';
 $strAndThen = 'og derefter';
+$strAngularLinks = 'Angulære links';
 $strAnIndex = 'Der er tilføjet et indeks til %s';
 $strAny = 'Enhver';
 $strAnyHost = 'Enhver vært';
@@ -111,6 +109,7 @@ $strBzError = 'phpMyAdmin kunne ikke komprimere dumpet på grund af en ødelagt
 $strBzip = '"bzipped"';
 
 $strCalendar = 'Kalender';
+$strCancel = 'Annuller';
 $strCanNotLoadExportPlugins = 'Kunne ikke indlæse eksportplugins, check venligst din installation!';
 $strCanNotLoadImportPlugins = 'Kunne ikke indlæse importplugins, check venligst din installation!';
 $strCannotLogin = 'Kan ikke logge ind på MySQL-serveren';
@@ -174,6 +173,8 @@ $strCreateNewTable = 'Opret ny tabel i database %s';
 $strCreate = 'Opret';
 $strCreatePage = 'Opret en ny side';
 $strCreatePdfFeat = 'Oprettelse af PDFer';
+$strCreateRelation = 'Opret relation';
+$strCreateTable  = 'Opret tabel';
 $strCreateUserDatabase = 'Database for bruger';
 $strCreateUserDatabaseName = 'Opret database med samme navn og tildel alle privilegier';
 $strCreateUserDatabaseNone = 'Ingen';
@@ -206,15 +207,7 @@ $strDataOnly = 'Kun data';
 $strDataPages = 'Sider der indeholder data';
 $strDBComment = 'Databasekommentar: ';
 $strDBCopy = 'Kopiér database til';
-$strDBGContextID = 'Sammenhæng-ID';
-$strDBGContext = 'Sammenhæng';
-$strDBGHits = 'Hits';
-$strDBGLine = 'Linje';
-$strDBGMaxTimeMs = 'Max tid, ms';
-$strDBGMinTimeMs = 'Min tid, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Tid/Hit, ms';
-$strDBGTotalTimeMs = 'Total tid, ms';
+$strDbIsEmpty = 'Database ser ud til at være tom!';
 $strDbPrivileges = 'Database-specifikke privilegier';
 $strDBRename = 'Omdøb database til';
 $strDbSpecific = 'database-specifik';
@@ -229,12 +222,16 @@ $strDeleted = 'Rækken er slettet!';
 $strDeletedRows = 'Slettede rækker:';
 $strDeleteNoUsersSelected = 'Ingen brugere valgt til sletning!';
 $strDelete = 'Slet';
+$strDeleteRelation = 'Slet relation';
 $strDeleting = 'Sletter %s';
 $strDelimiter = 'Adskiller';
 $strDelOld = 'Nuværende side har referencer til tabeller der ikke længere eksisterer. Vil du slette disse referencer?';
 $strDescending = 'Faldende';
 $strDescription = 'Beskrivelse';
+$strDesigner = 'Designer';
+$strDesignerHelpDisplayField = 'Visningsfeltet er vist som pink. For at sætte/fjerne et felt som visningsfelt, klik på "Vælg felt der skal vises" ikonet, og klik derefter på det pågældende feltnavn.';
 $strDictionary = 'ordbog';
+$strDirectLinks = 'Direkte links';
 $strDirtyPages = 'Beskidte sider';
 $strDisabled = 'Slået fra';
 $strDisableForeignChecks = 'Slå fremmednøgle-checks fra';
@@ -242,6 +239,8 @@ $strDisplayFeat = 'Vis muligheder';
 $strDisplayOrder = 'Rækkefølge af visning:';
 $strDisplayPDF = 'Vis PDF-skematik';
 $strDoAQuery = 'Kør en forespørgsel på felter (jokertegn: "%")';
+$strDocSQL = 'DocSQL';
+$strDocSQLOptions = 'DocSQL indstillinger';
 $strDocu = 'Dokumentation';
 $strDoYouReally = 'Er du sikker på at du vil ';
 $strDropDatabaseStrongWarning = 'Du er ved at DESTRUERE en komplet database!';
@@ -271,6 +270,9 @@ $strEnglish = 'Engelsk';
 $strEnglishPrivileges = ' NB: Navne på MySQL privilegier er på engelsk ';
 $strError = 'Fejl';
 $strErrorInZipFile = 'Fejl i ZIP arkiv:';
+$strErrorRelationAdded = 'Fejl: Relation ikke tilføjet.';
+$strErrorRelationExists = 'Fejl: Relation findes allerede.';
+$strErrorSaveTable = 'Fejl ved lagring af koordinater for Designer.';
 $strErrorRenamingTable = 'Fejl ved omdøbning af tabel  %1$s til %2$s';
 $strEscapeWildcards = 'Jokertegn _ og % skal være escaped med en \ foran for at bruge dem bogstaveligt';
 $strEsperanto = 'Esperanto';
@@ -280,6 +282,7 @@ $strExcelOptions = 'Excel-indstillinger';
 $strExecuteBookmarked = 'Udfør forespørgsel iflg. bogmærke';
 $strExplain = 'Forklar SQL';
 $strExport = 'Eksport';
+$strExportImportToScale = 'Eksporter/Importer til skala';
 $strExportMustBeFile = 'Valgte eksporttype skal gemmes som fil!';
 $strExtendedInserts = 'Udvidede inserts';
 $strExtra = 'Ekstra';
@@ -307,6 +310,7 @@ $strFlushQueryCache = 'Flush forespørgsel-mellemlager (query cache)';
 $strFlushTable = 'Flush tabellen ("FLUSH")';
 $strFlushTables = 'Flush (luk) alle tabeller';
 $strFontSize = 'Skriftstørrelse';
+$strForeignKeyError = 'Fejl ved oprettelse af fremmednøgle (check datatyper)';
 $strFormat = 'Format';
 $strFormEmpty = 'Ingen værdi i formularen !';
 $strFreePages = 'Frie sider';
@@ -334,7 +338,11 @@ $strHasBeenAltered = 'er ændret.';
 $strHasBeenCreated = 'er oprettet.';
 $strHaveToShow = 'Du skal vælge mindst en kolonne der skal vises';
 $strHebrew = 'Hebræisk';
+$strHelp = 'Hjælp';
 $strHexForBinary = 'Brug hexadecimal til binære felter';
+$strHide         = 'Skjul';
+$strHideShowAll = 'Skjul/Vis alle';
+$strHideShowNoRelation = 'Skjul/Vis tabeller uden relation';
 $strHome = 'Hjem';
 $strHomepageOfficial = 'Officiel phpMyAdmin hjemmeside ';
 $strHostEmpty = 'Der er intet værtsnavn!';
@@ -348,11 +356,11 @@ $strHungarian = 'Ungarsk';
 $strIcelandic = 'Islandsk';
 $strId = 'ID';
 $strIdxFulltext = 'Fuldtekst';
+$strIEUnsupported = 'Internet Explorer understøtter ikke denne funktion.';
 $strIgnoreDuplicates = 'Ignorér gentagne rækker';
 $strIgnore = 'Ignorer';
 $strIgnoreInserts = 'Brug ignorér inserts';
-$strIgnoringFile = 'Ignorerer fil %s';
-$strImportDocSQL = 'Importer docSQL Filer';
+$strImportExportCoords = 'Importer/Eksporter koordinater for PDF-opstilling';
 $strImportFiles = 'Importér filer';
 $strImportFormat = 'Format på importeret fil';
 $strImport = 'Import';
@@ -374,6 +382,7 @@ $strInnoDBDataFilePath = 'Datafiler';
 $strInnoDBDataHomeDir = 'Data hovedmappe';
 $strInnoDBDataHomeDirDesc = 'Den fælles del af stien til mappen med alle InnoDB datafiler.';
 $strInnoDBPages = 'sider';
+$strInnoDBRelationAdded = 'InnoDB-relation tilføjet';
 $strInnodbStat = 'InnoDB status';
 $strInsecureMySQL = 'Din konfigurationsfil indeholder indstillinger (root og intet kodeord) som svarer til en standard MySQL-priviligeret brugerkonto. Din MySQL server kører med denne standardindstilling, <u>er åben for indtrængen</u>, og du opfordres stærkt til at gøre noget ved dette sikkerhedshul.';
 $strInsertAsNewRow = 'Indsæt som ny række';
@@ -381,6 +390,7 @@ $strInsertedRowId = 'Indsat række-id:';
 $strInsertedRows = 'Indsatte rækker:';
 $strInsert = 'Indsæt';
 $strInternalNotNecessary = '* En intern relation er ikke nødvendig når den også eksisterer i InnoDB.';
+$strInternalRelationAdded = 'Intern relation tilføjet';
 $strInternalRelations = 'Interne relationer';
 $strInUse = 'i brug';
 $strInvalidAuthMethod = 'Ugyldig autorisationsmetode sat i konfiguration:';
@@ -408,6 +418,7 @@ $strKeepPass = 'Kodeord må ikke ændres';
 $strKeyCache = 'Nøglemellemlager (key cache)';
 $strKeyname = 'Nøglenavn';
 $strKill = 'Dræb (Kill)';
+$strKnownExternalBug = 'Funktionaliteten af %s er påvirket af en kendt fejl, se %s';
 $strKorean = 'Koreansk';
 
 $strLandscape = 'Liggende';
@@ -456,13 +467,14 @@ $strMIME_MIMEtype = 'MIME-type';
 $strMIME_nodescription = 'Der er ingen beskrivelse af denne transformation.<br />Spørg venligst forfatteren, hvad %s gør.';
 $strMIME_transformation = 'Browser transformation';
 $strMIME_transformation_note = 'For en liste over mulige transformationsindstillinger og deres MIME-type transformationer, klik på %stransformationsbeskrivelser%s';
-$strMIME_transformation_options_note = 'Indtast værdier for transformationsindstillinger ud fra følgende format: \'a\',\'b\',\'c\'...<br />Skulle du få brug for at indsætte en backslash ("\") eller en apostrof ("\'") i værdierne, backslash det (for eksempel \'\\\\xyz\' eller \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Indtast værdier for transformationsindstillinger ud fra følgende format: \'a\', 100, b,\'c\'...<br />Skulle du få brug for at indsætte en backslash ("\") eller en apostrof ("\'") i værdierne, backslash det (for eksempel \'\\\\xyz\' eller \'a\\\'b\').';
 $strMIME_transformation_options = 'Transformationsindstillinger';
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE (MIME-typer for tabellen)';
 $strMIME_without = 'MIME-typer skrevet med kursiv har ikke en separat transformationsfunktion';
 $strModifications = 'Rettelserne er gemt!';
 $strModifyIndexTopic = 'Ændring af et indeks';
 $strModify = 'Ret';
+$strMoveMenu = 'Flyt Menu';
 $strMoveTable = 'Flyt tabel til (database<b>.</b>tabel):';
 $strMoveTableOK = 'Tabel %s er flyttet til %s.';
 $strMoveTableSameNames = 'Kan ikke flytte tabellen til den samme!';
@@ -521,6 +533,7 @@ $strNoUsersFound = 'Ingen bruger(e) fundet.';
 $strNoValidateSQL = 'Spring over Validér SQL';
 $strNull = 'Nulværdi';
 $strNumberOfFields = 'Antal felter';
+$strNumberOfTables = 'Antal tabeller';
 $strNumSearchResultsInTable = '%s hit(s) i tabel <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> hit(s)';
 $strNumTables = 'Tabeller';
@@ -563,8 +576,10 @@ $strPhoneBook = 'telefonbog';
 $strPHP40203 = 'Du bruger PHP 4.2.3, som har en alvorlig fejl med multi-byte strenge (mbstring). Se PHP bug report 19404. Denne version af PHP kan ikke anbefales at bruge med phpMyAdmin.';
 $strPhp = 'Fremstil PHP-kode';
 $strPHPVersion = 'PHP-version';
+$strPleaseSelectPrimaryOrUniqueKey = 'Vælg venligst den primære nøgle eller en unik nøgle';
 $strPmaDocumentation = 'phpMyAdmin dokumentation';
 $strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktivet SKAL være sat i din konfigurationsfil!';
+$strPmaWiki = 'phpMyAdmin wiki';
 $strPolish = 'Polsk';
 $strPortrait = 'Stående';
 $strPos1 = 'Start';
@@ -635,16 +650,19 @@ $strQueryWindowLock = 'Overskriv ikke denne forespørgsel fra udenfor vinduet';
 
 $strReadRequests = 'Read-anmodninger';
 $strReceived = 'Modtaget';
+$strRecommended = 'anbefalet';
 $strRecords = 'Poster';
 $strReferentialIntegrity = 'Check reference-integriteten';
 $strRefresh = 'Opdatér';
 $strRelationalSchema = 'Relationel skematik';
+$strRelationDeleted = 'Relation slettet';
 $strRelationNotWorking = 'De ekstra features for at arbejde med linkede tabeller er deaktiveret. For at se hvorfor, klik %sher%s.';
 $strRelationsForTable = 'RELATIONS FOR TABLE (Relationer for tabellen)';
 $strRelations = 'Relationer';
 $strRelationView = 'Se Relationer';
 $strReloadingThePrivileges = 'Genindlæs privilegierne';
 $strReloadPrivileges = 'Genindlæs privilegier';
+$strReload = 'Genindlæs';
 $strRemoveSelectedUsers = 'Fjern valgte brugere';
 $strRenameDatabaseOK = 'Database %s er blevet omdøbt til %s';
 $strRenameTableOK = 'Tabellen %s er nu omdøbt til %s';
@@ -677,6 +695,7 @@ $strRunSQLQueryOnServer = 'Kør SQL-forespørgsel/forespørgsler på server %s';
 $strRussian = 'Russisk';
 
 $strSave = 'Gem';
+$strSavePosition = 'Gem position';
 $strSaveOnServer = 'Gem på serveren i mappen %s ';
 $strScaleFactorSmall = 'Skaleringsfaktoren er for lille til at tilpasse skematikken til en side';
 $strSearchFormTitle = 'Søg i databasen';
@@ -694,7 +713,9 @@ $strSelectADb = 'Vælg en database';
 $strSelectAll = 'Vælg alle';
 $strSelectBinaryLog = 'Vælg binærlog til gennemsyn';
 $strSelectFields = 'Vælg mindst eet felt:';
+$strSelectForeignKey = 'Vælg fremmednøgle';
 $strSelectNumRows = 'i forespørgsel';
+$strSelectReferencedKey = 'Vælg refereret nøgle';
 $strSelectTables = 'Vælg Tabeller';
 $strSend = 'Send (download)';
 $strSent = 'Sendt';
@@ -716,10 +737,14 @@ $strShowColor = 'Vis farve';
 $strShowDatadictAs = 'Data Dictionary-format';
 $strShowFullQueries = 'Vis fuldstændige forespørgsler';
 $strShowGrid = 'Vis gitter';
+$strShowHideLeftMenu = 'Vis/skjul venstre menu';
 $strShowingBookmark = 'Viser bogmærke';
+$strShowingPhp = 'Viser som PHP-kode';
 $strShowingRecords = 'Viser poster ';
+$strShowingSQL = 'Viser SQL-forespørgsel';
 $strShowOpenTables = 'Vis åbne tabeller';
 $strShowPHPInfo = 'Vis PHP-information';
+$strShow = 'Vis';
 $strShowSlaveHosts = 'Vis slaveværter';
 $strShowSlaveStatus = 'Vis slavestatus';
 $strShowStatusBinlog_cache_disk_useDescr = 'Antal transaktioner der brugte det midlertidige binære log mellemlager, men overskred værdien for binlog_cache_size og brugte en midlertidig fil til at gemme statements fra transaktionen.';
@@ -832,13 +857,14 @@ $strShowStatusThreads_runningDescr = 'Antallet af tråde der ikke sover.';
 $strShowTableDimension = 'Vis tabellernes dimensioner';
 $strShowTables = 'Vis tabeller';
 $strShowThisQuery = ' Vis forespørgslen her igen ';
-$strShow = 'Vis';
 $strSimplifiedChinese = 'Simplificeret Kinesisk';
 $strSingly = '(enkeltvis)';
 $strSize = 'Størrelse';
 $strSkipQueries = 'Antal poster (queries) der skal springes over fra start';
 $strSlovak = 'Slovakisk';
 $strSlovenian = 'Slovensk';
+$strSmallBigAll = 'Små/store alle';
+$strSnapToGrid = 'Snap til gitter';
 $strSocketProblem = '(eller den lokale MySQL servers socket er ikke korrekt konfigureret)';
 $strSortByKey = 'Sorteringsnøgle';
 $strSorting = 'Sortering';
@@ -858,6 +884,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Ugyldig identifikator';
 $strSQPBugUnclosedQuote = 'Ikke-lukket quote';
 $strSQPBugUnknownPunctuation = 'Ukendt tegnsætnings-streng';
+$strStandInStructureForView = 'Stand-in-struktur for visning';
 $strStatCheckTime = 'Sidste check';
 $strStatCreateTime = 'Oprettelse';
 $strStatement = 'Erklæringer';
@@ -873,6 +900,7 @@ $strStrucNativeExcel = 'Fødte MS Excel-data';
 $strStrucNativeExcelOptions = 'Fødte Excel eksportindstillinger';
 $strStrucOnly = 'Kun strukturen';
 $strStructPropose = 'Foreslå tabelstruktur';
+$strStructureForView = 'Struktur for visning';
 $strStructure = 'Struktur';
 $strSubmit = 'Send';
 $strSuccess = 'Din SQL-forespørgsel blev udført korrekt';
@@ -887,7 +915,9 @@ $strTableEmpty = 'Intet tabelnavn!';
 $strTableHasBeenDropped = 'Tabel %s er slettet';
 $strTableHasBeenEmptied = 'Tabel %s er tømt';
 $strTableHasBeenFlushed = 'Tabel %s er blevet flushet';
+$strTableIsEmpty = 'Tabel ser ud til at være tom!';
 $strTableMaintenance = 'Tabelvedligeholdelse';
+$strTableName = 'Tabelnavn';
 $strTableOfContents = 'Indholdsfortegnelse';
 $strTableOptions = 'Tabel-indstillinger';
 $strTables = '%s tabel(ler)';
@@ -905,14 +935,16 @@ $strThemeNoValidImgPath = 'Ingen gyldig billedsti for tema %s fundet!';
 $strThemePathNotFound = 'Sti til tema ikke fundet for tema %s!';
 $strTheme = 'Tema / Layout';
 $strThisHost = 'Denne Host';
-$strThisNotDirectory = 'Dette var ikke en mappe';
 $strThreads = 'Tråde';
 $strThreadSuccessfullyKilled = 'Tråd %s blev stoppet.';
 $strTimeoutInfo = 'Foregående import timede ud, efter genindsendelse vil fortsætte fra position %d.';
 $strTimeoutNothingParsed = 'Desværre blev der ikke parset nogen data ved sidste kørsel, dette betyder normalt at phpMyAdmin ikke vil være i stand til at gennemføre importen med mindre du forøger PHP-tidsbegrænsningerne.';
 $strTimeoutPassed = 'Script timeout nået, hvis du vil afslutte importen, indsend venligst samme fil igen og importen vil fortsætte hvor den slap.';
 $strTime = 'Tid';
+$strToFromPage = 'til/fra side';
 $strToggleScratchboard = 'tegnebræt til/fra';
+$strToggleSmallBig = 'Skift mellem små/store';
+$strToSelectRelation = 'For at vælge relation, klik :';
 $strTotal = 'total';
 $strTotalUC = 'Total';
 $strTraditionalChinese = 'Traditionelt Kinesisk';
@@ -924,7 +956,7 @@ $strTransformation_application_octetstream__hex = 'Viser hexadecimal udgave af d
 $strTransformation_image_jpeg__inline = 'Viser et klikbart minibillede; indstillinger: bredde,højde i pixel. Det originale perspektiv bevares.';
 $strTransformation_image_jpeg__link = 'Viser et link til dette billede (f.eks. direkte blob-download).';
 $strTransformation_image_png__inline = 'Se under image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Tager et TIME, TIMESTAMP eller DATETIME-felt og formatterer det til dit lokale datoformat. Første parameter er offset (i timer) som lægges til tidsstemplet (Default: 0). Andet parameter er et andet datoformat ud fra PHPs strftime() definition.';
+$strTransformation_text_plain__dateformat = 'Viser et TIME, TIMESTAMP, DATETIME eller numerisk unix tidsstempel-felt som formatteret dato. Den første indstilling er offset (i timer) som vil blive lagt til tidsstemplet (Standard: 0). Brug anden indstilling til at angive en anderledes dato-/tidsformatstreng. Tredje indstilling fastsætter om du vil se lokal dato eller UTC (brug "local" eller "utc" strenge) til dette. Ud fra dette har datoformatet forskellig værdi - for "local" se dokumentationen for PHP\'s strftime() funktion og for "utc" sker det ved brug af gmdate() funktionen.';
 $strTransformation_text_plain__external = 'KUN LINUX: Starter en ekstern applikation og føder feltdata via standard input. Returnerer standardoutputtet for applikationen. Standard er Tidy, for korrekt udskrivning af HTML-kode. Af sikkerhedsårsager er du nødt til manuelt at redigere filen libraries/transformations/text_plain__external.inc.php og indsætte de værktøjer du vil tillade kørsel af. Første indstilling er så nummeret på det program du vil bruge og den anden indstilling er parametrene for dette program. Tredie parameter vil, hvis sat til 1, konvertere outputtet vha. htmlspecialchars() (Standard er 1). Et fjerde parameter vil, hvis sat til 1, sætte et NOWRAP om cellens indhold så hele outputtet bliver vist uden omformattering (Standard 1)';
 $strTransformation_text_plain__formatted = 'Bevarer original formattering af feltet. Der laves ikke nogen Escaping.';
 $strTransformation_text_plain__imagelink = 'Viser et billede og et link, feltet indeholder filnavnet; første indstilling er et præfiks som "http://domain.com/", anden indstilling er bredde i pixel, tredie er højden.';
@@ -986,8 +1018,6 @@ $strWildcard = 'jokertegn';
 $strWindowNotFound = 'Det angivne browservindue kunne ikke opdateres. Måske har du lukket det overliggende vindue eller din browser blokerer for tvær-vindue opdateringer i sikkerhedsindstillingerne';
 $strWithChecked = 'Med det markerede:';
 $strWriteRequests = 'Write-anmodninger';
-$strWritingCommentNotPossible = 'Skrivning af kommentar ikke muligt';
-$strWritingRelationNotPossible = 'Skrivning af relation ikke muligt';
 $strWrongUser = 'Forkert brugernavn/kodeord. Adgang nægtet.';
 
 $strXMLOptions = 'XML-indstillinger';
