@@ -1,5 +1,5 @@
 <?php
-/* $Id: estonian-iso-8859-1.inc.php,v 2.153 2006/08/10 11:31:26 lem9 Exp $ */
+/* $Id: estonian-iso-8859-1.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /*
  * Translated by Marko Ellermaa, <marko.ellermaa@nlkp.net>
@@ -23,7 +23,6 @@ $datefmt = '%d.%m.%Y kell %H:%M:%S';
 $timespanfmt = '%s peva, %s tundi, %s minutit ja %s sekundit';
 
 $strAbortedClients = 'Katkestatud';
-$strAbsolutePathToDocSqlDir = 'Palun sisestage absoluutne tee webiserveris docSQL kataloogini';
 $strAccessDeniedCreateConfig = 'Arvatav phjus on te pole veel loonud seadete faili. Soovitavalt vid kasutada %1$ssetup script%2$s et seadistada.';
 $strAccessDeniedExplanation = 'phpMyAdmin proovis henduda MySQL serveriga ja server lkkas henduse tagasi. Te peaksite kontrollima serverit, kasutajanime ja parooli config.inc.php failis ning kontrollima, et need vastaks infole mis te saite oma MySQL serveri administraatori kest.';
 $strAccessDenied = 'Ligips keelatud';
@@ -33,8 +32,6 @@ $strAddClause = 'Lisa %s';
 $strAddConstraints = 'Lisa piirangud';
 $strAddDeleteColumn = 'Lisa/Kustuta vlja veerud';
 $strAddDeleteRow = 'Lisa/Kustuta kriteeriumirida';
-$strAddedColumnComment = 'Kommentaar lisatud vljale';
-$strAddedColumnRelation = 'Sltuvus lisatud vljale';
 $strAddFields = 'Lisa %s vli(jad)';
 $strAddHeaderComment = 'Lisa vaba kommentaar pisesse (\\n eraldab read)';
 $strAddIntoComments = 'Lisa kommentaaridesse';
@@ -59,6 +56,7 @@ $strAlterOrderBy = 'Muuda tabeli sorteeringut';
 $strAnalyzeTable = 'Analsi tabelit';
 $strAnd = 'ja';
 $strAndThen = 'ja siis';
+$strAngularLinks = 'Nurgelised lingid'; 
 $strAnIndex = 'Indeks lisati %s';
 $strAnyHost = 'Kik masinad';
 $strAny = 'kik';
@@ -111,6 +109,7 @@ $strBzError = 'phpMyAdmin ei suutnud pakkida seda andmebaasivljundit kuna Bz2 mo
 $strBzip = '"bzipitud"';
 
 $strCalendar = 'Kalender';
+$strCancel = 'Katkesta'; 
 $strCanNotLoadExportPlugins = 'Viga eksportimis moodulite laadimisel, palun kontrolli seadeid!';
 $strCanNotLoadImportPlugins = 'Pole vimalik Importida mooduleid (plugins), palun kontrolli seadeid!';
 $strCannotLogin = 'Ei suuda MySQL serverisse logida';
@@ -174,10 +173,12 @@ $strCreateNewDatabase = 'Loo uus andmebaas';
 $strCreateNewTable = 'Loo uus tabel andmebaasi %s';
 $strCreatePage = 'Loo uus leht';
 $strCreatePdfFeat = 'PDF-ide tegemine';
+$strCreateRelation = 'Suhte loomine (relation)';  
+$strCreateTable  = 'Loo tabel';
 $strCreateUserDatabase = 'Andmebaas kasutajale';  
 $strCreateUserDatabaseName = 'Loo sama nimega andmebaas ja anna kik igused'; 
 $strCreateUserDatabaseNone = 'Puudub';  
-$strCreateUserDatabaseWildcard = 'Anna kik igused Metanimele (username_%)';
+$strCreateUserDatabaseWildcard = 'Anna kik igused Metanimele (username\_%)';
 $strCreationDates = 'Loo/muuda/kontrolli kuupevi';
 $strCriteria = 'Kriteerium';
 $strCroatian = 'Horvaatia';
@@ -195,7 +196,7 @@ $strDatabaseEmpty = 'Andmebaasi nimi on thi!';
 $strDatabaseExportOptions = 'Andmebaasi eksportimise seaded';
 $strDatabaseHasBeenDropped = 'Andmebaas %s kustutatud.';
 $strDatabaseNoTable = 'See andmebaas ei sisalda tabelit!';
-$strDatabases = 'andmebaasid';
+$strDatabases = 'Andmebaasid';
 $strDatabasesDropped = 'andmebaasid %s kustutati nnestunult.';
 $strDatabasesStats = 'Andmebaaside statistika';
 $strDatabasesStatsDisable = 'Keelake statistika';
@@ -206,15 +207,7 @@ $strDataOnly = 'Ainult andmed';
 $strDataPages = 'Lehed andmetega';
 $strDBComment = 'Andmebaasi kommentaar: ';
 $strDBCopy = 'Kopeeri andmebaas';
-$strDBGContextID = 'Sisu ID';
-$strDBGContext = 'Sisu';
-$strDBGHits = 'Vajutusi';
-$strDBGLine = 'Rida';
-$strDBGMaxTimeMs = 'Max aeg, ms';
-$strDBGMinTimeMs = 'Min aeg, ms';
-$strDBGModule = 'Moodul';
-$strDBGTimePerHitMs = 'Aeg/vajutus, ms';
-$strDBGTotalTimeMs = 'Koguaeg, ms';
+$strDbIsEmpty = 'Andmebaas tundub olevat thi!'; 
 $strDbPrivileges = 'Andmebaas-spetsiifilised privileegid';
 $strDBRename = 'Nimeta andmebaas mber';
 $strDbSpecific = 'andmebaasiphine';
@@ -229,19 +222,24 @@ $strDeleted = 'Rida kustutatud';
 $strDeletedRows = 'Kustuta read:';
 $strDelete = 'Kustuta';
 $strDeleteNoUsersSelected = 'htegi kasutajat pole valitud kustutamiseks!';
+$strDeleteRelation = 'Kustuta suhe';  
 $strDeleting = 'Kustutan %s';
 $strDelimiter = 'Eraldaja'; 
 $strDelOld = 'Antud lehel on viiteid tabelitele mida enam ei ole. Kas te soovite kustutada need viited?';
 $strDescending = 'Kahanev';
 $strDescription = 'Kirjeldus';
+$strDesigner = 'Kujundaja';
 $strDictionary = 'snaraamat';
+$strDirectLinks = 'Otselingid';  
 $strDirtyPages = 'Mustad lehed';
 $strDisabled = 'Keelatud';
-$strDisableForeignChecks = 'Keela foreign keyde kontroll';
+$strDisableForeignChecks = 'Keela vrvtmete (foreign key) kontroll';
 $strDisplayFeat = 'Kuva vimalused';
 $strDisplayOrder = 'Nitamise jrjekord:';
 $strDisplayPDF = 'Nita PDF skeemi';
 $strDoAQuery = 'Tee "pring nite jrgi" (lhend: "%")';
+$strDocSQL = 'DocSQL';  
+$strDocSQLOptions = 'DocSQL valikud';  
 $strDocu = 'Dokumentatsioon';
 $strDoYouReally = 'Kas te testi tahate ';
 $strDropDatabaseStrongWarning = 'Thelepanu! Te HVITATE kogu andmebaasi!';
@@ -280,6 +278,7 @@ $strExcelOptions = 'Excel\'i seaded';
 $strExecuteBookmarked = 'Kivita salvestatud pring';
 $strExplain = 'Seleta SQL-i';
 $strExport = 'Ekspordi';
+$strExportImportToScale = 'Ekspordi/Impordi skaala';
 $strExportMustBeFile = 'Valitud eksportimise tp tuleb salvestada faili!';
 $strExtendedInserts = 'Laiendatud lisamised';
 $strExtra = 'Ekstra';
@@ -307,6 +306,7 @@ $strFlushQueryCache = 'Thjenda pringute vahemlu';
 $strFlushTables = 'Thjenda (sulge) kik tabelid';
 $strFlushTable = 'htlusta tabelid ("FLUSH")';
 $strFontSize = 'Fondi suurus';
+$strForeignKeyError = 'Viga luues vrvtit (foreign key) (kontrolli admetpe)';
 $strFormat = 'Formaat';
 $strFormEmpty = 'Puuduv vrtus vormis !';
 $strFreePages = 'Vabad lehed';
@@ -334,7 +334,11 @@ $strHasBeenAltered = 'on muudetud.';
 $strHasBeenCreated = 'on loodud.';
 $strHaveToShow = 'Te peate valima vhemalt he veeru kuvamiseks';
 $strHebrew = 'Heebrea';
+$strHelp = 'Abi';  
 $strHexForBinary = 'Kasuta 16nd koodi binaarvljades';
+$strHide         = 'Peida';
+$strHideShowAll = 'Peida/Nita kik';
+$strHideShowNoRelation = 'Peida/Nita tabelid millel puudub suhe'; 
 $strHome = 'Esileht';
 $strHomepageOfficial = 'Ametlik phpMyAdmini koduleht';
 $strHostEmpty = 'Masin on thi!';
@@ -351,8 +355,7 @@ $strIdxFulltext = 'Tistekst';
 $strIgnoreDuplicates = 'Ignoreeri korduvaid ridasid';
 $strIgnore = 'Ignoreeri';
 $strIgnoreInserts = 'Kasutaja ignoreeritavaid lisamisi';
-$strIgnoringFile = 'Jtan vahele faili %s';
-$strImportDocSQL = 'docSQL failide importimine';
+$strImportExportCoords = 'Impordi/Ekspordi kordinaadid PDF skeemile';
 $strImportFiles = 'Importige failid';
 $strImportFormat = 'Imporditud faili formaat';
 $strImport = 'Import';
@@ -374,6 +377,7 @@ $strInnoDBDataFilePath = 'Andmefailid';
 $strInnoDBDataHomeDir = 'Andmete kodukataloog';
 $strInnoDBDataHomeDirDesc = 'hine kataloogi nimeosa kigi InnoDB andmefailide jaoks.';
 $strInnoDBPages = 'lehti';
+$strInnoDBRelationAdded = 'InnoDB suhe lisatud';
 $strInnodbStat = 'InnoDB staatus';
 $strInsecureMySQL = 'Teie konfiguratsioonifail sisaldab seadeid (root kasutaja ilma paroolita) mis vastab MySQL-i vaikimisi priviligeeritud kasutajale. Kui Teie MySQL-i server jookseb sellise seadega on ta avatud rnnakutele, soovitav on see turvaauk kiiresti parandada.';
 $strInsertAsNewRow = 'Lisa uue reana';
@@ -381,6 +385,7 @@ $strInsertedRowId = 'Lisatud rea id:';
 $strInsertedRows = 'Lisatud read:';
 $strInsert = 'Lisa';
 $strInternalNotNecessary = '* Sisene seos ei ole vajalik kui ta eksisteerib ka InnoDB-s.';
+$strInternalRelationAdded = 'Sisemine suhe loodud'; 
 $strInternalRelations = 'Sisesed seosed';
 $strInUse = 'kasutusel';
 $strInvalidAuthMethod = 'Vigane autoriseerimise meetod konfiguratsioonifailis:';
@@ -408,10 +413,12 @@ $strKeepPass = 'rge muutke parooli';
 $strKeyCache = 'Vtme vahemlu';
 $strKeyname = 'Vtme nimi';
 $strKill = 'Tapa';
+$strKnownExternalBug = 'See %s funktionaalsus on mjutatud tuntud viga, vaata %s';
 $strKorean = 'Korea';
 
 $strLandscape = 'Laipilt';
 $strLanguageFileNotFound = 'Ei leia keele fail "%1$s" .';
+$strLanguage = 'Keel';  
 $strLanguageUnknown = 'Tundmatu keel: %1$s.';
 $strLatchedPages = 'Lukustatud lehed';
 $strLatexCaption = 'Tabeli seletus';
@@ -455,13 +462,14 @@ $strMIME_MIMEtype = 'MIME-tp';
 $strMIME_nodescription = 'Selle transformatsiooni jaoks ei ole kirjeldust.<br />Palun ksige autorilt, mida %s teeb.';
 $strMIME_transformation = 'Browseri transformatsioon';
 $strMIME_transformation_note = 'Transformatsiooni vimaluste ja tema MIME-tbi transformatsiooni nimekirjaks vajutage %stransformatsiooni kirjeldusele%s';
-$strMIME_transformation_options_note = 'Palun sisestage transformatsiooniks vajalikud vrtused, kasutades jrgmist formaati: \'a\',\'b\',\'c\'...<br />Kui teil on vaja edastada kaldkriips ("\") vi lakoma ("\'") nende vrtuste seas, varjestage see tagurpidi kaldkriipsuga (niteks \'\\\\xyz\' vi \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Palun sisestage transformatsiooniks vajalikud vrtused, kasutades jrgmist formaati: \'a\', 100, b,\'c\'...<br />Kui teil on vaja edastada kaldkriips ("\") vi lakoma ("\'") nende vrtuste seas, varjestage see tagurpidi kaldkriipsuga (niteks \'\\\\xyz\' vi \'a\\\'b\').';
 $strMIME_transformation_options = 'Transformeerimise seaded';
 $strMIMETypesForTable = 'MIME TBID TABELILE';
 $strMIME_without = 'MIME-tbid kursiivis ei oma eraldi transofrmatsiooni funktsiooni';
 $strModifications = 'Muutused salvestatud';
 $strModifyIndexTopic = 'Muuda indeksit';
 $strModify = 'Muuda';
+$strMoveMenu = 'Liiguta men';  
 $strMoveTableOK = 'Tabel %s viidu le andmebaasi %s.';
 $strMoveTableSameNames = 'Ei saa tabelit iseendasse liigutada!';
 $strMoveTable = 'Vii tabel le (andmebaas<b>.</b>tabel):';
@@ -520,6 +528,7 @@ $strNoUsersFound = 'Ei leitud htegi kasutajat.';
 $strNoValidateSQL = 'Jta SQL-i kontroll vahele';
 $strNull = 'Null';
 $strNumberOfFields = 'Vljade arv';
+$strNumberOfTables = 'Tabelite arv';
 $strNumSearchResultsInTable = '%s vaste(t) tabelis <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Kokku:</b> <i>%s</i> vaste(t)';
 $strNumTables = 'Tabelid';
@@ -562,8 +571,10 @@ $strPhoneBook = 'telefoniraamat';
 $strPHP40203 = 'Te kasutate PHP 4.2.3, milles on tsine viga mitmebaidiste tekstidega (mbstring). Vaadake PHP vearaportit 19404. Seda PHP versiooni ei soovitata kasutada phpMyAdminiga.';
 $strPhp = 'Loo PHP kood';
 $strPHPVersion = 'PHP versioon';
+$strPleaseSelectPrimaryOrUniqueKey = 'Palun vali primaarne vi unkaalne vti'; 
 $strPmaDocumentation = 'phpMyAdmini dokumentatsioon';
 $strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> konstant peab teie konfiguratsioonifailis mratud olema!';
+$strPmaWiki = 'phpMyAdmin wiki';  
 $strPolish = 'Poola';
 $strPortrait = 'Portreepilt';
 $strPos1 = 'Algus';
@@ -634,15 +645,18 @@ $strQueryWindowLock = 'Antud pringut mitte muuta vljaspool akent.';
 
 $strReadRequests = 'Prdumised lugemiseks';
 $strReceived = 'Saadud';
+$strRecommended = 'soovituslik';  
 $strRecords = 'Kirjeid';
 $strReferentialIntegrity = 'Kontrolli prinevust:';
 $strRefresh = 'Uuenda';
 $strRelationalSchema = 'Seoseskeem';
+$strRelationDeleted = 'Suhe kustutatud'; 
 $strRelationNotWorking = 'Lisavimalused ttamiseks lingitud tabelitega on deaktiveeritud. Et lugeda miks see nii on, vajutage %ssiia%s.';
 $strRelationsForTable = 'SEOSED TABELILE';
 $strRelations = 'Suhted';
 $strRelationView = 'Prinevuse vaade';
 $strReloadingThePrivileges = 'Taaslaen privileege';
+$strReload = 'Lae uuesti';  
 $strReloadPrivileges = 'Lae privileegid uuesti';
 $strRemoveSelectedUsers = 'Eemalda valitud kasutajad';
 $strRenameDatabaseOK = 'Andmebaas %s on mber nimetatud %s';
@@ -676,6 +690,7 @@ $strRunSQLQuery = 'Pri SQL pring(uid) andmebaasist %s';
 $strRussian = 'Vene';
 
 $strSaveOnServer = 'Salvestage serverisse kataloogi %s';
+$strSavePosition = 'Salvesta positsioon';  
 $strSave = 'Salvesta';
 $strScaleFactorSmall = 'Skalaarfaktor on liiga vike, et skeem mahuks hele lehele.';
 $strSearchFormTitle = 'Otsi andmebaasist';
@@ -693,7 +708,9 @@ $strSelectADb = 'Valige andmebaas';
 $strSelectAll = 'Mrgista kik';
 $strSelectBinaryLog = 'Valige binaarne logi vaatamiseks';
 $strSelectFields = 'Vali vljad (vhemalt ks):';
+$strSelectForeignKey = 'Vali vrvti(Foreign Key)';  
 $strSelectNumRows = 'pringus';
+$strSelectReferencedKey = 'Vali eelistus vti (referenced key)';
 $strSelectTables = 'Vali tabelid';
 $strSend = 'Salvesta failina';
 $strSent = 'Saadetud';
@@ -715,8 +732,11 @@ $strShowColor = 'Nita vrvi';
 $strShowDatadictAs = 'Andmesnastiku formaat';
 $strShowFullQueries = 'Nita tispikkasid pringuid';
 $strShowGrid = 'Nita vrgustiku';
+$strShowHideLeftMenu = 'Nita/Peida vasak men';
 $strShowingBookmark = 'Nitan jrjehoidjat';
+$strShowingPhp = 'Nitan PHP koodina'; 
 $strShowingRecords = 'Nita ridu';
+$strShowingSQL = 'Nitan SQL pringut';  
 $strShow = 'Nita';
 $strShowOpenTables = 'Nita avatud tabeleid';
 $strShowPHPInfo = 'Nita PHP informatsiooni';
@@ -838,6 +858,7 @@ $strSize = 'Suurus';
 $strSkipQueries = 'Kske (pringuid) mida algusest vahele jtta';
 $strSlovak = 'Slovaki';
 $strSlovenian = 'Sloveenia';
+$strSmallBigAll = 'Kik Vikeseks/Suureks';  
 $strSocketProblem = '(vi kohaliku MySQL serveri soketid ei ole korrektselt seadistatud)';
 $strSortByKey = 'Sorteeri vtme jrgi';
 $strSorting = 'Jrjestamine';
@@ -857,6 +878,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Vigane identifikaator';
 $strSQPBugUnclosedQuote = 'Sulgemata jutumrk/lakoma';
 $strSQPBugUnknownPunctuation = 'Tundmatu suunav tekst';
+$strStandInStructureForView = 'Sise-vaate struktuur';
 $strStatCheckTime = 'Viimane vaatamine';
 $strStatCreateTime = 'Loodud';
 $strStatement = 'Parameerid';
@@ -872,6 +894,7 @@ $strStrucNativeExcel = 'Loomulikud MS Exceli andmed';
 $strStrucNativeExcelOptions = 'Plised Exceli eksportimise seaded';
 $strStrucOnly = 'Ainult struktuur';
 $strStructPropose = 'Soovita tabeli struktuuri';
+$strStructureForView = 'Vaate (view) struktuur';  
 $strStructure = 'Struktuur';
 $strSubmit = 'Vali';
 $strSuccess = 'Teie SQL pring tideti edukalt';
@@ -886,7 +909,9 @@ $strTableEmpty = 'Tabeli nimi on thi!';
 $strTableHasBeenDropped = 'Tabel %s kustutatud';
 $strTableHasBeenEmptied = 'Tabel %s thjendatud';
 $strTableHasBeenFlushed = 'Tabel %s htlustatud';
+$strTableIsEmpty = 'Tabel tundub olevat thi!';  
 $strTableMaintenance = 'Tabeli hooldus';
+$strTableName = 'Tabeli nimi';  
 $strTableOfContents = 'Sisukord';
 $strTableOptions = 'Tabeli seaded';
 $strTables = '%s tabel(it)';
@@ -904,14 +929,15 @@ $strThemeNoValidImgPath = 'Ei leia pildi kataloogi teemale %s!';
 $strThemePathNotFound = 'Ei leia kataloogi teemale %s!';
 $strTheme = 'Teema / Stiil';
 $strThisHost = 'Antud host';
-$strThisNotDirectory = 'See ei olnud kataloog';
 $strThreads = 'Limud';
 $strThreadSuccessfullyKilled = 'Protsess %s katkestati edukalt.';
 $strTime = 'Aeg';
 $strTimeoutInfo = 'Eelmine Import aegus, peale uuesti postitamist jtkub asukohast %d.';
 $strTimeoutNothingParsed = 'Kuigi viimasel laadimisel andmeid ei tdeldud, see thendab enamasti et phpMyAdmin pole vimeline Importi lpetama, kui sa php skripti aega ei pikenda.';
 $strTimeoutPassed = 'Skripti ajalimiit on letatud, kui soovid importimist jtkata, palun lae sama fail uuesti ja import jtkub.';
+$strToFromPage = 'Kuhu/Kust leht';  
 $strToggleScratchboard = 'vaheta mrkmetahvlit';
+$strToSelectRelation = 'Et valida suhe, kliki :';
 $strTotal = 'kokku';
 $strTotalUC = 'Kokku';
 $strTraditionalChinese = 'Traditsionaalne Hiina';
@@ -923,7 +949,7 @@ $strTransformation_application_octetstream__hex = 'Kuvab andmed kuueteistkmnend
 $strTransformation_image_jpeg__inline = 'Kuvab lingitud vikepildi; seaded: laius,krgus pikslites (hoiab alles originaalpildi laiuse-krguse suhte)';
 $strTransformation_image_jpeg__link = 'Kuvab lingi sellele pildile (otsene binaarne allalaadimine, jne.).';
 $strTransformation_image_png__inline = 'Vaata image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Vtab TIME, TIMESTAMP vi DATETIME tpi vlja ja teisendab selle Teie lokaalse ajaseade jrgi. Esimene seade on lisa (tundides) , mis lisatakse ajale (vaikimisi: 0). Teine seade on teistsugune ajamrang vastavalt PHP  strftime() funktsioonile.';
+$strTransformation_text_plain__dateformat = 'Nitab TIME, TIMESTAMP, DATETIME vi numbrilist unixi ajatempli vlja formaaditud kuupevana. Esimene valik on ajanihe (tundides) mis lisatakse ajatemplile (Vaikimisi: 0). Kasuta teist valikut et tpsustada kuupeva formaat. Kolmas valik annab valida kas kuupev kasutab kohalikku aega vi UTC oma (kasuta "local" (kohalik) vi "utc" stringe). Sellest tulenevalt, kuupeva formaadil on teine vrtus - "local" vrtuse tpsustamiseks vaata dokumentatsiooni PHP strftime() funktsiooni kasutamise kohta ja  kasutades "utc" vaata gmdate() funtsiooni kasutamist.'; 
 $strTransformation_text_plain__external = 'AINULT LINUXILE: Kivitab vlise aplikatsiooni ja annab talle standard sisendisse ette vlja sisu. Tagastab aplikatsiooni standard vljundi. Vaikimisi on selleks Tidy, et kuvada ilusti formaaditud HTML koodi. Turvariskide maandamiseks peate te ksitsi muutma faili libraries/transformations/text_plain__external.inc.php ja lisama sinna programmid mida te lasete kivitada. Esimene seade on siis kasutatava programmi number, teine seade on programmi parameetrid. Kui kolmas seade on 1 siis tdeldakse vljund funktsiooniga htmlspecialchars() (vaikimisi 1). Kui neljas seade on  1 pannakse NOWRAP sisu lahtrile nii, et kogu vljund kuvatakse ilma formaati muutmata(vaikimisi 1)';
 $strTransformation_text_plain__formatted = 'Hoiab alles originaalset vlja formaati. Ei varjestata.';
 $strTransformation_text_plain__imagelink = 'Kuvab pildi ja lingi, vli sisaldab failinime; esimene seade on eelnev tekst nagu "http://domain.com/", teine seade on laius pikslites, kolmas on krgus.';
@@ -985,8 +1011,6 @@ $strWildcard = 'metamrk';
 $strWindowNotFound = 'Vajaliku sirvija akent ei suudetud uuendada. Vibolla Te olete peaakna sulgenud vi Teie sirvija ei luba akendevahelist suhtlist tnu turvaseadetele.';
 $strWithChecked = 'Valitud:';
 $strWriteRequests = 'Prdumised kirjutamiseks';
-$strWritingCommentNotPossible = 'Kommentaaride kirjutamine ei ole vimalik.';
-$strWritingRelationNotPossible = 'Sltuvuse kirjutamine ei ole vimalik';
 $strWrongUser = 'Vale kasutajanimi/parool. Ligips keelatud.';
 
 $strXMLOptions = 'XML seaded';  
@@ -999,6 +1023,14 @@ $strZip = '"zipitud"';
 
 // To translate:
 
-$strLanguage = 'Language';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
