@@ -1,5 +1,5 @@
 <?php
-/* $Id: estonian-utf-8.inc.php,v 2.153 2006/08/10 11:31:26 lem9 Exp $ */
+/* $Id: estonian-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /*
  * Translated by Marko Ellermaa, <marko.ellermaa@nlkp.net>
@@ -24,7 +24,6 @@ $datefmt = '%d.%m.%Y kell %H:%M:%S';
 $timespanfmt = '%s päeva, %s tundi, %s minutit ja %s sekundit';
 
 $strAbortedClients = 'Katkestatud';
-$strAbsolutePathToDocSqlDir = 'Palun sisestage absoluutne tee webiserveris docSQL kataloogini';
 $strAccessDeniedCreateConfig = 'Arvatav põhjus on te pole veel loonud seadete faili. Soovitavalt võid kasutada %1$ssetup script%2$s et seadistada.';
 $strAccessDeniedExplanation = 'phpMyAdmin proovis ühenduda MySQL serveriga ja server lükkas ühenduse tagasi. Te peaksite kontrollima serverit, kasutajanime ja parooli config.inc.php failis ning kontrollima, et need vastaks infole mis te saite oma MySQL serveri administraatori käest.';
 $strAccessDenied = 'Ligipääs keelatud';
@@ -34,8 +33,6 @@ $strAddClause = 'Lisa %s';
 $strAddConstraints = 'Lisa piirangud';
 $strAddDeleteColumn = 'Lisa/Kustuta välja veerud';
 $strAddDeleteRow = 'Lisa/Kustuta kriteeriumirida';
-$strAddedColumnComment = 'Kommentaar lisatud väljale';
-$strAddedColumnRelation = 'Sõltuvus lisatud väljale';
 $strAddFields = 'Lisa %s väli(jad)';
 $strAddHeaderComment = 'Lisa vaba kommentaar päisesse (\\n eraldab read)';
 $strAddIntoComments = 'Lisa kommentaaridesse';
@@ -60,6 +57,7 @@ $strAlterOrderBy = 'Muuda tabeli sorteeringut';
 $strAnalyzeTable = 'Analüüsi tabelit';
 $strAnd = 'ja';
 $strAndThen = 'ja siis';
+$strAngularLinks = 'Nurgelised lingid'; 
 $strAnIndex = 'Indeks lisati %s';
 $strAnyHost = 'Kõik masinad';
 $strAny = 'kõik';
@@ -112,6 +110,7 @@ $strBzError = 'phpMyAdmin ei suutnud pakkida seda andmebaasiväljundit kuna Bz2
 $strBzip = '"bzipitud"';
 
 $strCalendar = 'Kalender';
+$strCancel = 'Katkesta'; 
 $strCanNotLoadExportPlugins = 'Viga eksportimis moodulite laadimisel, palun kontrolli seadeid!';
 $strCanNotLoadImportPlugins = 'Pole võimalik Importida mooduleid (plugins), palun kontrolli seadeid!';
 $strCannotLogin = 'Ei suuda MySQL serverisse logida';
@@ -175,10 +174,12 @@ $strCreateNewDatabase = 'Loo uus andmebaas';
 $strCreateNewTable = 'Loo uus tabel andmebaasi %s';
 $strCreatePage = 'Loo uus leht';
 $strCreatePdfFeat = 'PDF-ide tegemine';
+$strCreateRelation = 'Suhte loomine (relation)';  
+$strCreateTable  = 'Loo tabel';
 $strCreateUserDatabase = 'Andmebaas kasutajale';  
 $strCreateUserDatabaseName = 'Loo sama nimega andmebaas ja anna kõik õigused'; 
 $strCreateUserDatabaseNone = 'Puudub';  
-$strCreateUserDatabaseWildcard = 'Anna kõik õigused Metanimele (username_%)';
+$strCreateUserDatabaseWildcard = 'Anna kõik õigused Metanimele (username\_%)';
 $strCreationDates = 'Loo/muuda/kontrolli kuupäevi';
 $strCriteria = 'Kriteerium';
 $strCroatian = 'Horvaatia';
@@ -196,7 +197,7 @@ $strDatabaseEmpty = 'Andmebaasi nimi on tühi!';
 $strDatabaseExportOptions = 'Andmebaasi eksportimise seaded';
 $strDatabaseHasBeenDropped = 'Andmebaas %s kustutatud.';
 $strDatabaseNoTable = 'See andmebaas ei sisalda tabelit!';
-$strDatabases = 'andmebaasid';
+$strDatabases = 'Andmebaasid';
 $strDatabasesDropped = 'andmebaasid %s kustutati õnnestunult.';
 $strDatabasesStats = 'Andmebaaside statistika';
 $strDatabasesStatsDisable = 'Keelake statistika';
@@ -207,15 +208,7 @@ $strDataOnly = 'Ainult andmed';
 $strDataPages = 'Lehed andmetega';
 $strDBComment = 'Andmebaasi kommentaar: ';
 $strDBCopy = 'Kopeeri andmebaas';
-$strDBGContextID = 'Sisu ID';
-$strDBGContext = 'Sisu';
-$strDBGHits = 'Vajutusi';
-$strDBGLine = 'Rida';
-$strDBGMaxTimeMs = 'Max aeg, ms';
-$strDBGMinTimeMs = 'Min aeg, ms';
-$strDBGModule = 'Moodul';
-$strDBGTimePerHitMs = 'Aeg/vajutus, ms';
-$strDBGTotalTimeMs = 'Koguaeg, ms';
+$strDbIsEmpty = 'Andmebaas tundub olevat tühi!'; 
 $strDbPrivileges = 'Andmebaas-spetsiifilised privileegid';
 $strDBRename = 'Nimeta andmebaas ümber';
 $strDbSpecific = 'andmebaasipõhine';
@@ -230,19 +223,24 @@ $strDeleted = 'Rida kustutatud';
 $strDeletedRows = 'Kustuta read:';
 $strDelete = 'Kustuta';
 $strDeleteNoUsersSelected = 'Ühtegi kasutajat pole valitud kustutamiseks!';
+$strDeleteRelation = 'Kustuta suhe';  
 $strDeleting = 'Kustutan %s';
 $strDelimiter = 'Eraldaja'; 
 $strDelOld = 'Antud lehel on viiteid tabelitele mida enam ei ole. Kas te soovite kustutada need viited?';
 $strDescending = 'Kahanev';
 $strDescription = 'Kirjeldus';
+$strDesigner = 'Kujundaja';
 $strDictionary = 'sõnaraamat';
+$strDirectLinks = 'Otselingid';  
 $strDirtyPages = 'Mustad lehed';
 $strDisabled = 'Keelatud';
-$strDisableForeignChecks = 'Keela foreign keyde kontroll';
+$strDisableForeignChecks = 'Keela võõrvõtmete (foreign key) kontroll';
 $strDisplayFeat = 'Kuva võimalused';
 $strDisplayOrder = 'Näitamise järjekord:';
 $strDisplayPDF = 'Näita PDF skeemi';
 $strDoAQuery = 'Tee "päring näite järgi" (lühend: "%")';
+$strDocSQL = 'DocSQL';  
+$strDocSQLOptions = 'DocSQL valikud';  
 $strDocu = 'Dokumentatsioon';
 $strDoYouReally = 'Kas te tõesti tahate ';
 $strDropDatabaseStrongWarning = 'Tähelepanu! Te HÄVITATE kogu andmebaasi!';
@@ -281,6 +279,7 @@ $strExcelOptions = 'Excel\'i seaded';
 $strExecuteBookmarked = 'Käivita salvestatud päring';
 $strExplain = 'Seleta SQL-i';
 $strExport = 'Ekspordi';
+$strExportImportToScale = 'Ekspordi/Impordi skaala';
 $strExportMustBeFile = 'Valitud eksportimise tüüp tuleb salvestada faili!';
 $strExtendedInserts = 'Laiendatud lisamised';
 $strExtra = 'Ekstra';
@@ -308,6 +307,7 @@ $strFlushQueryCache = 'Tühjenda päringute vahemälu';
 $strFlushTables = 'Tühjenda (sulge) kõik tabelid';
 $strFlushTable = 'Ühtlusta tabelid ("FLUSH")';
 $strFontSize = 'Fondi suurus';
+$strForeignKeyError = 'Viga luues võõrvõtit (foreign key) (kontrolli admetüüpe)';
 $strFormat = 'Formaat';
 $strFormEmpty = 'Puuduv väärtus vormis !';
 $strFreePages = 'Vabad lehed';
@@ -335,7 +335,11 @@ $strHasBeenAltered = 'on muudetud.';
 $strHasBeenCreated = 'on loodud.';
 $strHaveToShow = 'Te peate valima vähemalt ühe veeru kuvamiseks';
 $strHebrew = 'Heebrea';
+$strHelp = 'Abi';  
 $strHexForBinary = 'Kasuta 16nd koodi binaarväljades';
+$strHide         = 'Peida';
+$strHideShowAll = 'Peida/Näita kõik';
+$strHideShowNoRelation = 'Peida/Näita tabelid millel puudub suhe'; 
 $strHome = 'Esileht';
 $strHomepageOfficial = 'Ametlik phpMyAdmini koduleht';
 $strHostEmpty = 'Masin on tühi!';
@@ -352,8 +356,7 @@ $strIdxFulltext = 'Täistekst';
 $strIgnoreDuplicates = 'Ignoreeri korduvaid ridasid';
 $strIgnore = 'Ignoreeri';
 $strIgnoreInserts = 'Kasutaja ignoreeritavaid lisamisi';
-$strIgnoringFile = 'Jätan vahele faili %s';
-$strImportDocSQL = 'docSQL failide importimine';
+$strImportExportCoords = 'Impordi/Ekspordi kordinaadid PDF skeemile';
 $strImportFiles = 'Importige failid';
 $strImportFormat = 'Imporditud faili formaat';
 $strImport = 'Import';
@@ -375,6 +378,7 @@ $strInnoDBDataFilePath = 'Andmefailid';
 $strInnoDBDataHomeDir = 'Andmete kodukataloog';
 $strInnoDBDataHomeDirDesc = 'Ühine kataloogi nimeosa kõigi InnoDB andmefailide jaoks.';
 $strInnoDBPages = 'lehti';
+$strInnoDBRelationAdded = 'InnoDB suhe lisatud';
 $strInnodbStat = 'InnoDB staatus';
 $strInsecureMySQL = 'Teie konfiguratsioonifail sisaldab seadeid (root kasutaja ilma paroolita) mis vastab MySQL-i vaikimisi priviligeeritud kasutajale. Kui Teie MySQL-i server jookseb sellise seadega on ta avatud rünnakutele, soovitav on see turvaauk kiiresti parandada.';
 $strInsertAsNewRow = 'Lisa uue reana';
@@ -382,6 +386,7 @@ $strInsertedRowId = 'Lisatud rea id:';
 $strInsertedRows = 'Lisatud read:';
 $strInsert = 'Lisa';
 $strInternalNotNecessary = '* Sisene seos ei ole vajalik kui ta eksisteerib ka InnoDB-s.';
+$strInternalRelationAdded = 'Sisemine suhe loodud'; 
 $strInternalRelations = 'Sisesed seosed';
 $strInUse = 'kasutusel';
 $strInvalidAuthMethod = 'Vigane autoriseerimise meetod konfiguratsioonifailis:';
@@ -409,10 +414,12 @@ $strKeepPass = 'Ärge muutke parooli';
 $strKeyCache = 'Võtme vahemälu';
 $strKeyname = 'Võtme nimi';
 $strKill = 'Tapa';
+$strKnownExternalBug = 'See %s funktionaalsus on mõjutatud tuntud viga, vaata %s';
 $strKorean = 'Korea';
 
 $strLandscape = 'Laipilt';
 $strLanguageFileNotFound = 'Ei leia keele fail "%1$s" .';
+$strLanguage = 'Keel';  
 $strLanguageUnknown = 'Tundmatu keel: %1$s.';
 $strLatchedPages = 'Lukustatud lehed';
 $strLatexCaption = 'Tabeli seletus';
@@ -456,13 +463,14 @@ $strMIME_MIMEtype = 'MIME-tüüp';
 $strMIME_nodescription = 'Selle transformatsiooni jaoks ei ole kirjeldust.<br />Palun küsige autorilt, mida %s teeb.';
 $strMIME_transformation = 'Browseri transformatsioon';
 $strMIME_transformation_note = 'Transformatsiooni võimaluste ja tema MIME-tüübi transformatsiooni nimekirjaks vajutage %stransformatsiooni kirjeldusele%s';
-$strMIME_transformation_options_note = 'Palun sisestage transformatsiooniks vajalikud väärtused, kasutades järgmist formaati: \'a\',\'b\',\'c\'...<br />Kui teil on vaja edastada kaldkriips ("\") või ülakoma ("\'") nende väärtuste seas, varjestage see tagurpidi kaldkriipsuga (näiteks \'\\\\xyz\' või \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Palun sisestage transformatsiooniks vajalikud väärtused, kasutades järgmist formaati: \'a\', 100, b,\'c\'...<br />Kui teil on vaja edastada kaldkriips ("\") või ülakoma ("\'") nende väärtuste seas, varjestage see tagurpidi kaldkriipsuga (näiteks \'\\\\xyz\' või \'a\\\'b\').';
 $strMIME_transformation_options = 'Transformeerimise seaded';
 $strMIMETypesForTable = 'MIME TÜÜBID TABELILE';
 $strMIME_without = 'MIME-tüübid kursiivis ei oma eraldi transofrmatsiooni funktsiooni';
 $strModifications = 'Muutused salvestatud';
 $strModifyIndexTopic = 'Muuda indeksit';
 $strModify = 'Muuda';
+$strMoveMenu = 'Liiguta menüü';  
 $strMoveTableOK = 'Tabel %s viidu üle andmebaasi %s.';
 $strMoveTableSameNames = 'Ei saa tabelit iseendasse liigutada!';
 $strMoveTable = 'Vii tabel üle (andmebaas<b>.</b>tabel):';
@@ -521,6 +529,7 @@ $strNoUsersFound = 'Ei leitud ühtegi kasutajat.';
 $strNoValidateSQL = 'Jäta SQL-i kontroll vahele';
 $strNull = 'Null';
 $strNumberOfFields = 'Väljade arv';
+$strNumberOfTables = 'Tabelite arv';
 $strNumSearchResultsInTable = '%s vaste(t) tabelis <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Kokku:</b> <i>%s</i> vaste(t)';
 $strNumTables = 'Tabelid';
@@ -563,8 +572,10 @@ $strPhoneBook = 'telefoniraamat';
 $strPHP40203 = 'Te kasutate PHP 4.2.3, milles on tõsine viga mitmebaidiste tekstidega (mbstring). Vaadake PHP vearaportit 19404. Seda PHP versiooni ei soovitata kasutada phpMyAdminiga.';
 $strPhp = 'Loo PHP kood';
 $strPHPVersion = 'PHP versioon';
+$strPleaseSelectPrimaryOrUniqueKey = 'Palun vali primaarne või unkaalne võti'; 
 $strPmaDocumentation = 'phpMyAdmini dokumentatsioon';
 $strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> konstant peab teie konfiguratsioonifailis määratud olema!';
+$strPmaWiki = 'phpMyAdmin wiki';  
 $strPolish = 'Poola';
 $strPortrait = 'Portreepilt';
 $strPos1 = 'Algus';
@@ -635,15 +646,18 @@ $strQueryWindowLock = 'Antud päringut mitte muuta väljaspool akent.';
 
 $strReadRequests = 'Pöördumised lugemiseks';
 $strReceived = 'Saadud';
+$strRecommended = 'soovituslik';  
 $strRecords = 'Kirjeid';
 $strReferentialIntegrity = 'Kontrolli pärinevust:';
 $strRefresh = 'Uuenda';
 $strRelationalSchema = 'Seoseskeem';
+$strRelationDeleted = 'Suhe kustutatud'; 
 $strRelationNotWorking = 'Lisavõimalused töötamiseks lingitud tabelitega on deaktiveeritud. Et lugeda miks see nii on, vajutage %ssiia%s.';
 $strRelationsForTable = 'SEOSED TABELILE';
 $strRelations = 'Suhted';
 $strRelationView = 'Pärinevuse vaade';
 $strReloadingThePrivileges = 'Taaslaen privileege';
+$strReload = 'Lae uuesti';  
 $strReloadPrivileges = 'Lae privileegid uuesti';
 $strRemoveSelectedUsers = 'Eemalda valitud kasutajad';
 $strRenameDatabaseOK = 'Andmebaas %s on ümber nimetatud %s';
@@ -677,6 +691,7 @@ $strRunSQLQuery = 'Päri SQL päring(uid) andmebaasist %s';
 $strRussian = 'Vene';
 
 $strSaveOnServer = 'Salvestage serverisse kataloogi %s';
+$strSavePosition = 'Salvesta positsioon';  
 $strSave = 'Salvesta';
 $strScaleFactorSmall = 'Skalaarfaktor on liiga väike, et skeem mahuks ühele lehele.';
 $strSearchFormTitle = 'Otsi andmebaasist';
@@ -694,7 +709,9 @@ $strSelectADb = 'Valige andmebaas';
 $strSelectAll = 'Märgista kõik';
 $strSelectBinaryLog = 'Valige binaarne logi vaatamiseks';
 $strSelectFields = 'Vali väljad (vähemalt üks):';
+$strSelectForeignKey = 'Vali võõrvõti(Foreign Key)';  
 $strSelectNumRows = 'päringus';
+$strSelectReferencedKey = 'Vali eelistus võti (referenced key)';
 $strSelectTables = 'Vali tabelid';
 $strSend = 'Salvesta failina';
 $strSent = 'Saadetud';
@@ -716,8 +733,11 @@ $strShowColor = 'Näita värvi';
 $strShowDatadictAs = 'Andmesõnastiku formaat';
 $strShowFullQueries = 'Näita täispikkasid päringuid';
 $strShowGrid = 'Näita võrgustiku';
+$strShowHideLeftMenu = 'Näita/Peida vasak menüü';
 $strShowingBookmark = 'Näitan järjehoidjat';
+$strShowingPhp = 'Näitan PHP koodina'; 
 $strShowingRecords = 'Näita ridu';
+$strShowingSQL = 'Näitan SQL päringut';  
 $strShow = 'Näita';
 $strShowOpenTables = 'Näita avatud tabeleid';
 $strShowPHPInfo = 'Näita PHP informatsiooni';
@@ -839,6 +859,7 @@ $strSize = 'Suurus';
 $strSkipQueries = 'Käske (päringuid) mida algusest vahele jätta';
 $strSlovak = 'Slovaki';
 $strSlovenian = 'Sloveenia';
+$strSmallBigAll = 'Kõik Väikeseks/Suureks';  
 $strSocketProblem = '(või kohaliku MySQL serveri soketid ei ole korrektselt seadistatud)';
 $strSortByKey = 'Sorteeri võtme järgi';
 $strSorting = 'Järjestamine';
@@ -858,6 +879,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Vigane identifikaator';
 $strSQPBugUnclosedQuote = 'Sulgemata jutumärk/ülakoma';
 $strSQPBugUnknownPunctuation = 'Tundmatu suunav tekst';
+$strStandInStructureForView = 'Sise-vaate struktuur';
 $strStatCheckTime = 'Viimane vaatamine';
 $strStatCreateTime = 'Loodud';
 $strStatement = 'Parameerid';
@@ -873,6 +895,7 @@ $strStrucNativeExcel = 'Loomulikud MS Exceli andmed';
 $strStrucNativeExcelOptions = 'Põlised Exceli eksportimise seaded';
 $strStrucOnly = 'Ainult struktuur';
 $strStructPropose = 'Soovita tabeli struktuuri';
+$strStructureForView = 'Vaate (view) struktuur';  
 $strStructure = 'Struktuur';
 $strSubmit = 'Vali';
 $strSuccess = 'Teie SQL päring täideti edukalt';
@@ -887,7 +910,9 @@ $strTableEmpty = 'Tabeli nimi on tühi!';
 $strTableHasBeenDropped = 'Tabel %s kustutatud';
 $strTableHasBeenEmptied = 'Tabel %s tühjendatud';
 $strTableHasBeenFlushed = 'Tabel %s ühtlustatud';
+$strTableIsEmpty = 'Tabel tundub olevat tühi!';  
 $strTableMaintenance = 'Tabeli hooldus';
+$strTableName = 'Tabeli nimi';  
 $strTableOfContents = 'Sisukord';
 $strTableOptions = 'Tabeli seaded';
 $strTables = '%s tabel(it)';
@@ -905,14 +930,15 @@ $strThemeNoValidImgPath = 'Ei leia pildi kataloogi teemale %s!';
 $strThemePathNotFound = 'Ei leia kataloogi teemale %s!';
 $strTheme = 'Teema / Stiil';
 $strThisHost = 'Antud host';
-$strThisNotDirectory = 'See ei olnud kataloog';
 $strThreads = 'Lõimud';
 $strThreadSuccessfullyKilled = 'Protsess %s katkestati edukalt.';
 $strTime = 'Aeg';
 $strTimeoutInfo = 'Eelmine Import aegus, peale uuesti postitamist jätkub asukohast %d.';
 $strTimeoutNothingParsed = 'Kuigi viimasel laadimisel andmeid ei töödeldud, see tähendab enamasti et phpMyAdmin pole võimeline Importi lõpetama, kui sa php skripti aega ei pikenda.';
 $strTimeoutPassed = 'Skripti ajalimiit on ületatud, kui soovid importimist jätkata, palun lae sama fail uuesti ja import jätkub.';
+$strToFromPage = 'Kuhu/Kust leht';  
 $strToggleScratchboard = 'vaheta märkmetahvlit';
+$strToSelectRelation = 'Et valida suhe, kliki :';
 $strTotal = 'kokku';
 $strTotalUC = 'Kokku';
 $strTraditionalChinese = 'Traditsionaalne Hiina';
@@ -924,7 +950,7 @@ $strTransformation_application_octetstream__hex = 'Kuvab andmed kuueteistkümnen
 $strTransformation_image_jpeg__inline = 'Kuvab lingitud väikepildi; seaded: laius,kõrgus pikslites (hoiab alles originaalpildi laiuse-kõrguse suhte)';
 $strTransformation_image_jpeg__link = 'Kuvab lingi sellele pildile (otsene binaarne allalaadimine, jne.).';
 $strTransformation_image_png__inline = 'Vaata image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Võtab TIME, TIMESTAMP või DATETIME tüüpi välja ja teisendab selle Teie lokaalse ajaseade järgi. Esimene seade on lisa (tundides) , mis lisatakse ajale (vaikimisi: 0). Teine seade on teistsugune ajamäärang vastavalt PHP  strftime() funktsioonile.';
+$strTransformation_text_plain__dateformat = 'Näitab TIME, TIMESTAMP, DATETIME või numbrilist unix´i ajatempli välja formaaditud kuupäevana. Esimene valik on ajanihe (tundides) mis lisatakse ajatemplile (Vaikimisi: 0). Kasuta teist valikut et täpsustada kuupäeva formaat. Kolmas valik annab valida kas kuupäev kasutab kohalikku aega või UTC oma (kasuta "local" (kohalik) või "utc" stringe). Sellest tulenevalt, kuupäeva formaadil on teine väärtus - "local" väärtuse täpsustamiseks vaata dokumentatsiooni PHP strftime() funktsiooni kasutamise kohta ja  kasutades "utc" vaata gmdate() funtsiooni kasutamist.'; 
 $strTransformation_text_plain__external = 'AINULT LINUXILE: Käivitab välise aplikatsiooni ja annab talle standard sisendisse ette välja sisu. Tagastab aplikatsiooni standard väljundi. Vaikimisi on selleks Tidy, et kuvada ilusti formaaditud HTML koodi. Turvariskide maandamiseks peate te käsitsi muutma faili libraries/transformations/text_plain__external.inc.php ja lisama sinna programmid mida te lasete käivitada. Esimene seade on siis kasutatava programmi number, teine seade on programmi parameetrid. Kui kolmas seade on 1 siis töödeldakse väljund funktsiooniga htmlspecialchars() (vaikimisi 1). Kui neljas seade on  1 pannakse NOWRAP sisu lahtrile nii, et kogu väljund kuvatakse ilma formaati muutmata(vaikimisi 1)';
 $strTransformation_text_plain__formatted = 'Hoiab alles originaalset välja formaati. Ei varjestata.';
 $strTransformation_text_plain__imagelink = 'Kuvab pildi ja lingi, väli sisaldab failinime; esimene seade on eelnev tekst nagu "http://domain.com/", teine seade on laius pikslites, kolmas on kõrgus.';
@@ -986,8 +1012,6 @@ $strWildcard = 'metamärk';
 $strWindowNotFound = 'Vajaliku sirvija akent ei suudetud uuendada. Võibolla Te olete peaakna sulgenud või Teie sirvija ei luba akendevahelist suhtlist tänu turvaseadetele.';
 $strWithChecked = 'Valitud:';
 $strWriteRequests = 'Pöördumised kirjutamiseks';
-$strWritingCommentNotPossible = 'Kommentaaride kirjutamine ei ole võimalik.';
-$strWritingRelationNotPossible = 'Sõltuvuse kirjutamine ei ole võimalik';
 $strWrongUser = 'Vale kasutajanimi/parool. Ligipääs keelatud.';
 
 $strXMLOptions = 'XML seaded';  
@@ -1000,6 +1024,14 @@ $strZip = '"zipitud"';
 
 // To translate:
 
-$strLanguage = 'Language';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
