@@ -1,16 +1,16 @@
 <?php
-/* $Id: french-iso-8859-15.inc.php,v 2.39.2.2 2005/12/02 17:58:40 lem9 Exp $ */
+/* $Id: french-iso-8859-1.inc.php 10018 2007-02-26 17:26:53Z lem9 $ */
 
-$charset = 'iso-8859-15';
+$charset = 'iso-8859-1';
 $text_dir = 'ltr';
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ' ';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits = array('Octets', 'Ko', 'Mo', 'Go', 'To', 'Po', 'Eo');
+$byteUnits = array('o', 'Kio', 'Mio', 'Gio', 'Tio', 'Pio', 'Eio');
 
-$day_of_week = array('Dimanche', 'Lundi', 'Mardi', 'Mercredi', 'Jeudi', 'Vendredi', 'Samedi');
+$mysql_5_0_doc_lang = 'fr';
+
+$day_of_week = array('Dim', 'Lun', 'Mar', 'Mer', 'Jeu', 'Ven', 'Sam');
 $month = array('Janvier', 'Fvrier', 'Mars', 'Avril', 'Mai', 'Juin', 'Juillet', 'Aot', 'Septembre', 'Octobre', 'Novembre', 'Dcembre');
 // Voir http://www.php.net/manual/en/function.strftime.php pour la variable
 // ci-dessous
@@ -19,20 +19,17 @@ $datefmt = '%A %d %B %Y  %H:%M';
 $timespanfmt = '%s jours, %s heures, %s minutes et %s secondes';
 
 $strAbortedClients = 'Arrts prmaturs';
-$strAbsolutePathToDocSqlDir = 'Veuillez entrer le chemin absolu du rpertoire docSQL sur le serveur web';
 $strAccessDenied = 'Accs refus';
+$strAccessDeniedCreateConfig = 'La raison probable est que vous n\'avez pas cr de fichier de configuration. Vous pouvez utiliser le %1$sscript de configuration%2$s dans ce but.';
 $strAccessDeniedExplanation = 'phpMyAdmin a tent de se connecter au serveur MySQL, et le serveur a rejet la connexion. Veuillez vrifier les valeurs de "host", "username" et "password" dans config.inc.php et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
 $strAction = 'Action';
 $strAddAutoIncrement = 'Inclure la valeur courante de l\'AUTO_INCREMENT';
+$strAddClause = 'Ajouter %s';
 $strAddConstraints = 'Inclure les contraintes de cls trangres';
 $strAddDeleteColumn = 'Ajouter/effacer x colonne(s)';
 $strAddDeleteRow = 'Ajouter/effacer x ligne(s)';
-$strAddDropDatabase = 'Ajouter DROP DATABASE';
-$strAddedColumnComment = 'Commentaire ajout pour la colonne';
-$strAddedColumnRelation = 'Relation ajoute pour la colonne';
 $strAddFields = 'Ajouter %s champ(s)';
 $strAddHeaderComment = 'Commentaires mis en en-tte (\\n spare les lignes)';
-$strAddIfNotExists = 'Ajouter "IF NOT EXISTS"';
 $strAddIntoComments = 'Inclure sous forme de commentaires';
 $strAddNewField = 'Ajouter un champ';
 $strAddPrivilegesOnDb = 'Ajouter des privilges sur cette base de donnes';
@@ -55,6 +52,7 @@ $strAlterOrderBy = '<b>Ordonner</b> la table par';
 $strAnalyzeTable = 'Analyser la table';
 $strAnd = 'et';
 $strAndThen = 'et ensuite';
+$strAngularLinks = 'Liens angulaires';
 $strAnIndex = 'Un index a t ajout sur %s';
 $strAnyHost = 'Tout serveur';
 $strAny = 'N\'importe quel';
@@ -92,6 +90,7 @@ $strBookmarkReplace = 'Remplacer un signet existant du mme nom';
 $strBookmarkThis = 'Conserver cette requte dans les signets';
 $strBookmarkView = 'Voir uniquement';
 $strBrowse = 'Afficher';
+$strBrowseDistinctValues = 'Affiche les valeurs distinctes';
 $strBrowseForeignValues = 'Afficher les valeurs de la table lie';
 $strBufferPoolActivity = 'Activit de la mmoire-tampon';
 $strBufferPool = 'Mmoire-tampon';
@@ -106,6 +105,8 @@ $strBzError = 'phpMyAdmin n\'a pu compresser le fichier export en raison d\'une
 $strBzip = '"bzipp"';
 
 $strCalendar = 'Calendrier';
+$strCancel = 'Annuler';
+$strCanNotLoadExportPlugins = 'Erreur lors du chargement des modules d\'exportation!';
 $strCanNotLoadImportPlugins = 'Chargement impossible des greffons d\'importation, veuillez vrifier votre installation!';
 $strCannotLogin = 'Connexion au serveur MySQL non permise';
 $strCantLoad = 'PHP ne peut charger l\'extension %s, [br]veuillez vrifier votre configuration de PHP';
@@ -146,6 +147,7 @@ $strCompatibleHashing = 'compatible MySQL&nbsp;4.0';
 $strCompleteInserts = 'Insertions compltes';
 $strCompression = 'Compression';
 $strCompressionWillBeDetected = 'Ces modes de compression seront dtects automatiquement : %s';
+$strConfigDefaultFileError = 'Chargement de la configuration par dfaut impossible depuis "%1$s"';
 $strConfigFileError = 'phpMyAdmin n\'a pu lire votre fichier de configuration!<br />Il est possible qu\'il contienne une erreur de syntaxe, ou que PHP soit incapable de le trouver<br /> l\'aide du lien suivant, vous pouvez vrifier le message d\'erreur gnr par PHP;<br />la plupart du temps, un apostrophe ou un point-virgule sont manquants.<br />Si vous recevez une page blanche, aucune erreur n\'a t dtecte.';
 $strConfigureTableCoord = 'Les coordonnes de la table %s n\'ont pas t configures';
 $strConnectionError = 'Connexion impossible: rglages incorrects.';
@@ -167,6 +169,12 @@ $strCreateNewDatabase = 'Crer une base de donnes';
 $strCreateNewTable = '<b>Crer une nouvelle table</b> sur la base %s';
 $strCreatePage = 'Crer une page';
 $strCreatePdfFeat = 'Gnration de schmas en PDF';
+$strCreateRelation = 'Nouvelle relation';
+$strCreateTable  = 'Nouvelle table';
+$strCreateUserDatabase = 'Base de donnes pour cet utilisateur';
+$strCreateUserDatabaseName = 'Crer une base portant son nom et donner  cet utilisateur tous les privilges sur cette base';
+$strCreateUserDatabaseNone = 'Aucune';
+$strCreateUserDatabaseWildcard = 'Donner les privilges passepartout ("%")';
 $strCreationDates = 'Dates de cration/modification/vrification';
 $strCriteria = 'Critre';
 $strCroatian = 'croate';
@@ -195,15 +203,7 @@ $strDataOnly = 'Donnes seulement';
 $strDataPages = 'Pages contenant des donnes';
 $strDBComment = '<b>Commentaire</b> sur la base de donnes: ';
 $strDBCopy = 'Copier la base de donnes vers';
-$strDBGContext = 'Contexte';
-$strDBGContextID = 'Identificateur de contexte';
-$strDBGHits = 'Occurences';
-$strDBGLine = 'Ligne';
-$strDBGMaxTimeMs = 'Dure maximum, ms';
-$strDBGMinTimeMs = 'Dure minimum, ms';
-$strDBGModule = 'Module';
-$strDBGTimePerHitMs = 'Dure/Occurence, ms';
-$strDBGTotalTimeMs = 'Dure totale, ms';
+$strDbIsEmpty = 'La base de donnes semble vide!';
 $strDbPrivileges = 'Privilges spcifiques  une base de donnes';
 $strDBRename = '<b>Changer le nom</b> de la base de donnes pour';
 $strDbSpecific = 'spcifique  cette base de donnes';
@@ -218,11 +218,16 @@ $strDeleted = 'L\'enregistrement a t effac';
 $strDeletedRows = 'Nombre d\'enregistrements effacs :';
 $strDelete = 'Effacer';
 $strDeleteNoUsersSelected = 'Aucun utilisateur n\'a t choisi en vue de le dtruire!';
+$strDeleteRelation = 'Effacer la relation';
 $strDeleting = 'Destruction de %s';
+$strDelimiter = 'Dlimiteur';
 $strDelOld = 'Cette page fait rfrence  des tables qui n\'existent plus. Voulez-vous effacer ces rfrences?';
 $strDescending = 'Dcroissant';
 $strDescription = 'Description';
+$strDesigner = 'Concepteur';
+$strDesignerHelpDisplayField = 'Le champ  afficher est montr en rose. Pour indiquer qu\'un champ est ou n\'est plus le champ  afficher, cliquer l\'icne "Champ  afficher", puis cliquer sur le nom de champ appropri.';
 $strDictionary = 'dictionnaire';
+$strDirectLinks = 'Liens directs';
 $strDirtyPages = 'Pages modifies';
 $strDisabled = 'dsactiv';
 $strDisableForeignChecks = 'Dsactiver la vrification des cls trangres';
@@ -230,10 +235,11 @@ $strDisplayFeat = 'Affichage infobulle';
 $strDisplayOrder = 'Ordre d\'affichage :';
 $strDisplayPDF = '<b>Afficher le schma</b> en PDF';
 $strDoAQuery = 'Recherche par valeur (passepartout: "%")';
+$strDocSQL = 'DocSQL';
+$strDocSQLOptions = 'Options DocSQL';
 $strDocu = 'Documentation';
 $strDoYouReally = 'Voulez-vous vraiment effectuer ';
 $strDropDatabaseStrongWarning = 'Vous tes sur le point de DTRUIRE une base de donnes!';
-$strDropSelectedDatabases = 'Supprimer les bases de donnes slectionnes';
 $strDrop = 'Supprimer';
 $strDropUsersDb = 'Supprimer les bases de donnes portant le mme nom que les utilisateurs';
 $strDumpingData = 'Contenu de la table';
@@ -249,7 +255,6 @@ $strEmptyResultSet = 'MySQL n\'a retourn aucun enregistrement.';
 $strEmpty = 'Vider';
 $strEnabled = 'activ';
 $strEncloseInTransaction = 'Utiliser le mode transactionnel';
-$strEnclosingOptional = 'Il est optionnel d\'entourer les champs';
 $strEndCut = 'Fin de la section  couper';
 $strEnd = 'Fin';
 $strEndRaw = 'Fin des informations sur l\'anomalie';
@@ -261,6 +266,10 @@ $strEnglish = 'anglais';
 $strEnglishPrivileges = ' Veuillez noter que les noms de privilges sont exprims en anglais';
 $strError = 'Erreur';
 $strErrorInZipFile = 'Erreur rencontre dans l\'archive ZIP :';
+$strErrorRelationAdded = 'Erreur: relation non ajoute.';
+$strErrorRelationExists = 'Erreur: relation dj existante.';
+$strErrorRenamingTable = 'Erreur lors du renommage de %1$s en %2$s';
+$strErrorSaveTable = 'Erreur lors de la sauvegarde des coordonnes Concepteur.';
 $strEscapeWildcards = 'Prfixer avec \ les passepartouts _ et % pour un usage littral';
 $strEsperanto = 'Espranto';
 $strEstonian = 'estonien';
@@ -269,6 +278,8 @@ $strExcelOptions = 'Options Excel';
 $strExecuteBookmarked = 'Excuter la requte en signets';
 $strExplain = 'Expliquer SQL';
 $strExport = 'Exporter';
+$strExportImportToScale = 'Exporter/Importer  l\'chelle';
+$strExportMustBeFile = 'Ce choix d\'exportation doit tre sauvegard dans un fichier!';
 $strExtendedInserts = 'Insertions tendues';
 $strExtra = 'Extra';
 
@@ -282,7 +293,10 @@ $strFieldsEscapedBy = 'Caractre spcial';
 $strFieldsTerminatedBy = 'Champs termins par';
 $strFileAlreadyExists = 'Le fichier %s existe dj sur le serveur, veuillez changer le nom, ou cocher l\'option craser';
 $strFileCouldNotBeRead = 'Le fichier n\'a pu tre lu';
-$strFileNameTemplateHelp = 'Utilisez __DB__ comme nom de base, __TABLE__ comme nom de table et %stoute option valide de strftime%s comme indicateur de date/heure, le suffixe sera ajout automatiquement. Tout autre texte sera prserv.';
+$strFileNameTemplateDescription = 'Cette valeur est interprte avec %1$sstrftime%2$s, vous pouvez donc utiliser des chanes de format d\'heure. Ces transformations additionnelles vont se produire: %3$s. Tout autre texte sera conserv tel quel.';
+$strFileNameTemplateDescriptionDatabase = 'nom de base de donnes';
+$strFileNameTemplateDescriptionServer = 'nom de serveur';
+$strFileNameTemplateDescriptionTable = 'nom de table';
 $strFileNameTemplate = 'Modle de nom de fichier';
 $strFileNameTemplateRemember = 'se souvenir du modle';
 $strFileToImport = 'Fichier  importer';
@@ -291,11 +305,14 @@ $strFlushPrivilegesNote = 'Note: phpMyAdmin obtient la liste des privilges direc
 $strFlushQueryCache = 'Vider la cache des requtes';
 $strFlushTable = 'Recharger la table ("FLUSH")';
 $strFlushTables = 'Fermer toutes les tables';
+$strFontSize = 'Taille du texte';
+$strForeignKeyError = 'Erreur lors de la cration de la cl trangre (vrifiez les types de donnes';
 $strFormat = 'format';
 $strFormEmpty = 'Formulaire incomplet !';
 $strFreePages = 'Pages libres';
 $strFullText = 'Textes complets';
 $strFunction = 'Fonction';
+$strFunctions = 'Fonctions';
 
 $strGenBy = 'Gnr par';
 $strGeneralRelationFeat = 'Fonctions relationnelles';
@@ -317,7 +334,11 @@ $strHasBeenAltered = 'a t modifi(e).';
 $strHasBeenCreated = 'a t cr(e).';
 $strHaveToShow = 'Vous devez choisir au moins une colonne  afficher';
 $strHebrew = 'hbreu';
+$strHelp = 'Aide';
 $strHexForBinary = 'Encoder les champs binaires en hexadcimal';
+$strHide         = 'Cacher';
+$strHideShowAll = 'Cacher/montrer tout';
+$strHideShowNoRelation = 'Cacher/montrer les tables sans liens';
 $strHome = 'Accueil';
 $strHomepageOfficial = 'Site officiel de phpMyAdmin';
 $strHostEmpty = 'Le nom de serveur est vide';
@@ -331,15 +352,15 @@ $strHungarian = 'hongrois';
 $strIcelandic = 'islandais';
 $strId = 'ID';
 $strIdxFulltext = 'Texte entier';
+$strIEUnsupported = 'Fonction non disponible sous Internet Explorer.';
 $strIgnoreDuplicates = 'Ignorer les doublons';
 $strIgnore = 'Ignorer';
 $strIgnoreInserts = 'Ignorer les erreurs de doublons (INSERT IGNORE)';
-$strIgnoringFile = 'Fichier %s ignor';
-$strImportDocSQL = 'Importer des fichiers docSQL';
+$strImportExportCoords = 'Importer/Exporter les coordonnes pour le schma PDF';
 $strImportFiles = 'Importe les fichiers';
-$strImportFinished = 'Importation termine avec succs.';
 $strImportFormat = 'Format du fichier d\'importation';
 $strImport = 'Importer';
+$strImportSuccessfullyFinished = 'L\'importation s\'est termine avec succs, %d requtes excutes.';
 $strIndexes = 'Index';
 $strIndexHasBeenDropped = 'L\'index %s a t effac';
 $strIndex = 'Index';
@@ -357,24 +378,31 @@ $strInnoDBDataFilePath = 'Fichiers de donnes';
 $strInnoDBDataHomeDirDesc = 'Le chemin du rpertoire pour tous les fichiers de donnes InnoDB.';
 $strInnoDBDataHomeDir = 'Rpertoire des donnes';
 $strInnoDBPages = 'pages';
+$strInnoDBRelationAdded = 'Relation InnoDB ajoute';
 $strInnodbStat = 'tat InnoDB';
 $strInsecureMySQL = 'Votre fichier de configuration fait rfrence  l\'utilisateur root sans mot de passe, ce qui correspond  la valeur par dfaut de MySQL.  Votre serveur MySQL est donc ouvert aux intrusions, et vous devriez corriger ce problme de scurit.';
 $strInsertAsNewRow = 'Sauvegarder un nouvel enregistrement';
 $strInsertedRowId = 'Identifiant de l\'enregistrement insr:';
 $strInsertedRows = 'Nombre d\'enregistrements insrs :';
 $strInsert = 'Insrer';
-$strInsertNewRow = 'Insrer un nouvel enregistrement';
 $strInternalNotNecessary = '* Si une relation existe dans InnoDB, il n\'est pas ncessaire de la dfinir dans les relations internes.';
+$strInternalRelationAdded = 'Relation interne ajoute';
 $strInternalRelations = 'Relations internes';
 $strInUse = 'utilis';
 $strInvalidAuthMethod = 'Le fichier de configuration contient un type d\'authentification invalide :';
 $strInvalidColumnCount = 'Le nombre de champs doit tre plus grand que zro.';
 $strInvalidColumn = 'La colonne %s est invalide!';
-$strInvalidCSVInput = 'Impossible d\'analyser ces donnes CSV!';
+$strInvalidCSVFieldCount = 'Nombre de champs invalide dans les donnes CSV  la ligne %d';
+$strInvalidCSVFormat = 'Format invalide pour les donnes CSV  la ligne %d.';
+$strInvalidCSVParameter = 'Paramtres invalides pour l\'importation CSV: %s';
+$strInvalidDatabase = 'Nom de base de donnes invalide';
 $strInvalidFieldAddCount = 'Vous devez ajouter au moins un champ';
 $strInvalidFieldCount = 'La table doit comporter au moins un champ';
 $strInvalidLDIImport = 'Ce greffon ne supporte pas les importations en format comprim!';
 $strInvalidRowNumber = '%d n\'est pas un numro d\'enregistrement valable.';
+$strInvalidServerHostname = 'Nom d\'hte (hostname) invalide pour le serveur %1$s. Veuillez vrifier votre configuration.';
+$strInvalidServerIndex = 'Indice de serveur invalide: "%s"';
+$strInvalidTableName = 'Nom de table invalide';
 
 $strJapanese = 'japonais';
 $strJoins = 'Jointures';
@@ -386,9 +414,13 @@ $strKeepPass = 'Conserver le mot de passe';
 $strKeyCache = 'Cache des cls';
 $strKeyname = 'Nom de la cl';
 $strKill = 'Supprimer';
+$strKnownExternalBug = 'La fonctionnalit %s est affecte par une anomalie connue, voir %s';
 $strKorean = 'coren';
 
 $strLandscape = 'Paysage';
+$strLanguageFileNotFound = 'Fichier de langue "%1$s" inexistant.';
+$strLanguage = 'Langue';
+$strLanguageUnknown = 'Langue inconnue: %1$s.';
 $strLatchedPages = 'Pages verrouilles';
 $strLatexCaption = 'Sous-titre de la table';
 $strLatexContent = 'Contenu de la table __TABLE__';
@@ -430,7 +462,7 @@ $strMIME_description = 'Description';
 $strMIME_MIMEtype = 'Type MIME';
 $strMIME_nodescription = 'Aucune description n\'est disponible pour cette transformation.<br />Veuillez demander  son auteur, des dtails sur %s.';
 $strMIME_transformation_note = 'La %sdescription des transformations%s explique les transformations possibles en fonction des types MIME.';
-$strMIME_transformation_options_note = 'Veuillez entrer les valeurs des options de transformation en suivant ce format: \'a\',\'b\',\'c\'...<br />Si vous devez entrer un caractre ("\") ou une apostrophe ("\'") parmi ces valeurs, faites-le prcder du caractre d\'chappement, par exemple  \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Veuillez entrer les valeurs des options de transformation en suivant ce format: \'a\', 100, b,\'c\'...<br />Si vous devez entrer un caractre ("\") ou une apostrophe ("\'") parmi ces valeurs, faites-le prcder du caractre d\'chappement, par exemple  \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_transformation_options = 'Options de transformation';
 $strMIME_transformation = 'Transformation';
 $strMIMETypesForTable = 'TYPES MIME POUR LA TABLE';
@@ -438,6 +470,7 @@ $strMIME_without = 'Les types MIME affiches en italiques ne possdent pas de fonc
 $strModifications = 'Les modifications ont t sauvegardes.';
 $strModifyIndexTopic = 'Modifier une clef';
 $strModify = 'Modifier';
+$strMoveMenu = 'Dplacer le menu';
 $strMoveTable = '<b>Dplacer</b> la table vers (base<b>.</b>table)&nbsp;:';
 $strMoveTableOK = 'La table %s a t dplace vers %s.';
 $strMoveTableSameNames = 'On ne peut dplacer la table sur elle-mme!';
@@ -455,10 +488,9 @@ $strMyISAMRepairThreads = 'Nombre de fils d\'excution pour la rparation';
 $strMyISAMSortBufferSizeDesc = 'La mmoire tampon qui est alloue pour trier les index MyISAM durant une opration REPAIR TABLE ou pour crer les index lors d\'un CREATE INDEX ou ALTER TABLE';
 $strMyISAMSortBufferSize = 'Taille de la mmoire tampon';
 $strMySQLCharset = 'Jeu de caractres pour MySQL';
+$strMysqlClientVersion = 'Version du client MySQL';
 $strMySQLConnectionCollation = 'Interclassement pour la connexion MySQL';
-$strMySQLReloaded = 'MySQL recharg.';
 $strMySQLSaid = 'MySQL a rpondu:';
-$strMySQLServerProcess = 'MySQL %pma_s1% sur le serveur %pma_s2% - utilisateur&nbsp;: %pma_s3%';
 $strMySQLShowProcess = 'Afficher les processus';
 $strMySQLShowStatus = 'Afficher l\'tat du serveur';
 $strMySQLShowVars = 'Afficher les variables du serveur';
@@ -468,6 +500,7 @@ $strNext = 'Suivant';
 $strNoActivity = 'Aucune activit depuis %s secondes ou plus, veuillez vous reconnecter';
 $strNoDatabases = 'Aucune base de donnes';
 $strNoDatabasesSelected = 'Aucune base de donnes n\'a t slectionne.';
+$strNoDataReceived = 'Aucune donnes n\'a t reu en vue de l\'importation. Aucun nom de fichier n\'a t fourni, ou encore la taille du fichier a dpass la limite permise par votre configuration de PHP. Voir FAQ 1.16';
 $strNoDescription = 'pas de description';
 $strNoDetailsForEngine = 'Aucune information dtaille sur l\'tat n\'est disponible pour ce moteur de stockage.';
 $strNoDropDatabases = 'La commande "DROP DATABASE" est dsactive.';
@@ -489,7 +522,6 @@ $strNoRowsSelected = 'Aucun enregistrement n\'a t slectionn';
 $strNoSpace = 'Espace-disque insuffisant pour enregistrer le fichier %s.';
 $strNoTablesFound = 'Aucune table n\'a t trouve dans cette base.';
 $strNoThemeSupport = 'Les thmes ne sont pas supports, veuillez vrifier votre configuration et/ou vos thmes dans le rpertoire %s.';
-$strNothingToImport = 'Il n\'y a rien  importer!';
 $strNotNumber = 'Ce n\'est pas un nombre !';
 $strNotOK = 'en erreur';
 $strNotSet = 'La table <b>%s</b> est absente ou non dfinie dans %s';
@@ -497,11 +529,17 @@ $strNoUsersFound = 'Il n\'y a aucun utilisateur';
 $strNoValidateSQL = 'Ne pas valider SQL';
 $strNull = 'Null';
 $strNumberOfFields = 'Nombre de champs';
+$strNumberOfTables = 'Nombre de tables';
 $strNumSearchResultsInTable = '%s occurence(s) dans la table <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Total :</b> <i>%s</i> occurence(s)';
 $strNumTables = 'Tables';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheetOptions = 'Options pour tableur "Open Document"';
+$strOpenDocumentSpreadsheet = 'Tableur "Open Document"';
+$strOpenDocumentTextOptions = 'Options pour texte "Open Document"';
+$strOpenDocumentText = 'Texte "Open Document"';
+$strOpenNewWindow = 'Ouvrir une nouvelle fentre phpMyAdmin';
 $strOperations = 'Oprations';
 $strOperator = 'Oprateur';
 $strOptimizeTable = 'Optimiser la table';
@@ -522,6 +560,10 @@ $strPasswordNotSame = 'Les mots de passe doivent tre identiques';
 $strPdfDbSchema = 'Schema de la base "%s" - Page %s';
 $strPdfInvalidTblName = 'La table "%s" n\'existe pas !';
 $strPdfNoTables = 'Pas de table !';
+$strPDFOptions = 'Options PDF';
+$strPDF = 'PDF';
+$strPDFReportExplanation = '(Gnre un rapport contenant les donnes d\'une seule table)';
+$strPDFReportTitle = 'Titre du rapport';
 $strPerHour = 'par heure';
 $strPerMinute = 'par minute';
 $strPerSecond = 'par seconde';
@@ -530,8 +572,10 @@ $strPhoneBook = 'annuaire tlphonique';
 $strPHP40203 = 'Vous utilisez PHP 4.2.3, et cette version a un srieux problme avec les caractres multi-octets (mbstring), tel que dcrit sur le rapport d\'anomalies 19404 chez PHP.  Il n\'est pas recommand d\'utiliser cette version de PHP avec phpMyAdmin.';
 $strPhp = 'Crer source PHP';
 $strPHPVersion = 'Version de PHP';
+$strPleaseSelectPrimaryOrUniqueKey = 'Veuillez choisir la cl primaire ou une cl unique';
 $strPmaDocumentation = 'Documentation de phpMyAdmin';
 $strPmaUriError = 'Le paramtre <tt>$cfg[\'PmaAbsoluteUri\']</tt> DOIT tre renseign dans votre fichier de configuration !';
+$strPmaWiki = 'Wiki phpMyAdmin';
 $strPolish = 'polonais';
 $strPortrait = 'Portrait';
 $strPos1 = 'Dbut';
@@ -581,7 +625,10 @@ $strPrivDescUpdate = 'Permission de changer des donnes.';
 $strPrivDescUsage = 'Pas de privilges';
 $strPrivileges = 'Privilges';
 $strPrivilegesReloaded = 'Les privilges ont t rechargs.';
+$strProcedures = 'Procdures';
+$strProcesses = 'Processus';
 $strProcesslist = 'Liste des processus';
+$strProtocolVersion = 'Version du protocole';
 $strPutColNames = 'Afficher les noms de champ en premire ligne';
 
 $strQBEDel = 'Effacer';
@@ -590,6 +637,7 @@ $strQBE = 'Requte';
 $strQueryCache = 'Cache des requtes';
 $strQueryFrame = 'Fentre SQL';
 $strQueryOnDb = 'Requte SQL sur la base <b>%s</b>&nbsp;:';
+$strQueryResultsOperations = 'Oprations sur les rsultats de la requte';
 $strQuerySQLHistory = 'Historique SQL';
 $strQueryStatistics = '<b>Statistiques sur les requtes</b>: Depuis son dmarrage, %s requtes ont t envoyes au serveur.';
 $strQueryTime = 'traitement: %01.4f sec.';
@@ -598,17 +646,19 @@ $strQueryWindowLock = 'Ne pas craser cette requte depuis une autre fentre';
 
 $strReadRequests = 'Requtes de lecture';
 $strReceived = 'Reu';
+$strRecommended = 'recommand';
 $strRecords = 'Enregistrements';
 $strReferentialIntegrity = 'Vrifier l\'intgrit rfrentielle';
 $strRefresh = 'Actualiser';
 $strRelationalSchema = 'Schma relationnel';
+$strRelationDeleted = 'Relation supprime';
 $strRelationNotWorking = 'Certaines fonctionnalits ayant trait aux tables relies sont dsactives. Pour une analyse du problme, cliquez %sici%s.';
 $strRelationsForTable = 'RELATIONS POUR LA TABLE';
 $strRelations = 'Relations';
 $strRelationView = 'Gestion des relations';
-$strReloadFailed = 'MySQL n\'a pu tre recharg.';
 $strReloadingThePrivileges = 'Chargement des privilges en cours.';
-$strReloadMySQL = 'Recharger MySQL';
+$strReloadPrivileges = 'Recharger les privilges';
+$strReload = 'Recharger';
 $strRemoveSelectedUsers = 'Effacer les utilisateurs slectionns.';
 $strRenameDatabaseOK = 'La base de donnes %s a t renomme en %s';
 $strRenameTable = '<b>Changer le nom</b> de la table pour';
@@ -641,6 +691,7 @@ $strRunSQLQueryOnServer = 'Excuter une ou des requtes SQL sur le serveur %s';
 $strRussian = 'russe';
 
 $strSaveOnServer = 'Sauvegarder sur le serveur dans le rpertoire %s';
+$strSavePosition = 'Sauvegarder la position';
 $strSave = 'Sauvegarder';
 $strScaleFactorSmall = 'Veuillez augmenter l\'chelle car le schma dborde la page';
 $strSearchFormTitle = 'Effectuer une nouvelle recherche dans la base de donnes';
@@ -658,17 +709,19 @@ $strSelectADb = 'Choisissez une base de donnes';
 $strSelectAll = 'Tout slectionner';
 $strSelectBinaryLog = 'Slectionnez le log binaire  consulter';
 $strSelectFields = 'Choisir les champs  afficher (au moins un)';
+$strSelectForeignKey = 'Choisissez la cl trangre';
 $strSelectNumRows = 'dans la requte';
+$strSelectReferencedKey = 'Slectionnez la cl rfrence';
 $strSelectTables = 'Choisissez les tables';
 $strSend = 'Transmettre';
 $strSent = 'Envoy';
 $strServerChoice = 'Choix du serveur';
 $strServerNotResponding = 'Le serveur ne rpond pas.';
 $strServer = 'Serveur';
+$strServers = 'Serveurs';
 $strServerStatusDelayedInserts = 'Insertions avec dlais';
 $strServerStatus = 'Informations sur le serveur';
 $strServerStatusUptime = 'Ce serveur MySQL fonctionne depuis %s. Il a dmarr le %s.';
-$strServerTabProcesslist = 'Processus';
 $strServerTabVariables = 'Variables';
 $strServerTrafficNotes = '<b>Statistiques sur le trafic</b>: Ce tableau indique le trafic rseau observ sur ce serveur MySQL depuis son dmarrage.';
 $strServerVars = 'Variables et rglages du serveur';
@@ -681,8 +734,11 @@ $strShowColor = 'Couleurs';
 $strShowDatadictAs = 'Orientation du dictionnaire:';
 $strShowFullQueries = 'Afficher les requtes compltes';
 $strShowGrid = 'Grille';
+$strShowHideLeftMenu = 'Montrer/cacher le menu de gauche';
 $strShowingBookmark = 'Affichage du signet';
+$strShowingPhp = 'Affichage du code PHP';
 $strShowingRecords = 'Affichage des enregistrements';
+$strShowingSQL = 'Affichage de la requte SQL';
 $strShowOpenTables = 'Montrer les tables ouvertes';
 $strShowPHPInfo = 'Afficher les informations relatives  PHP';
 $strShowSlaveHosts = 'Montrer les serveurs esclaves';
@@ -803,6 +859,8 @@ $strSize = 'Taille';
 $strSkipQueries = 'Nombre d\'enregistrements (requtes)  ignorer  partir du dbut';
 $strSlovak = 'slovaque';
 $strSlovenian = 'slovne';
+$strSmallBigAll = 'Agrandir/rduire tout';
+$strSnapToGrid = 'Accrocher  la grille';
 $strSocketProblem = '(ou l\'interface de connexion ("socket") vers le serveur MySQL local n\'est pas correctement configure)';
 $strSortByKey = 'Trier sur l\'index';
 $strSorting = 'Mcanisme de tri';
@@ -810,8 +868,9 @@ $strSort = 'Tri';
 $strSpaceUsage = 'Espace utilis';
 $strSpanish = 'espagnol';
 $strSplitWordsWithSpace = 'Sparer les mots par un espace (" ").';
-$strSQLExportCompatibility = 'Compatibilit de l\'exportation';
+$strSQLCompatibility = 'Mode de compatibilit SQL';
 $strSQLExportType = 'Type d\'exportation';
+$strSQLImportOptions = 'Options SQL';
 $strSQLOptions = 'options SQL';
 $strSQLParserBugMessage = 'Il semble que vous ayiez trouv une anomalie dans l\'analyseur syntaxique SQL. Veuillez examiner votre requte attentivement, et vrifier que vos apostrophes sont conformes. Il se pourrait aussi que vous ayiez charg un fichier dont le contenu binaire n\'est pas entre apostrophes.  Si vous avez accs  MySQL via son interface de commande en mode ligne, vous pouvez y essayer votre requte. Le message d\'erreur prsent plus bas pourrait vous indiquer la source du problme. En dernier recours, veuillez trouver la plus courte requte possible qui cause le problme, et soumettre un rapport d\'anomalie en incluant la section  couper:';
 $strSQLParserUserError = 'Il semble qu\'il y ait une erreur dans votre requte SQL. Le message ci-bas peut vous aider  en trouver la cause.';
@@ -821,20 +880,23 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Identificateur invalide';
 $strSQPBugUnclosedQuote = 'Apostrophe non ferm';
 $strSQPBugUnknownPunctuation = 'Ponctuation invalide';
+$strStandInStructureForView = 'Doublure de structure pour la vue';
 $strStatCheckTime = 'Dernire vrification';
 $strStatCreateTime = 'Cration';
 $strStatement = 'Information';
+$strStatisticsOverrun = 'Sur un serveur surcharg, la capacit des compteurs d\'octets peut tre dpasse, auquel cas les statistiques rapportes par MySQL peuvent tre inexactes.';
 $strStatUpdateTime = 'Dernire modification';
 $strStatus = 'tat';
 $strStorageEngine = 'Moteur de stockage';
 $strStorageEngines = 'Moteurs de stockage';
 $strStrucCSV = 'CSV';
 $strStrucData = 'Structure et donnes';
-$strStrucDrop = 'Inclure des noncs "DROP TABLE"';
 $strStrucExcelCSV = 'CSV pour MS Excel';
 $strStrucNativeExcel = 'Donnes MS Excel (format natif)';
+$strStrucNativeExcelOptions = 'Options pour Excel natif';
 $strStrucOnly = 'Structure seule';
 $strStructPropose = 'Suggrer des optimisations quant  la structure de la table';
+$strStructureForView = 'Structure de la vue';
 $strStructure = 'Structure';
 $strSubmit = 'Excuter';
 $strSuccess = 'Votre requte SQL a t excute avec succs';
@@ -849,28 +911,36 @@ $strTableEmpty = 'Le nom de la table est vide';
 $strTableHasBeenDropped = 'La table %s a t efface';
 $strTableHasBeenEmptied = 'La table %s a t vide';
 $strTableHasBeenFlushed = 'La table %s a t recharge';
+$strTableIsEmpty = 'La table semble vide!';
 $strTableMaintenance = '<b>Maintenance</b> de la table';
+$strTableName = 'Nom de la table';
 $strTableOfContents = 'Table des matires';
 $strTableOptions = '<b>Options</b> pour cette table';
 $strTables = '%s table(s)';
 $strTableStructure = 'Structure de la table';
 $strTable = 'Table';
-$strTableType = '<b>Type</b> de la table';
 $strTakeIt = 'utiliser celui-ci';
 $strTblPrivileges = 'Privilges spcifiques  une table';
 $strTempData = 'Donnes temporaires';
 $strTextAreaLength = 'Il est possible que ce champ<br />ne soit pas ditable<br />en raison de sa longueur';
 $strThai = 'tha';
+$strThemeDefaultNotFound = 'Thme par dfaut %s inexistant!';
+$strThemeNoPreviewAvailable = 'Prvisualisation non disponible.';
+$strThemeNotFound = 'Thme %s inexistant!';
+$strThemeNoValidImgPath = 'Chemin des images inexistant pour le thme %s!';
+$strThemePathNotFound = 'Chemin non trouv pour le thme %s!';
 $strTheme = 'Thme / Style';
 $strThisHost = 'Ce serveur';
-$strThisNotDirectory = 'Ceci n\'est pas un rpertoire';
 $strThreads = 'Fils d\'excution';
 $strThreadSuccessfullyKilled = 'Le processus %s a t limin.';
 $strTime = 'Dure';
 $strTimeoutInfo = 'L\'importation prcdente a chou en raison du temps; retransmettez et le traitement reprendra  la position %d.';
 $strTimeoutNothingParsed = 'Cependant lors du dernier traitement, aucune section n\a t analyse; ceci signifie que phpMyAdmin ne pourra terminer cette importation,  moins que la limite de temps de PHP ne soit augmente';
 $strTimeoutPassed = 'La limite de temps a t atteinte; si vous voulez terminer l\'importation, soumettez  nouveau le mme fichier et l\'importation continuera.';
+$strToFromPage = 'de/vers la page';
 $strToggleScratchboard = 'diteur visuel';
+$strToggleSmallBig = 'Bascule agrandir/rduire';
+$strToSelectRelation = 'Pour slectionner un lien, cliquez :';
 $strTotal = 'total';
 $strTotalUC = 'Total';
 $strTraditionalChinese = 'chinois traditionnel';
@@ -878,11 +948,11 @@ $strTraditionalSpanish = 'espagnol traditionnel';
 $strTraffic = 'Trafic';
 $strTransactionCoordinator = 'Coordonnateur des transactions';
 $strTransformation_application_octetstream__download = 'Affiche un lien pour tlcharger le contenu binaire d\'une colonne. La premire option est le nom du fichier binaire. La seconde option est le nom de la colonne contenant le nom du fichier. Si vous utilisez la seconde option, veuillez laisser la premire option vide.';
-$strTransformation_application_octetstream__hex = 'Affiche une reprsentation hexadcimale des donnes.';
+$strTransformation_application_octetstream__hex = 'Affiche une reprsentation hexadcimale des donnes. Le premier paramtre est optionnel et spcifie combien d\'espaces seront ajouts.';
 $strTransformation_image_jpeg__inline = 'Affiche une image timbre-poste cliquable; les options sont: largeur,hauteur en pixels (conserve le rapport original)';
 $strTransformation_image_jpeg__link = 'Affiche un lien vers cette image';
 $strTransformation_image_png__inline = 'Voir image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Change le format des champs de type TIME, TIMESTAMP ou DATETIME selon votre format local de date/heure. La premire option est le dcalage horaire qui sera ajout (par dfaut 0). La seconde option est un format en accord avec les paramtres de la fonction PHP strftime().';
+$strTransformation_text_plain__dateformat = 'Affiche un champ TIME, TIMESTAMP, DATETIME ou un champ numrique contenant une valeur TIMESTAMP UNIX en tant que date formate. La premire option est le dcalage (en heures)  ajouter (par dfaut, 0). La seconde option sert  indiquer le format de date ou d\'heure. La troisime option dtermine si vous voulez la date locale ("local") ou UTC ("utc"). Pour le format "local", le second paramtre utilise le format de la fonction PHP strftime() et pour le format "utc", il utilise la fonction gmdate().';
 $strTransformation_text_plain__external = '(Linux seulement) Excute un programme externe et lui envoit le contenu du champ via l\'entre standard. Puis capture la sortie standard de ce programme externe. Le programme par dfaut est tidy, pour un affichage embelli du code HTML.  Pour des raisons de scurit, vous devez diter le script libraries/transformations/text_plain__external.inc.php et y insrer les noms de programme externe possibles. La premire option est le numro du programme que vous voulez utiliser, la seconde option contient les paramtres pour ce programme. En troisime option, une valeur de 1 va convertir le rsultat avec la fonction htmlspecialchars() (par dfaut, 1). En option 4, une valeur de 1 va ajouter NOWRAP  la cellule affiche (par dfaut, 1).';
 $strTransformation_text_plain__formatted = 'Prserve le contenu original du champ, sans ajout de caractres d\'chappement.';
 $strTransformation_text_plain__imagelink = 'Affiche une image et un lien, le champ contient le nom du fichier; en premire option, un prfixe comme "http://domaine.com/", en seconde option, la largeur en pixels, en troisime option la hauteur en pixels.';
@@ -906,8 +976,10 @@ $strUpdateQuery = 'Mise--jour de la requte';
 $strUpdComTab = 'La documentation indique comment mettre  jour votre table Column_comments';
 $strUpgrade = 'Vous devriez utiliser %s en version %s ou plus rcente.';
 $strUploadLimit = 'Vous avez probablement tent de tlcharger un fichier trop volumineux. Veuillez vous rfrer  la %sdocumentation%s pour des faons de contourner cette limite.';
+$strUploadsNotAllowed = 'Les tlchargements vers ce serveur ne sont pas permis.';
 $strUsage = 'Espace';
 $strUseBackquotes = 'Protger les noms des tables et des champs par des&nbsp;"`"';
+$strUsedPhpExtensions = 'Extensions PHP utilises';
 $strUseHostTable = 'Utiliser la table Host';
 $strUserAlreadyExists = 'L\'utilisateur %s existe dj!';
 $strUserEmpty = 'Le nom d\'utilisateur est vide';
@@ -931,6 +1003,7 @@ $strViewDump = '<b>Afficher le schma</b> de la table';
 $strViewDumpDatabases = 'Schma et/ou contenu des bases de donnes';
 $strViewDumpDB = 'Schma et donnes de la base ';
 $strViewHasBeenDropped = 'La vue %s a t supprime';
+$strViewMaxExactCount = 'Cette vue comporte plus de %d enregistrements. Veuillez vous rfrer  la %sdocumentation%s.';
 $strView = 'Vue';
 
 $strWebServerUploadDirectoryError = 'Le rpertoire de transfert est inaccessible';
@@ -941,10 +1014,9 @@ $strWildcard = 'passepartout';
 $strWindowNotFound = 'La fentre principale n\'a pu tre mise  jour. Il est possible que vous l\'ayiez ferme, ou encore que votre navigateur bloque les mises  jour inter-fentres pour des raisons de scurit.';
 $strWithChecked = 'Pour la slection :';
 $strWriteRequests = 'Requtes d\'criture';
-$strWritingCommentNotPossible = 'Ajout de commentaire impossible';
-$strWritingRelationNotPossible = 'Ajout de relation impossible';
 $strWrongUser = 'Erreur d\'utilisateur/mot de passe. Accs refus';
 
+$strXMLOptions = 'Options XML';
 $strXML = 'XML';
 
 $strYes = 'Oui';
