@@ -1,17 +1,17 @@
 <?php
-/* $Id: french-utf-8.inc.php,v 2.152.2.2 2006/03/23 17:42:12 lem9 Exp $ */
+/* $Id: french-utf-8.inc.php 10018 2007-02-26 17:26:53Z lem9 $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr';
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ' ';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits = array('Octets', 'Ko', 'Mo', 'Go', 'To', 'Po', 'Eo');
+$byteUnits = array('o', 'Kio', 'Mio', 'Gio', 'Tio', 'Pio', 'Eio');
 
-$day_of_week = array('Dimanche', 'Lundi', 'Mardi', 'Mercredi', 'Jeudi', 'Vendredi', 'Samedi');
+$mysql_5_0_doc_lang = 'fr';
+
+$day_of_week = array('Dim', 'Lun', 'Mar', 'Mer', 'Jeu', 'Ven', 'Sam');
 $month = array('Janvier', 'Février', 'Mars', 'Avril', 'Mai', 'Juin', 'Juillet', 'Août', 'Septembre', 'Octobre', 'Novembre', 'Décembre');
 // Voir http://www.php.net/manual/en/function.strftime.php pour la variable
 // ci-dessous
@@ -20,21 +20,17 @@ $datefmt = '%A %d %B %Y à %H:%M';
 $timespanfmt = '%s jours, %s heures, %s minutes et %s secondes';
 
 $strAbortedClients = 'Arrêts prématurés';
-$strAbsolutePathToDocSqlDir = 'Veuillez entrer le chemin absolu du répertoire docSQL sur le serveur web';
 $strAccessDenied = 'Accès refusé';
 $strAccessDeniedCreateConfig = 'La raison probable est que vous n\'avez pas créé de fichier de configuration. Vous pouvez utiliser le %1$sscript de configuration%2$s dans ce but.';
 $strAccessDeniedExplanation = 'phpMyAdmin a tenté de se connecter au serveur MySQL, et le serveur a rejeté la connexion. Veuillez vérifier les valeurs de "host", "username" et "password" dans config.inc.php et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
 $strAction = 'Action';
 $strAddAutoIncrement = 'Inclure la valeur courante de l\'AUTO_INCREMENT';
+$strAddClause = 'Ajouter %s';
 $strAddConstraints = 'Inclure les contraintes de clés étrangères';
 $strAddDeleteColumn = 'Ajouter/effacer x colonne(s)';
 $strAddDeleteRow = 'Ajouter/effacer x ligne(s)';
-$strAddDropDatabase = 'Ajouter DROP DATABASE';
-$strAddedColumnComment = 'Commentaire ajouté pour la colonne';
-$strAddedColumnRelation = 'Relation ajoutée pour la colonne';
 $strAddFields = 'Ajouter %s champ(s)';
 $strAddHeaderComment = 'Commentaires mis en en-tête (\\n sépare les lignes)';
-$strAddIfNotExists = 'Ajouter "IF NOT EXISTS"';
 $strAddIntoComments = 'Inclure sous forme de commentaires';
 $strAddNewField = 'Ajouter un champ';
 $strAddPrivilegesOnDb = 'Ajouter des privilèges sur cette base de données';
@@ -57,6 +53,7 @@ $strAlterOrderBy = '<b>Ordonner</b> la table par';
 $strAnalyzeTable = 'Analyser la table';
 $strAnd = 'et';
 $strAndThen = 'et ensuite';
+$strAngularLinks = 'Liens angulaires';
 $strAnIndex = 'Un index a été ajouté sur %s';
 $strAnyHost = 'Tout serveur';
 $strAny = 'N\'importe quel';
@@ -109,6 +106,8 @@ $strBzError = 'phpMyAdmin n\'a pu compresser le fichier exporté en raison d\'un
 $strBzip = '"bzippé"';
 
 $strCalendar = 'Calendrier';
+$strCancel = 'Annuler';
+$strCanNotLoadExportPlugins = 'Erreur lors du chargement des modules d\'exportation!';
 $strCanNotLoadImportPlugins = 'Chargement impossible des greffons d\'importation, veuillez vérifier votre installation!';
 $strCannotLogin = 'Connexion au serveur MySQL non permise';
 $strCantLoad = 'PHP ne peut charger l\'extension %s, [br]veuillez vérifier votre configuration de PHP';
@@ -171,6 +170,12 @@ $strCreateNewDatabase = 'Créer une base de données';
 $strCreateNewTable = '<b>Créer une nouvelle table</b> sur la base %s';
 $strCreatePage = 'Créer une page';
 $strCreatePdfFeat = 'Génération de schémas en PDF';
+$strCreateRelation = 'Nouvelle relation';
+$strCreateTable  = 'Nouvelle table';
+$strCreateUserDatabase = 'Base de données pour cet utilisateur';
+$strCreateUserDatabaseName = 'Créer une base portant son nom et donner à cet utilisateur tous les privilèges sur cette base';
+$strCreateUserDatabaseNone = 'Aucune';
+$strCreateUserDatabaseWildcard = 'Donner les privilèges passepartout ("%")';
 $strCreationDates = 'Dates de création/modification/vérification';
 $strCriteria = 'Critère';
 $strCroatian = 'croate';
@@ -199,15 +204,7 @@ $strDataOnly = 'Données seulement';
 $strDataPages = 'Pages contenant des données';
 $strDBComment = '<b>Commentaire</b> sur la base de données: ';
 $strDBCopy = 'Copier la base de données vers';
-$strDBGContext = 'Contexte';
-$strDBGContextID = 'Identificateur de contexte';
-$strDBGHits = 'Occurences';
-$strDBGLine = 'Ligne';
-$strDBGMaxTimeMs = 'Durée maximum, ms';
-$strDBGMinTimeMs = 'Durée minimum, ms';
-$strDBGModule = 'Module';
-$strDBGTimePerHitMs = 'Durée/Occurence, ms';
-$strDBGTotalTimeMs = 'Durée totale, ms';
+$strDbIsEmpty = 'La base de données semble vide!';
 $strDbPrivileges = 'Privilèges spécifiques à une base de données';
 $strDBRename = '<b>Changer le nom</b> de la base de données pour';
 $strDbSpecific = 'spécifique à cette base de données';
@@ -222,11 +219,16 @@ $strDeleted = 'L\'enregistrement a été effacé';
 $strDeletedRows = 'Nombre d\'enregistrements effacés :';
 $strDelete = 'Effacer';
 $strDeleteNoUsersSelected = 'Aucun utilisateur n\'a été choisi en vue de le détruire!';
+$strDeleteRelation = 'Effacer la relation';
 $strDeleting = 'Destruction de %s';
+$strDelimiter = 'Délimiteur';
 $strDelOld = 'Cette page fait référence à des tables qui n\'existent plus. Voulez-vous effacer ces références?';
 $strDescending = 'Décroissant';
 $strDescription = 'Description';
+$strDesigner = 'Concepteur';
+$strDesignerHelpDisplayField = 'Le champ à afficher est montré en rose. Pour indiquer qu\'un champ est ou n\'est plus le champ à afficher, cliquer l\'icône "Champ à afficher", puis cliquer sur le nom de champ approprié.';
 $strDictionary = 'dictionnaire';
+$strDirectLinks = 'Liens directs';
 $strDirtyPages = 'Pages modifiées';
 $strDisabled = 'désactivé';
 $strDisableForeignChecks = 'Désactiver la vérification des clés étrangères';
@@ -234,6 +236,8 @@ $strDisplayFeat = 'Affichage infobulle';
 $strDisplayOrder = 'Ordre d\'affichage :';
 $strDisplayPDF = '<b>Afficher le schéma</b> en PDF';
 $strDoAQuery = 'Recherche par valeur (passepartout: "%")';
+$strDocSQL = 'DocSQL';
+$strDocSQLOptions = 'Options DocSQL';
 $strDocu = 'Documentation';
 $strDoYouReally = 'Voulez-vous vraiment effectuer ';
 $strDropDatabaseStrongWarning = 'Vous êtes sur le point de DÉTRUIRE une base de données!';
@@ -263,6 +267,10 @@ $strEnglish = 'anglais';
 $strEnglishPrivileges = ' Veuillez noter que les noms de privilèges sont exprimés en anglais';
 $strError = 'Erreur';
 $strErrorInZipFile = 'Erreur rencontrée dans l\'archive ZIP :';
+$strErrorRelationAdded = 'Erreur: relation non ajoutée.';
+$strErrorRelationExists = 'Erreur: relation déjà existante.';
+$strErrorRenamingTable = 'Erreur lors du renommage de %1$s en %2$s';
+$strErrorSaveTable = 'Erreur lors de la sauvegarde des coordonnées Concepteur.';
 $strEscapeWildcards = 'Préfixer avec \ les passepartouts _ et % pour un usage littéral';
 $strEsperanto = 'Espéranto';
 $strEstonian = 'estonien';
@@ -271,6 +279,8 @@ $strExcelOptions = 'Options Excel';
 $strExecuteBookmarked = 'Exécuter la requête en signets';
 $strExplain = 'Expliquer SQL';
 $strExport = 'Exporter';
+$strExportImportToScale = 'Exporter/Importer à l\'échelle';
+$strExportMustBeFile = 'Ce choix d\'exportation doit être sauvegardé dans un fichier!';
 $strExtendedInserts = 'Insertions étendues';
 $strExtra = 'Extra';
 
@@ -296,11 +306,14 @@ $strFlushPrivilegesNote = 'Note: phpMyAdmin obtient la liste des privilèges dir
 $strFlushQueryCache = 'Vider la cache des requêtes';
 $strFlushTable = 'Recharger la table ("FLUSH")';
 $strFlushTables = 'Fermer toutes les tables';
+$strFontSize = 'Taille du texte';
+$strForeignKeyError = 'Erreur lors de la création de la clé étrangère (vérifiez les types de données';
 $strFormat = 'format';
 $strFormEmpty = 'Formulaire incomplet !';
 $strFreePages = 'Pages libres';
 $strFullText = 'Textes complets';
 $strFunction = 'Fonction';
+$strFunctions = 'Fonctions';
 
 $strGenBy = 'Généré par';
 $strGeneralRelationFeat = 'Fonctions relationnelles';
@@ -322,7 +335,11 @@ $strHasBeenAltered = 'a été modifié(e).';
 $strHasBeenCreated = 'a été créé(e).';
 $strHaveToShow = 'Vous devez choisir au moins une colonne à afficher';
 $strHebrew = 'hébreu';
+$strHelp = 'Aide';
 $strHexForBinary = 'Encoder les champs binaires en hexadécimal';
+$strHide         = 'Cacher';
+$strHideShowAll = 'Cacher/montrer tout';
+$strHideShowNoRelation = 'Cacher/montrer les tables sans liens';
 $strHome = 'Accueil';
 $strHomepageOfficial = 'Site officiel de phpMyAdmin';
 $strHostEmpty = 'Le nom de serveur est vide';
@@ -336,11 +353,11 @@ $strHungarian = 'hongrois';
 $strIcelandic = 'islandais';
 $strId = 'ID';
 $strIdxFulltext = 'Texte entier';
+$strIEUnsupported = 'Fonction non disponible sous Internet Explorer.';
 $strIgnoreDuplicates = 'Ignorer les doublons';
 $strIgnore = 'Ignorer';
 $strIgnoreInserts = 'Ignorer les erreurs de doublons (INSERT IGNORE)';
-$strIgnoringFile = 'Fichier %s ignoré';
-$strImportDocSQL = 'Importer des fichiers docSQL';
+$strImportExportCoords = 'Importer/Exporter les coordonnées pour le schéma PDF';
 $strImportFiles = 'Importe les fichiers';
 $strImportFormat = 'Format du fichier d\'importation';
 $strImport = 'Importer';
@@ -362,14 +379,15 @@ $strInnoDBDataFilePath = 'Fichiers de données';
 $strInnoDBDataHomeDirDesc = 'Le chemin du répertoire pour tous les fichiers de données InnoDB.';
 $strInnoDBDataHomeDir = 'Répertoire des données';
 $strInnoDBPages = 'pages';
+$strInnoDBRelationAdded = 'Relation InnoDB ajoutée';
 $strInnodbStat = 'État InnoDB';
 $strInsecureMySQL = 'Votre fichier de configuration fait référence à l\'utilisateur root sans mot de passe, ce qui correspond à la valeur par défaut de MySQL.  Votre serveur MySQL est donc ouvert aux intrusions, et vous devriez corriger ce problème de sécurité.';
 $strInsertAsNewRow = 'Sauvegarder un nouvel enregistrement';
 $strInsertedRowId = 'Identifiant de l\'enregistrement inséré:';
 $strInsertedRows = 'Nombre d\'enregistrements insérés :';
 $strInsert = 'Insérer';
-$strInsertNewRow = 'Insérer un nouvel enregistrement';
 $strInternalNotNecessary = '* Si une relation existe dans InnoDB, il n\'est pas nécessaire de la définir dans les relations internes.';
+$strInternalRelationAdded = 'Relation interne ajoutée';
 $strInternalRelations = 'Relations internes';
 $strInUse = 'utilisé';
 $strInvalidAuthMethod = 'Le fichier de configuration contient un type d\'authentification invalide :';
@@ -378,12 +396,14 @@ $strInvalidColumn = 'La colonne %s est invalide!';
 $strInvalidCSVFieldCount = 'Nombre de champs invalide dans les données CSV à la ligne %d';
 $strInvalidCSVFormat = 'Format invalide pour les données CSV à la ligne %d.';
 $strInvalidCSVParameter = 'Paramètres invalides pour l\'importation CSV: %s';
+$strInvalidDatabase = 'Nom de base de données invalide';
 $strInvalidFieldAddCount = 'Vous devez ajouter au moins un champ';
 $strInvalidFieldCount = 'La table doit comporter au moins un champ';
 $strInvalidLDIImport = 'Ce greffon ne supporte pas les importations en format comprimé!';
 $strInvalidRowNumber = '%d n\'est pas un numéro d\'enregistrement valable.';
 $strInvalidServerHostname = 'Nom d\'hôte (hostname) invalide pour le serveur %1$s. Veuillez vérifier votre configuration.';
 $strInvalidServerIndex = 'Indice de serveur invalide: "%s"';
+$strInvalidTableName = 'Nom de table invalide';
 
 $strJapanese = 'japonais';
 $strJoins = 'Jointures';
@@ -395,10 +415,12 @@ $strKeepPass = 'Conserver le mot de passe';
 $strKeyCache = 'Cache des clés';
 $strKeyname = 'Nom de la clé';
 $strKill = 'Supprimer';
+$strKnownExternalBug = 'La fonctionnalité %s est affectée par une anomalie connue, voir %s';
 $strKorean = 'coréen';
 
 $strLandscape = 'Paysage';
 $strLanguageFileNotFound = 'Fichier de langue "%1$s" inexistant.';
+$strLanguage = 'Langue';
 $strLanguageUnknown = 'Langue inconnue: %1$s.';
 $strLatchedPages = 'Pages verrouillées';
 $strLatexCaption = 'Sous-titre de la table';
@@ -441,7 +463,7 @@ $strMIME_description = 'Description';
 $strMIME_MIMEtype = 'Type MIME';
 $strMIME_nodescription = 'Aucune description n\'est disponible pour cette transformation.<br />Veuillez demander à son auteur, des détails sur %s.';
 $strMIME_transformation_note = 'La %sdescription des transformations%s explique les transformations possibles en fonction des types MIME.';
-$strMIME_transformation_options_note = 'Veuillez entrer les valeurs des options de transformation en suivant ce format: \'a\',\'b\',\'c\'...<br />Si vous devez entrer un caractère ("\") ou une apostrophe ("\'") parmi ces valeurs, faites-le précéder du caractère d\'échappement, par exemple  \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Veuillez entrer les valeurs des options de transformation en suivant ce format: \'a\', 100, b,\'c\'...<br />Si vous devez entrer un caractère ("\") ou une apostrophe ("\'") parmi ces valeurs, faites-le précéder du caractère d\'échappement, par exemple  \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_transformation_options = 'Options de transformation';
 $strMIME_transformation = 'Transformation';
 $strMIMETypesForTable = 'TYPES MIME POUR LA TABLE';
@@ -449,6 +471,7 @@ $strMIME_without = 'Les types MIME affichées en italiques ne possèdent pas de
 $strModifications = 'Les modifications ont été sauvegardées.';
 $strModifyIndexTopic = 'Modifier une clef';
 $strModify = 'Modifier';
+$strMoveMenu = 'Déplacer le menu';
 $strMoveTable = '<b>Déplacer</b> la table vers (base<b>.</b>table)&nbsp;:';
 $strMoveTableOK = 'La table %s a été déplacée vers %s.';
 $strMoveTableSameNames = 'On ne peut déplacer la table sur elle-même!';
@@ -478,6 +501,7 @@ $strNext = 'Suivant';
 $strNoActivity = 'Aucune activité depuis %s secondes ou plus, veuillez vous reconnecter';
 $strNoDatabases = 'Aucune base de données';
 $strNoDatabasesSelected = 'Aucune base de données n\'a été sélectionnée.';
+$strNoDataReceived = 'Aucune données n\'a été reçu en vue de l\'importation. Aucun nom de fichier n\'a été fourni, ou encore la taille du fichier a dépassé la limite permise par votre configuration de PHP. Voir FAQ 1.16';
 $strNoDescription = 'pas de description';
 $strNoDetailsForEngine = 'Aucune information détaillée sur l\'état n\'est disponible pour ce moteur de stockage.';
 $strNoDropDatabases = 'La commande "DROP DATABASE" est désactivée.';
@@ -499,7 +523,6 @@ $strNoRowsSelected = 'Aucun enregistrement n\'a été sélectionné';
 $strNoSpace = 'Espace-disque insuffisant pour enregistrer le fichier %s.';
 $strNoTablesFound = 'Aucune table n\'a été trouvée dans cette base.';
 $strNoThemeSupport = 'Les thèmes ne sont pas supportés, veuillez vérifier votre configuration et/ou vos thèmes dans le répertoire %s.';
-$strNothingToImport = 'Il n\'y a rien à importer!';
 $strNotNumber = 'Ce n\'est pas un nombre !';
 $strNotOK = 'en erreur';
 $strNotSet = 'La table <b>%s</b> est absente ou non définie dans %s';
@@ -507,11 +530,16 @@ $strNoUsersFound = 'Il n\'y a aucun utilisateur';
 $strNoValidateSQL = 'Ne pas valider SQL';
 $strNull = 'Null';
 $strNumberOfFields = 'Nombre de champs';
+$strNumberOfTables = 'Nombre de tables';
 $strNumSearchResultsInTable = '%s occurence(s) dans la table <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Total :</b> <i>%s</i> occurence(s)';
 $strNumTables = 'Tables';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheetOptions = 'Options pour tableur "Open Document"';
+$strOpenDocumentSpreadsheet = 'Tableur "Open Document"';
+$strOpenDocumentTextOptions = 'Options pour texte "Open Document"';
+$strOpenDocumentText = 'Texte "Open Document"';
 $strOpenNewWindow = 'Ouvrir une nouvelle fenêtre phpMyAdmin';
 $strOperations = 'Opérations';
 $strOperator = 'Opérateur';
@@ -535,6 +563,7 @@ $strPdfInvalidTblName = 'La table "%s" n\'existe pas !';
 $strPdfNoTables = 'Pas de table !';
 $strPDFOptions = 'Options PDF';
 $strPDF = 'PDF';
+$strPDFReportExplanation = '(Génère un rapport contenant les données d\'une seule table)';
 $strPDFReportTitle = 'Titre du rapport';
 $strPerHour = 'par heure';
 $strPerMinute = 'par minute';
@@ -544,8 +573,10 @@ $strPhoneBook = 'annuaire téléphonique';
 $strPHP40203 = 'Vous utilisez PHP 4.2.3, et cette version a un sérieux problème avec les caractères multi-octets (mbstring), tel que décrit sur le rapport d\'anomalies 19404 chez PHP.  Il n\'est pas recommandé d\'utiliser cette version de PHP avec phpMyAdmin.';
 $strPhp = 'Créer source PHP';
 $strPHPVersion = 'Version de PHP';
+$strPleaseSelectPrimaryOrUniqueKey = 'Veuillez choisir la clé primaire ou une clé unique';
 $strPmaDocumentation = 'Documentation de phpMyAdmin';
 $strPmaUriError = 'Le paramètre <tt>$cfg[\'PmaAbsoluteUri\']</tt> DOIT être renseigné dans votre fichier de configuration !';
+$strPmaWiki = 'Wiki phpMyAdmin';
 $strPolish = 'polonais';
 $strPortrait = 'Portrait';
 $strPos1 = 'Début';
@@ -595,6 +626,8 @@ $strPrivDescUpdate = 'Permission de changer des données.';
 $strPrivDescUsage = 'Pas de privilèges';
 $strPrivileges = 'Privilèges';
 $strPrivilegesReloaded = 'Les privilèges ont été rechargés.';
+$strProcedures = 'Procédures';
+$strProcesses = 'Processus';
 $strProcesslist = 'Liste des processus';
 $strProtocolVersion = 'Version du protocole';
 $strPutColNames = 'Afficher les noms de champ en première ligne';
@@ -605,6 +638,7 @@ $strQBE = 'Requête';
 $strQueryCache = 'Cache des requêtes';
 $strQueryFrame = 'Fenêtre SQL';
 $strQueryOnDb = 'Requête SQL sur la base <b>%s</b>&nbsp;:';
+$strQueryResultsOperations = 'Opérations sur les résultats de la requête';
 $strQuerySQLHistory = 'Historique SQL';
 $strQueryStatistics = '<b>Statistiques sur les requêtes</b>: Depuis son démarrage, %s requêtes ont été envoyées au serveur.';
 $strQueryTime = 'traitement: %01.4f sec.';
@@ -613,16 +647,19 @@ $strQueryWindowLock = 'Ne pas écraser cette requête depuis une autre fenêtre'
 
 $strReadRequests = 'Requêtes de lecture';
 $strReceived = 'Reçu';
+$strRecommended = 'recommandé';
 $strRecords = 'Enregistrements';
 $strReferentialIntegrity = 'Vérifier l\'intégrité référentielle';
 $strRefresh = 'Actualiser';
 $strRelationalSchema = 'Schéma relationnel';
+$strRelationDeleted = 'Relation supprimée';
 $strRelationNotWorking = 'Certaines fonctionnalités ayant trait aux tables reliées sont désactivées. Pour une analyse du problème, cliquez %sici%s.';
 $strRelationsForTable = 'RELATIONS POUR LA TABLE';
 $strRelations = 'Relations';
 $strRelationView = 'Gestion des relations';
 $strReloadingThePrivileges = 'Chargement des privilèges en cours.';
-$strReloadMySQL = 'Recharger MySQL';
+$strReloadPrivileges = 'Recharger les privilèges';
+$strReload = 'Recharger';
 $strRemoveSelectedUsers = 'Effacer les utilisateurs sélectionnés.';
 $strRenameDatabaseOK = 'La base de données %s a été renommée en %s';
 $strRenameTable = '<b>Changer le nom</b> de la table pour';
@@ -655,6 +692,7 @@ $strRunSQLQueryOnServer = 'Exécuter une ou des requêtes SQL sur le serveur %s'
 $strRussian = 'russe';
 
 $strSaveOnServer = 'Sauvegarder sur le serveur dans le répertoire %s';
+$strSavePosition = 'Sauvegarder la position';
 $strSave = 'Sauvegarder';
 $strScaleFactorSmall = 'Veuillez augmenter l\'échelle car le schéma déborde la page';
 $strSearchFormTitle = 'Effectuer une nouvelle recherche dans la base de données';
@@ -672,17 +710,19 @@ $strSelectADb = 'Choisissez une base de données';
 $strSelectAll = 'Tout sélectionner';
 $strSelectBinaryLog = 'Sélectionnez le log binaire à consulter';
 $strSelectFields = 'Choisir les champs à afficher (au moins un)';
+$strSelectForeignKey = 'Choisissez la clé étrangère';
 $strSelectNumRows = 'dans la requête';
+$strSelectReferencedKey = 'Sélectionnez la clé référencée';
 $strSelectTables = 'Choisissez les tables';
 $strSend = 'Transmettre';
 $strSent = 'Envoyé';
 $strServerChoice = 'Choix du serveur';
 $strServerNotResponding = 'Le serveur ne répond pas.';
 $strServer = 'Serveur';
+$strServers = 'Serveurs';
 $strServerStatusDelayedInserts = 'Insertions avec délais';
 $strServerStatus = 'Informations sur le serveur';
 $strServerStatusUptime = 'Ce serveur MySQL fonctionne depuis %s. Il a démarré le %s.';
-$strServerTabProcesslist = 'Processus';
 $strServerTabVariables = 'Variables';
 $strServerTrafficNotes = '<b>Statistiques sur le trafic</b>: Ce tableau indique le trafic réseau observé sur ce serveur MySQL depuis son démarrage.';
 $strServerVars = 'Variables et réglages du serveur';
@@ -695,8 +735,11 @@ $strShowColor = 'Couleurs';
 $strShowDatadictAs = 'Orientation du dictionnaire:';
 $strShowFullQueries = 'Afficher les requêtes complètes';
 $strShowGrid = 'Grille';
+$strShowHideLeftMenu = 'Montrer/cacher le menu de gauche';
 $strShowingBookmark = 'Affichage du signet';
+$strShowingPhp = 'Affichage du code PHP';
 $strShowingRecords = 'Affichage des enregistrements';
+$strShowingSQL = 'Affichage de la requête SQL';
 $strShowOpenTables = 'Montrer les tables ouvertes';
 $strShowPHPInfo = 'Afficher les informations relatives à PHP';
 $strShowSlaveHosts = 'Montrer les serveurs esclaves';
@@ -817,6 +860,8 @@ $strSize = 'Taille';
 $strSkipQueries = 'Nombre d\'enregistrements (requêtes) à ignorer à partir du début';
 $strSlovak = 'slovaque';
 $strSlovenian = 'slovène';
+$strSmallBigAll = 'Agrandir/réduire tout';
+$strSnapToGrid = 'Accrocher à la grille';
 $strSocketProblem = '(ou l\'interface de connexion ("socket") vers le serveur MySQL local n\'est pas correctement configurée)';
 $strSortByKey = 'Trier sur l\'index';
 $strSorting = 'Mécanisme de tri';
@@ -824,7 +869,7 @@ $strSort = 'Tri';
 $strSpaceUsage = 'Espace utilisé';
 $strSpanish = 'espagnol';
 $strSplitWordsWithSpace = 'Séparer les mots par un espace (" ").';
-$strSQLExportCompatibility = 'Compatibilité de l\'exportation';
+$strSQLCompatibility = 'Mode de compatibilité SQL';
 $strSQLExportType = 'Type d\'exportation';
 $strSQLImportOptions = 'Options SQL';
 $strSQLOptions = 'options SQL';
@@ -836,6 +881,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Identificateur invalide';
 $strSQPBugUnclosedQuote = 'Apostrophe non fermé';
 $strSQPBugUnknownPunctuation = 'Ponctuation invalide';
+$strStandInStructureForView = 'Doublure de structure pour la vue';
 $strStatCheckTime = 'Dernière vérification';
 $strStatCreateTime = 'Création';
 $strStatement = 'Information';
@@ -846,11 +892,12 @@ $strStorageEngine = 'Moteur de stockage';
 $strStorageEngines = 'Moteurs de stockage';
 $strStrucCSV = 'CSV';
 $strStrucData = 'Structure et données';
-$strStrucDrop = 'Inclure des énoncés "DROP TABLE"';
 $strStrucExcelCSV = 'CSV pour MS Excel';
 $strStrucNativeExcel = 'Données MS Excel (format natif)';
+$strStrucNativeExcelOptions = 'Options pour Excel natif';
 $strStrucOnly = 'Structure seule';
 $strStructPropose = 'Suggérer des optimisations quant à la structure de la table';
+$strStructureForView = 'Structure de la vue';
 $strStructure = 'Structure';
 $strSubmit = 'Exécuter';
 $strSuccess = 'Votre requête SQL a été exécutée avec succès';
@@ -865,13 +912,14 @@ $strTableEmpty = 'Le nom de la table est vide';
 $strTableHasBeenDropped = 'La table %s a été effacée';
 $strTableHasBeenEmptied = 'La table %s a été vidée';
 $strTableHasBeenFlushed = 'La table %s a été rechargée';
+$strTableIsEmpty = 'La table semble vide!';
 $strTableMaintenance = '<b>Maintenance</b> de la table';
+$strTableName = 'Nom de la table';
 $strTableOfContents = 'Table des matières';
 $strTableOptions = '<b>Options</b> pour cette table';
 $strTables = '%s table(s)';
 $strTableStructure = 'Structure de la table';
 $strTable = 'Table';
-$strTableType = '<b>Type</b> de la table';
 $strTakeIt = 'utiliser celui-ci';
 $strTblPrivileges = 'Privilèges spécifiques à une table';
 $strTempData = 'Données temporaires';
@@ -884,14 +932,16 @@ $strThemeNoValidImgPath = 'Chemin des images inexistant pour le thème %s!';
 $strThemePathNotFound = 'Chemin non trouvé pour le thème %s!';
 $strTheme = 'Thème / Style';
 $strThisHost = 'Ce serveur';
-$strThisNotDirectory = 'Ceci n\'est pas un répertoire';
 $strThreads = 'Fils d\'exécution';
 $strThreadSuccessfullyKilled = 'Le processus %s a été éliminé.';
 $strTime = 'Durée';
 $strTimeoutInfo = 'L\'importation précédente a échoué en raison du temps; retransmettez et le traitement reprendra à la position %d.';
 $strTimeoutNothingParsed = 'Cependant lors du dernier traitement, aucune section n\a été analysée; ceci signifie que phpMyAdmin ne pourra terminer cette importation, à moins que la limite de temps de PHP ne soit augmentée';
 $strTimeoutPassed = 'La limite de temps a été atteinte; si vous voulez terminer l\'importation, soumettez à nouveau le même fichier et l\'importation continuera.';
+$strToFromPage = 'de/vers la page';
 $strToggleScratchboard = 'Éditeur visuel';
+$strToggleSmallBig = 'Bascule agrandir/réduire';
+$strToSelectRelation = 'Pour sélectionner un lien, cliquez :';
 $strTotal = 'total';
 $strTotalUC = 'Total';
 $strTraditionalChinese = 'chinois traditionnel';
@@ -899,11 +949,11 @@ $strTraditionalSpanish = 'espagnol traditionnel';
 $strTraffic = 'Trafic';
 $strTransactionCoordinator = 'Coordonnateur des transactions';
 $strTransformation_application_octetstream__download = 'Affiche un lien pour télécharger le contenu binaire d\'une colonne. La première option est le nom du fichier binaire. La seconde option est le nom de la colonne contenant le nom du fichier. Si vous utilisez la seconde option, veuillez laisser la première option vide.';
-$strTransformation_application_octetstream__hex = 'Affiche une représentation hexadécimale des données.';
+$strTransformation_application_octetstream__hex = 'Affiche une représentation hexadécimale des données. Le premier paramètre est optionnel et spécifie combien d\'espaces seront ajoutés.';
 $strTransformation_image_jpeg__inline = 'Affiche une image timbre-poste cliquable; les options sont: largeur,hauteur en pixels (conserve le rapport original)';
 $strTransformation_image_jpeg__link = 'Affiche un lien vers cette image';
 $strTransformation_image_png__inline = 'Voir image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Change le format des champs de type TIME, TIMESTAMP ou DATETIME selon votre format local de date/heure. La première option est le décalage horaire qui sera ajouté (par défaut 0). La seconde option est un format en accord avec les paramètres de la fonction PHP strftime().';
+$strTransformation_text_plain__dateformat = 'Affiche un champ TIME, TIMESTAMP, DATETIME ou un champ numérique contenant une valeur TIMESTAMP UNIX en tant que date formatée. La première option est le décalage (en heures) à ajouter (par défaut, 0). La seconde option sert à indiquer le format de date ou d\'heure. La troisième option détermine si vous voulez la date locale ("local") ou UTC ("utc"). Pour le format "local", le second paramètre utilise le format de la fonction PHP strftime() et pour le format "utc", il utilise la fonction gmdate().';
 $strTransformation_text_plain__external = '(Linux seulement) Exécute un programme externe et lui envoit le contenu du champ via l\'entrée standard. Puis capture la sortie standard de ce programme externe. Le programme par défaut est tidy, pour un affichage embelli du code HTML.  Pour des raisons de sécurité, vous devez éditer le script libraries/transformations/text_plain__external.inc.php et y insérer les noms de programme externe possibles. La première option est le numéro du programme que vous voulez utiliser, la seconde option contient les paramètres pour ce programme. En troisième option, une valeur de 1 va convertir le résultat avec la fonction htmlspecialchars() (par défaut, 1). En option 4, une valeur de 1 va ajouter NOWRAP à la cellule affichée (par défaut, 1).';
 $strTransformation_text_plain__formatted = 'Préserve le contenu original du champ, sans ajout de caractères d\'échappement.';
 $strTransformation_text_plain__imagelink = 'Affiche une image et un lien, le champ contient le nom du fichier; en première option, un préfixe comme "http://domaine.com/", en seconde option, la largeur en pixels, en troisième option la hauteur en pixels.';
@@ -927,6 +977,7 @@ $strUpdateQuery = 'Mise-à-jour de la requête';
 $strUpdComTab = 'La documentation indique comment mettre à jour votre table Column_comments';
 $strUpgrade = 'Vous devriez utiliser %s en version %s ou plus récente.';
 $strUploadLimit = 'Vous avez probablement tenté de télécharger un fichier trop volumineux. Veuillez vous référer à la %sdocumentation%s pour des façons de contourner cette limite.';
+$strUploadsNotAllowed = 'Les téléchargements vers ce serveur ne sont pas permis.';
 $strUsage = 'Espace';
 $strUseBackquotes = 'Protéger les noms des tables et des champs par des&nbsp;"`"';
 $strUsedPhpExtensions = 'Extensions PHP utilisées';
@@ -964,10 +1015,9 @@ $strWildcard = 'passepartout';
 $strWindowNotFound = 'La fenêtre principale n\'a pu être mise à jour. Il est possible que vous l\'ayiez fermée, ou encore que votre navigateur bloque les mises à jour inter-fenêtres pour des raisons de sécurité.';
 $strWithChecked = 'Pour la sélection :';
 $strWriteRequests = 'Requêtes d\'écriture';
-$strWritingCommentNotPossible = 'Ajout de commentaire impossible';
-$strWritingRelationNotPossible = 'Ajout de relation impossible';
 $strWrongUser = 'Erreur d\'utilisateur/mot de passe. Accès refusé';
 
+$strXMLOptions = 'Options XML';
 $strXML = 'XML';
 
 $strYes = 'Oui';
