@@ -1,5 +1,5 @@
 <?php
-/* $Id: greek-utf-8.inc.php,v 2.141 2006/08/09 12:55:37 lem9 Exp $ */
+/* $Id: greek-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /* Translated by Kyriakos Xagoraris <theremon at users.sourceforge.net> */
 
@@ -22,15 +22,12 @@ $datefmt = '%d %B %Y, στις %I:%M %p';
 $timespanfmt = '%s μέρες, %s ώρες, %s λεπτά and %s δευτερόλεπτα'; 
 
 $strAbortedClients = 'Ακυρωμένες συνδέσεις'; 
-$strAbsolutePathToDocSqlDir = 'Παρακαλώ εισάγετε την απόλυτη διαδρομή στον διακομιστή για τον υποκατάλογο του docSQL';  
 $strAccessDeniedExplanation = 'Το phpMyAdmin προσπάθησε να συνδεθεί με τον διακομιστή MySQL αλλά ο διακομιστής απέριψε τη σύνδεση. Θα πρέπει να ελέγξετε την διεύθυνση, το όνομα χρήστη και τον κωδικό πρόσβασης στο αρχείο ρυθμίσεων config.inc.php και να βεβαιωθείτε ότι αντιστοιχούν σε αυτά που σας έχει δώσει ο διαχειρηστής του διακομιστή MySQL.'; 
 $strAccessDenied = '\'Αρνηση Πρόσβασης';
 $strAction = 'Ενέργεια';
 $strAddAutoIncrement = 'Προσθήκη τιμής AUTO_INCREMENT';  
 $strAddDeleteColumn = 'Προσθήκη/Αφαίρεση Στήλης Πεδίου';
 $strAddDeleteRow = 'Προσθήκη/Αφαίρεση Γραμμής Κριτηρίων';
-$strAddedColumnComment = 'Το σχόλιο της στήλης προστέθηκε';  
-$strAddedColumnRelation = 'Η συσχέτιση της στήλης προστέθηκε';  
 $strAddIntoComments = 'Προσθήκη στα σχόλια';
 $strAddNewField = 'Προσθήκη νέου Πεδίου';
 $strAddPrivilegesOnDb = 'Προσθήκη προνομίων στην ακόλουθη βάση δεδομένων'; 
@@ -146,15 +143,6 @@ $strDataDict = 'Λεξικό δεδομένων';
 $strDataOnly = 'Μόνο τα δεδομένα';
 $strData = 'Δεδομένα';
 $strDBComment = 'Σχόλιο βάσης: ';
-$strDBGContext = 'Context';  
-$strDBGContextID = 'Context ID';  
-$strDBGHits = 'Hits';  
-$strDBGLine = 'Γραμμή';  
-$strDBGMaxTimeMs = 'Μεγ. χρόνος, ms';  
-$strDBGMinTimeMs = 'Ελαχ. χρόνος, ms';  
-$strDBGModule = 'Module';  
-$strDBGTimePerHitMs = 'Χρόνος/Hit, ms';  
-$strDBGTotalTimeMs = 'Συνολ. χρόνου, ms';  
 $strDbPrivileges = 'Προνόμια βάσης δεδομένων'; 
 $strDbSpecific = 'Χρήστης Βάσης';  
 $strDefaultValueHelp = 'Για προκαθορισμένες τιμές, παρακαλώ εισάγετε μία τιμή, χωρίς χαρακτήρες διαφυγής ή εισαγωγικά, χρησιμοποιώντας τη μορφή: a';  
@@ -249,8 +237,6 @@ $strHungarian = 'Ουγγρικά';
 $strId = 'ID'; 
 $strIdxFulltext = 'Πλήρες κείμενο';
 $strIgnore = 'Παράληψη';
-$strIgnoringFile = 'Παράκαμψη του αρχείου %s';  
-$strImportDocSQL = 'Εισαγωγή αρχείων docSQL';  
 $strImportFiles = 'Εισαγωγή αρχείων';  
 $strIndexes = 'Ευρετήρια';
 $strIndexHasBeenDropped = 'Το ευρετήριο %s διεγράφη';
@@ -298,7 +284,7 @@ $strMIME_description = 'Περιγραφή';
 $strMIME_MIMEtype = 'Τύπος MIME';
 $strMIME_nodescription = 'Δεν υπάρχει διαθέσιμη περιγραφή για αυτή τη μετατροπή.<br />Παρακαλώ απευθηνθείτε στον δημιουργό της για να μάθετε, τι κάνει η μετατροπή %s.';
 $strMIME_transformation_note = 'Για μία λίστα με τις διαθέσιμες μετατροπές και τις μετατροπές τύπου MIME, πατήστε %sπεριγραφές μετατροπών%s';
-$strMIME_transformation_options_note = 'Παρακαλώ εισάγετε τις τιμές για τη μετατροπή χρησιμοποιώντας τη μορφή: \'a\',\'b\',\'c\'...<br />Εάν χρειαστείτε να χρησιμοποιήσετε καθέτους ("\") ή μονά εισαγωγικά ("\'") στις τιμές, χρησιμοποιείτε καθέτους (παράδειγμα \'\\\\xyz\' ή \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Παρακαλώ εισάγετε τις τιμές για τη μετατροπή χρησιμοποιώντας τη μορφή: \'a\', 100, b,\'c\'...<br />Εάν χρειαστείτε να χρησιμοποιήσετε καθέτους ("\") ή μονά εισαγωγικά ("\'") στις τιμές, χρησιμοποιείτε καθέτους (παράδειγμα \'\\\\xyz\' ή \'a\\\'b\').';
 $strMIME_transformation_options = 'Επιλογές μετατροπής';
 $strMIME_transformation = 'Μετατροπή περιηγητή';
 $strMIME_without = 'Οι τύποι MIME που εμφανίζονται με πλάγια γράμματα δεν έχουν ξεχωριστή λειτουργία μετατροπής';
@@ -551,7 +537,6 @@ $strTblPrivileges = 'Προνόμια πινάκων';
 $strTextAreaLength = ' Εξαιτίας του μεγέθος του,<br /> αυτό το πεδίο ίσως να μη μπορεί να διορθωθεί ';
 $strThai = 'Ταϋλανδικά';  
 $strThisHost = 'Αυτός ο διακομιστής'; 
-$strThisNotDirectory = 'Δεν ήταν φάκελος';  
 $strThreadSuccessfullyKilled = 'Η λειτουργία %s διεκόπη.'; 
 $strTime = 'Χρόνος'; 
 $strToggleScratchboard = '(Απ)ενεργοποίηση πίνακα σχεδιασμού';  
@@ -562,7 +547,6 @@ $strTraffic = 'Κίνηση';
 $strTransformation_image_jpeg__inline = 'Εμφανίζει μια εικόνα προεπισκόπησης με σύνδεσμο; επιλογές: πλάτος, ύψος σε pixels (διατηρεί τις αρχικές αναλογίες)';
 $strTransformation_image_jpeg__link = 'Εμφανίζει έναν σύνδεσμο για αυτήν την εικόνα.';
 $strTransformation_image_png__inline = 'Δείτε image/jpeg: inline';  
-$strTransformation_text_plain__dateformat = 'Παίρνει ένα πεδίο TIME, TIMESTAMP ή DATETIME και το μορφοποιεί χρησιμοποιώντας την τοπική μορφή. Η πρώτη επιλογή είναι η διαφορά (σε ώρες) που θα προστεθεί στην ώρα (Εξ\' ορισμού: 0). Η δεύτερη επιλογή είναι μορφή ημερομηνίας όπως ορίζεται από τις διαθέσιμες παραμέτρους της εντολής strftime() της PHP.';
 $strTransformation_text_plain__external = 'ΜΟΝΟ ΓΙΑ LINUX: Εκτελεί μία εξωτερική εφαρμογή και στέλνει τα δεδομένα μέσω \'standard input\'. Επιστρέφει το αποτέλεσμα της εφαρμογής. Εξ\' ορισμού τιμή είναι το Tidy, που τυπώνει μορφοποιημένο κώδικα HTML. Για λόγους ασφαλείες, πρέπει χειροκίνητα να αλλάξετε το αρχείο libraries/transformations/text_plain__external.inc.php και να εισάγετε τις εφαρμογές που εσείς επιτρέπετε να εκτελούνται. Η πρώτη επιλογή είναι ο αριθμός της εφαρμογής που θέλετε να χρησιμοποιήσετε και η δεύτερη επιλογή είναι οι παράμετροι της. Η τρίτη επιλογή, αν τεθεί σε 1 θα μετατρέψει το αποτέλεσμα χρησιμοποιώντας την εντολή htmlspecialchars() (Εξ\' ορισμού τιμή: 1). Η τέταρτη επιλογή, αν τεθεί σε 1 θα εισάγει NOWRAP στο κελί περιεχομένου ούτως ώστε όλο το αποτέλεσμα να εμφανιστεί χωρίς αλλαγές στην διάταξη (Εξ\' ορισμού τιμή: 1)';
 $strTransformation_text_plain__formatted = 'Διατηρεί την αρχική μορφοποίηση του πεδίου. Δεν χρησιμοποιούνται χαρακτήρες διαφυγής.';
 $strTransformation_text_plain__imagelink = 'Εμφανίζει μία εικόνα και ένα σύνδεσμο, το πεδίο περιέχει το όνομα αρχείου. Η πρώτη επιλογή είναι ένα πρόθεμα όπως "http://domain.com/", η δεύτερη επιλογή είναι το πλάτος σε pixels, η τρίτη είναι το ύψος.';  
@@ -612,8 +596,6 @@ $strWestEuropean = 'Δυτικής Ευρώπης';
 $strWildcard = 'μπαλαντέρ';  
 $strWindowNotFound = 'Δεν ήταν δυνατό να ανανεωθεί το target παράθυρο του περιηγητή. Ίσως κλείσατε το parent παράθυρο ή ο περιηγητής σας δεν επιτρέπει τις ανανεώσεις μεταξύ παραθύρων λόγω ρυθμίσεων ασφαλείας.';  
 $strWithChecked = 'Με τους επιλεγμένους:';
-$strWritingCommentNotPossible = 'Η εγγραφή του σχολίου δεν ήταν δυνατή';  
-$strWritingRelationNotPossible = 'Η εγγραφή της σχέσης δεν ήταν δυνατή';  
 $strWrongUser = 'Λανθασμένο όνομα χρήστη/κωδικός πρόσβασης. \'Αρνηση πρόσβασης.';
 
 $strXML = 'XML';
@@ -1006,7 +988,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1021,4 +1003,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
