@@ -6,8 +6,6 @@
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr'; // ('ltr': balról jobbra, 'rtl': jobbról balra)
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ' ';
 $number_decimal_separator = '.';
 // Byte, Kilo, Mega, Giga, Tera, Peta, Exa rövidítései
@@ -22,7 +20,6 @@ $datefmt = '%Y. %B %d. %H:%M';
 $timespanfmt = '%s nap, %s óra, %s perc, %s másodperc'; 
 
 $strAbortedClients = 'Megszakítva'; 
-$strAbsolutePathToDocSqlDir = 'Írja be az abszolút elérési utat a docSQL könyvtárhoz';  
 $strAccessDeniedExplanation = 'A phpMyAdmin megpróbált csatlakozni a MySQL szerverhez, de a szerver elutasította a kapcsolatot. Ellen&#337;rizze a host, username és jelszó mez&#337;ket a config.inc.php fájlban, és bizonyosodjon meg róla, hogy ezek megfelelnek a MySQL szerver adminisztrátorától kapott információknak.';  
 $strAccessDenied = 'Hozzáférés megtagadva';
 $strAction = 'Parancs';
@@ -30,12 +27,8 @@ $strAddAutoIncrement = 'AUTO_INCREMENT érték hozzáadása';
 $strAddConstraints = 'Megszorítás hozzáadása';  
 $strAddDeleteColumn = 'Mez&#337; Oszlopokat Hozzáad/Töröl';
 $strAddDeleteRow = 'Kritérium Sort Hozzáad/Töröl';
-$strAddDropDatabase = 'DROP DATABASE hozzáadása';
-$strAddedColumnComment = 'Megjegyzés hozzáf&#369;zve az oszlophoz:';  
-$strAddedColumnRelation = 'Kapcsolat hozzáf&#369;zve az oszlophoz:';  
 $strAddFields = '%s mez&#337; hozzáadása';
 $strAddHeaderComment = 'Egyedi megjegyzés hozzáadása a fejléchez (\\n töri a sorokat)';  
-$strAddIfNotExists = 'IF NOT EXISTS hozzáadása';  
 $strAddIntoComments = 'Hozzáadás a megjegyzéshez';
 $strAddNewField = 'Új mez&#337; hozzáadása';
 $strAddPrivilegesOnDb = 'Privilégiumok hozzáadása a következ&#337; adatbázison:';
@@ -191,15 +184,6 @@ $strDataOnly = 'Csak adatok';
 $strDataPages = 'Adatokat tartalmazó lapok';
 $strDBComment = 'Adatbázis megjegyzés: ';
 $strDBCopy = 'Adatbázis másolása ide';
-$strDBGContextID = 'Tartalom ID';  
-$strDBGContext = 'Tartalom';  
-$strDBGHits = 'Találat';  
-$strDBGLine = 'Vonal';  
-$strDBGMaxTimeMs = 'Legnagyobb id&#337;, ms';  
-$strDBGMinTimeMs = 'Legkisebb id&#337;, ms';  
-$strDBGModule = 'Modul';  
-$strDBGTimePerHitMs = 'Id&#337;/Találat, ms';  
-$strDBGTotalTimeMs = 'Összes id&#337;, ms';  
 $strDbPrivileges = 'Adatbázis-specifikus privilégiumok'; 
 $strDBRename = 'Adatbázis átnevezése';  
 $strDbSpecific = 'adatbázis-specifikus';  
@@ -321,8 +305,6 @@ $strId = 'ID';
 $strIdxFulltext = 'Fulltext';
 $strIgnore = 'Elutasít';
 $strIgnoreInserts = 'Mell&#337;z&#337; beszúrások használata';  
-$strIgnoringFile = '%s fájl mell&#337;zése';  
-$strImportDocSQL = 'DocSQL fájlok importja';  
 $strImportFiles = 'Fájlok importja';  
 $strImportFormat = 'Importálandó fájl formátuma';
 $strImport = 'Import';
@@ -339,7 +321,6 @@ $strInsertAsNewRow = 'Beszúrás új sorként';
 $strInsert = 'Beszúr';
 $strInsertedRowId = 'A beszúrt rekord id-je:';  
 $strInsertedRows = 'Beszúrt sorok:';
-$strInsertNewRow = 'Új sor beszúrása';
 $strInternalNotNecessary = '* Egy bels&#337; kapcsolat nem szükséges, ha az létezik az InnoDB-ben is.';  
 $strInternalRelations = 'Bels&#337; kapcsolatok';  
 $strInUse = 'használatban';
@@ -401,7 +382,7 @@ $strMIME_nodescription = 'Ehhez az átalakításhoz nem érhet&#337; el leírás
 $strMIME_transformation = 'Böngész&#337; átalakítás';
 $strMIME_transformation_note = 'Az elérhet&#337; átalakítási beállítások listájához és a hozzájuk tartozó MIME-típusokhoz kattintson ide: %stransformation descriptions%s';
 $strMIME_transformation_options = 'Átalakítás beállítások';
-$strMIME_transformation_options_note = 'Az átalakítás beállításokhoz írja be az értékeket a kovetkez&#337; formátumban: \'a\',\'b\',\'c\'...<br />Ha visszapert ("\") vagy idéz&#337;jelet ("\'") akar beszúrni, használjon visszapert (például: \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Az átalakítás beállításokhoz írja be az értékeket a kovetkez&#337; formátumban: \'a\', 100, b,\'c\'...<br />Ha visszapert ("\") vagy idéz&#337;jelet ("\'") akar beszúrni, használjon visszapert (például: \'\\\\xyz\' or \'a\\\'b\').';
 $strMIMETypesForTable = 'Tábla MIME-típusok';  
 $strMIME_without = 'A d&#337;lttel írt MIME-típusok nem választják el az átalakítási funkciókat';
 $strModifications = 'A változásokat elmentettem';
@@ -446,7 +427,6 @@ $strNoRowsSelected = 'Nincs sor kiválasztva';
 $strNoSpace = 'Nincs elég hely elmenteni a fájlt: %s.';  
 $strNoTablesFound = 'Nincs tábla az adatbázisban.';
 $strNoThemeSupport = 'Nincs téma támogatás, ellen&#337;rizd a beállításokat és/vagy a témákat a %s könyvtárban.';
-$strNothingToImport = 'Nem adtál meg importálandó adatot!';
 $strNotNumber = 'Ez nem egy szám!';
 $strNotOK = 'Nincs rendben';
 $strNotSet = '<b>%s</b> táblát nem találtam vagy nincs benne: %s';
@@ -537,6 +517,7 @@ $strPrivDescUpdate = 'Engedélyezi az adatok megváltoztatását.';
 $strPrivDescUsage = 'Nincsenek privilégiumok.'; 
 $strPrivileges = 'Privilégiumok';
 $strPrivilegesReloaded = 'A privilégiumok újratöltése sikeres volt.'; 
+$strProcesses = 'Folyamatok'; 
 $strProcesslist = 'Folyamatlista'; 
 $strPutColNames = 'Tegye a mez&#337;neveket az els&#337; sorhoz';  
 
@@ -563,7 +544,6 @@ $strRelationsForTable = 'Tábla-kapcsolatok';
 $strRelations = 'Kapcsolatok';  
 $strRelationView = 'Reláció nézet';
 $strReloadingThePrivileges = 'Privilégiumok újratöltése'; 
-$strReloadMySQL = 'MySQL újratöltése';
 $strRemoveSelectedUsers = 'A kiválasztott felhasználók törlése'; 
 $strRenameDatabaseOK = '%s adatbázis átneveztem erre: %s';  
 $strRenameTableOK = '%s táblát átneveztem erre: %s';
@@ -620,7 +600,6 @@ $strServerNotResponding = 'A szerver nem válaszol';
 $strServerStatus = 'Futási információk'; 
 $strServerStatusUptime = 'Ez a MySQL szerver fut: %s. Elindítva: %s.'; 
 $strServer = 'Szerver';  
-$strServerTabProcesslist = 'Folyamatok'; 
 $strServerTabVariables = 'Változók'; 
 $strServerTrafficNotes = '<b>Szerver forgalom</b>: Ezek a táblák mutatják a MySQL szerver hálózati forgalom-statisztikáit az indulástól kezdve.';
 $strServerVars = 'Szerver változók és beállítások'; 
@@ -688,7 +667,6 @@ $strSort = 'Sorrendezés';
 $strSpaceUsage = 'Helyfoglalás';
 $strSpanish = 'Spanyol';  
 $strSplitWordsWithSpace = 'A szavak fel vannak osztva szóköz karakter szerint (" ").';
-$strSQLExportCompatibility = 'SQL export kompatibilitás';
 $strSQLExportType = 'Export típus';  
 $strSQLOptions = 'SQL beállítások';
 $strSQLParserBugMessage = 'Esély van rá, hogy egy hibát találhattál az SQL szintaktikai elemz&#337;ben (parser). Vizsgáld meg gondosan a lekérdezésedet, ellen&#337;rizd, hogy az idéz&#337;jelek jók és jól illeszkednek. Más lehetséges hiba oka lehet, hogy binárisan töltöttél fel egy fájlt az idézett szövegmez&#337;n kívül. Kipróbálhatod a lekérésedet a MySQL parancssoros felületén.  A MySQL szerver hibakimenete alul látható, ha van ott valami, az segíthet felderíteni a hiba okát. Ha még mindig gondjaid vannak, vagy a szintaktiaki elemz&#337; (parser) hibát jelez, ahol a parancssoros felületen végrehajtódik, redukáld a problémát okozó SQL lekérdezést egy egyszer&#369; lekérdezéssé, és küldd el egy hibajelzésben (bug report) az alsó Kivágás részben lev&#337; adatokkal együtt:';
@@ -706,7 +684,6 @@ $strStatUpdateTime = 'Utolsó módosítás';
 $strStatus = 'Állapot'; 
 $strStrucCSV = 'CSV adat';
 $strStrucData = 'Szerkezet és adatok';
-$strStrucDrop = '\'Tábla eldobás\' hozzáadása';
 $strStrucExcelCSV = 'MS Excel CSV adat';
 $strStrucNativeExcel = 'Natív MS Excel adat';  
 $strStrucOnly = 'Csak szerkezet';
@@ -731,7 +708,6 @@ $strTableOptions = 'Tábla opciók';
 $strTables = '%s tábla';
 $strTableStructure = 'Tábla szerkezet:';
 $strTable = 'Tábla';
-$strTableType = 'Tábla típusa';
 $strTakeIt = 'csináld';  
 $strTblPrivileges = 'Tábla-specifikus privilégiumok'; 
 $strTempData = 'Ideiglenes adatok';
@@ -739,7 +715,6 @@ $strTextAreaLength = ' Mivel ez a hossz,<br /> ez a mez&#337; nem szerkeszthet&#
 $strThai = 'Thai';  
 $strTheme = 'Téma / Stílus';  
 $strThisHost = 'Ez a gép'; 
-$strThisNotDirectory = 'Ez nem alkönyvtár volt';  
 $strThreads = 'Szálak';
 $strThreadSuccessfullyKilled = 'A %s. szálat sikerült megszüntetni.'; 
 $strTime = 'Id&#337;'; 
@@ -753,7 +728,6 @@ $strTransformation_application_octetstream__download = 'Egy linket jelenít meg
 $strTransformation_image_jpeg__inline = 'Kattintható ikon mutatása; beállítások: szélesség,magasság pixelben (megtartja az eredeti képarányt)';  
 $strTransformation_image_jpeg__link = 'Egy linket mutat a képhez (közvetlen ablakos letöltés).';
 $strTransformation_image_png__inline = 'image/jpeg megtekintése: bent';  
-$strTransformation_text_plain__dateformat = 'A TIME, TIMESTAMP vagy DATETIME mez&#337;k és formátumok az ön helyi dátumformátumát használják. Els&#337; opció az eltérés (órában), ami hozzáadódik az id&#337;höz (alapértelmezett: 0). A második egy különböz&#337; id&#337;formátum a PHP strftime() paramétere szerint.';
 $strTransformation_text_plain__external = 'Csak LINUX: Elindít egy küls&#337; programot, ami megkapja az adatokat a standard inputon. Visszatér a program standard outputján. Alapértelmezett a Tidy, csinos HTML kódot kap. Biztonsági megfontolásokból kézzel kell szerkeszteni a libraries/transformations/text_plain__external.inc.php fájlt, és beírni a program nevét, amit futtatni akar. Az els&#337; opció a program száma, amit futtatni akar, a második a program paramáterei. A harmadik opció ha egyenl&#337; eggyel, akkor a kimenet konvertálva lesz a htmlspecialchars() eljárással (alapértelmezett 1). A negyedik opció ha egyre van beállítva, egy NOWRAP formázást ad minden mez&#337;höz, így a kimenet újratördelés nélkül látszik (alapértelmezett 1)';
 $strTransformation_text_plain__formatted = 'A mez&#337; eredeti formázásának meg&#337;rzése. Nincs kivétel.';
 $strTransformation_text_plain__imagelink = 'Egy képet es egy linket jelenít meg, a mez&#337; tartalmazza a fájlnevet; az els&#337; opcíó egy el&#337;tag, mint pl.: "http://domain.com/", a második a szélesség pixelben, a harmadik pedig a magasság.';  
@@ -809,8 +783,6 @@ $strWildcard = 'helyettesít&#337; jel';
 $strWindowNotFound = 'A cél böngész&#337;ablakot nem tudtam újratölteni. Talán a szül&#337;ablak be lett zárva, vagy a böngész&#337; biztonsági beállítása tiltja az ablakok közti újratöltést';  
 $strWithChecked = 'A kijelöltekkel végzend&#337; m&#369;velet:';
 $strWriteRequests = 'Írási kérelmek';
-$strWritingCommentNotPossible = 'Megjegyzés írása nem lehetséges';  
-$strWritingRelationNotPossible = 'Kapcsolat írása nem lehetséges';  
 $strWrongUser = 'Hibás felhasználói név/jelszó. Hozzáférés megtagadva.';
 
 $strXML = 'XML';
@@ -821,15 +793,18 @@ $strZeroRemovesTheLimit = 'Megjegyzés: A 0 (nulla) beállítása törli a limit
 $strZip = '"zippel tömörítve"';
 
 // To translate:
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
 $strAndThen = 'and then';  //to translate
 
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
 $strBufferReadMissesInPercent = 'Read misses in %';  //to translate
 $strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
 $strBusyPages = 'Busy pages';  //to translate
 
 $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
 
 $strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
 
@@ -837,9 +812,15 @@ $strEngines = 'Engines';  //to translate
 $strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
 $strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
 
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+
 $strHandler = 'Handler';  //to translate
 
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
 $strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
 $strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
@@ -852,12 +833,20 @@ $strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoD
 $strInnoDBPages = 'lapok';  //to translate
 $strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
 $strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
 $strInvalidRowNumber = '%d is not valid row number.';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
 
 $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
+$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+
 $strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
 $strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
 $strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
@@ -868,11 +857,19 @@ $strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table ind
 $strMyISAMRepairThreads = 'Repair threads';  //to translate
 $strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
 $strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
 
 $strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
 
-$strPasswordHashing = 'Password Hashing';  //to translate
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 
+$strPasswordHashing = 'Password Hashing';  //to translate
+$strPDFOptions = 'PDF options';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+
+$strReloadPrivileges = 'Reload privileges';  //to translate
 $strReplication = 'Replication';  //to translate
 
 $strSelectBinaryLog = 'Select binary log to view';  //to translate
@@ -951,48 +948,102 @@ $strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache.
 $strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
 $strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
 $strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
+$strSQLCompatibility = 'SQL compatibility mode';  //to translate
+$strSQLImportOptions = 'SQL options';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
 
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
 $strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
 $strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
 $strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
 $strTransactionCoordinator = 'Transaction coordinator';  //to translate
-$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
+$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
 
 $strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
 $strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
-
-
-$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
-$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
-$strFileNameTemplateDescriptionTable = 'table name';  //to translate
-$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
-$strFileNameTemplateDescriptionServer = 'server name';  //to translate
-$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
-$strProtocolVersion = 'Protocol version';  //to translate
-$strMysqlClientVersion = 'MySQL client version';  //to translate
 $strUsedPhpExtensions = 'Used PHP extensions';  //to translate
-$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
-$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
-$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
-$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
-$strPDF = 'PDF';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
-$strPDFReportTitle = 'Report title';  //to translate
-$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
-$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
-$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
-$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strThemeNotFound = 'Theme %s not found!';  //to translate
-$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
-$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
-$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
-$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
-$strBrowseDistinctValues = 'Browse distinct values';  //to translate
-$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+
 $strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
+
+$strQueryResultsOperations = 'Query results operations';  //to translate
+$strAddClause = 'Add %s';  //to translate
+$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
+$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
+$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
+$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
+$strXMLOptions = 'XML options';  //to translate
+$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
+$strCreateUserDatabase = 'Database for user';  //to translate
+$strCreateUserDatabaseNone = 'None';  //to translate
+$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
+$strOpenDocumentText = 'Open Document Text';  //to translate
+$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
+$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
+$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
+$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
+$strInvalidTableName = 'Invalid table name';  //to translate
+$strInvalidDatabase = 'Invalid database';  //to translate
+$strServers = 'Servers';  //to translate
+$strDelimiter = 'Delimiter';  //to translate
+$strFunctions = 'Functions';  //to translate
+$strProcedures = 'Procedures';  //to translate
+$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
+$strFontSize = 'Font size';  //to translate
+$strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
