@@ -1,5 +1,5 @@
 <?php
-/* $Id: indonesian-iso-8859-1.inc.php,v 2.150 2006/08/09 12:55:37 lem9 Exp $ */
+/* $Id: indonesian-iso-8859-1.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
@@ -16,7 +16,6 @@ $datefmt = '%d. %B %Y jam %H:%M';
 $timespanfmt = '%s hari, %s jam, %s menit dan %s detik';
 
 $strAbortedClients = 'Pembatalan';
-$strAbsolutePathToDocSqlDir = 'Silakan menentukan Absolute Path pada webserver yang menunjuk ke direktori docSQL';
 $strAccessDenied = 'Akses ditolak';
 $strAccessDeniedExplanation = 'phpMyAdmin telah berusaha untuk membuka koneksi ke server MySQL tetapi koneksi ditolak oleh server. Silakan periksa kembali nama host, nama pengguna dan kata sandi pada file config.inc.php untuk memastikan kecocokannya dengan informasi yang telah diberikan oleh administrator server MySQL.';
 $strAction = 'Aksi';
@@ -24,8 +23,6 @@ $strAddAutoIncrement = 'Menambahkan nilai AUTO_INCREMENT';
 $strAddConstraints = 'Menambahkan pembatas';
 $strAddDeleteColumn = 'Menambahkan/Hapus kolom';
 $strAddDeleteRow = 'Menambahkan/Hapus baris';
-$strAddedColumnComment = 'Komentar untuk kolum telah ditambahkan';
-$strAddedColumnRelation = 'Relasi untuk kolum telah ditambahkan';
 $strAddFields = 'Menambahkan %s field(s)';
 $strAddHeaderComment = 'Menambahkan komentar individual pada Header (\\n membelahkan garis)';
 $strAddIntoComments = 'Penambahkan pada komentar:';
@@ -183,15 +180,6 @@ $strDataOnly = 'Data saja';
 $strDataPages = 'Halaman yang berisi data';
 $strDBComment = 'Komentar Database: ';
 $strDBCopy = 'Salin database ke';
-$strDBGContextID = 'Susunan ID';
-$strDBGContext = 'Susunan';
-$strDBGHits = 'Hits';
-$strDBGLine = 'Baris';
-$strDBGMaxTimeMs = 'Maks waktu, ms';
-$strDBGMinTimeMs = 'Min waktu, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Waktu/Hit, ms';
-$strDBGTotalTimeMs = 'Jumlah Waktu, ms';
 $strDbPrivileges = 'Hak (privileges) khusus terhadap Database';
 $strDBRename = 'Ubah nama database menjadi';
 $strDbSpecific = 'database-spesifik';
@@ -311,8 +299,6 @@ $strId = 'ID';
 $strIdxFulltext = 'Teks penuh';
 $strIgnore = 'Abaikan';
 $strIgnoreInserts = 'Gunakan perintah INSERT dengan mengabaikan kesalahan';
-$strIgnoringFile = 'Abaikan file %s';
-$strImportDocSQL = 'Impor file docSQL';
 $strImportFiles = 'Impor file';
 $strIndexes = 'Indeks';
 $strIndexHasBeenDropped = 'Indeks %s telah dihapus';
@@ -392,7 +378,7 @@ $strMIME_description = 'Deskripsi';
 $strMIME_MIMEtype = 'Tipe MIME';
 $strMIME_nodescription = 'Tidak ada deskripsi untuk transformasi ini.<br />Mohon ditanyakan kepada penulis tentang artinya %s.';
 $strMIME_transformation_note = 'Untuk tampilan daftar tentang pilihan transformasi dan transformasi jenis MIME-nya, silakan klik pada %sDeskripsi Transformasi%s';
-$strMIME_transformation_options_note = 'Mohon masukkan nilai untuk pilihan transformasi dengan menggunakan format sbb.: \'a\',\'b\',\'c\'...<br />Bila sebuah Backslash ("\") atau Single Quote ("\'") diperlukan di antara nilai tersebut, mohon gunakan tanda Backslash (contoh: \'\\\\xyz\' atau \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Mohon masukkan nilai untuk pilihan transformasi dengan menggunakan format sbb.: \'a\', 100, b,\'c\'...<br />Bila sebuah Backslash ("\") atau Single Quote ("\'") diperlukan di antara nilai tersebut, mohon gunakan tanda Backslash (contoh: \'\\\\xyz\' atau \'a\\\'b\').';
 $strMIME_transformation_options = 'Pilihan transformasi';
 $strMIME_transformation = 'Transformasi Browser';
 $strMIMETypesForTable = 'TIPE MIME UNTUK TABEL';
@@ -694,7 +680,6 @@ $strTextAreaLength = ' Disebabkan ukuran panjangnya,<br /> field ini tidak dapat
 $strThai = 'Bahasa Thailand';
 $strTheme = 'Desain Penampilan';
 $strThisHost = 'Host yang ini';
-$strThisNotDirectory = 'Ini bukan direktori';
 $strThreadSuccessfullyKilled = 'Sukses hentikan Thread %s.';
 $strTime = 'Jangka Waktu';
 $strToggleScratchboard = 'pindah buku catatan (Scratchboard)';
@@ -708,7 +693,6 @@ $strTransformation_application_octetstream__hex = 'Menampilkan representasi data
 $strTransformation_image_jpeg__inline = 'Tampilkan Thumbnail yang bisa diklik; pilihan: lebar, tinggi dalam piksel (rasio asli dipertahankan)';
 $strTransformation_image_jpeg__link = 'Tampilkan link ke gambar ini (direct blob download, i.e.).';
 $strTransformation_image_png__inline = 'Lihat image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Menggunakan format waktu setempat untuk field TIME, TIMESTAMP atau DATETIME. Pilihan pertama adalah Offset (dalam jam) yang akan ditambahkan pada Timestamp (Default: 0). Pilihan kedua adalah Dateformat yang berbeda sesuai dengan parameter yang tersedia pada strftime() dari PHP.';
 $strTransformation_text_plain__external = 'HANYA UNTUK LINUX: Luncurkan aplikasi eksternal dan mengisi data Field dengan cara standar. Menghasilkan output standar dari aplikasi yang bersangkutan. Default-nya adalah Tidy untuk mempercantik kode HTML cetakan. Dengan alasan pengamanan sistem, Anda perlu meng-edit file libraries/transformations/text_plain__external.inc.php dan menambahkan Tools yang akan diizinkan secara manual. Pilihan pertama adalah jumlah dari program yang ingin digunakan dan pilihan kedua adalah parameter untuk program-program tersebut. Parameter ketiga, bila diset ke 1 akan mengubah output dengan menggunakan htmlspecialchars() (Default adalah 1). Parameter keempat, bila diset ke 1 akan menambahkan sebuah NOWRAP pada Content Cell dengan hasil output yang akan ditampilkan tanpa keperluan untuk me-format ulang (Default 1)';
 $strTransformation_text_plain__formatted = 'Menyimpan format asli dari field. Escaping tidak dilakukan.';
 $strTransformation_text_plain__imagelink = 'Tampilkan sebuah gambar dan sebuah Link, nama file berada dalam field; pilihan utama adalah awalan seperti "http://domain.com/", pilihan kedua adalah lebar dalam piksel, pilihan ketiga adalah tingginya.';
@@ -764,8 +748,6 @@ $strWildcard = 'wildcard';
 $strWindowNotFound = 'Mengupdate jendela browser gagal. Ada kemungkinan Anda telah menutup jendela induknya atau pilihan keamanan pada browser Anda melarang untuk mengupdate dengan cara Cross-Window';
 $strWithChecked = 'yang ditandai:';
 $strWriteRequests = 'Permintaan penulisan';
-$strWritingCommentNotPossible = 'Penulisan komentar tidak dapat dilaksanakan';
-$strWritingRelationNotPossible = 'Penulisan relasi tidak dapat dilaksanakan';
 $strWrongUser = 'Nama Pengguna/Kata Sandi salah. Akses ditolak.';
 
 $strXML = 'XML';
@@ -998,7 +980,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1013,4 +995,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
