@@ -1,5 +1,5 @@
 <?php
-/* $Id: latvian-windows-1257.inc.php,v 2.147 2006/08/09 12:55:38 lem9 Exp $ */
+/* $Id: latvian-windows-1257.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Latvian language file by Sandis Jrics <sandisj at parks.lv>
@@ -21,7 +21,6 @@ $datefmt = '%d.%m.%Y %H:%M';
 $timespanfmt = '%s dienas, %s stundas, %s mintes un %s sekundes';
 
 $strAbortedClients = 'Prtraukts';
-$strAbsolutePathToDocSqlDir = 'Ldzu ievadiet absolto ceu ldz docSQL direktorijai uz servera';
 $strAccessDeniedExplanation = 'phpMyAdmin minja pieslgties MySQL serverim, un serveris noraidja pieslgumu. Ldzu prbaudiet hostu, lietotjvrdu un paroli config.inc.php fail, un prliecinieties, ka tie atbilst informcijai, ko Jums deva MySQL servera administrators.';
 $strAccessDenied = 'Pieeja aizliegta';
 $strAction = 'Darbba';
@@ -29,8 +28,6 @@ $strAddAutoIncrement = 'Pievienot AUTO_INCREMENT vrtbu';
 $strAddConstraints = 'Pievienot ierobeojumus';
 $strAddDeleteColumn = 'Pievienot/Dzst laukus (kolonnas)';
 $strAddDeleteRow = 'Pievienot/Dzst ierakstu';
-$strAddedColumnComment = 'Pievienots komentrs kolonnai';
-$strAddedColumnRelation = 'Pievienota relcija kolonnai';
 $strAddFields = 'Pievienot %s lauku(s)';
 $strAddHeaderComment = 'Ievietot virsrakst komentru (\\n atdala rindas)';
 $strAddIntoComments = 'Pievienot komentros';
@@ -175,15 +172,6 @@ $strDataDict = 'Datu vrdnca';
 $strDataOnly = 'Tikai dati';
 $strDBComment = 'Datubzes komentrs: ';
 $strDBCopy = 'Kopt datubzi uz';
-$strDBGContextID = 'Konteksta ID';
-$strDBGContext = 'Konteksts';
-$strDBGHits = 'Apmekljumi';
-$strDBGLine = 'Lnija';
-$strDBGMaxTimeMs = 'Maks. laiks, ms';
-$strDBGMinTimeMs = 'Min. laiks, ms';
-$strDBGModule = 'Modulis';
-$strDBGTimePerHitMs = 'Viena apmekljuma laiks, ms';
-$strDBGTotalTimeMs = 'Laiks kop, ms';
 $strDbPrivileges = 'Datubu specifisks privilijas';
 $strDBRename = 'Prsaukt datubzi par';
 $strDbSpecific = 'datubzei specifisks';
@@ -290,8 +278,6 @@ $strId = 'ID';
 $strIdxFulltext = 'Pilni teksti';
 $strIgnore = 'Ignort';
 $strIgnoreInserts = 'Lietot IGNORE INSERTS';
-$strIgnoringFile = 'Ignorjam failu %s';
-$strImportDocSQL = 'Importt docSQL failus';
 $strImportFiles = 'Importt failus';
 $strIndexes = 'Indeksi';
 $strIndexHasBeenDropped = 'Indekss %s tika izdzsts';
@@ -355,7 +341,7 @@ $strMIME_description = 'Apraksts';
 $strMIME_MIMEtype = 'MIME tips';
 $strMIME_nodescription = 'ai transformcijai nav apraksta.<br />Jautjiet autoram, ko %s dara.';
 $strMIME_transformation_note = 'Lai iegtu pieejamo transformciju opcijas un to MIME tipu transformcijas, uzklikiniet uz %stransformciju apraksti%s';
-$strMIME_transformation_options_note = 'Ldzu ievadiet transformciju opciju vrtbas, lietojot o formatu: \'a\',\'b\',\'c\'...<br />Ja Jums jlieto atpakaj slpsvtra ("\") vai vienkr pdia ("\'") starp m vrtbm, lieciet ts priek vl vienu atpakajo slpsvtru (piemram \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Ldzu ievadiet transformciju opciju vrtbas, lietojot o formatu: \'a\', 100, b,\'c\'...<br />Ja Jums jlieto atpakaj slpsvtra ("\") vai vienkr pdia ("\'") starp m vrtbm, lieciet ts priek vl vienu atpakajo slpsvtru (piemram \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_transformation_options = 'Transformcijas opcijas';
 $strMIME_transformation = 'Prlkprogrammas transformcija';
 $strMIMETypesForTable = 'MIME TIPI TABULAI';
@@ -633,7 +619,6 @@ $strTextAreaLength = ' Sava garuma d,<br /> is lauks var bt neredijams ';
 $strThai = 'Taizemieu';
 $strTheme = 'Tma / Stils';
 $strThisHost = 'is hosts';
-$strThisNotDirectory = 'T nebija direktorija';
 $strThreadSuccessfullyKilled = 'Process %s tika veiksmgi nogalints.';
 $strTime = 'Laiks';
 $strToggleScratchboard = 'pardt/noslpt piezmju tafeli';
@@ -646,7 +631,6 @@ $strTransformation_application_octetstream__download = 'Rdt saiti uz lauka binro
 $strTransformation_image_jpeg__inline = 'Parda klikinmo sktlu; opcijas: platums, augstums pikseos (saglabjot oriinls proporcijas)';
 $strTransformation_image_jpeg__link = 'Parda linku uz o attlu (tiea blob lauka lajuplde).';
 $strTransformation_image_png__inline = 'Skatties image/jpeg: k ierindotu attlu';
-$strTransformation_text_plain__dateformat = 'em TIME, TIMESTAMP vai DATETIME lauku, un format to izmantojot Jsu loklo datuma formatu. Pirm opcija ir nobde (stunds), kas tiks pievienota timestamp laukam (noklust: 0). Otr opcija ir datuma formats, saska ar PHP finkcijas strftime() parametriem.';
 $strTransformation_text_plain__external = 'Tikai LINUX: Palai rjo aplikciju un padod lauka datus ts standartievad. Atgrie aplikcijas standartizvadi. Noklusjums ir Tidy, kas izskaistina HTML kodu. Drobas apsvrumu d, nepiecieams manuli redit failu libraries/transformations/text_plain__external.inc.php un ielikt rkus, kurus Js ataujat palaist. Pirm opcija ir programmas numurs, ko Js vlaties lietot, otr opcija ir parametri ai programmai. Tre opcija, ja ir vienda ar 1, konvert izvadi, izmantojot htmlspecialchars() (noklusjums ir 1). Ceturtais parametrs, ja viends ar 1, liek NOWRAP parametru satura nai, t k izvade tiks attlota bez prformatanas. (noklusjums ir 1)';
 $strTransformation_text_plain__formatted = 'Saglab lauka oriinlo formatjumu. Specilo rakstzmju pasargana netiek veikta.';
 $strTransformation_text_plain__imagelink = 'Parda attlu un linku, lauks satur faila nosauumu; pirm opcija ir prefikss, piemram, "http://domens.lv/", otr opcija ir platums pikseos, tre ir augstums.';
@@ -698,8 +682,6 @@ $strWestEuropean = 'Rietumeiropas';
 $strWildcard = 'aizstjjzme';
 $strWindowNotFound = 'Neizdevs atjaunot galveno prlkprogramas logu. Varbt esat viu aizvrui, vai ar Jsu prlkprogramma bloe starplogu saskarsmi Jsu drobas iestdjumu d.';
 $strWithChecked = 'Ar iezmto:';
-$strWritingCommentNotPossible = 'Komentra rakstana nav iespjama';
-$strWritingRelationNotPossible = 'Relcijas rakstana nav iespjama';
 $strWrongUser = 'Kdains lietotjvrds/parole. Pieeja aizliegta.';
 
 $strXML = 'XML';
@@ -1005,7 +987,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1020,4 +1002,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
