@@ -1,5 +1,5 @@
 <?php
-/* $Id: portuguese-iso-8859-15.inc.php,v 2.76.2.1 2006/08/30 10:43:15 nijel Exp $ */
+/* $Id: portuguese-iso-8859-1.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Portuguese language file by
@@ -7,7 +7,7 @@
  *   Antnio Raposo <cfmsoft@users.sourceforge.net>
  */
 
-$charset = 'iso-8859-15';
+$charset = 'iso-8859-1';
 $text_dir = 'ltr';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
@@ -25,7 +25,6 @@ $datefmt = '%d-%B-%Y s %H:%M';
 $timespanfmt = '%s dias, %s horas, %s minutos e %s segundos';
 
 $strAbortedClients = 'Abortado';
-$strAbsolutePathToDocSqlDir = 'Introduza o caminho absoluto at  directoria docSQL no Servidor Web';
 $strAccessDenied = 'Acesso Negado';
 $strAccessDeniedExplanation = 'O phpMyAdmin tentou ligar-se ao servidor MySQL, e o servidor rejeitou a ligao. Verifique o anfitrio, nome de utilizador e palavra-passe no config.inc.php e assegure-se que correspondem  informao fornecida pelo administrador do MySQL.';
 $strAction = 'Aces';
@@ -33,8 +32,6 @@ $strAddAutoIncrement = 'Adicionar valor AUTO_INCREMENT';
 $strAddConstraints = 'Adicionar limitadores';
 $strAddDeleteColumn = 'Adicionar/Remover Campos';
 $strAddDeleteRow = 'Adicionar/Remover Critrios';
-$strAddedColumnComment = 'Comentrios para coluna adicionados';
-$strAddedColumnRelation = 'Relao para a coluna adicionada';
 $strAddIntoComments = 'Adicionar aos comentrios';
 $strAddNewField = 'Adiciona novo campo';
 $strAddPrivilegesOnDb = 'Adicionar privilgios na base de dados seguinte';
@@ -151,15 +148,6 @@ $strData = 'Dados';
 $strDataDict = 'Dicionario de dados';
 $strDataOnly = 'Apenas dados';
 $strDBComment = 'Comentrio da Base de Dados: ';
-$strDBGContext = 'Contexto';
-$strDBGContextID = 'ID de Contexto';
-$strDBGHits = 'Hits';
-$strDBGLine = 'Linha';
-$strDBGMaxTimeMs = 'Tempo mx, ms';
-$strDBGMinTimeMs = 'Tempo min, ms';
-$strDBGModule = 'Mdulo';
-$strDBGTimePerHitMs = 'Tempo/Hit, ms';
-$strDBGTotalTimeMs = 'Tempo total, ms';
 $strDbPrivileges = 'Privilgios especficos da Base de Dados';
 $strDbSpecific = 'Especifico da Base de Dados';
 $strDefault = 'Defeito';
@@ -252,8 +240,6 @@ $strHungarian = 'Hngaro';
 $strId = 'ID'; //(same in portuguese)
 $strIdxFulltext = 'Texto Completo';
 $strIgnore = 'Ignora';
-$strIgnoringFile = 'A ignorar ficheiro %s';
-$strImportDocSQL = 'Importar ficheiros docSQL';
 $strImportFiles = 'Importar';
 $strIndexes = 'ndices';
 $strIndexHasBeenDropped = 'O ndice %s foi eliminado';
@@ -311,7 +297,7 @@ $strMIME_description = 'Descrio';
 $strMIME_MIMEtype = 'MIME-type';  //(same in portuguese)
 $strMIME_nodescription = 'No h descrio disponvel para esta transformao.<br />Pergunte ao autor, o que %s faz.';
 $strMIME_transformation_note = 'Para uma lista de opes de transformao disponveis e suas transformaes MIME-type , clique em %stransformation descriptions%s';
-$strMIME_transformation_options_note = 'Introduza os valores para as opes de transformao a usando este formato: \'a\',\'b\',\'c\'...<br />Se por acaso precisar de inserir um backslash ("\") ou uma pelica ("\'") no meio desses valores, faa-o backslashes (por exemplo \'\\\\xyz\' ou \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Introduza os valores para as opes de transformao a usando este formato: \'a\', 100, b,\'c\'...<br />Se por acaso precisar de inserir um backslash ("\") ou uma pelica ("\'") no meio desses valores, faa-o backslashes (por exemplo \'\\\\xyz\' ou \'a\\\'b\').';
 $strMIME_transformation_options = 'Opes de tranformao';
 $strMIME_transformation = 'Transformao do navegador';
 $strMIME_without = 'MIME-types impressos em itlico no tem uma funo de transformao separada';
@@ -562,7 +548,6 @@ $strTblPrivileges = 'Privilgios especficos da tabela';
 $strTextAreaLength = ' Devido ao seu tamanho,<br /> este campo pode no ser editvel ';
 $strThai = 'Tailands';
 $strThisHost = 'Este Anfitrio';
-$strThisNotDirectory = 'Isto no era uma directoria';
 $strTime = 'Tempo';
 $strTotal = 'total';
 $strTotalUC = 'Total'; // (same in portuguese)
@@ -612,8 +597,6 @@ $strWebServerUploadDirectoryError = 'No  possivel alcanar a directoria que confi
 $strWelcome = 'Bemvindo ao %s';
 $strWestEuropean = 'Europeu de Oeste';
 $strWithChecked = 'Com os seleccionados:';
-$strWritingCommentNotPossible = 'No  possvel escrever comentrio';
-$strWritingRelationNotPossible = 'No  possvel escrever relao';
 $strWrongUser = 'Utilizador ou Palavra-passe errada. Acesso Negado.';
 
 $strXML = 'XML';// (Same in portuguese)
@@ -974,7 +957,6 @@ $strTraditionalSpanish = 'Traditional Spanish';  //to translate
 $strTransactionCoordinator = 'Transaction coordinator';  //to translate
 $strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
 $strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
-$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';//to translate
 $strTransformation_text_plain__external = 'LINUX ONLY: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';//to translate
 $strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';  //to translate
 $strTransformation_text_plain__link = 'Displays a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is a title for the link.';  //to translate
@@ -1009,7 +991,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1024,4 +1006,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
