@@ -1,5 +1,5 @@
 <?php
-/* $Id: russian-windows-1251.inc.php,v 2.146 2006/08/10 11:41:33 lem9 Exp $ */
+/* $Id: russian-windows-1251.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Translated by Gosha Sakovich <gt2 at users.sourceforge.net>
@@ -24,7 +24,6 @@ $datefmt = '%B %d %Y ., %H:%M';
 $timespanfmt = '%s , %s , %s   %s ';
 
 $strAbortedClients = '';
-$strAbsolutePathToDocSqlDir = '       docSQL, ';
 $strAccessDenied = '  ';
 $strAccessDeniedCreateConfig = '  -   .       %1$s %2$s.';
 $strAccessDeniedExplanation = 'phpMyAdmin     MySQL,    .   ,     config.inc.php.';
@@ -34,8 +33,6 @@ $strAddClause = ' %s';
 $strAddConstraints = ' ';
 $strAddDeleteColumn = '/  ';
 $strAddDeleteRow = '/  ';
-$strAddedColumnComment = '   ';
-$strAddedColumnRelation = '   ';
 $strAddFields = ' %s ()';
 $strAddHeaderComment = '     ( : \\n)';
 $strAddIntoComments = '  ';
@@ -161,7 +158,7 @@ $strCreatePdfFeat = ' PDF-';
 $strCreateUserDatabase = '   ';
 $strCreateUserDatabaseName = '    -     ';
 $strCreateUserDatabaseNone = ' ';
-$strCreateUserDatabaseWildcard = '     (username_%)';
+$strCreateUserDatabaseWildcard = '     (username\_%)';
 $strCreationDates = '// ';
 $strCriteria = '';
 $strCroatian = '';
@@ -190,12 +187,6 @@ $strDataOnly = ' ';
 $strDataPages = '  ';
 $strDBComment = ' : ';
 $strDBCopy = '  ';
-$strDBGContext = '';
-$strDBGContextID = ' ID';
-$strDBGMaxTimeMs = ' , ms';
-$strDBGMinTimeMs = ' , ms';
-$strDBGModule = '';
-$strDBGTotalTimeMs = ' , ms';
 $strDbPrivileges = ' ,    ';
 $strDBRename = '   ';
 $strDbSpecific = '  ';
@@ -324,9 +315,7 @@ $strIdxFulltext = '';
 $strIgnore = '';
 $strIgnoreDuplicates = '  ';
 $strIgnoreInserts = ' ';
-$strIgnoringFile = '  %s';
 $strImport = '';
-$strImportDocSQL = ' docSQL ';
 $strImportFiles = ' ';
 $strImportFormat = '  ';
 $strImportSuccessfullyFinished = '  ,  : %d.';
@@ -413,7 +402,7 @@ $strMIME_nodescription = '     .<br />,     %s.';
 $strMIME_transformation = ' ';
 $strMIME_transformation_note = '        MIME-   %s %s';
 $strMIME_transformation_options = ' ';
-$strMIME_transformation_options_note = ',    ,   : \'a\',\'b\',\'c\'...<br />    ("\")  ("\'"),   ( \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = ',    ,   : \'a\', 100, b,\'c\'...<br />    ("\")  ("\'"),   ( \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_without = 'MIME-,  ,     ';
 $strMIMETypesForTable = 'MIME- ';
 $strModifications = '  ';
@@ -775,7 +764,6 @@ $strThemeDefaultNotFound = ' - %s  !';
 $strThemeNoPreviewAvailable = '  .';
 $strThemeNotFound = ' %s  !';
 $strThisHost = ' ';
-$strThisNotDirectory = '   ';
 $strThreads = '';
 $strThreadSuccessfullyKilled = 'Thread %s  .';
 $strTime = '';
@@ -789,7 +777,6 @@ $strTransformation_application_octetstream__download = '      .  :    .  :
 $strTransformation_image_jpeg__inline = ' ,    ; : ,   (  )';
 $strTransformation_image_jpeg__link = '     (direct blob download, i.e.).';
 $strTransformation_image_png__inline = '. image/jpeg: inline';
-$strTransformation_text_plain__dateformat = '  TIME, TIMESTAMP  DATETIME          .   -   ( ),     timestamp ( : 0).   -        ,    PHP strftime().';
 $strTransformation_text_plain__external = ' LINUX:         .    .   Tidy,   HTML .   ,      libraries/transformations/text_plain__external.inc.php   ,    .   -   ,    ,  -   .     1   ,  htmlspecialchars() (  1).     1  NOWRAP,         (  1)';
 $strTransformation_text_plain__formatted = '   .   .';
 $strTransformation_text_plain__imagelink = '   ,    ;   -    "http://domain.com/",  -   ,  - .';
@@ -841,8 +828,6 @@ $strWestEuropean = '-';
 $strWildcard = '';
 $strWindowNotFound = '      . ,           -  ';
 $strWithChecked = ' :';
-$strWritingCommentNotPossible = '  ';
-$strWritingRelationNotPossible = '  ';
 $strWrongUser = ' /.   .';
 
 $strXML = 'XML';
@@ -874,9 +859,6 @@ $strBusyPages = 'Busy pages';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
 
-$strDBGHits = 'Hits';  //to translate
-$strDBGLine = 'Line';  //to translate
-$strDBGTimePerHitMs = 'Time/Hit, ms';  //to translate
 $strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
 
 $strEngineAvailable = '%s is available on this MySQL server.';  //to translate
@@ -1018,4 +1000,52 @@ $strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocu
 
 $strWriteRequests = 'Write requests';  //to translate
 
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
