@@ -1,5 +1,5 @@
 <?php
-/* $Id: serbian_latin-windows-1250.inc.php,v 2.152 2006/08/09 12:55:39 lem9 Exp $ */
+/* $Id: serbian_latin-windows-1250.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /**
  * Translated by:
@@ -22,7 +22,6 @@ $datefmt = '%d. %B %Y. u %H:%M';
 $timespanfmt = '%s dana, %s sati, %s minuta i %s sekundi';
 
 $strAbortedClients = 'Prekinuto';
-$strAbsolutePathToDocSqlDir = 'Unesite kompletnu putanju do direktorijuma docSQL na veb serveru';
 $strAccessDeniedExplanation = 'phpMyAdmin je pokuao da se povee na MySQL server, ali je server odbio povezivanje. Proverite naziv domaina, korisniko ime i lozinku u config.inc.php i uverite se da odgovaraju podacima koje ste dobili od administratora MySQL servera.';
 $strAccessDenied = 'Pristup odbijen';
 $strAction = 'Akcija';
@@ -30,8 +29,6 @@ $strAddAutoIncrement = 'Dodaj AUTO_INCREMENT vrednost';
 $strAddConstraints = 'Dodaj ogranienja';
 $strAddDeleteColumn = 'Dodaj/obrii kolonu';
 $strAddDeleteRow = 'Dodaj/obrii polje za kriterijum';
-$strAddedColumnComment = 'Dodat je komentar koloni';
-$strAddedColumnRelation = 'Dodata je relacija koloni';
 $strAddFields = 'Dodaj %s polja';
 $strAddHeaderComment = 'Dodaj komentar u zaglavlje (\\n razdvaja linije)';
 $strAddIntoComments = 'Dodaj u komentare';
@@ -189,15 +186,6 @@ $strDataPages = 'Strane sa podacima';
 $strData = 'Podaci';
 $strDBComment = 'Komentar baze:';
 $strDBCopy = 'Kopiraj bazu u';
-$strDBGContextID = 'Kontekst ID';
-$strDBGContext = 'Kontekst';
-$strDBGHits = 'Pogodaka';
-$strDBGLine = 'Linija';
-$strDBGMaxTimeMs = 'Max vreme, ms';
-$strDBGMinTimeMs = 'Min vreme, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Vreme/pogodak, ms';
-$strDBGTotalTimeMs = 'Ukupno vreme, ms';
 $strDbPrivileges = 'Privilegije vezane za bazu';
 $strDBRename = 'Preimenuj bazu u';
 $strDbSpecific = 'Specifino za bazu';
@@ -317,8 +305,6 @@ $strId = 'ID';
 $strIdxFulltext = 'Tekst klju';
 $strIgnore = 'Ignorii';
 $strIgnoreInserts = 'Ignorii duplikate pri umetanju';
-$strIgnoringFile = 'Ignoriem datoteku %s';
-$strImportDocSQL = 'Uvoz docSQL datoteka';
 $strImportFiles = 'Uvoz datoteka';
 $strIndexes = 'Kljuevi';
 $strIndexHasBeenDropped = 'Klju %s je obrisan';
@@ -398,7 +384,7 @@ $strMIME_description = 'Opis';
 $strMIME_MIMEtype = 'MIME-tipovi';
 $strMIME_nodescription = 'Nema opisa za ovu transformaciju.<br />Molimo pitajte autora ta %s radi.';
 $strMIME_transformation_note = 'Za listu dostupnih opcija transformacije i njihove transformacije MIME-tipova, kliknite na %sopise transformacija%s';
-$strMIME_transformation_options_note = 'Molimo unesite vrednosti za opcije transformacije koristei ovaj oblik: \'a\',\'b\',\'c\'...<br />Ako treba da unesete obrnutu kosu crtu ("\\") ili apostrof ("\'") u te vrednosti, stavite obrnutu kosu crtu ispred njih (na primer \'\\\\xyz\' ili \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Molimo unesite vrednosti za opcije transformacije koristei ovaj oblik: \'a\', 100, b,\'c\'...<br />Ako treba da unesete obrnutu kosu crtu ("\\") ili apostrof ("\'") u te vrednosti, stavite obrnutu kosu crtu ispred njih (na primer \'\\\\xyz\' ili \'a\\\'b\').';
 $strMIME_transformation_options = 'Opcije transformacije';
 $strMIME_transformation = 'Tranformacije itaa';
 $strMIMETypesForTable = 'MIME TIPOVI ZA TABELU';
@@ -700,7 +686,6 @@ $strTextAreaLength = 'Zbog njehove veliine, polje<br />moda neete moi da izmenit
 $strThai = 'Tajski';
 $strTheme = 'Tema / stil';
 $strThisHost = 'Ovaj server';
-$strThisNotDirectory = 'Ovo nije direktorijum';
 $strThreadSuccessfullyKilled = 'Proces %s je uspeno prekinut.';
 $strTime = 'Vreme';
 $strToggleScratchboard = 'Ukljui/iskljui radnu tablu';
@@ -714,7 +699,6 @@ $strTransformation_application_octetstream__hex = 'Prikazuje heksadecimalni prik
 $strTransformation_image_jpeg__inline = 'Prikazuje umanjenu sliku na koju je mogue kliknuti; opcije: irina, visina u pikselima (uva originalni odnos)';
 $strTransformation_image_jpeg__link = 'Prikazuje link ka ovoj slici (npr. direktno preuzimanje iz BLOB-a).';
 $strTransformation_image_png__inline = 'Prikai JPEG slike na strani';
-$strTransformation_text_plain__dateformat = 'Uzima TIME, TIMESTAMP ili DATETIME polje i formatira ga koristei lokalni oblik prikazivanja datuma. Prva opcija je ofset (u satima) koji se dodaje vremenskoj oznaci (podrazumevano: 0). Druga opcija je razliit format datuma prema parametrima koji su dostupni za PHP-ov strftime().';
 $strTransformation_text_plain__external = 'SAMO LINUX: Pokree eksternu aplikaciju i popunjava podatke u poljima preko standardnog ulaza. Vraa standardni izlaz aplikacije. Podrazumevano je Tidy, za lepi prikaz HTML koda. Zbog sigurnosnih razloga, morate runo izmeniti datoteku libraries/transformations/text_plain__external.inc.php i dodati alate koje elite da koristite. Prva opcija je broj programa koje elite da koristite, a druga su parametri programa. Ako se trei parametar postavi na 1 izlaz e biti konvertovan koristei htmlspecialchars() (podrazumevano je 1). Ako je etvrti parametar postavljen na 1, NOWRAP e biti dodato eliji sa sadrajem tako da e izlaz biti prikazan bez izmena. (podrazumevano 1)';
 $strTransformation_text_plain__formatted = 'uva originalno formatiranje polja. Escaping se ne vri.';
 $strTransformation_text_plain__imagelink = 'Prikazuje sliku i link, polje sadri naziv datoteke; prva opcija je prefiks kao "http://domain.com/", druga opcija je irina u pikselima, trea je visina.';
@@ -770,8 +754,6 @@ $strWildcard = 'doker';
 $strWindowNotFound = 'Odredini prozor pretraivaa nije mogao da bude auriran. Moda ste zatvorili matini prozor, ili va pretraiva onemoguava auriranje meu prozorima zbog sigurnosnih podeavanja';
 $strWithChecked = 'Oznaeno:';
 $strWriteRequests = 'Zahtevi za upis';
-$strWritingCommentNotPossible = 'Pisanje komentara nije mogue';
-$strWritingRelationNotPossible = 'Upisivanje relacije nije mogue';
 $strWrongUser = 'Pogreno korisniko ime/lozinka. Pristup odbijen.';
 
 $strXML = 'XML';
@@ -1004,7 +986,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1019,4 +1001,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
