@@ -1,5 +1,5 @@
 <?php
-/* $Id: slovenian-utf-8.inc.php,v 2.144 2006/08/09 12:55:40 lem9 Exp $ */
+/* $Id: slovenian-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /* By: urska.colner, agenda d.o.o. <urska.colner@agenda.si>, uros kositer, agenda d.o.o. <urosh@agenda.si> */
 
@@ -19,7 +19,6 @@ $datefmt = '%d %B %Y ob %I:%M %p';
 $timespanfmt = '%s dni, %s ur, %s minut in %s sekund';
 
 $strAbortedClients = 'Prekinjeno';
-$strAbsolutePathToDocSqlDir = 'Vnesite absolutno pot do docSQL mape na strežniku';
 $strAccessDenied = 'Dostop zavrnjen';
 $strAccessDeniedExplanation = 'phpMyAdmin se je poskušal povezati na MySQL strežnik, ki je zavrnil povezavo. Preverite, ali gostitelj, uporabniško ime in geslo v datoteki config.inc.php ustrezajo podatkom administratorja MySQL strežnika.';
 $strAction = 'Akcija';
@@ -27,8 +26,6 @@ $strAddAutoIncrement = 'Dodaj AUTO_INCREMENT vrednost';
 $strAddConstraints = 'Dodaj omejitve';
 $strAddDeleteColumn = 'Dodaj/Odstrani stolpec \'Polje\'';
 $strAddDeleteRow = 'Dodaj/Odstrani vrstico \'Kriterij\'';
-$strAddedColumnComment = 'Dodan komentar za stolpec';
-$strAddedColumnRelation = 'Dodana relacija za stolpec';
 $strAddHeaderComment = 'Dodaj prilagojen komentar v glavo (\\n prelomi vrstice)';
 $strAddIntoComments = 'Dodaj med komentarje';
 $strAddNewField = 'Dodaj novo polje';
@@ -161,15 +158,6 @@ $strDataDict = 'Podatkovni slovar';
 $strDataOnly = 'Samo podatki';
 $strData = 'Podatki';
 $strDBComment = 'Komentar zbirke podatkov: ';
-$strDBGContextID = 'Kontekst ID';
-$strDBGContext = 'Kontekst';
-$strDBGHits = 'Zadetki';
-$strDBGLine = 'Vrstica';
-$strDBGMaxTimeMs = 'Največji čas, ms';
-$strDBGMinTimeMs = 'Najmanjši čas, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Čas/Zadetek, ms';
-$strDBGTotalTimeMs = 'Skupni čas, ms';
 $strDbPrivileges = 'Privilegiji tipični za podatkovno bazo';
 $strDBRename = 'Preimenuj podatkovno bazo v';
 $strDbSpecific = 'glede na zbirko podatkov';
@@ -271,8 +259,6 @@ $strId = 'ID';
 $strIdxFulltext = 'Polno besedilo';
 $strIgnoreInserts = 'Uporabi možnost prezri vstavke';
 $strIgnore = 'Prezri';
-$strIgnoringFile = 'Prezrl sem datoteko %s';
-$strImportDocSQL = 'Uvozi docSQL datoteke';
 $strImportFiles = 'Uvozi datoteke';
 $strIndexes = 'Indeksi';
 $strIndexHasBeenDropped = 'Indeks %s je zavržen';
@@ -332,7 +318,7 @@ $strMIME_MIMEtype = 'MIME-vrsta';
 $strMIME_nodescription = 'Za to pretvorbo ni na voljo opisa.<br />Za funkcije %s se pozanimajte pri avtorju.';
 $strMIME_transformation_note = 'Seznam razpoložljivih možnosti pretvorbe in pretvorbe MIME-vrst boste videli, če kliknete na %sopise transformacij%s';
 $strMIME_transformation_options = 'Možnosti pretvorbe';
-$strMIME_transformation_options_note = 'Vrednosti za možnosti pretvorbe vnesite v naslednji obliki: \'a\',\'b\',\'c\'...<br />Če želite med vrednosti vnesti poševnico nazaj ("\") ali enojni narekovaj ("\'"), morate pred ta znak postaviti (še eno) poševnico nazaj (npr. \'\\\\xyz\' ali \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Vrednosti za možnosti pretvorbe vnesite v naslednji obliki: \'a\', 100, b,\'c\'...<br />Če želite med vrednosti vnesti poševnico nazaj ("\") ali enojni narekovaj ("\'"), morate pred ta znak postaviti (še eno) poševnico nazaj (npr. \'\\\\xyz\' ali \'a\\\'b\').';
 $strMIME_transformation = 'Pretvorba z brskalnikom';
 $strMIMETypesForTable = 'VRSTE MIME ZA TABELO';
 $strMIME_without = 'MIME-vrste, ki so napisano ležeče, nimajo lastne pretvorbene funkcije';
@@ -591,7 +577,6 @@ $strTblPrivileges = 'Privilegiji tipični za tabelo';
 $strTextAreaLength = ' Zaradi njegove dolžine<br /> polja ne bo mogoče urejati ';
 $strThai = 'Tajsko';
 $strThisHost = 'Ta strežnik';
-$strThisNotDirectory = 'To ni bila mapa';
 $strThreadSuccessfullyKilled = 'Tema %s je bila prekinjena.';
 $strTime = 'Čas';
 $strToggleScratchboard = 'preklopi odložišče (scratchboard)';
@@ -603,7 +588,6 @@ $strTransformation_application_octetstream__download = 'Prikaži povezavo za pre
 $strTransformation_image_jpeg__inline = 'Prikaže sličico, na katero lahko kliknete; možnosti: širina, višina v slikovnih pikah (obdrži prvotna razmerja)';
 $strTransformation_image_jpeg__link = 'Pokaže povezavo na grafiko (neposredni BLOB prenos, ipd.).';
 $strTransformation_image_png__inline = 'Pokaži sliko/jpeg: vključeno';
-$strTransformation_text_plain__dateformat = 'Oblikuje polje TIME, TIMESTAMP ali DATETIME glede na lokalne oblike za prikaz časa. Prva možnost je odmik (v urah), ki bo dodan polju timestamp (Privzeto: 0). Druga možnost je drugačna oblika prikaza datuma, glede na parametre za PHP strftime().';
 $strTransformation_text_plain__external = 'SAMO ZA LINUX: Zažene zunanjo aplikacijo in podaja podatke za fielddata preko standardnega vhoda. Vrne standardni izhod aplikacije. Privzeto je Tidy, za tiskanje HTML-kode. Zaradi varnostnih razlogov morate ročno urediti datoteko libraries/transformations/text_plain__external.inc.php in vstaviti orodja za zaganjanje. Prva možnost je številka programa, ki ga želite uporabiti, druga možnost pa so parametri za program. Če tretji parameter nastavite na 1, bo s pomočjo htmlspecialchars() pretvoril izhod (Privzeto: 1). Če nastavite četrti parameter na 1, bo v celico z vsebino (content cell) vnesel NOWRAP in tako prikazal celoten izhod brez preoblikovanja (Privzeto: 1)';
 $strTransformation_text_plain__formatted = 'Ohrani izvirno oblikovanje polja, brez izgubljanja vsebine.';
 $strTransformation_text_plain__imagelink = 'Prikaže sliko in povezavo, polje vsebuje ime datoteke; najprej je predpona, npr. "http://domena.com/", druga možnost je širina v slikovnih pikah, tretja pa višina.';
@@ -654,8 +638,6 @@ $strWestEuropean = 'Zahodno evropsko';
 $strWildcard = 'nadomestni znak';
 $strWindowNotFound = 'Ciljnega okna ni bilo mogoče osvežiti. Morda ste zaprli nadrejeno okno ali pa vaš brskalnik blokira osveževanje varnostnih parametrov med okni.';
 $strWithChecked = 'Z označenim:';
-$strWritingCommentNotPossible = 'Zapisovanje komentarjev ni mogoče';
-$strWritingRelationNotPossible = 'Zapisovanje relacij ni mogoče';
 $strWrongUser = 'Napačno uporabniško ime/geslo. Dostop zavrnjen.';
 
 $strXML = 'XML';
@@ -1003,7 +985,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1018,4 +1000,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
