@@ -1,7 +1,7 @@
 <?php
-/* $Id: spanish-iso-8859-1.inc.php,v 2.157.2.1 2006/08/30 10:43:15 nijel Exp $ */
+/* $Id: spanish-iso-8859-15.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
-$charset = 'iso-8859-1';
+$charset = 'iso-8859-15';
 $text_dir = 'ltr';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
@@ -18,17 +18,15 @@ $datefmt = '%d-%m-%Y a las %H:%M:%S';
 $timespanfmt = '%s das, %s horas, %s minutos y %s segundos';
 
 $strAbortedClients = 'Abortado';
-$strAbsolutePathToDocSqlDir = 'Por favor, escriba la ruta absoluta del servidor que lleve al directorio docSQL';
 $strAccessDenied = 'Acceso denegado ';
 $strAccessDeniedCreateConfig = 'La razn ms probable es que usted no cre un archivo de configuracin. Utilice %1$ssetup script%2$s para crear una.';
 $strAccessDeniedExplanation = 'phpMyAdmin intent conectarse con el servidor MySQL, y el servidor rechaz esta conexin. Deber revisar el host, nombre de usuario y contrasea en config.inc.php y asegurarse que corresponden con la informacin provista por el administrador del servidor MySQL.';
 $strAction = 'Accin';
 $strAddAutoIncrement = 'Aadir el valor AUTO_INCREMENT';
+$strAddClause = 'Aada %s';
 $strAddConstraints = 'Aadir restricciones';
 $strAddDeleteColumn = 'Aadir/borrar columna de criterio';
 $strAddDeleteRow = 'Aadir/borrar fila de criterio';
-$strAddedColumnComment = 'Se aadi un comentario para la columna';
-$strAddedColumnRelation = 'Se aadi una relacin para la columna';
 $strAddFields = 'Aadir %s campo(s)';
 $strAddHeaderComment = 'Aadir su propio comentario en el encabezado (\\n segmenta las oraciones)';
 $strAddIntoComments = 'Aadir en los comentarios';
@@ -53,6 +51,7 @@ $strAlterOrderBy = 'Modificar el ORDER BY de la tabla';
 $strAnalyzeTable = 'Analizar la tabla';
 $strAndThen = 'y luego';
 $strAnd = 'y luego';
+$strAngularLinks = 'Enlaces angulares';
 $strAnIndex = 'Se aadi un ndice en %s';
 $strAny = 'cualquiera';
 $strAnyHost = 'Cualquier servidor';
@@ -105,6 +104,8 @@ $strBzError = 'Si desea usar las opciones de compresin Bz2, deber actualizar su
 $strBzip = '"Comprimido con bzip"';
 
 $strCalendar = 'Calendario';
+$strCancel = 'Cancelar';
+$strCanNotLoadExportPlugins = 'No se cargaron los plugins de exportacin.  Por favor, revise su instalacin!';
 $strCanNotLoadImportPlugins = 'No se pudieron cargar los plugins de importacin, por favor revise su instalacin';
 $strCannotLogin = 'El servidor MySQL no autoriz su ingreso';
 $strCantLoad = 'no se pudo cargar la extensin %s,<br />por favor revise su configuracin de PHP.';
@@ -167,6 +168,12 @@ $strCreateNewDatabase = 'Crear nueva base de datos';
 $strCreateNewTable = 'Crear nueva tabla en la base de datos %s';
 $strCreatePage = 'Crear una nueva pgina';
 $strCreatePdfFeat = 'Creacin de los PDF';
+$strCreateRelation = 'Crear relacin';
+$strCreateTable  = 'Crear tabla';
+$strCreateUserDatabase = 'Base de datos para el usuario';
+$strCreateUserDatabaseName = 'Crear base de datos con el mismo nombre y otorgue todos los privilegios';
+$strCreateUserDatabaseNone = 'Ninguna';
+$strCreateUserDatabaseWildcard = 'Otorgue todos los privilegios al nombre que contiene comodn (username\_%)';
 $strCreationDates = 'Fechas de creacin/actualizacin/revisin';
 $strCriteria = 'Criterio';
 $strCroatian = 'Croata';
@@ -195,15 +202,7 @@ $strDataOnly = 'Solamente datos';
 $strDataPages = 'Pginas que contienen datos'; 
 $strDBComment = 'Comentario de la base de datos: ';
 $strDBCopy = 'Copiar la base de datos a';
-$strDBGContext = 'Contexto';
-$strDBGContextID = 'ID del contexto';
-$strDBGHits = 'Hits';
-$strDBGLine = 'Lnea';
-$strDBGMaxTimeMs = 'Tiempo mximo, ms';
-$strDBGMinTimeMs = 'Tiempo mnimo, ms';
-$strDBGModule = 'Mdulo';
-$strDBGTimePerHitMs = 'Tiempo/Hit, ms';
-$strDBGTotalTimeMs = 'Tiempo total, ms';
+$strDbIsEmpty = 'La base de datos, parece estar vaca!';
 $strDbPrivileges = 'Privilegios especficos para la base de datos';
 $strDBRename = 'Cambiar el nombre de la base de datos a';
 $strDbSpecific = 'especfico para la base de datos';
@@ -218,11 +217,16 @@ $strDelete = 'Borrar';
 $strDeleted = 'La fila se ha borrado';
 $strDeletedRows = 'Filas borradas: ';
 $strDeleteNoUsersSelected = 'No se han seleccionado usuarios para eliminar!';
+$strDeleteRelation = 'Eliminar la relacin';
 $strDeleting = 'Borrando %s';
+$strDelimiter = 'Delimitador';
 $strDelOld = 'La pgina actual tiene referencias a tablas que ya no existen.  Desea eliminar esas referencias?';
 $strDescending = 'Descendente';
 $strDescription = 'Descripcin';
+$strDesigner = 'Diseador';
+$strDesignerHelpDisplayField = 'El campo Display se halla en color rosado. Para activar o desactivar un campo como un campo Display, d clic en el cono "Seleccione el campo a mostrar", luego d clic en el nombre apropiado del campo.';
 $strDictionary = 'diccionario';
+$strDirectLinks = 'Enlaces directos';
 $strDirtyPages = 'Pginas que requieren ser depuradas'; 
 $strDisabled = 'Deshabilitado';
 $strDisableForeignChecks = 'Deshabilitar la revisin de las llaves extranjeras (foreign keys)';
@@ -230,6 +234,8 @@ $strDisplayFeat = 'Mostrar las opciones';  //Features = opciones, componentes?
 $strDisplayOrder = 'Mostrar en este orden:';
 $strDisplayPDF = 'Mostrar esquema PDF';
 $strDoAQuery = 'Hacer una consulta (comodn: "%")';
+$strDocSQL = 'DocSQL';
+$strDocSQLOptions = 'Opciones DocSQL';
 $strDocu = 'Documentacin';
 $strDoYouReally = 'Realmente desea ';
 $strDropDatabaseStrongWarning = 'Est a punto de DESTRUIR una base de datos completa!';
@@ -259,6 +265,10 @@ $strEnglish = 'Ingls';
 $strEnglishPrivileges = ' Nota: Los nombres de los privilegios de MySQL estn expresados en ingls ';
 $strError = 'Error';
 $strErrorInZipFile = 'Error en el archivo ZIP:';
+$strErrorRelationAdded = 'Error: no se aadi la relacin.';
+$strErrorRelationExists = 'Error: la relacin ya existe.';
+$strErrorRenamingTable = 'Error al cambiar el nombre de la tabla %1$s a %2$s';
+$strErrorSaveTable = 'Error guardando las coordenadas para el Diseador.';
 $strEscapeWildcards = 'Los comodines _ y % deben acompaarse de \ para usarlos de manera literal';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estonio';
@@ -267,6 +277,8 @@ $strExcelOptions = 'Opciones de Excel';
 $strExecuteBookmarked = 'Ejecute la consulta marcada previamente';
 $strExplain = 'Explicar el SQL';
 $strExport = 'Exportar';
+$strExportImportToScale = 'Exporte/Importe a escala';
+$strExportMustBeFile = 'El formato de exportacin seleccionado debe grabarse en el archivo!';
 $strExtendedInserts = 'INSERTs extendidos';
 $strExtra = 'Extra';
 
@@ -292,11 +304,14 @@ $strFlushPrivilegesNote = 'Nota: phpMyAdmin obtiene los privilegios de los usuar
 $strFlushQueryCache = 'Vaciar el cache de consultas';
 $strFlushTables = 'Vaciar el cache de todas las tablas';
 $strFlushTable = 'Vaciar el cach de la tabla ("FLUSH")';
+$strFontSize = 'Tamao del font';
+$strForeignKeyError = 'Error creando llaves extranjeras (foreign keys).  Revise los tipos de datos';
 $strFormat = 'Formato';
 $strFormEmpty = 'Falta un valor en el formulario!';
 $strFreePages = 'Pginas libres'; 
 $strFullText = 'Textos completos';
 $strFunction = 'Funcin';
+$strFunctions = 'Funciones';
 
 $strGenBy = 'Generado por';
 $strGeneralRelationFeat = 'Opciones de relacin general';  //Features = opciones, componentes?
@@ -318,7 +333,11 @@ $strHasBeenAltered = 'fue modificada.';
 $strHasBeenCreated = 'se cre.';
 $strHaveToShow = 'Debe elegir al menos una columna para mostrar';
 $strHebrew = 'Hebreo';
+$strHelp = 'Ayuda';
 $strHexForBinary = 'Usar hexadecimal para campos binarios';
+$strHide         = 'Ocultar';
+$strHideShowAll = 'Ocultar/mostrar todo';
+$strHideShowNoRelation = 'Ocultar/mostrar Tablas que no tengan relacin';
 $strHomepageOfficial = 'Pgina oficial de phpMyAdmin';
 $strHome = 'Pgina de inicio';
 $strHostEmpty = 'El nombre del servidor est vaco!!';
@@ -332,19 +351,19 @@ $strHungarian = 'Hngaro';
 $strIcelandic = 'Islands';
 $strId = 'Identificacin';
 $strIdxFulltext = 'Texto completo';
+$strIEUnsupported = 'Internet Explorer no reconoce esa funcin.';
 $strIgnoreDuplicates = 'Ignore las filas duplicadas';
 $strIgnore = 'Ignorar';
 $strIgnoreInserts = 'Usar la opcin ignore inserts';
-$strIgnoringFile = 'Ignorando el archivo %s';
-$strImportDocSQL = 'Importar archivos docSQL';
+$strImportExportCoords = 'Importar/Exportar coordenadas para el esquema PDF';
 $strImportFiles = 'Importar archivos';
 $strImportFormat = 'Formato del archivo importado';
 $strImport = 'Importar';
 $strImportSuccessfullyFinished = 'La importacin se ejecut exitosamente, se ejecutaron %d consultas.';
 $strIndexes = 'ndices';
 $strIndexHasBeenDropped = 'El ndice %s ha sido eliminado';
-$strIndexName = 'Nombre del ndice&nbsp;:';
 $strIndex = 'ndice';
+$strIndexName = 'Nombre del ndice&nbsp;:';
 $strIndexType = 'Tipo de ndice&nbsp;:';
 $strIndexWarningMultiple = 'Se cre ms de una clave %s para la columna `%s`';
 $strIndexWarningPrimary = 'Las claves PRIMARIA e NDICE no deben seleccionarse juntas para la columna `%s`';
@@ -358,6 +377,7 @@ $strInnoDBDataFilePath = 'Archivos de datos';
 $strInnoDBDataHomeDirDesc = 'La parte constante de la ruta del directorio para todos los archivos de datos InnoDB.'; 
 $strInnoDBDataHomeDir = 'Directorio raz de los datos';
 $strInnoDBPages = 'pginas';
+$strInnoDBRelationAdded = 'Se aadi la relacin InnoDB';
 $strInnodbStat = 'Estado del InnoDB';
 $strInsecureMySQL = 'Su archivo de configuracin contiene parmetros (root sin contrasea) que corresponden a la cuenta privilegiada predeterminada de MySQL. Su servidor de MySQL est usando estos valores, lo que constituye una vulnerabilidad.  Se le recomienda corregir esta brecha de seguridad.  Por ejemplo, desde la pgina de inicio de phpMyAdmin seleccione Privilegios y agregue la contrasea a root@localhost.  Deber escribir la misma contrasea en config.inc.php de phpMyAdmin';
 $strInsertAsNewRow = 'Insertar como una nueva fila';
@@ -365,6 +385,7 @@ $strInsertedRowId = 'Se insert la ID de la fila:';
 $strInsertedRows = 'Filas insertadas:';
 $strInsert = 'Insertar';
 $strInternalNotNecessary = '* No es necesaria una relacin interna cuando tambin existe en InnoDB.';
+$strInternalRelationAdded = 'Se aadi la relacin interna';
 $strInternalRelations = 'Relaciones internas';
 $strInUse = 'en uso';
 $strInvalidAuthMethod = 'El mtodo de autenticacin no es vlido en la configuracin actual:';
@@ -373,12 +394,14 @@ $strInvalidColumn = 'Las columnas especificadas (%s) no son vlidas!';
 $strInvalidCSVFieldCount = 'El nmero de campos de los datos CSV en la lnea %d no es vlido.';
 $strInvalidCSVFormat = 'El formato de los datos CSV en la lnea %d no es vlido.';
 $strInvalidCSVParameter = 'Parmetro no vlido para importar CSV: %s';
+$strInvalidDatabase = 'La base de datos no es vlida';
 $strInvalidFieldAddCount = 'Debe aadir al menos un campo.';
 $strInvalidFieldCount = 'La tabla debe tener al menos un campo.';
 $strInvalidLDIImport = 'Este plugin no tiene soporte para importaciones comprimidas!';
 $strInvalidRowNumber = '%d no es un nmero de fila vlido.';
 $strInvalidServerHostname = 'El nombre del host no es vlido para el servidor %1$s. Por favor, revise su configuracin.';
 $strInvalidServerIndex = 'No es vlido el ndice del servidor: "%s"';
+$strInvalidTableName = 'El nombre de la tabla no es vlido';
 
 $strJapanese = 'Japons';
 $strJoins = 'Vnculos (Joins)';
@@ -390,10 +413,12 @@ $strKeepPass = 'No cambiar la contrasea';
 $strKeyCache = 'Cache principal';
 $strKeyname = 'Nombre de la clave';
 $strKill = 'Matar el proceso';
+$strKnownExternalBug = 'La funcionalidad %s est afectada por un fallo conocido, vea %s';
 $strKorean = 'Coreano';
 
 $strLandscape = 'Orientacin horizontal';
 $strLanguageFileNotFound = 'No se hall el archivo de idioma "%1$s".';
+$strLanguage = 'Idioma';
 $strLanguageUnknown = 'Idioma desconocido: %1$s.';
 $strLatchedPages = 'Pginas vinculadas';
 $strLatexCaption = 'Subtitulado de la tabla';
@@ -444,6 +469,7 @@ $strMIME_without = 'MIME-types impresos en itlicas no tienen una funcin de trans
 $strModifications = 'Se han guardado las modificaciones';
 $strModifyIndexTopic = 'Modificar un ndice';
 $strModify = 'Modificar';
+$strMoveMenu = 'Mover el Men';
 $strMoveTable = 'Mover tabla a (Base de datos<b>.</b>tabla):';
 $strMoveTableOK = 'La tabla %s ha sido movida a %s.';
 $strMoveTableSameNames = 'No es posible mover la tabla a la misma!';
@@ -473,6 +499,7 @@ $strNext = 'Prxima';
 $strNoActivity = 'No ha habido actividad desde hace %s o ms segundos, por favor reingrese al sitio';
 $strNoDatabases = 'No hay bases de datos';
 $strNoDatabasesSelected = 'No se seleccionaron bases de datos.';
+$strNoDataReceived = 'No se recibieron datos para importar. O no se envi el nombre del archivo, o el tamao del archivo excedi el mximo permitido por su configuracin PHP. Por favor, lea el FAQ 1.16.';
 $strNoDescription = 'Sin descripcin';
 $strNoDetailsForEngine = 'No existe informacin detallada acerca de las condiciones en que se encuentra este motor de almacenamiento.';
 $strNoDropDatabases = 'Los enunciados \"DROP DATABASE\" estn deshabilitados.';
@@ -501,11 +528,16 @@ $strNoUsersFound = 'Usuario(s) no encontrado(s).';
 $strNoValidateSQL = 'Salir de la validacin del SQL';
 $strNull = 'Nulo';
 $strNumberOfFields = 'Nmero de campos';
+$strNumberOfTables = 'Nmero de tablas';
 $strNumSearchResultsInTable = '%s resultado(s) en la tabla <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> resultado(s)';
 $strNumTables = 'Tablas';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheet = 'Hoja de clculo Open Document';
+$strOpenDocumentSpreadsheetOptions = 'Opciones de la hoja de clculo Open Document';
+$strOpenDocumentTextOptions = 'Opciones del texto Open Document';
+$strOpenDocumentText = 'Texto Open Document';
 $strOpenNewWindow = 'Abrir nueva ventana de phpMyAdmin';
 $strOperations = 'Operaciones';
 $strOperator = 'Operador';
@@ -529,6 +561,7 @@ $strPdfInvalidTblName = 'La tabla "%s" no existe!';
 $strPdfNoTables = 'No existen tablas';
 $strPDFOptions = 'Opciones del PDF';
 $strPDF = 'PDF';
+$strPDFReportExplanation = '(Genera un reporte conteniendo los datos de una sola tabla)';
 $strPDFReportTitle = 'Ttulo del reporte';
 $strPerHour = 'por hora';
 $strPerMinute = 'por minuto';
@@ -538,8 +571,10 @@ $strPhoneBook = 'directorio telefnico';
 $strPHP40203 = 'Usted est usando PHP 4.2.3, el cual tiene un error de codificacin en cuanto a las "cadenas de caracteres multi-byte" (mbstring). Lea el reporte 19404 de PHP. No se recomienda el uso de phpMyAdmin con esta versin de PHP.';
 $strPhp = 'Crear cdigo PHP';
 $strPHPVersion = 'Versin de PHP';
+$strPleaseSelectPrimaryOrUniqueKey = 'Por favor, seleccione la clave primaria o una clave nica';
 $strPmaDocumentation = 'Documentacin de phpMyAdmin';
 $strPmaUriError = 'El contenido de <tt>$cfg[\'PmaAbsoluteUri\']</tt> DEBE constar en config.inc.php!';
+$strPmaWiki = 'Wiki del phpMyAdmin';
 $strPolish = 'Polaco';
 $strPortrait = 'Orientacin vertical';
 $strPos1 = 'Empezar';
@@ -589,6 +624,7 @@ $strPrivDescUpdate = 'Permite cambiar los datos.';
 $strPrivDescUsage = 'Sin privilegios.';
 $strPrivileges = 'Privilegios';
 $strPrivilegesReloaded = 'Los privilegios fueron cargados nuevamente de manera exitosa.';
+$strProcedures = 'Procedimientos';
 $strProcesses = 'Procesos';
 $strProcesslist = 'Lista de procesos';
 $strProtocolVersion = 'Versin del protocolo';
@@ -600,6 +636,7 @@ $strQBEIns = 'Insertar';
 $strQueryCache = 'Cache de consultas';
 $strQueryFrame = 'Ventana de consulta';
 $strQueryOnDb = 'Consulta a la base de datos <b>%s</b>:';
+$strQueryResultsOperations = 'Operaciones sobre los resultados de la consulta';
 $strQuerySQLHistory = 'Historial-SQL';
 $strQueryStatistics = '<b>Estadsticas de consulta</b>: Desde su inicio, %s consultas han sido enviadas al servidor.';
 $strQueryTime = 'La consulta tard %01.4f seg';
@@ -608,15 +645,19 @@ $strQueryWindowLock = 'No sobreescribir esta consulta desde fuera de la ventana'
 
 $strReadRequests = 'Lea las solicitudes';
 $strReceived = 'Recibido';
+$strRecommended = 'recomendado';
 $strRecords = 'Registros';
 $strReferentialIntegrity = 'Comprobar la integridad referencial:';
 $strRefresh = 'Actualizar';
 $strRelationalSchema = 'Esquema relacionado';
+$strRelationDeleted = 'La relacin fue eliminada';
 $strRelationNotWorking = 'Las opciones adicionales para trabajar con tablas vinculadas fueron desactivadas. Para saber porqu, d clic %saqu%s.';  //Features = opciones, componentes?
 $strRelationsForTable = 'RELACIONES PARA LA TABLA';
 $strRelations = 'Relaciones';
 $strRelationView = 'Vista de relaciones';
+$strReload = 'Cargar nuevamente';
 $strReloadingThePrivileges = 'Cargando los privilegios nuevamente';
+$strReloadPrivileges = 'Cargar los privilegios nuevamente';
 $strRemoveSelectedUsers = 'Eliminar a los usuarios seleccionados';
 $strRenameDatabaseOK = 'La base de datos %s ha sido cambiada de nombre a %s';
 $strRenameTable = 'Cambiar el nombre de la tabla a';
@@ -650,6 +691,7 @@ $strRussian = 'Ruso';
 
 $strSave = 'Grabar';
 $strSaveOnServer = 'Guardar en el servidor, en el directorio %s ';
+$strSavePosition = 'Guardar posicin';
 $strScaleFactorSmall = 'El factor de la escala es demasiado pequeo para poner el esquema en una pgina';
 $strSearch = 'Buscar';
 $strSearchFormTitle = 'Buscar en la base de datos';
@@ -666,13 +708,16 @@ $strSelectADb = 'Seleccionar una base de datos';
 $strSelectAll = 'Seleccionar todo';
 $strSelectBinaryLog = 'Seleccionar el log binario que desea examinar';
 $strSelectFields = 'Seleccionar campos (al menos uno):';
+$strSelectForeignKey = 'Seleccione la llave extranjera (foreign key)';
 $strSelectNumRows = 'en la consulta';
+$strSelectReferencedKey = 'Seleccione la llave de referencia';
 $strSelectTables = 'Seleccionar tablas';
 $strSend = 'Enviar (genera un archivo descargable)';
 $strSent = 'Enviado';
 $strServerChoice = 'Eleccin del servidor';
 $strServerNotResponding = 'El servidor no est respondiendo';
 $strServer = 'Servidor';
+$strServers = 'Servidores';
 $strServerStatusDelayedInserts = 'Delayed inserts';
 $strServerStatus = 'Informacin acerca del tiempo de ejecucin del proceso principal';
 $strServerStatusUptime = 'Este servidor MySQL ha estado activo durante %s. Se inici en %s.';
@@ -687,8 +732,11 @@ $strShowColor = 'Mostrar color';
 $strShowDatadictAs = 'Formato del Diccionario de Datos';
 $strShowFullQueries = 'Mostrar las consultas enteras';
 $strShowGrid = 'Mostrar la cuadrcula';
+$strShowHideLeftMenu = 'Ocultar/mostrar men izquierdo';
 $strShowingBookmark = 'Mostrando el favorito';
+$strShowingPhp = 'Mostrar como cdigo PHP';
 $strShowingRecords = 'Mostrando registros ';
+$strShowingSQL = 'Mostrando la consulta SQL';
 $strShow = 'Mostrar';
 $strShowOpenTables = 'Mostrar las tablas que estn abiertas';
 $strShowPHPInfo = 'Mostrar la informacin de PHP';
@@ -810,6 +858,8 @@ $strSize = 'Tamao';
 $strSkipQueries = 'Nmero de registros (consultas) a saltarse desde el inicio';
 $strSlovak = 'Eslovaco'; 
 $strSlovenian = 'Esloveno';
+$strSmallBigAll = 'Pequeo/grande todos';
+$strSnapToGrid = 'Cuadrcula magntica';
 $strSocketProblem = '(o el socket del servidor MySQL local no est configurado correctamente)';
 $strSortByKey = 'Organizar segn la clave';
 $strSorting = 'Organizando (sorting)';
@@ -817,6 +867,7 @@ $strSort = 'Ordenar';
 $strSpaceUsage = 'Espacio utilizado';
 $strSpanish = 'Espaol';
 $strSplitWordsWithSpace = 'Palabras separadas por un espacio (" ").';
+$strSQLCompatibility = 'Modalidad compatible con SQL';
 $strSQLExportType = 'Tipo de exportacin';
 $strSQLImportOptions = 'Opciones SQL';
 $strSQLOptions = 'Opciones SQL';
@@ -828,6 +879,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'El identificador no es vlido';
 $strSQPBugUnclosedQuote = 'Comillas sin cerrar';
 $strSQPBugUnknownPunctuation = 'Signo de puntuacin desconocido';
+$strStandInStructureForView = 'Estructura Stand-in para la vista';
 $strStatCheckTime = 'ltima revisin';
 $strStatCreateTime = 'Creacin';
 $strStatement = 'Enunciado';
@@ -840,9 +892,11 @@ $strStrucCSV = 'Datos CSV ';
 $strStrucData = 'Estructura y datos';
 $strStrucExcelCSV = 'CSV para datos de MS Excel';
 $strStrucNativeExcel = 'Datos de MS Excel en formato nativo';
+$strStrucNativeExcelOptions = 'Opciones de exportacin nativas para Excel';
 $strStrucOnly = 'nicamente la estructura ';
 $strStructPropose = 'Planteamiento de la estructura de tabla';
 $strStructure = 'Estructura';
+$strStructureForView = 'Estructura para la vista';
 $strSubmit = 'Enviar';
 $strSuccess = 'Su consulta se ejecut con xito';
 $strSum = 'Nmero de filas';
@@ -856,7 +910,9 @@ $strTableEmpty = 'El nombre de la tabla est vaco!';
 $strTableHasBeenDropped = 'Se ha eliminado la tabla %s';
 $strTableHasBeenEmptied = 'Se ha vaciado la tabla %s';
 $strTableHasBeenFlushed = 'Se ha vaciado el cach de la tabla %s';
+$strTableIsEmpty = 'La tabla, parece estar vaca!';
 $strTableMaintenance = 'Mantenimiento de la tabla';
+$strTableName = 'Nombre de la tabla';
 $strTableOfContents = 'Tabla de contenidos';
 $strTableOptions = 'Opciones de la tabla';
 $strTables = '%s tabla(s)';
@@ -874,14 +930,16 @@ $strThemeNoValidImgPath = 'No se hall la ruta de imgenes para la plantilla de in
 $strThemePathNotFound = 'No se hall la ruta de la plantilla de interfaz (theme) para la plantilla %s!';
 $strTheme = 'Tema / Estilo';
 $strThisHost = 'Este Host';
-$strThisNotDirectory = 'Esto no es un directorio';
 $strThreads = 'Procesos';
 $strThreadSuccessfullyKilled = 'El proceso %s fue destruido exitosamente.';
 $strTimeoutInfo = 'Se agot el tiempo de ejecucin en la importacin previa; si lo reenva continuar desde la posicin %d.';
 $strTimeoutNothingParsed = 'Sin embargo, en la ejecucin ms reciente no se procesaron datos.  Esto usualmente significa que phpMyAdmin no ser capaz de completar esta importacin a menos que usted incremente el tiempo de ejecucin de php.';
 $strTimeoutPassed = 'Se ha agotado el tiempo de ejecucin del script; si desea completar la importacin, por favor, reenve el mismo archivo y la importacin continuar.';
 $strTime = 'Tiempo';
+$strToFromPage = 'pgina de/a la';
 $strToggleScratchboard = 'cambiar el estado del scratchboard';
+$strToggleSmallBig = 'Alterne entre pequeo y grande';
+$strToSelectRelation = 'Para seleccionar la relacin, d clic en:';
 $strTotal = 'total';
 $strTotalUC = 'Total';
 $strTraditionalChinese = 'Chino tradicional';
@@ -889,10 +947,11 @@ $strTraditionalSpanish = 'Espaol tradicional';
 $strTraffic = 'Trfico';
 $strTransactionCoordinator = 'Coordinador de transaccin';
 $strTransformation_application_octetstream__download = 'Mostrar un enlace para descargar los datos binarios de un campo. La primera opcin es el nombre del archivo binario.  La segunda opcin es un nombre de campo factible de una fila de la tabla que contiene el nombre del campo. Si usted aporta una segunda opcin, necesariamente deber consignar la primera opcin a una cadena de caracteres vaca';
+$strTransformation_application_octetstream__hex = 'Muestra los datos en representacin hexadecimal. El primer parmetro es opcional y especifica cun a menudo se aadir espacio (2 nibbles, es decir, 1 byte de manera predeterminada).';
 $strTransformation_image_jpeg__inline = 'Muestra un thumbnail que puede abrirse mediante un clic; opciones: width, height en pxeles (mantiene la proporcin original)';
 $strTransformation_image_jpeg__link = 'Muestra un enlace a esta imagen (i.e., blob descarga directa).';
 $strTransformation_image_png__inline = 'Ver imagen/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Toma un campo TIME, TIMESTAMP o DATETIME y lo formatea usando su formato de fechas local. La primera opcin es el offset (en horas) que se aadir al timestamp (Predeterminado: 0). La segunda opcin es un dateformat diferente de acuerdo con los parmetros disponibles para el strftime() del PHP.';
+$strTransformation_text_plain__dateformat = 'Toma un campo TIME, TIMESTAMP o DATETIME y lo formatea usando su formato de fechas local. La primera opcin es el offset (en horas) que se aadir al timestamp (Predeterminado: 0). La segunda opcin es un dateformat diferente de acuerdo con los parmetros disponibles para el strftime() del PHP. La tercera opcin determina si usted quiere ver la fecha local o la UTC (use strings "local" o "utc") para eso. Segn eso, el formato de la fecha tendr un valor diferente - para "local" mire la documentacin para la funcin strftime() del PHP y para "utc" se hace usando la funcin gmdate().';
 $strTransformation_text_plain__external = 'LINUX SOLAMENTE: Ejecuta una aplicacin externa y alimenta el fielddata mediante input estndar. Retorna el output estndar de la aplicacin. El predeterminado es Tidy, para mostrar cdigo HTML agradable para la impresin. Por razones de seguridad, debe editar manualmente el archivo libraries/transformations/text_plain__external.inc.php e insertar las herramientas que permitir se ejecuten. La primera opcin ser el nmero del programa que querr utilizar y la segunda opcin son los parmetros para el programa. El tercer parmetro, de ser 1 convertir el output usando htmlspecialchars() (el predeterminado es 1). Un cuarto parmetro, de ser 1 pondr un NOWRAP a la celda de contenido para que todo el output se muestre sin reformatear (Predeterminado 1)';
 $strTransformation_text_plain__formatted = 'Mantiene el formato original del campo. No se puede hacer Escape.';
 $strTransformation_text_plain__imagelink = 'Muestra una imagen y un enlace, el campo contiene el nombre del archivo; la primera opcin es un prefijo como "http://dominio.com/", la segunda opcin es el ancho en pxeles, el tercero es el alto.';
@@ -916,6 +975,7 @@ $strUpdateQuery = 'Modificar la consulta';
 $strUpdComTab = 'Para actualizar su tabla Columna_comentarios (Column_comments), por favor revise la documentacin';
 $strUpgrade = 'Usted debera actualizar su %s a la versin %s o ms reciente.';
 $strUploadLimit = 'Usted probablemente intent cargar un archivo demasiado grande.  Por favor, refirase a %sdocumentation%s para hallar modos de superar esta limitante.';
+$strUploadsNotAllowed = 'No est permitido subir archivos a este servidor.';
 $strUsage = 'Uso';
 $strUseBackquotes = 'Usar "backquotes" con tablas y nombres de campo';
 $strUsedPhpExtensions = 'Extensiones PHP utilizadas';
@@ -942,7 +1002,7 @@ $strViewDumpDatabases = 'Ver el volcado (schema) de la base de datos';
 $strViewDumpDB = 'Ver el volcado esquema de la base de datos';
 $strViewDump = 'Mostrar el volcado esquema de la tabla';
 $strViewHasBeenDropped = 'Se descart el modo de visualizacin %s';
-$strViewMaxExactCount = 'Esta visualizacin tiene ms de %s filas. Por favor, refirase a la %sdocumentation%s.';
+$strViewMaxExactCount = 'Esta visualizacin tiene ms de %s filas. Por favor, refirase a la %sdocumentacin%s.';
 $strView = 'Visualizar';
 
 $strWebServerUploadDirectory = 'directorio en el servidor web para subir los archivos';
@@ -953,10 +1013,9 @@ $strWildcard = 'comodn';
 $strWindowNotFound = 'La ventana del navegador no pudo actualizarse. Quiz cerr la ventana principal o su navegador est bloqueando las actualizaciones en ventanas mltiples debido a sus parmetros de seguridad.';
 $strWithChecked = 'Para los elementos que estn marcados:';
 $strWriteRequests = 'Escribir las solicitudes';
-$strWritingCommentNotPossible = 'No fue posible escribir el comentario';
-$strWritingRelationNotPossible = 'No fue posible escribir la relacin';
 $strWrongUser = 'El nombre de usuario o la contrasea est equivocado. El acceso fue denegado.';
 
+$strXMLOptions = 'Opciones XML';
 $strXML = 'XML';
 
 $strYes = 'S';
@@ -964,39 +1023,4 @@ $strYes = 'S';
 $strZeroRemovesTheLimit = 'Nota: si cambia los parmetros de estas opciones a 0 (cero), remueve el lmite.';
 $strZip = '"comprimido con zip"';
 
-// To translate:
-
-$strQueryResultsOperations = 'Query results operations';  //to translate
-
-$strReloadPrivileges = 'Reload privileges';  //to translate
-
-$strSQLCompatibility = 'SQL compatibility mode';  //to translate
-
-$strTransformation_application_octetstream__hex = 'Muestra los datos en representacin hexadecimal. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
-
-$strAddClause = 'Add %s';  //to translate
-$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
-$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
-$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
-$strCreateUserDatabase = 'Database for user';  //to translate
-$strCreateUserDatabaseNone = 'None';  //to translate
-$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
-$strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
-$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
-$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
-$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
-$strInvalidTableName = 'Invalid table name';  //to translate
-$strInvalidDatabase = 'Invalid database';  //to translate
-$strServers = 'Servers';  //to translate
-$strDelimiter = 'Delimiter';  //to translate
-$strFunctions = 'Functions';  //to translate
-$strProcedures = 'Procedures';  //to translate
-$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
-$strFontSize = 'Font size';  //to translate
-$strLanguage = 'Language';  //to translate
 ?>
