@@ -1,5 +1,5 @@
 <?php
-/* $Id: swedish-utf-8.inc.php,v 2.157.2.1 2006/08/12 19:51:06 lem9 Exp $ */
+/* $Id: swedish-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 /*
  * Translated by Björn T. Hallberg <bjornth at users.sourceforge.net>
@@ -7,6 +7,7 @@
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
+$allow_recoding = TRUE;
 $text_dir = 'ltr';
 $number_thousands_separator = ' ';
 $number_decimal_separator = ',';
@@ -21,7 +22,6 @@ $datefmt = '%d %B %Y kl %H:%M';
 $timespanfmt = '%s dagar, %s timmar, %s minuter och %s sekunder';
 
 $strAbortedClients = 'Avbrutna';
-$strAbsolutePathToDocSqlDir = 'Ange absolut sökväg på webbservern till docSQL-katalog';
 $strAccessDenied = 'Åtkomst nekad';
 $strAccessDeniedCreateConfig = 'Trolig orsak till detta är att du inte skapade en konfigurationsfil. Du vill kanske använda %1$suppsättningsskript%2$s för att skapa en.';
 $strAccessDeniedExplanation = 'phpMyAdmin försökte skapa en förbindelse till MySQL-servern, men servern nekade uppkopplingen. Kontrollera värd, användarnamn och lösenord i config.inc.php och förvissa dig om att de stämmer överens med informationen från administratören av MySQL-servern.';
@@ -31,8 +31,6 @@ $strAddClause = 'Lägg till %s';
 $strAddConstraints = 'Lägg till restriktioner';
 $strAddDeleteColumn = 'Lägg till/ta bort fältkolumner';
 $strAddDeleteRow = 'Lägg till/ta bort villkorsrader';
-$strAddedColumnComment = 'La till kommentar för kolumn';
-$strAddedColumnRelation = 'La till relation för kolumn';
 $strAddFields = 'Lägg till %s fält';
 $strAddHeaderComment = 'Lägg till egen kommentar i huvud (\\n delar rader)';
 $strAddIntoComments = 'Lägg till i kommentarer';
@@ -57,6 +55,7 @@ $strAlterOrderBy = 'Sortera om tabellen efter';
 $strAnalyzeTable = 'Analysera tabell';
 $strAnd = 'Och';
 $strAndThen = 'och sedan';
+$strAngularLinks = 'Vinklade länkar';
 $strAnIndex = 'Ett index har lagts till för %s';
 $strAnyHost = 'Vilken värd som helst';
 $strAnyUser = 'Vilken användare som helst';
@@ -109,6 +108,7 @@ $strBzError = 'phpMyAdmin kunde inte komprimera SQL-satserna på grund av ett tr
 $strBzip = '"bzippad"';
 
 $strCalendar = 'Kalender';
+$strCancel = 'Avbryt';
 $strCanNotLoadExportPlugins = 'Kunde inte ladda export-tillägg. Kontrollera din installation.';
 $strCanNotLoadImportPlugins = 'Kunde inte ladda tillägg för import. Kontrollera din installation!';
 $strCannotLogin = 'Kan ej logga in på MySQL-server';
@@ -171,11 +171,13 @@ $strCreateNewDatabase = 'Skapa ny databas';
 $strCreateNewTable = 'Skapa ny tabell i databas %s';
 $strCreatePage = 'Skapa en ny sida';
 $strCreatePdfFeat = 'Skapande av PDF-sidor';
+$strCreateRelation = 'Skapa relation';
 $strCreate = 'Skapa';
+$strCreateTable  = 'Skapa tabell';
 $strCreateUserDatabase = 'Databas för användare';
 $strCreateUserDatabaseName = 'Skapa databas med samma namn och ge alla privilegier';
 $strCreateUserDatabaseNone = 'Ingen';
-$strCreateUserDatabaseWildcard = 'Ge alla privilegier till namn med jokertecken (username_%)';
+$strCreateUserDatabaseWildcard = 'Ge alla privilegier till namn med jokertecken (username\_%)';
 $strCreationDates = 'Skapad/Uppdaterad/Kontrollerad datum';
 $strCriteria = 'Villkor';
 $strCroatian = 'Kroatisk';
@@ -204,15 +206,7 @@ $strDataOnly = 'Enbart data';
 $strDataPages = 'Sidor innehållande data';
 $strDBComment = 'Databaskommentar: ';
 $strDBCopy = 'Kopiera databas till';
-$strDBGContextID = 'Innehålls-ID';
-$strDBGContext = 'Innehåll';
-$strDBGHits = 'Träffar';
-$strDBGLine = 'Rad';
-$strDBGMaxTimeMs = 'Max tid, ms';
-$strDBGMinTimeMs = 'Min tid, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Tid/träff, ms';
-$strDBGTotalTimeMs = 'Total tid, ms';
+$strDbIsEmpty = 'Databasen verkar vara tom!';
 $strDbPrivileges = 'Databasspecifika privilegier';
 $strDBRename = 'Döp om databasen till';
 $strDbSpecific = 'databasspecifik';
@@ -227,12 +221,16 @@ $strDeleted = 'Raden har raderats';
 $strDeletedRows = 'Raderade rader';
 $strDeleteNoUsersSelected = 'Inga användare valda för borttagning!';
 $strDelete = 'Radera';
+$strDeleteRelation = 'Ta bort relation';
 $strDeleting = 'Tar bort %s';
 $strDelimiter = 'Avgränsare';
 $strDelOld = 'Nuvarande sida har referenser till tabeller som inte längre existerar. Vill du ta bort dessa referenser?';
 $strDescending = 'Fallande';
 $strDescription = 'Beskrivning';
+$strDesigner = 'Designer';
+$strDesignerHelpDisplayField = 'Visningsfältet visas i rosa. För att ange ett fält som visningsfält, klicka på ikonen "Välj fält som ska visas" och klicka sedan på lämpligt fältnamn.';
 $strDictionary = 'lexikon';
+$strDirectLinks = 'Direkta länkar';
 $strDirtyPages = 'Orena sidor';
 $strDisabled = 'Inaktiverat';
 $strDisableForeignChecks = 'Stäng av kontroll av främmande nycklar';
@@ -240,6 +238,8 @@ $strDisplayFeat = 'Visningsfunktionaliteter';
 $strDisplayOrder = 'Visningsordning:';
 $strDisplayPDF = 'Visa PDF-schema';
 $strDoAQuery = 'Utför en "Query By Example" (jokertecken: "%")';
+$strDocSQL = 'DocSQL';
+$strDocSQLOptions = 'DocSQL-alternativ';
 $strDocu = 'Dokumentation';
 $strDoYouReally = 'Vill du verkligen ';
 $strDropDatabaseStrongWarning = 'Du håller på att FÖRGÖRA en hel databas!';
@@ -269,7 +269,10 @@ $strEnglish = 'Engelsk';
 $strEnglishPrivileges = ' Obs! MySQL-privilegiumnamn anges på engelska ';
 $strError = 'Fel';
 $strErrorInZipFile = 'Fel i ZIP-arkiv:';
+$strErrorRelationAdded = 'Fel: Relation inte tillagd.';
+$strErrorRelationExists = 'Fel: Relation finns redan.';
 $strErrorRenamingTable = 'Fel vid namnbyte på tabell %1$s till %2$s';
+$strErrorSaveTable = 'Fel vid sparande av koordinater för Designer.';
 $strEscapeWildcards = 'Jokerteknen _ och % måste föregås av ett \ för att användas i egentlig betydelse';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estnisk';
@@ -278,6 +281,7 @@ $strExcelOptions = 'Excel-alternativ';
 $strExecuteBookmarked = 'Utför bokmärkt fråga';
 $strExplain = 'Förklara SQL-kod';
 $strExport = 'Exportera';
+$strExportImportToScale = 'Exportera/importera till skala';
 $strExportMustBeFile = 'Vald export-typ måste sparas i fil!';
 $strExtendedInserts = 'Utökade infogningar';
 $strExtra = 'Extra';
@@ -305,6 +309,7 @@ $strFlushQueryCache = 'Rensa frågecache';
 $strFlushTable = 'Rensa tabell';
 $strFlushTables = 'Stäng alla tabeller';
 $strFontSize = 'Teckenstorlek';
+$strForeignKeyError = 'Fel vid skapande av främmande nyckel (kontrollera datatyper)';
 $strFormat = 'Format';
 $strFormEmpty = 'Värde saknas i formuläret!';
 $strFreePages = 'Fria sidor';
@@ -332,7 +337,11 @@ $strHasBeenAltered = 'har ändrats.';
 $strHasBeenCreated = 'har skapats.';
 $strHaveToShow = 'Du måste välja minst en kolumn som ska visas';
 $strHebrew = 'Hebreisk';
+$strHelp = 'Hjälp';
 $strHexForBinary = 'Använd hexadecimalt för binära fält';
+$strHide = 'Dölj';
+$strHideShowAll = 'Dölj/visa alla';
+$strHideShowNoRelation = 'Dölj/visa tabeller utan relationer';
 $strHome = 'Hem';
 $strHomepageOfficial = 'phpMyAdmin:s officiella hemsida';
 $strHostEmpty = 'Värdnamnet är tomt!';
@@ -346,11 +355,11 @@ $strHungarian = 'Ungersk';
 $strIcelandic = 'Isländska';
 $strId = 'ID';
 $strIdxFulltext = 'Heltext';
+$strIEUnsupported = 'Internet Explorer saknar stöd för denna funktion.';
 $strIgnoreDuplicates = 'Ignorera dubblerade rader';
 $strIgnore = 'Ignorera';
 $strIgnoreInserts = 'Använd IGNORE i infogningar';
-$strIgnoringFile = 'Ignorerar fil %s';
-$strImportDocSQL = 'Importera docSQL-filer';
+$strImportExportCoords = 'Importera/exportera koordinater för PDF-schema';
 $strImportFiles = 'Importera filer';
 $strImportFormat = 'Format på importerad fil';
 $strImport = 'Importera';
@@ -372,6 +381,7 @@ $strInnoDBDataFilePath = 'Datafiler';
 $strInnoDBDataHomeDirDesc = 'Den gemensamma delen av sökvägen för alla InnoDB-datafiler.';
 $strInnoDBDataHomeDir = 'Hemkatalog för data';
 $strInnoDBPages = 'sidor';
+$strInnoDBRelationAdded = 'InnoDB relation tillagd';
 $strInnodbStat = 'InnoDB-status';
 $strInsecureMySQL = 'Din konfigurationsfil innehåller inställningar (root-konto utan lösenord) som motsvarar MySQL:s privilegierade standardkonto. Din MySQL-server körs med denna standardinställning och är öppen för intrång, så du bör verkligen täppa till detta säkerhetshål.';
 $strInsertAsNewRow = 'Lägg till som ny rad';
@@ -379,6 +389,7 @@ $strInsertedRowId = 'Tillagd rads id:';
 $strInsertedRows = 'Tillagda rader:';
 $strInsert = 'Lägg till';
 $strInternalNotNecessary = '* En intern relation är inte nödvändig när den även finns i InnoDB.';
+$strInternalRelationAdded = 'Intern relation tillagd';
 $strInternalRelations = 'Interna relationer';
 $strInUse = 'används';
 $strInvalidAuthMethod = 'Ogiltig metod för autentisering angiven i konfiguration:';
@@ -406,6 +417,7 @@ $strKeepPass = 'Ändra inte lösenordet';
 $strKeyCache = 'Nyckelcache';
 $strKeyname = 'Nyckel';;
 $strKill = 'Döda';
+$strKnownExternalBug = 'Funktionaliteten för %s påverkas av en känd bugg, se %s';
 $strKorean = 'Koreansk';
 
 $strLandscape = 'Liggande';
@@ -453,7 +465,7 @@ $strMIME_description = 'Beskrivning';
 $strMIME_MIMEtype = 'MIME-typ';
 $strMIME_nodescription = 'Ingen beskrivning för denna omvandling finns tillgänglig.<br />Vänligen fråga upphovsmannen vad %s gör.';
 $strMIME_transformation_note = 'För en lista med tillgängliga omvandlingsparametrar och deras MIME-typomvandlingar, klicka på %somvandlingsbeskrivningar%s';
-$strMIME_transformation_options_note = 'Ange värdena för omvandlingsparametrar enligt följande format: \'a\',\'b\',\'c\'...<br />Om du behöver lägga till ett bakåtstreck ("\") eller ett enkelcitat ("\'") i värdena, skriv ett bakåtstreck före tecknet (t.ex. \'\\\\xyz\' eller \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Ange värdena för omvandlingsparametrar enligt följande format: \'a\', 100, b,\'c\'...<br />Om du behöver lägga till ett bakåtstreck ("\") eller ett enkelcitat ("\'") i värdena, skriv ett bakåtstreck före tecknet (t.ex. \'\\\\xyz\' eller \'a\\\'b\').';
 $strMIME_transformation_options = 'Omvandlingsparametrar';
 $strMIME_transformation = 'Webbläsaromvandling';
 $strMIMETypesForTable = 'MIME-TYPER FÖR TABELL';
@@ -461,6 +473,7 @@ $strMIME_without = 'Kursiverade MIME-typer har inte någon separat omvandlingsfu
 $strModifications = 'Ändringarna har sparats';
 $strModify = 'Ändra';
 $strModifyIndexTopic = 'Ändra ett index';
+$strMoveMenu = 'Flytta meny';
 $strMoveTable = 'Flytta tabellen till (databas<b>.</b>tabell):';
 $strMoveTableOK = 'Tabellen %s har flyttats till %s.';
 $strMoveTableSameNames = 'Kan inte flytta tabell till samma namn!';
@@ -519,6 +532,7 @@ $strNoUsersFound = 'Hittade ingen användare.';
 $strNoValidateSQL = 'Utan SQL-validering';
 $strNull = 'Null';
 $strNumberOfFields = 'Antal fält';
+$strNumberOfTables = 'Antal tabeller';
 $strNumSearchResultsInTable = '%s träff(ar) i tabell <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Totalt:</b> <i>%s</i> träff(ar)';
 $strNumTables = 'Tabeller';
@@ -561,8 +575,10 @@ $strPhoneBook = 'telefonbok';
 $strPHP40203 = 'Du använder PHP 4.2.3, vilken har en allvarlig bugg med multi-byte-strängar (mbstring). Se PHP:s buggrapport 19404. Denna version av PHP är inte rekommenderad för användning tillsammans med phpMyAdmin.';
 $strPhp = 'Skapa PHP-kod';
 $strPHPVersion = 'PHP-version';
+$strPleaseSelectPrimaryOrUniqueKey = 'Välj den primära nyckeln eller en unik nyckel';
 $strPmaDocumentation = 'phpMyAdmin dokumentation';
 $strPmaUriError = 'Variabeln <tt>$cfg[\'PmaAbsoluteUri\']</tt> MÅSTE anges i din konfigurationsfil!';
+$strPmaWiki = 'phpMyAdmin wiki';
 $strPolish = 'Polska';
 $strPortrait = 'Stående';
 $strPos1 = 'Början';
@@ -633,16 +649,19 @@ $strQueryWindowLock = 'Skriv inte över denna fråga utifrån detta fönster';
 
 $strReadRequests = 'Läsefterfrågningar';
 $strReceived = 'Mottagna';
+$strRecommended = 'rekommenderad';
 $strRecords = 'Rader';
 $strReferentialIntegrity = 'Kontrollera referensintegritet:';
 $strRefresh = 'Uppdatera';
 $strRelationalSchema = 'Relationsschema';
+$strRelationDeleted = 'Relation borttagen';
 $strRelationNotWorking = 'Den extra funktionaliteten för att hantera länkade tabeller har inaktiverats. %sVisa orsaken%s.';
 $strRelationsForTable = 'RELATIONER FÖR TABELL';
 $strRelations = 'Relationer';
 $strRelationView = 'Visa relationer';
 $strReloadingThePrivileges = 'Laddar om privilegierna';
 $strReloadPrivileges = 'Ladda om privilegier';
+$strReload = 'Uppdatera';
 $strRemoveSelectedUsers = 'Ta bort markerade användare';
 $strRenameDatabaseOK = 'Databas %s har döpts om till %s';
 $strRenameTable = 'Döp om tabellen till';
@@ -675,6 +694,7 @@ $strRunSQLQueryOnServer = 'Kör SQL-fråga/frågor på server %s';
 $strRussian = 'Rysk';
 
 $strSaveOnServer = 'Spara på servern i katalogen %s';
+$strSavePosition = 'Spara position';
 $strSave = 'Spara';
 $strScaleFactorSmall = 'Skalfaktorn är för liten för att schemat ska få plats på en sida';
 $strSearchFormTitle = 'Sök i databas';
@@ -692,7 +712,9 @@ $strSelectADb = 'Välj en databas';
 $strSelectAll = 'Markera alla';
 $strSelectBinaryLog = 'Välj binär logg att visa';
 $strSelectFields = 'Välj fält (minst ett):';
+$strSelectForeignKey = 'Välj främmande nyckel';
 $strSelectNumRows = 'i fråga';
+$strSelectReferencedKey = 'Välj refererad nyckel';
 $strSelectTables = 'Välj tabeller';
 $strSend = 'Spara som fil';
 $strSent = 'Skickade';
@@ -714,8 +736,11 @@ $strShowColor = 'Visa färger';
 $strShowDatadictAs = 'Format för datalexikon';
 $strShowFullQueries = 'Visa fullständiga frågor';
 $strShowGrid = 'Visa rutnät';
+$strShowHideLeftMenu = 'Visa/Dölj vänster meny';
 $strShowingBookmark = 'Visar bokmärke';
+$strShowingPhp = 'Visar som PHP-kod';
 $strShowingRecords = 'Visar rader ';
+$strShowingSQL = 'Visar SQL-fråga';
 $strShowOpenTables = 'Visa öppna tabeller';
 $strShowPHPInfo = 'Visa PHP-information';
 $strShowSlaveHosts = 'Visa slav-värdar';
@@ -837,6 +862,8 @@ $strSize = 'Storlek';
 $strSkipQueries = 'Antal poster (rader) att hoppa över från början';
 $strSlovak = 'Slovakiska';
 $strSlovenian = 'Slovenska';
+$strSmallBigAll = 'Små/stora alla';
+$strSnapToGrid = 'Fäst vid rutnät';
 $strSocketProblem = '(eller den lokala MySQL-serverns socket är inte korrekt konfigurerad)';
 $strSortByKey = 'Sortera efter nyckel';
 $strSorting = 'Sortering';
@@ -856,6 +883,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Ogiltig identifierare';
 $strSQPBugUnclosedQuote = 'Oavslutat citat';
 $strSQPBugUnknownPunctuation = 'Okänd interpunktion i sträng';
+$strStandInStructureForView = 'Ersättningsstruktur för visning';
 $strStatCheckTime = 'Senaste kontroll';
 $strStatCreateTime = 'Skapades';
 $strStatement = 'Uppgift';
@@ -871,6 +899,7 @@ $strStrucNativeExcel = 'Naturlig MS Excel-data';
 $strStrucNativeExcelOptions = 'Ursprunglig Excel exportalternativ';
 $strStrucOnly = 'Enbart struktur';
 $strStructPropose = 'Föreslå tabellstruktur';
+$strStructureForView = 'Struktur för visning';
 $strStructure = 'Struktur';
 $strSubmit = 'Sänd';
 $strSuccess = 'Din SQL-fråga utfördes korrekt';
@@ -885,7 +914,9 @@ $strTableEmpty = 'Tabellnamnet är tomt!';
 $strTableHasBeenDropped = 'Tabellen %s har tagits bort';
 $strTableHasBeenEmptied = 'Tabellen %s har tömts';
 $strTableHasBeenFlushed = 'Tabellen %s har rensats';
+$strTableIsEmpty = 'Tabellen verkar vara tom!';
 $strTableMaintenance = 'Tabellunderhåll';
+$strTableName = 'Tabellnamn';
 $strTableOfContents = 'Innehållsförteckning';
 $strTableOptions = 'Tabellalternativ';
 $strTables = '%s tabell(er)';
@@ -903,14 +934,16 @@ $strThemeNoValidImgPath = 'Ingen giltig sökväg till bilder för tema %s hittad
 $strThemePathNotFound = 'Temats sökväg för tema %s hittades inte!';
 $strTheme = 'Tema / Stil';
 $strThisHost = 'Denna värd';
-$strThisNotDirectory = 'Detta var inte en katalog';
 $strThreads = 'Trådar';
 $strThreadSuccessfullyKilled = 'Tråd %s dödades med framgång.';
 $strTimeoutInfo = 'Tidsbegränsningen överskreds vid föregående import. Efter återupptagning av importen kommer den fortsätta från position %d.';
 $strTimeoutNothingParsed = 'Dock blev inga data bearbetade i senaste körningen. Detta betyder vanligtvis att phpMyAdmin inte kan slutföra denna import såvida du inte ökar php:s tidsbegränsningar.';
 $strTimeoutPassed = 'Skriptets tidsbegränsning har överskridits. Om du vill slutföra importen, importera samma fil igen så kommer importen att återupptas.';
 $strTime = 'Tid';
+$strToFromPage = 'till/från sida';
 $strToggleScratchboard = 'Visa/dölj skisstavla';
+$strToggleSmallBig = 'Växla liten/stor';
+$strToSelectRelation = 'För att välja relation, klicka :';
 $strTotal = 'totalt';
 $strTotalUC = 'Totalt';
 $strTraditionalChinese = 'Traditionell kinesiska';
@@ -922,7 +955,7 @@ $strTransformation_application_octetstream__hex = 'Visar hexadecimal representat
 $strTransformation_image_jpeg__inline = 'Visar en klickbar tumnagelbild. Parametrarna är maximal bredd och höjd i pixlar. Bildens ursprungliga proportioner bibehålls.';
 $strTransformation_image_jpeg__link = 'Visar en länk för att ladda ner denna bild.';
 $strTransformation_image_png__inline = 'Se image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Visar ett TIME, TIMESTAMP eller DATETIME-fält enligt ditt lokala datum-/tidsformat. Första parametern är förskjutningen (i timmar) som kommer att läggas till tidsstämpeln (standardvärde: 0). Använd andra parametern för att ange ett annat datum-/tidsformat; se dokumentationen för PHP:s funktion strftime().';
+$strTransformation_text_plain__dateformat = 'Visar en TIME, TIMESTAMP, DATETIME eller numerisk unix tidsstämpel som ett formaterat datum. Första parametern är förskjutning (i timmar) som kommer adderas till tidsstämpeln (standardvärde: 0). Använd andra parametern för att ange ett annorlunda datum/tid-format. Tredje parametern avgör ifall du vill se lokalt datum eller UTC (ange "local" eller "utc"). Enligt detta har datumformatet olika värden - för "local" se dokumentationen för PHP:s funktion strftime() och för "utc" se funktionen gmdate().';
 $strTransformation_text_plain__external = 'ENDAST LINUX: Startar en extern applikation och skickar fältdata till den via standard-indata. Returnerar applikationens standard-utdata. Standard är Tidy, för att snygga till HTML-kod. Av säkerhetsskäl måste du manuellt redigera filen libraries/transformations/text_plain__external.inc.php och infoga verktygen du vill tillåta ska få köras. Den första parametern är då numret för det program som du vill använda och den andra parametern är parametrarna för programmet. Om den tredje parametern sätts till 1 kommer utdata konverteras mha htmlspecialchars() (standardvärde: 1). Om den fjärde parametern sätts till 1 kommer radbrytning att undvikas så att all utdata kommer att visas på en rad (standardvärde: 1).';
 $strTransformation_text_plain__formatted = 'Visar innehållet i fältet som det är, utan att köra det genom htmlspecialchars(). Det innebär att fältet antas innehålla korrekt HTML-kod.';
 $strTransformation_text_plain__imagelink = 'Visar en bild och en länk; fältet innehåller filnamnet. Första parametern är ett URL-prefix såsom "http://www.example.com/". Andra och tredje parametern är bredden och höjden i pixlar.';
@@ -984,8 +1017,6 @@ $strWildcard = 'jokertecken';
 $strWindowNotFound = 'Målfönstret kunde inte uppdateras. Orsaken kan vara att du stängt föräldrafönstret eller att din webbläsares säkerhetsinställningar blockerar uppdateringar mellan fönster.';
 $strWithChecked = 'Med markerade:';
 $strWriteRequests = 'Skrivefterfrågningar';
-$strWritingCommentNotPossible = 'Skrivning av kommentar inte möjlig';
-$strWritingRelationNotPossible = 'Skrivning av relation inte möjlig';
 $strWrongUser = 'Fel användarnamn/lösenord. Åtkomst nekad.';
 
 $strXMLOptions = 'XML-alternativ';
