@@ -1,5 +1,5 @@
 <?php
-/* $Id: thai-utf-8.inc.php,v 2.142 2006/08/09 12:55:40 lem9 Exp $ */
+/* $Id: thai-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 // first created 2002/04/29 Arthit Suriyawongkul & Warit Wanasathian
 // last modified 2004/08/22 Arthit Suriyawongkul
@@ -21,14 +21,11 @@ $datefmt = '%d %B %Y  %Rน.';
 $timespanfmt = '%s วัน, %s ชั่วโมง, %s นาที, %s วินาที';
 
 $strAbortedClients = 'ยกเลิก';
-$strAbsolutePathToDocSqlDir = 'กรุณาใส่ absolute path ของไดเรกทอรี docSQL บนเว็บเซิร์ฟเวอร์';
 $strAccessDenied = 'ไม่อนุญาตให้ใช้งาน';
 $strAction = 'กระทำการ';
 $strAddAutoIncrement = 'เพิ่มค่า AUTO_INCREMENT';
 $strAddDeleteColumn = 'เพิ่ม/ลบ คอลัมน์ (ฟิลด์)';
 $strAddDeleteRow = 'เพิ่ม/ลบ แถว';
-$strAddedColumnComment = 'เพิ่ม หมายเหตุ สำหรับคอลัมน์';
-$strAddedColumnRelation = 'เพิ่ม รีเลชัน สำหรับคอลัมน์';
 $strAddNewField = 'เพิ่มฟิลด์ใหม่';
 $strAddPrivilegesOnDb = 'เพิ่มสิทธิของฐานข้อมูลต่อไปนี้';
 $strAddPrivilegesOnTbl = 'เพิ่มสิทธิของตารางต่อไปนี้';
@@ -147,15 +144,6 @@ $strDatabasesStatsHeavyTraffic = 'โปรดทราบ: การเปิ
 $strDataDict = 'พจนานุกรมข้อมูล';
 $strDataOnly = 'เฉพาะข้อมูล';
 $strDBComment = 'หมายเหตุของฐานข้อมูล: ';
-$strDBGContext = 'คอนเท็กซ์';
-$strDBGContextID = 'หมายเลขคอนเท็กซ์';
-$strDBGHits = 'ฮิต';
-$strDBGLine = 'บรรทัด';
-$strDBGMaxTimeMs = 'เวลามากสุด, มิลลิวินาที';
-$strDBGMinTimeMs = 'เวลาน้อยสุด, มิลลิวินาที';
-$strDBGModule = 'โมดูล';
-$strDBGTimePerHitMs = 'เวลา/ฮิต, มิลลิวินาที';
-$strDBGTotalTimeMs = 'เวลาทั้งหมด, มิลลิวินาที';
 $strDbPrivileges = 'สิทธิเจาะจงเฉพาะฐานข้อมูล';
 $strDBRename = 'เปลี่ยนชื่อฐานข้อมูลเป็น';
 $strDbSpecific = 'เฉพาะฐานข้อมูล';
@@ -249,8 +237,6 @@ $strIcelandic = 'ไอซ์แลนด์';
 $strId = 'ID';
 $strIdxFulltext = 'ข้อความเต็ม (fulltext)';
 $strIgnore = 'ไม่สนใจ';
-$strIgnoringFile = 'ไม่สนใจไฟล์ %s';
-$strImportDocSQL = 'นำเข้าไฟล์ docSQL';
 $strImportFiles = 'นำเข้าไฟล์';
 $strIndex = 'ดัชนี';
 $strIndexes = 'ดัชนี';
@@ -555,7 +541,6 @@ $strTextAreaLength = 'เนื่องจากความยาวของ
 $strThai = 'ไทย';
 $strTheme = 'หน้าตา';
 $strThisHost = 'โฮสต์นี้';
-$strThisNotDirectory = 'นี่ไม่ใช่ไดเรกทอรี';
 $strThreadSuccessfullyKilled = 'เธรด %s ถูกทำลายเรียบร้อยแล้ว.';
 $strTime = 'เวลา';
 $strTotal = 'ทั้งหมด';
@@ -608,8 +593,6 @@ $strWelcome = '%s ยินดีต้อนรับ';
 $strWestEuropean = 'ยุโรปตะวันตก';
 $strWildcard = 'ไวล์การ์ด';
 $strWithChecked = 'ทำกับที่เลือก:';
-$strWritingCommentNotPossible = 'การเขียนหมายเหตุนั้นเป็นไปไม่ได้';
-$strWritingRelationNotPossible = 'การเขียนรีเลชันนั้นเป็นไปไม่ได้';
 $strWrongUser = 'อนุญาตให้เข้าใช้ไม่ได้ ชื่อผู้ใช้หรือรหัสผ่านผิด';
 
 $strXML = 'XML';
@@ -770,7 +753,7 @@ $strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem
 $strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
 $strMIME_transformation = 'Browser transformation';//to translate
 $strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s';//to translate
-$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';//to translate
+$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\', 100, b,\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';//to translate
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
 $strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function';//to translate
 $strMyISAMDataPointerSize = 'Data pointer size';  //to translate
@@ -971,7 +954,6 @@ $strToggleScratchboard = 'toggle scratchboard';  //to translate
 $strTransactionCoordinator = 'Transaction coordinator';  //to translate
 $strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
 $strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
-$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';//to translate
 $strTransformation_text_plain__external = 'สำหรับ ลีนุกซ์ เท่านั้น: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';//to translate
 $strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';  //to translate
 $strTransformation_text_plain__link = 'Displays a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is a title for the link.';  //to translate
@@ -1005,7 +987,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1020,4 +1002,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
