@@ -1,5 +1,5 @@
 <?php
-/* $Id: ukrainian-utf-8.inc.php,v 2.142 2006/08/09 12:55:40 lem9 Exp $ */
+/* $Id: ukrainian-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -19,14 +19,11 @@ $datefmt = '%B %d %Y р., %H:%M';
 $timespanfmt = '%s днів, %s годин, %s хвилин і %s секунд';
 
 $strAbortedClients = 'Перервано';
-$strAbsolutePathToDocSqlDir = 'Прошу задати абсолютний шлях на веб-сервері до каталогу docSQL';
 $strAccessDeniedExplanation = 'phpMyAdmin спробував з\'єднатися з MySQL сервером, але сервер не дозволив під\'єднання. Прошу перевірити значення host, username та password у файлі config.inc.php та впевнитися, що вони відповідають даним отриманим Вами від адміністратора MySQL сервера.';
 $strAccessDenied = 'Доступ заборонено';
 $strAction = 'Дія';
 $strAddDeleteColumn = 'Додати/забрати колонку критерію';
 $strAddDeleteRow = 'Додати/забрати рядок критерію';
-$strAddedColumnComment = 'Додано коментар до колонки';
-$strAddedColumnRelation = 'Додано зв\'язок для колонки';
 $strAddIntoComments = 'Додати коментар';
 $strAddNewField = 'Додати нове поле';
 $strAddPrivilegesOnDb = 'Додати права для цієї бази даних';
@@ -146,15 +143,6 @@ $strDataDict = 'Словник даних';
 $strDataOnly = 'Лише дані';
 $strData = 'Дані';
 $strDBComment = 'Коментар бази даних: ';
-$strDBGContextID = 'Контекст ID';
-$strDBGContext = 'Контекст';
-$strDBGHits = 'Hits';
-$strDBGLine = 'Рядок';
-$strDBGMaxTimeMs = 'Макс час, мс';
-$strDBGMinTimeMs = 'Мін час, мс';
-$strDBGModule = 'Модуль';
-$strDBGTimePerHitMs = 'Time/Hit, мс';
-$strDBGTotalTimeMs = 'Загальний час, мс';
 $strDbPrivileges = 'Права, які стосуються бази даних';
 $strDbSpecific = 'специфічний для бази даних';
 $strDefaultValueHelp = 'Для значень за замовчуванням, введіть лише значення, без використання зворотніх слешів чи лапок, у такому форматі: a';
@@ -249,8 +237,6 @@ $strHungarian = 'Мадярське';
 $strId = 'ID';
 $strIdxFulltext = 'ПовнТекст';
 $strIgnore = 'Ігноруровати';
-$strIgnoringFile = 'Проіґноровано файл %s';
-$strImportDocSQL = 'Імпортувати docSQL файли';
 $strImportFiles = 'Імпорт файлів';
 $strIndexes = 'Індекси';
 $strIndexHasBeenDropped = 'Індекс %s було знищено';
@@ -298,7 +284,7 @@ $strMIME_description = 'Опис';
 $strMIME_MIMEtype = 'MIME-type';
 $strMIME_nodescription = 'Немає опису для цього перетворення.<br />Прошу питатися автора, що робить %s.';
 $strMIME_transformation_note = 'Щоб отримати список можливих опцій і їх MIME-type перетворень, натисніть %sописи перетворень%s';
-$strMIME_transformation_options_note = 'Прошу вписати значення опцій перетворення у такому форматі: \'a\',\'b\',\'c\'...<br />Якщо необхідно подати зворотній слеш ("\") чи поодинокі лапки ("\'") у цих значеннях, поставте перед ними додатковий зворотній слеш (наприклад \'\\\\xyz\' чи \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Прошу вписати значення опцій перетворення у такому форматі: \'a\', 100, b,\'c\'...<br />Якщо необхідно подати зворотній слеш ("\") чи поодинокі лапки ("\'") у цих значеннях, поставте перед ними додатковий зворотній слеш (наприклад \'\\\\xyz\' чи \'a\\\'b\').';
 $strMIME_transformation_options = 'Опції перетворення';
 $strMIME_transformation = 'Перетворення МІМЕ-типу бровзером';
 $strMIME_without = 'MIME-types подані курсивом не мають окремих функцій перетворення';
@@ -551,7 +537,6 @@ $strTblPrivileges = 'Права, які стосуються таблиці';
 $strTextAreaLength = ' Через велику довжину,<br /> це поле не може бути відредаговано ';
 $strThai = 'Тайське';
 $strThisHost = 'Цей хост';
-$strThisNotDirectory = 'Це не каталог';
 $strThreadSuccessfullyKilled = 'Процес %s припинено.';
 $strTime = 'Час';
 $strToggleScratchboard = 'ввімкнути чорновик (scratchboard)';
@@ -562,7 +547,6 @@ $strTraffic = 'Трафік';
 $strTransformation_image_jpeg__inline = 'Відображає clickable thumbnail; опції: ширина, висота у пікселах (зберігає початкові пропорції)';
 $strTransformation_image_jpeg__link = 'Відображає лінк до цього малюнку (direct blob download, i.e.).';
 $strTransformation_image_png__inline = 'Див. image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Взяти поле TIME, TIMESTAMP чи DATETIME і сформатувати його відповідно до локального формату дати. Перша опція - це інтервал (в годинах) який буде додано до часової мітки (за замовчуванням: 0). Друга опція - інший формат дати відповідно до параметрів заданих для PHP strftime().';
 $strTransformation_text_plain__external = 'LINUX ONLY: Запускає зовнішню програму і подає дані через стандартний ввід. Повертає снаддартний вивід програми. За замовчуванням програмою є Tidy, яка гарно друкує HTML код. З міркувань безпеки, Вам потрібно самостійно відредагувати файл libraries/transformations/text_plain__external.inc.php та вписати програми дозволені для запуску. У такому випадку, перша опція - кількість програм, які Ви бажаєте використовувати і друга - параметри для програм. Третя опція, встановлена в 1, буде ковертувати вивід використовуючи htmlspecialchars() (за замовчуванням: 1). Четверта опція, встановлена в 1, буде додавати NOWRAP до кожної комірки контенту, так що веси вивід буде показано без переформатування (за замовчуванням: 1)';
 $strTransformation_text_plain__formatted = 'Зберігає початкове форматування поля. Не вносяться модифікації.';
 $strTransformation_text_plain__imagelink = 'Показує малюнок і лінк, поле містить назву файлу; перша опція - префікс, подібно до "http://domain.com/", друга - ширина в пікселах, третя - висота.';
@@ -610,8 +594,6 @@ $strWelcome = 'Ласкаво просимо до %s';
 $strWestEuropean = 'Західно Європейське';
 $strWildcard = 'шаблон';
 $strWithChecked = 'З відміченими:';
-$strWritingCommentNotPossible = 'Неможливо додати коментар';
-$strWritingRelationNotPossible = 'Неможливо додати зв\'язок';
 $strWrongUser = 'Невірний логін/пароль. Доступ не дозволено.';
 
 $strXML = 'XML';
@@ -1003,7 +985,7 @@ $strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
 $strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
@@ -1018,4 +1000,52 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strDocSQLOptions = 'DocSQL options';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
 ?>
