@@ -1,11 +1,26 @@
 <?php
-/* $Id: htmlexcel.php,v 1.2.2.1 2006/03/16 13:30:39 nijel Exp $ */
+/* $Id: htmlexcel.php 9315 2006-08-16 09:10:23Z nijel $ */
 // vim: expandtab sw=4 ts=4 sts=4:
 
 /**
  * Set of functions used to build CSV dumps of tables
  */
 
+if (isset($plugin_list)) {
+    $plugin_list['htmlexcel'] = array(
+        'text' => 'strHTMLExcel',
+        'extension' => 'xls',
+        'mime_type' => 'application/vnd.ms-excel',
+        'force_file' => true,
+        'options' => array(
+            array('type' => 'text', 'name' => 'null', 'text' => 'strReplaceNULLBy'),
+            array('type' => 'bool', 'name' => 'columns', 'text' => 'strPutColNames'),
+            array('type' => 'hidden', 'name' => 'data'),
+            ),
+        'options_text' => 'strHTMLExcelOptions',
+        );
+} else {
+
 /**
  * Outputs comment
  *
@@ -53,7 +68,7 @@ xmlns="http://www.w3.org/TR/REC-html40">
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html>
 <head>
-	<meta http-equiv="Content-type" content="text/html;charset=<?php echo isset($charset_of_file) ? $charset_of_file : $charset; ?>" />
+	<meta http-equiv="Content-type" content="text/html;charset=' . ( isset($charset_of_file) ? $charset_of_file : $charset ) .'" />
 <style id="Classeur1_16681_Styles">
 </style>
 
@@ -130,7 +145,7 @@ function PMA_exportData($db, $table, $crlf, $error_url, $sql_query) {
     $fields_cnt  = PMA_DBI_num_fields($result);
 
     // If required, get fields name at the first line
-    if (isset($GLOBALS[$what . '_shownames']) && $GLOBALS[$what . '_shownames'] == 'yes') {
+    if (isset($GLOBALS[$what . '_columns'])) {
         $schema_insert = '<tr>';
         for ($i = 0; $i < $fields_cnt; $i++) {
             $schema_insert .= '<td class=xl2216681 nowrap><b>' . htmlspecialchars(stripslashes(PMA_DBI_field_name($result, $i))) . '</b></td>';
@@ -146,7 +161,7 @@ function PMA_exportData($db, $table, $crlf, $error_url, $sql_query) {
         $schema_insert = '<tr>';
         for ($j = 0; $j < $fields_cnt; $j++) {
             if (!isset($row[$j]) || is_null($row[$j])) {
-                $value = $GLOBALS[$what . '_replace_null'];
+                $value = $GLOBALS[$what . '_null'];
             } elseif ($row[$j] == '0' || $row[$j] != '') {
                 $value = $row[$j];
             } else {
@@ -163,4 +178,6 @@ function PMA_exportData($db, $table, $crlf, $error_url, $sql_query) {
 
     return TRUE;
 }
+
+}
 ?>
