@@ -1,5 +1,5 @@
 <?php
-/* $Id: sqlparser.data.php,v 2.25.2.1 2006/08/12 19:14:11 lem9 Exp $ */
+/* $Id: sqlparser.data.php 10061 2007-03-04 14:07:42Z lem9 $ */
 // vim: expandtab sw=4 ts=4 sts=4:
 
 
@@ -29,12 +29,18 @@ $PMA_SQPdata_function_name = array (
     'ADDTIME',
     'AES_DECRYPT',
     'AES_ENCRYPT',
-    'AREA',                     // polygon-property-functions.html
+    'AREA',                     // Area() polygon-property-functions.html
+    'ASBINARY',                 // AsBinary()
     'ASCII',
     'ASIN',
+    'ASTEXT',                   // AsText()
     'ATAN',
     'ATAN2',
     'AVG',
+    'BDMPOLYFROMTEXT',          // BdMPolyFromText()
+    'BDMPOLYFROMWKB',           // BdMPolyFromWKB()
+    'BDPOLYFROMTEXT',           // BdPolyFromText()
+    'BDPOLYFROMWKB',            // BdPolyFromWKB()
     'BENCHMARK',
     'BIN',
     'BIT_AND',
@@ -42,11 +48,12 @@ $PMA_SQPdata_function_name = array (
     'BIT_LENGTH',
     'BIT_OR',
     'BIT_XOR',                  // group-by-functions.html
-    'Boundary',                 // general-geometry-property-functions.html
+    'BOUNDARY',                 // Boundary() general-geometry-property-functions.html
+    'BUFFER',                   // Buffer()
     'CAST',
     'CEIL',
     'CEILING',
-    'CENTROID',                 // multipolygon-property-functions.html
+    'CENTROID',                 // Centroid() multipolygon-property-functions.html
     'CHAR',                     // string-functions.html
     'CHARACTER_LENGTH',
     'CHARSET',                  // information-functions.html
@@ -58,13 +65,16 @@ $PMA_SQPdata_function_name = array (
     'CONCAT',
     'CONCAT_WS',
     'CONNECTION_ID',
+    'CONTAINS',                 // Contains()
     'CONV',
     'CONVERT',
     'CONVERT_TZ',
+    'CONVEXHULL',               // ConvexHull()
     'COS',
     'COT',
     'COUNT',
     'CRC32',                    // mathematical-functions.html
+    'CROSSES',                  // Crosses()
     'CURDATE',
     'CURRENT_DATE',
     'CURRENT_TIME',
@@ -88,16 +98,21 @@ $PMA_SQPdata_function_name = array (
     'DEGREES',
     'DES_DECRYPT',
     'DES_ENCRYPT',
-    'DIMENSION',                // general-geometry-property-functions.html
+    'DIFFERENCE',               // Difference()
+    'DIMENSION',                // Dimension() general-geometry-property-functions.html
+    'DISJOINT',                 // Disjoint()
+    'DISTANCE',                 // Distance()
     'ELT',
     'ENCODE',
     'ENCRYPT',
-    'ENDPOINT',                 // linestring-property-functions.html
-    'ENVELOPE',                 // general-geometry-property-functions.html
+    'ENDPOINT',                 // EndPoint() linestring-property-functions.html
+    'ENVELOPE',                 // Envelope() general-geometry-property-functions.html
+    'EQUALS',                   // Equals()
     'EXP',
     'EXPORT_SET',
-    'EXTERIORRING',             // polygon-property-functions.html
+    'EXTERIORRING',             // ExteriorRing() polygon-property-functions.html
     'EXTRACT',
+    'EXTRACTVALUE',             // ExtractValue() xml-functions.html
     'FIELD',
     'FIND_IN_SET',
     'FLOOR',
@@ -105,11 +120,20 @@ $PMA_SQPdata_function_name = array (
     'FOUND_ROWS',
     'FROM_DAYS',
     'FROM_UNIXTIME',
-    'GEOMETRYN',                // geometrycollection-property-functions.html
-    'GEOMETRYTYPE',             // general-geometry-property-functions.html
+    'GEOMCOLLFROMTEXT',         // GeomCollFromText()
+    'GEOMCOLLFROMWKB',          // GeomCollFromWKB()
+    'GEOMETRYCOLLECTION',       // GeometryCollection()
+    'GEOMETRYCOLLECTIONFROMTEXT',   // GeometryCollectionFromText()
+    'GEOMETRYCOLLECTIONFROMWKB',    // GeometryCollectionFromWKB()
+    'GEOMETRYFROMTEXT',         // GeometryFromText()
+    'GEOMETRYFROMWKB',          // GeometryFromWKB()
+    'GEOMETRYN',                // GeometryN() geometrycollection-property-functions.html
+    'GEOMETRYTYPE',             // GeometryType() general-geometry-property-functions.html
+    'GEOMFROMTEXT',             // GeomFromText()
+    'GEOMFROMWKB',              // GeomFromWKB()
     'GET_FORMAT',
     'GET_LOCK',
-    'GLENGTH',                  // linestring-property-functions.html
+    'GLENGTH',                  // GLength() linestring-property-functions.html
     'GREATEST',
     'GROUP_CONCAT',
     'GROUP_UNIQUE_USERS',
@@ -121,13 +145,15 @@ $PMA_SQPdata_function_name = array (
     'INET_NTOA',
     'INSERT',                   // string-functions.html
     'INSTR',
-    'INTERIORRINGN',            // polygon-property-functions.html
+    'INTERIORRINGN',            // InteriorRingN() polygon-property-functions.html
+    'INTERSECTION',             // Intersection()
+    'INTERSECTS',               // Intersects()
     'INTERVAL',
-    'ISCLOSED',                 // multilinestring-property-functions.html
-    'ISEMPTY',                  // general-geometry-property-functions.html
+    'ISCLOSED',                 // IsClosed() multilinestring-property-functions.html
+    'ISEMPTY',                  // IsEmpty() general-geometry-property-functions.html
     'ISNULL',
-    'ISRING',                   // linestring-property-functions.html
-    'ISSIMPLE',                 // general-geometry-property-functions.html
+    'ISRING',                   // IsRing() linestring-property-functions.html
+    'ISSIMPLE',                 // IsSimple() general-geometry-property-functions.html
     'IS_FREE_LOCK',
     'IS_USED_LOCK',             // miscellaneous-functions.html
     'LAST_DAY',
@@ -136,6 +162,11 @@ $PMA_SQPdata_function_name = array (
     'LEAST',
     'LEFT',
     'LENGTH',
+    'LINEFROMTEXT',             // LineFromText()
+    'LINEFROMWKB',              // LineFromWKB()
+    'LINESTRING',               // LineString()
+    'LINESTRINGFROMTEXT',       // LineStringFromText()
+    'LINESTRINGFROMWKB',        // LineStringFromWKB()
     'LN',
     'LOAD_FILE',
     'LOCALTIME',
@@ -152,29 +183,62 @@ $PMA_SQPdata_function_name = array (
     'MAKE_SET',
     'MASTER_POS_WAIT',
     'MAX',
+    'MBRCONTAINS',              // MBRContains()
+    'MBRDISJOINT',              // MBRDisjoint()
+    'MBREQUAL',                 // MBREqual()
+    'MBRINTERSECTS',            // MBRIntersects()
+    'MBROVERLAPS',              // MBROverlaps()
+    'MBRTOUCHES',               // MBRTouches()
+    'MBRWITHIN',                // MBRWithin()
     'MD5',
     'MICROSECOND',
     'MID',
     'MIN',
     'MINUTE',
+    'MLINEFROMTEXT',            // MLineFromText()
+    'MLINEFROMWKB',             // MLineFromWKB()
     'MOD',
     'MONTH',
     'MONTHNAME',
     'NOW',
+    'MPOINTFROMTEXT',           // MPointFromText()
+    'MPOINTFROMWKB',            // MPointFromWKB()
+    'MPOLYFROMTEXT',            // MPolyFromText()
+    'MPOLYFROMWKB',             // MPolyFromWKB()
+    'MULTILINESTRING',          // MultiLineString()
+    'MULTILINESTRINGFROMTEXT',  // MultiLineStringFromText()
+    'MULTILINESTRINGFROMWKB',   // MultiLineStringFromWKB()
+    'MULTIPOINT',               // MultiPoint()
+    'MULTIPOINTFROMTEXT',       // MultiPointFromText()
+    'MULTIPOINTFROMWKB',        // MultiPointFromWKB()
+    'MULTIPOLYGON',             // MultiPolygon()
+    'MULTIPOLYGONFROMTEXT',     // MultiPolygonFromText()
+    'MULTIPOLYGONFROMWKB',      // MultiPolygonFromWKB()
+    'NAME_CONST',               // NAME_CONST()
+    'NOW',                      // NOW()
     'NULLIF',
-    'NUMGEOMETRIES',            // geometrycollection-property-functions.html
-    'NUMINTERIORRINGS',         // polygon-property-functions.html
-    'NUMPOINTS',                // linestring-property-functions.html
+    'NUMGEOMETRIES',            // NumGeometries() geometrycollection-property-functions.html
+    'NUMINTERIORRINGS',         // NumInteriorRings() polygon-property-functions.html
+    'NUMPOINTS',                // NumPoints() linestring-property-functions.html
     'OCT',
     'OCTET_LENGTH',
     'OLD_PASSWORD',
     'ORD',
+    'OVERLAPS',                 // Overlaps()
     'PASSWORD',
     'PERIOD_ADD',
     'PERIOD_DIFF',
     'PI',
-    'POINTN',                   // linestring-property-functions.html
-    'POINTONSURFACE',           // multipolygon-property-functions.html
+    'POINT',                    // Point()
+    'POINTFROMTEXT',            // PointFromText()
+    'POINTFROMWKB',             // PointFromWKB()
+    'POINTN',                   // PointN() inestring-property-functions.html
+    'POINTONSURFACE',           // PointOnSurface() multipolygon-property-functions.html
+    'POLYFROMTEXT',             // PolyFromText()
+    'POLYFROMWKB',              // PolyFromWKB()
+    'POLYGON',                  // Polygon()
+    'POLYGONFROMTEXT',          // PolygonFromText()
+    'POLYGONFROMWKB',           // PolygonFromWKB()
     'POSITION',
     'POW',
     'POWER',
@@ -182,6 +246,7 @@ $PMA_SQPdata_function_name = array (
     'QUOTE',
     'RADIANS',
     'RAND',
+    'RELATED',                  // Related()
     'RELEASE_LOCK',
     'REPEAT',
     'REPLACE',                  // string-functions.html
@@ -204,7 +269,7 @@ $PMA_SQPdata_function_name = array (
     'SPACE',
     'SQRT',
     'SRID',                     // general-geometry-property-functions.html
-    'STARTPOINT',               // linestring-property-functions.html
+    'STARTPOINT',               // StartPoint() linestring-property-functions.html
     'STD',
     'STDDEV',
     'STDDEV_POP',               // group-by-functions.html
@@ -212,10 +277,12 @@ $PMA_SQPdata_function_name = array (
     'STRCMP',
     'STR_TO_DATE',
     'SUBDATE',
+    'SUBSTR',
     'SUBSTRING',
     'SUBSTRING_INDEX',
     'SUBTIME',
     'SUM',
+    'SYMDIFFERENCE',            // SymDifference()
     'SYSDATE',
     'SYSTEM_USER',
     'TAN',
@@ -226,6 +293,7 @@ $PMA_SQPdata_function_name = array (
     'TIMESTAMPDIFF',
     'TIME_FORMAT',
     'TIME_TO_SEC',
+    'TOUCHES',                  // Touches()
     'TO_DAYS',
     'TRIM',
     'TRUNCATE',                 // mathematical-functions.html
@@ -235,6 +303,7 @@ $PMA_SQPdata_function_name = array (
     'UNHEX',                    // string-functions.html
     'UNIQUE_USERS',
     'UNIX_TIMESTAMP',
+    'UPDATEXML',                // UpdateXML() xml-functions.html
     'UPPER',
     'USER',
     'UTC_DATE',
@@ -248,13 +317,14 @@ $PMA_SQPdata_function_name = array (
     'WEEK',
     'WEEKDAY',
     'WEEKOFYEAR',
+    'WITHIN',                   // Within()
     'X',                        // point-property-functions.html
     'Y',                        // point-property-functions.html
     'YEAR',
     'YEARWEEK'
 );
 //$PMA_SQPdata_function_name_cnt = count($PMA_SQPdata_function_name);
-$PMA_SQPdata_function_name_cnt = 229;
+$PMA_SQPdata_function_name_cnt = 299;
 // DEBUG
 //$test_PMA_SQPdata_function_name = $PMA_SQPdata_function_name;
 //sort($PMA_SQPdata_function_name);
@@ -300,6 +370,7 @@ $PMA_SQPdata_column_attrib = array (
 $PMA_SQPdata_column_attrib_cnt = 29;
 
 $PMA_SQPdata_reserved_word = array (
+    'ACCESSIBLE',       // 5.1
     'ACTION',
     'ADD',
     'AFTER',
@@ -329,7 +400,6 @@ $PMA_SQPdata_reserved_word = array (
     'CHARSET',
     'CHECK',
     'CHECKSUM',
-    'CLIENT',
     'COLLATE',
     'COLLATION',
     'COLUMN',
@@ -363,6 +433,7 @@ $PMA_SQPdata_reserved_word = array (
     'DO',
     'DROP',
     'DUMPFILE',
+    'DUPLICATE',
     'DYNAMIC',
     'ELSE',
     'ENCLOSED',
@@ -427,6 +498,7 @@ $PMA_SQPdata_reserved_word = array (
     'LEVEL',
     'LIKE',
     'LIMIT',
+    'LINEAR',               // 5.1
     'LINES',
     'LOAD',
     'LOCAL',
@@ -488,7 +560,10 @@ $PMA_SQPdata_reserved_word = array (
     'RAID_CHUNKS',
     'RAID_CHUNKSIZE',
     'RAID_TYPE',
+    'RANGE',                // 5.1
     'READ',
+    'READ_ONLY',            // 5.1
+    'READ_WRITE',           // 5.1
     'REFERENCES',
     'REGEXP',
     'RELOAD',
@@ -578,11 +653,12 @@ $PMA_SQPdata_reserved_word = array (
     'YEAR_MONTH'
 );
 //$PMA_SQPdata_reserved_word_cnt = count($PMA_SQPdata_reserved_word);
-$PMA_SQPdata_reserved_word_cnt = 274;
+$PMA_SQPdata_reserved_word_cnt = 279;
 
 // words forbidden to be used as column or table name,
 // as seen in http://dev.mysql.com/doc/mysql/en/reserved-words.html
 $PMA_SQPdata_forbidden_word = array (
+    'ACCESSIBLE',       // 5.1
     'ACTION',
     'ADD',
     'AFTER',
@@ -632,7 +708,6 @@ $PMA_SQPdata_forbidden_word = array (
     'CHECK',
     'CHECKSUM',
     'CIPHER',
-    'CLIENT',
     'CLOSE',
     'COLLATE',
     'COLLATION',
@@ -796,6 +871,7 @@ $PMA_SQPdata_forbidden_word = array (
     'LEVEL',
     'LIKE',
     'LIMIT',
+    'LINEAR',               // 5.1
     'LINES',
     'LINESTRING',
     'LOAD',
@@ -903,7 +979,10 @@ $PMA_SQPdata_forbidden_word = array (
     'RAID_CHUNKS',
     'RAID_CHUNKSIZE',
     'RAID_TYPE',
+    'RANGE',                // 5.1
     'READ',
+    'READ_ONLY',            // 5.1
+    'READ_WRITE',           // 5.1
     'READS',
     'REAL',
     'RECOVER',
@@ -1064,7 +1143,7 @@ $PMA_SQPdata_forbidden_word = array (
     'ZEROFILL'
 );
 // echo count($PMA_SQPdata_forbidden_word);
-$PMA_SQPdata_forbidden_word_cnt = 479;
+$PMA_SQPdata_forbidden_word_cnt = 483;
 
 $PMA_SQPdata_column_type = array (
     'BIGINT',
@@ -1084,6 +1163,8 @@ $PMA_SQPdata_column_type = array (
     'FLOAT',
     'FLOAT4',
     'FLOAT8',
+    'GEOMETRY',             // spatial
+    'GEOMETRYCOLLECTION',   // spatial
     'INT',
     'INT1',
     'INT2',
@@ -1091,6 +1172,7 @@ $PMA_SQPdata_column_type = array (
     'INT4',
     'INT8',
     'INTEGER',
+    'LINESTRING',           // spatial
     'LONG',
     'LONGBLOB',
     'LONGTEXT',
@@ -1098,10 +1180,15 @@ $PMA_SQPdata_column_type = array (
     'MEDIUMINT',
     'MEDIUMTEXT',
     'MIDDLEINT',
+    'MULTILINESTRING',      // spatial
+    'MULTIPOINT',           // spatial
+    'MULTIPOLYGON',         // spatial
     'NCHAR',
     'NUMERIC',
+    'POINT',                // spatial
+    'POLYGON',              // spatial
     'REAL',
-    'SERIAL',           //BIGINT UNSIGNED NOT NULL AUTO_INCREMENT UNIQUE
+    'SERIAL',               // alsias for BIGINT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY
     'SET',
     'SMALLINT',
     'TEXT',
@@ -1115,7 +1202,7 @@ $PMA_SQPdata_column_type = array (
     'YEAR'
 );
 //$PMA_SQPdata_column_type_cnt = count($PMA_SQPdata_column_type);
-$PMA_SQPdata_column_type_cnt = 46;
+$PMA_SQPdata_column_type_cnt = 54;
 
 // check counts
 /*
