@@ -1,5 +1,5 @@
 <?php
-/* $Id: querywindow.php,v 2.37 2006/07/03 15:01:44 cybot_tm Exp $ */
+/* $Id: querywindow.php 10144 2007-03-20 11:22:31Z cybot_tm $ */
 // vim: expandtab sw=4 ts=4 sts=4:
 
 require_once('./libraries/common.lib.php');
@@ -35,17 +35,6 @@ $cfgRelation = PMA_getRelationsParam();
 $_sql_history = array();
 $_input_query_history = array();
 
-/**
- * Get the list and number of available databases.
- * Skipped if no server selected: in this case no database should be displayed
- * before the user choose among available ones at the welcome screen.
- */
-if ($server > 0) {
-    PMA_availableDatabases(); // this function is defined in "common.lib.php"
-} else {
-    $num_dbs = 0;
-}
-
 // garvin: For re-usability, moved http-headers and stylesheets
 // to a seperate file. It can now be included by libraries/header.inc.php,
 // querywindow.php.
@@ -183,11 +172,11 @@ if ( ! empty( $query_history_latest ) && ! empty( $query_history_latest_db ) ) {
         'table' => isset($query_history_latest_table) ? $query_history_latest_table : '',
     );
 
-    $sql_query = urldecode($query_history_latest);
+    $sql_query = $query_history_latest;
     $db = $query_history_latest_db;
     $table = $query_history_latest_table;
 } elseif ( ! empty( $query_history_latest ) ) {
-    $sql_query = urldecode($query_history_latest);
+    $sql_query = $query_history_latest;
 }
 
 if (isset($sql_query)) {
@@ -238,9 +227,9 @@ if (isset($no_js) && $no_js) {
     // ... we redirect to appropriate query sql page
     // works only full if $db and $table is also stored/grabbed from $_COOKIE
     if ( isset( $table ) && strlen($table) ) {
-        require './tbl_properties.php';
+        require './tbl_sql.php';
     } elseif ( isset($db) && strlen($db) ) {
-        require './db_details.php';
+        require './db_sql.php';
     } else {
         require './server_sql.php';
     }
@@ -283,8 +272,8 @@ if ( count( $_sql_history ) > 0
                .'querydisplay_tab.value = \'' . $tab . '\';'
                .' document.getElementById(\'hiddenqueryform\').'
                .'query_history_latest.value = \''
-                . preg_replace('/(\r|\n)+/i', '\\n',
-                    htmlentities( $sql, ENT_QUOTES ) ) . '\';'
+               . preg_replace('/(\r|\n)+/i', '\\n',
+                    PMA_jsFormat($sql, false) ) . '\';'
                .' document.getElementById(\'hiddenqueryform\').'
                .'auto_commit.value = \'false\';'
                .' document.getElementById(\'hiddenqueryform\').'
@@ -305,8 +294,8 @@ if ( count( $_sql_history ) > 0
                .'querydisplay_tab.value = \'' . $tab . '\';'
                .' document.getElementById(\'hiddenqueryform\').'
                .'query_history_latest.value = \''
-                . preg_replace('/(\r|\n)+/i', '\\r\\n',
-                    htmlentities( $sql, ENT_QUOTES ) ) . '\';'
+               . preg_replace('/(\r|\n)+/i', '\\r\\n',
+                    PMA_jsFormat($sql, false) ) . '\';'
                .' document.getElementById(\'hiddenqueryform\').'
                .'auto_commit.value = \'true\';'
                .' document.getElementById(\'hiddenqueryform\').'
@@ -321,7 +310,7 @@ if ( count( $_sql_history ) > 0
                . htmlspecialchars( $query['table'] ) . '\';'
                .' document.getElementById(\'hiddenqueryform\').submit();'
                .' return false;">[' . htmlspecialchars( $query['db'] ) . '] '
-               . urldecode( $sql ) . '</a>' . "\n";
+               . htmlspecialchars($sql) . '</a>' . "\n";
 
         echo '</li>' . "\n";
     }
