@@ -99,7 +99,6 @@ form {
 
 textarea {
     overflow:           visible;
-    height:             8em;
 }
 
 fieldset {
@@ -195,13 +194,16 @@ table tr.even {
     text-align:         <?php echo $left; ?>;
 }
 
-/* marked tbale rows */
+<?php if ($GLOBALS['cfg']['BrowseMarkerEnable']) { ?>
+/* marked table rows */
 table tr.marked th,
 table tr.marked {
     background:   <?php echo $GLOBALS['cfg']['BrowseMarkerBackground']; ?>;
     color:   <?php echo $GLOBALS['cfg']['BrowseMarkerColor']; ?>;
 }
+<?php } ?>
 
+<?php if ($GLOBALS['cfg']['BrowsePointerEnable']) { ?>
 /* hovered items */
 .odd:hover,
 .even:hover,
@@ -217,6 +219,7 @@ table tr.hover th {
     background:   <?php echo $GLOBALS['cfg']['BrowsePointerBackground']; ?>;
     color:   <?php echo $GLOBALS['cfg']['BrowsePointerColor']; ?>;
 }
+<?php } ?>
 
 /**
  * marks table rows/cells if the db field is in a where condition
@@ -648,6 +651,7 @@ a.tab:hover,
 
 /* disabled drop/empty tabs */
 span.tab,
+a.warning,
 span.tabcaution {
     cursor:             url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>error.ico), default;
 }
@@ -1142,4 +1146,4 @@ li#li_flush_privileges {
 label.desc {
     width: 30em;
     float: <?php echo $left; ?>;
-}
\ No newline at end of file
+}
