@@ -29,7 +29,6 @@ $GLOBALS['cfg']['MainColor']                = '#000000';
 
 // background for the main frame
 $GLOBALS['cfg']['MainBackground']           = '#F5F5F5';
-// for a solid vertical line, uncomment this:
 //$GLOBALS['cfg']['MainBackground']       = '#F5F5F5 url(../' . $_SESSION['PMA_Theme']->getImgPath() . 'vertical_line.png) repeat-y';
 
 // foreground (text) color of the pointer in browse mode
@@ -52,7 +51,7 @@ $GLOBALS['cfg']['BrowseMarkerBackground']   = '#FFCC99';
  * if not set the browser default will be used
  * (depending on browser, DTD and system settings)
  */
-$GLOBALS['cfg']['FontFamily']           = '';
+$GLOBALS['cfg']['FontFamily']           = 'sans-serif';
 /**
  * fixed width font family, used in textarea
  */
